<?php
class Admin_Model_CampaignDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Admin_Model_DbTable_Campaign');
		}
		return $this->_dbTable;
	}

	public function AddCampaign(Admin_Model_Campaign $campaign)
	{
		try{
			$priceMapper = new Admin_Model_PricePlanDataMapper();
			$priceTable = $priceMapper->getDbTable();
			$priceData = array(
							'sppplan_name'			=>	$campaign->getPlanName(),
							'sppplan_type'			=>	$campaign->getPlanType(),	
							'sppintended_audience'	=>	$campaign->getAudience(),
							'sppamount'				=>	$campaign->getAmount(),
							'sppstate_id'			=>	$campaign->getState(),
							'sppregion_id'			=>	$campaign->getRegion(),
							'sppcity_id'			=>	$campaign->getCity(),
							'sppstart_date'			=>	$campaign->getStartDate(),
							'sppend_date'			=>	$campaign->getEndDate(),
							'spptime_selection'		=>	$campaign->getCampTime(),
							'sppcreated_on'			=>	date('Y-m-d H:i:s'),
							'sppstatus'				=>	1,
							'sppdelete_status'		=>	0,
							'sppdashboard'			=>	$campaign->getDashboardStatus()
			);
			$priceId = $priceTable->insert($priceData);
			
			if($campaign->getPlanType() == 'AUTO' || $campaign->getPlanType() == 'MANU'){
				$mapper = new Admin_Model_SponsorCampaignEmailDataMapper();
				$table = $mapper->getDbTable();
				$Emaildata = array(
									'scetotal_email_count'	=>	$campaign->getNoOfEmails(),
									'sceemail_count'		=>	$campaign->getNoOfEmails(),
									'scefk_price_plan'		=>	$priceId
				);
				$emailResult = $table->insert($Emaildata);
			}
			
			$data = array(
							'scad_name'			=>	$campaign->getCampName(),
							'scimage'			=>	$campaign->getCampImage(),
							'scweb_link'		=>	$campaign->getLink(),
							'scprice_plan'		=>	$priceId,
							'scsponsor_id'		=>	$campaign->getSponsor(),
							'scdesc'			=>	$campaign->getCampDesc(),
							'scstatus'			=>	1,
							'scdelete_status'	=>	0
							
			);
			$result = $this->getDbTable()->insert($data);
			if($result)
			{
				$mapper = new Admin_Model_SponsorCampaignEmailPostingDataMapper();
				$emailtable = $mapper->getDbTable();
				$Email = array(
									'sep_email_count'		=>	$campaign->getNoOfEmails(),
									'sep_remaining_count'	=>	0,
									'sep_campaign_id'		=>	$result,
				);
				$emailResult = $emailtable->insert($Email);
			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditCampaign(Admin_Model_Campaign $campaign)
	{
		try{
			$priceresult = '';
			$result = '';
			$db = Zend_Db_Table::getDefaultAdapter();
			if($campaign->getFormType() == 'campImage'){
				$set = array(
							'scdesc'			=>	$campaign->getCampDesc()
						);
				if($campaign->getCampImage()){
					$set['scimage']	= $campaign->getCampImage();
				}
				if($campaign->getLink()){
					$set['scweb_link']	= $campaign->getLink();
				}
				$where = $db->quoteInto('scid = ?',$campaign->getId());
				$result = $this->getDbTable()->update($set,$where);
			}else if($campaign->getFormType() == 'campPlan'){
				$priceSet = array(
									'sppamount'				=>	$campaign->getAmount(),
									'sppstart_date'			=>	$campaign->getStartDate(),
									'sppend_date'			=>	$campaign->getEndDate(),
									'spptime_selection'		=>	$campaign->getCampTime(),
							);
				$mapper = new Admin_Model_PricePlanDataMapper();
				$table = $mapper->getDbTable();
				
				$priceWhere = $db->quoteInto('sppid = ?',$campaign->getPriceId());
				$priceresult = $table->update($priceSet,$priceWhere);
			}else if($campaign->getFormType() == 'campLocation'){
				$priceSet = array(
									'sppstate_id'			=>	$campaign->getState(),
			           		        'sppregion_id'			=>	$campaign->getRegion(),
									'sppcity_id'			=>	$campaign->getCity()							
							);
				$mapper = new Admin_Model_PricePlanDataMapper();
				$table = $mapper->getDbTable();
				
				$priceWhere = $db->quoteInto('sppid = ?',$campaign->getPriceId());
				$priceresult = $table->update($priceSet,$priceWhere);
			}	
			if($result){
				return $result;
			}else if($priceresult){
				return $priceresult;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetCampaignDetailsById($campId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('camp'=>'mt.sponsor_campaign'),array('scid','scad_name','scdesc','scweb_link','scweb_link_count','scimage'))
				   ->join(array('spo'=>'mt.sponsor'),'camp.scsponsor_id = spo.spoid',array('spocompany_name','spocontact_person','spobilling_address','spophone_no','spoemail'))
				   ->join(array('spp'=>'mt.sponsor_price_plan'),'camp.scprice_plan = spp.sppid',array('sppid','sppplan_name','sppamount','sppintended_audience','sppplan_type','sppstate_id','sppregion_id','sppcity_id','sppstart_date','sppend_date','spptime_selection','sppdashboard'))
				   ->join(array('aud'=>'mt.intended_audience_bd'),'aud.code = spp.sppintended_audience',array('description as Audience'))
				   ->join(array('tim'=>'mt.sponsor_time_selection_bd'),'tim.code = spp.spptime_selection',array('code as timecode','description as TimeRange'))
				   ->join(array('note'=>'mt.sponsor_target_pages_bd'),'note.code = spp.sppplan_type',array('description as PlanType'))
				   ->joinLeft(array('sta'=>'mt.state_bd'),'spp.sppstate_id = sta.id',array('description as State'))
				   ->joinLeft(array('rgn'=>'mt.region_bd'),'spp.sppregion_id = rgn.id',array('description as Region'))
				   ->joinLeft(array('cit'=>'mt.city_bd'),'spp.sppcity_id = cit.id',array('description as City'))
				   ->where('camp.scid = ?',$campId);
//				   ->where('spo.spostatus = true')
//				   ->where('spo.spodelete_status = false')
//				   ->where('spp.sppstatus = true')
//				   ->where('spp.sppdelete_status = false');
			$result = $table->fetchRow($select);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetCampaignDetailsForPost(Application_Model_GetCampaignForPost $camp)
	{
		try{
			$date = date('Y-m-d');
			$time = date('H:i:s');
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('camp'=>'mt.sponsor_campaign'),array('scid','scad_name','scdesc','scimage','scweb_link'))
				   ->join(array('spo'=>'mt.sponsor'),'camp.scsponsor_id = spo.spoid',array('spocompany_name','spocontact_person','spobilling_address','spophone_no','spoemail'))
				   ->join(array('spp'=>'mt.sponsor_price_plan'),'camp.scprice_plan = spp.sppid',array('sppplan_name','sppamount','spptime_selection'))
				   ->join(array('aud'=>'mt.intended_audience_bd'),'aud.code = spp.sppintended_audience',array('description as Audience'))
				   ->join(array('note'=>'mt.sponsor_target_pages_bd'),'note.code = spp.sppplan_type',array('description as PlanType'))
				   ->joinLeft(array('sce'=>'mt.sponsor_campaign_email'),'sce.scefk_price_plan = spp.sppid',array('scetotal_email_count'));
				   
		    if($camp->getCampId() > 0){
		   		$select->where('camp.scid = ?',$camp->getCampId());	
		    }
		    if(!$camp->getIsAjaxCall()  && $camp->getStateId()){
		   		$select->where('spp.sppstate_id = ?',$camp->getStateId());
		    }
		    if($camp->getRegionId()){
		    	$select->where('spp.sppregion_id = ?',$camp->getRegionId());
		    }
			if($camp->getCityId()){
		    	$select->where('spp.sppcity_id = ?',$camp->getCityId());
		    }
			if(!$camp->getIsAjaxCall()){
				$select->where('spp.sppplan_type = ?','AUTO');
			}
			$select->where('spp.sppstart_date <= ?',$date)
				   ->where('spp.sppend_date >= ?',$date)
				   ->where('spp.sppintended_audience = ?',$camp->getAudType())
	//			   ->where('sce.sceemail_count >= ?',1)
					->where('camp.scstatus = true')
				   ->where('camp.scdelete_status = false')
				   ->where('spo.spostatus = true')
				   ->where('spo.spodelete_status = false')
				   ->where('spp.sppstatus = true')
				   ->where('spp.sppdelete_status =false');
			
			$result = $table->fetchAll($select);
			
			if($camp->getIsAjaxCall()){
				$campDetails[] = array("key"=>"","value"=>"Select Campaign");
				foreach($result as $row){
					$campDetails[] = array("key"=>$row->scid,"value"=>$row->scad_name);
				}
				return $campDetails;
			}else{
				$campaignDetails = array();
				$status = false;
				foreach($result as $row){
					$status = true;
					$timesArr = explode('-',trim($row->spptime_selection));
					$startTimeArr = explode(':',date("H:i:s",strtotime($timesArr[0])));
					$endTimeArr = explode(':',date("H:i:s",strtotime($timesArr[1])));
					$nowTimeArr = explode(':',$time);
					$dateArr = explode('-',$date);
					$startTime = mktime($startTimeArr[0],$startTimeArr[1],$startTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
					$endTime = mktime($endTimeArr[0],$endTimeArr[1],$endTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
					$nowTime = mktime($nowTimeArr[0],$nowTimeArr[1],$nowTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
					if($startTime <= $nowTime && $endTime >= $nowTime){
						$campDetails = new Admin_Model_Campaign();
						$campDetails->setId($row->scid)
									->setCampName($row->scad_name)
									->setCampDesc($row->scdesc)
									->setSponsor($row->spocompany_name)
									->setLink($row->scweb_link)
									->setCampImage($row->scimage);
						$campaignDetails[] = $campDetails;
					}			
				}
				if($status){
					return $campaignDetails;
				}else{
					$Campselect = $table->select();
					$Campselect->setIntegrityCheck(false);
					$Campselect->from(array('camp'=>'mt.sponsor_campaign'),array('scid','scad_name','scdesc','scimage','scweb_link'))
						   ->join(array('spo'=>'mt.sponsor'),'camp.scsponsor_id = spo.spoid',array('spocompany_name','spocontact_person','spobilling_address','spophone_no','spoemail'))
						   ->join(array('spp'=>'mt.sponsor_price_plan'),'camp.scprice_plan = spp.sppid',array('sppplan_name','sppamount','spptime_selection'))
						   ->join(array('aud'=>'mt.intended_audience_bd'),'aud.code = spp.sppintended_audience',array('description as Audience'))
						   ->join(array('note'=>'mt.sponsor_target_pages_bd'),'note.code = spp.sppplan_type',array('description as PlanType'))
						   ->joinLeft(array('sce'=>'mt.sponsor_campaign_email'),'sce.scefk_price_plan = spp.sppid',array('scetotal_email_count'));
						   
				    if(!$camp->getIsAjaxCall()){
						$Campselect->where('spp.sppplan_type = ?','AUTO');
					}
					$Campselect->where('spp.sppstart_date <= ?',$date)
						   ->where('spp.sppend_date >= ?',$date)
						   ->where('spp.sppintended_audience = ?',$camp->getAudType())
			//			   ->where('sce.sceemail_count >= ?',1)
							->where('camp.scstatus = true')
						   ->where('camp.scdelete_status = false')
						   ->where('spo.spostatus = true')
						   ->where('spo.spodelete_status = false')
						   ->where('spp.sppstatus = true')
						   ->where('spp.sppdelete_status =false');
					
					$resultSet = $table->fetchAll($Campselect);
					foreach($resultSet as $row){
						$status = true;
						$timesArr = explode('-',trim($row->spptime_selection));
						$startTimeArr = explode(':',date("H:i:s",strtotime($timesArr[0])));
						$endTimeArr = explode(':',date("H:i:s",strtotime($timesArr[1])));
						$nowTimeArr = explode(':',$time);
						$dateArr = explode('-',$date);
						$startTime = mktime($startTimeArr[0],$startTimeArr[1],$startTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
						$endTime = mktime($endTimeArr[0],$endTimeArr[1],$endTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
						$nowTime = mktime($nowTimeArr[0],$nowTimeArr[1],$nowTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
						if($startTime <= $nowTime && $endTime >= $nowTime){
							$campDetails = new Admin_Model_Campaign();
							$campDetails->setId($row->scid)
										->setCampName($row->scad_name)
										->setCampDesc($row->scdesc)
										->setSponsor($row->spocompany_name)
										->setLink($row->scweb_link)
										->setCampImage($row->scimage);
							$campaignDetails[] = $campDetails;
						}			
					}
					return $campaignDetails;
				}
				
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetCampaignDetailsForPostLogin(Application_Model_GetCampaignForPost $camp)
	{
		try{
			$date = date('Y-m-d');
			$time = date('H:i:s');
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('camp'=>'mt.sponsor_campaign'),array('scid','scad_name','scdesc','scimage'))
				   ->join(array('spo'=>'mt.sponsor'),'camp.scsponsor_id = spo.spoid',array('spocompany_name','spocontact_person','spobilling_address','spophone_no','spoemail'))
				   ->join(array('spp'=>'mt.sponsor_price_plan'),'camp.scprice_plan = spp.sppid',array('sppplan_name','sppamount','spptime_selection'))
				   ->join(array('aud'=>'mt.intended_audience_bd'),'aud.code = spp.sppintended_audience',array('description as Audience'))
				   ->join(array('note'=>'mt.sponsor_target_pages_bd'),'note.code = spp.sppplan_type',array('description as PlanType'))
				   ->joinLeft(array('sce'=>'mt.sponsor_campaign_email'),'sce.scefk_price_plan = spp.sppid',array('scetotal_email_count'));
				   
		    if($camp->getCampId() > 0){
		   		$select->where('camp.scid = ?',$camp->getCampId());	
		    }
		    if(!$camp->getIsAjaxCall()  && $camp->getStateId()){
		   		$select->where('spp.sppstate_id = ?',$camp->getStateId());
		    }
		    if($camp->getRegionId()){
		    	$select->where('spp.sppregion_id = ?',$camp->getRegionId());
		    }
			if($camp->getCityId()){
		    	$select->where('spp.sppcity_id = ?',$camp->getCityId());
		    }
			$select->where('spp.sppstart_date <= ?',$date)
				   ->where('spp.sppend_date >= ?',$date)
				   ->where('spp.sppdashboard = true')
				   ->where('spp.sppintended_audience = ?',$camp->getAudType())
	//			   ->where('sce.sceemail_count >= ?',1)
					->where('camp.scstatus = true')
				   ->where('camp.scdelete_status = false')
				   ->where('spo.spostatus = true')
				   ->where('spo.spodelete_status = false')
				   ->where('spp.sppstatus = true')
				   ->where('spp.sppdelete_status =false');
			
			$result = $table->fetchAll($select);
			
			if($camp->getIsAjaxCall()){
				$campDetails[] = array("key"=>"","value"=>"Select Campaign");
				foreach($result as $row){
					$campDetails[] = array("key"=>$row->scid,"value"=>$row->scad_name);
				}
				return $campDetails;
			}else{
				$campaignDetails = array();
				$status = false;
				foreach($result as $row){
					$status = true;
					$timesArr = explode('-',trim($row->spptime_selection));
					$startTimeArr = explode(':',date("H:i:s",strtotime($timesArr[0])));
					$endTimeArr = explode(':',date("H:i:s",strtotime($timesArr[1])));
					$nowTimeArr = explode(':',$time);
					$dateArr = explode('-',$date);
					$startTime = mktime($startTimeArr[0],$startTimeArr[1],$startTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
					$endTime = mktime($endTimeArr[0],$endTimeArr[1],$endTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
					$nowTime = mktime($nowTimeArr[0],$nowTimeArr[1],$nowTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
					if($startTime <= $nowTime && $endTime >= $nowTime){
						$campDetails = new Admin_Model_Campaign();
						$campDetails->setId($row->scid)
									->setCampName($row->scad_name)
									->setCampDesc($row->scdesc)
									->setSponsor($row->spocompany_name)
	//								->setLink($row->scweb_link)
									->setCampImage($row->scimage);
						$campaignDetails[] = $campDetails;
					}			
				}
				if($status){
					return $campaignDetails;
				}else{
					$Campselect = $table->select();
					$Campselect->setIntegrityCheck(false);
					$Campselect->from(array('camp'=>'mt.sponsor_campaign'),array('scid','scad_name','scdesc','scimage'))
						   ->join(array('spo'=>'mt.sponsor'),'camp.scsponsor_id = spo.spoid',array('spocompany_name','spocontact_person','spobilling_address','spophone_no','spoemail'))
						   ->join(array('spp'=>'mt.sponsor_price_plan'),'camp.scprice_plan = spp.sppid',array('sppplan_name','sppamount','spptime_selection'))
						   ->join(array('aud'=>'mt.intended_audience_bd'),'aud.code = spp.sppintended_audience',array('description as Audience'))
						   ->join(array('note'=>'mt.sponsor_target_pages_bd'),'note.code = spp.sppplan_type',array('description as PlanType'))
						   ->joinLeft(array('sce'=>'mt.sponsor_campaign_email'),'sce.scefk_price_plan = spp.sppid',array('scetotal_email_count'));
						   
				   
					$Campselect->where('spp.sppstart_date <= ?',$date)
						   ->where('spp.sppend_date >= ?',$date)
						   ->where('spp.sppintended_audience = ?',$camp->getAudType())
			//			   ->where('sce.sceemail_count >= ?',1)
							->where('camp.scstatus = true')
						   ->where('camp.scdelete_status = false')
						   ->where('spo.spostatus = true')
						   ->where('spo.spodelete_status = false')
						   ->where('spp.sppstatus = true')
						   ->where('spp.sppdelete_status =false');
					
					$resultSet = $table->fetchAll($Campselect);
					foreach($resultSet as $row){
						$status = true;
						$timesArr = explode('-',trim($row->spptime_selection));
						$startTimeArr = explode(':',date("H:i:s",strtotime($timesArr[0])));
						$endTimeArr = explode(':',date("H:i:s",strtotime($timesArr[1])));
						$nowTimeArr = explode(':',$time);
						$dateArr = explode('-',$date);
						$startTime = mktime($startTimeArr[0],$startTimeArr[1],$startTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
						$endTime = mktime($endTimeArr[0],$endTimeArr[1],$endTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
						$nowTime = mktime($nowTimeArr[0],$nowTimeArr[1],$nowTimeArr[2],$dateArr[1],$dateArr[2],$dateArr[0]);
						if($startTime <= $nowTime && $endTime >= $nowTime){
							$campDetails = new Admin_Model_Campaign();
							$campDetails->setId($row->scid)
										->setCampName($row->scad_name)
										->setCampDesc($row->scdesc)
										->setSponsor($row->spocompany_name)
		//								->setLink($row->scweb_link)
										->setCampImage($row->scimage);
							$campaignDetails[] = $campDetails;
						}			
					}
					return $campaignDetails;
				}
				
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetCampaignDetails()
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('scid','scad_name'))
				   ->where('scstatus = true')
				   ->where('scdelete_status = false')
				   ->order(array('scid'));
			$records = $table->fetchAll($select);
			return $records;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetCampaignDetailsBySponsorsId($sponsorid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('camp'=>'mt.sponsor_campaign'),array('scid','scad_name','scdesc','scstatus'))
				   ->join(array('spo'=>'mt.sponsor'),'spo.spoid = camp.scsponsor_id',array('spocompany_name','spostatus'))
				   ->join(array('spp'=>'mt.sponsor_price_plan'),'camp.scprice_plan = spp.sppid',array('sppplan_name','sppamount','sppintended_audience','sppplan_type','sppstate_id','sppregion_id','sppcity_id','sppstart_date','sppend_date'))
				   ->join(array('int'=>'mt.intended_audience_bd'),'int.code = spp.sppintended_audience',array('description as Audience'))
				   ->join(array('tim'=>'mt.sponsor_time_selection_bd'),'spp.spptime_selection = tim.code',array('description as Time'))
				   ->join(array('sep'=>'mt.sponsor_email_posting'),'sep.sep_campaign_id = camp.scid',array('(sep_remaining_count) as count'))
				   ->where('scsponsor_id = ?',$sponsorid)
				   ->where('spoid = ?',$sponsorid)
				   ->order('scid');
				  // ->where('scstatus = ?',true);
			$records = $table->fetchAll($select);
			return $records; 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditCampaignStatus($camid,$status)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array('scstatus'=>$status);
			$where = $db->quoteInto('scid = ?',$camid);
			$result = $this->getDbTable()->update($set,$where);
			return $result; 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	public function LinkCount($scid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('scweb_link_count','scweb_link'))
				   ->where('scid =?',$scid);
			$count = $table->fetchRow($select);
			if($count)
			{
				$Value = ($count->scweb_link_count) +1;
			}
			
			$campaign = new Admin_Model_Campaign;
			$data = array('scweb_link_count' =>$Value);
//			$where = $db->quoteInto('scid = ?',$scid);
			$updateCount = $this->getDbTable()->update($data,array('scid =?'=> $scid));
			return $count->scweb_link;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}