<?php
class Admin_Model_CompanyDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Admin_Model_DbTable_Company');
		}
		return $this->_dbTable;
	}
	
	public function addCompany(Admin_Model_Company $company)
	{
		try{
			$data= array(
				'com_companyname'		=> $company->getCompanyname(),
				'com_description'   	=> $company->getDescription(),
				'com_email'	 			=> $company->getEmail(),
				'com_phone'		 		=> $company->getPhone(),
				'com_address' 			=> $company->getAddress(),	
				'com_website'			=> $company->getWebsite(),
				'com_status'			=> $company->getStatus(),		
				'com_createdby'	 		=> $company->getCreatedby(),
				'com_createddatetime'	=> date('Y-m-d H:i:s'),
				'com_licensekey'		=> uniqid(),
				'com_logouturl'			=> $company->getLogoutUrl(),
				'com_countrycode'		=> $company->getCountrycode()									
			);	
				
			$user_id = $this->getDbTable()->insert($data);		
			return $user_id;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	public function UpdateCompany(Admin_Model_Company $company)
	{
		try{
			$set= array(
				'com_companyname'		=> $company->getCompanyname(),
				'com_description'   	=> $company->getDescription(),
				'com_email'	 			=> $company->getEmail(),
				'com_phone'		 		=> $company->getPhone(),
				'com_address' 			=> $company->getAddress(),
				'com_website'			=> $company->getWebsite(),	
				'com_updatedby'	 		=> $company->getCreatedby(),
				'com_updateddatetime'	=> date('Y-m-d H:i:s'),
				'com_logouturl'			=> $company->getLogoutUrl(),
				'com_countrycode'		=> $company->getCountrycode()							
			);	
			
			$where 	= array('com_id = ?' => $company->getId());
			
			$rows_affected = $this->getDbTable()->update($set,$where);				
			return $rows_affected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	public function getCompanys($offset)
	{
		try{
			$limit = 20;
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_id','com_companyname','com_email','com_phone','com_createddatetime','com_status','com_website','com_licensekey','com_countrycode'))
				   ->where('com_id <> ?',1);	

			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
			if($resultSet){
				return $resultSet;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getCompanyDetailsById($companyid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_companyname','com_email','com_phone','com_address','com_description','com_website','com_logouturl','com_countrycode'))
				   ->where('com_id = ?',$companyid);	
				   
			$result = $this->getDbTable()->fetchRow($select);
			$resultSet = "";
			if($result){
				$resultSet = array(
								'com_companyname' 	=> $result->com_companyname,
								'com_email' 		=> $result->com_email,
								'com_phone' 		=> $result->com_phone,
								'com_address' 		=> $result->com_address,
								'com_description'	=> $result->com_description,
								'com_website'		=> $result->com_website,
								'com_logouturl'		=> $result->com_logouturl,	
							);
				if($result->com_countrycode){
					$countryMapper  = new Application_Model_CountryDataMapper();
					$countryid = $countryMapper->getCountryidbyCountryCodeNumber($result->com_countrycode);
					$resultSet['com_countrycode'] = $countryid;
				}else{
					$resultSet['com_countrycode'] = "";
				}
			}
			
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateStatus($request)
	{
		try{
			if($request->status == "Activate"){
				$status = 1;
			}else{
				$status = 0;
			}
			$set = array('com_status'=>$status);
			$where 	= array('com_id = ?' => $request->companyid);
			
			$rows_affected = $this->getDbTable()->update($set,$where);				
			return $rows_affected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getComapnyNameList($userdata)
	{
		try{
			$companyid = $userdata['companyid'];
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_id','com_companyname'))
				   ->where('com_status = ?',true);
			if($companyid != 1){
				$select->where('com_id = ?',$companyid);
			}else{
				$select->where('com_id <> ?',1);
			}	
			
			$resultset =  $table->fetchAll($select);
			$compNames = array();
			$compNames[] = array('key'=>'','value'=>'Select Company');
			foreach($resultset as $result){
				$compNames[] = array('key'=>$result->com_id,'value'=>$result->com_companyname);
			}
			return $compNames;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getAllComapnyList()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				
				$userType = $data['Usertype'];
				$companyid = $data['companyid'];
				
				$table  = $this->getDbTable();
				$select = $table->select();
				
				$select->from($table,array('com_id','com_companyname'))
					   ->where('com_status = ?',true)
					    ->order('com_id');
				if($userType == "ADU" && $companyid != 1){
					$select->where('com_id = ? ', $companyid);
				}
				
				$resultset =  $table->fetchAll($select);
				$compNames = array();
				$compNames[] = array('key'=>'','value'=>'Select Company');
				foreach($resultset as $result){
					$compNames[] = array('key'=>$result->com_id,'value'=>$result->com_companyname);
				}
				return $compNames;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getComapnyStatusById($companyid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_status'))
				   ->where('com_id = ?',$companyid);
				   
			$result = $this->getDbTable()->fetchRow($select);

			$status = $result->com_status;
			return $status;   
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkCompanyExist($company)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$result = $db->fetchRow("select com_id from mt.company where com_companyname = '".$company."'");
			
			if((int)$result)
			{
				return true;	
			}else{
				return false;
			}
			 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkLicenseKey($licensekey)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_id','com_companyname','com_status'))
				   ->where('com_licensekey = ?',$licensekey);
				   
			$row = $this->getDbTable()->fetchRow($select);
			$resltArr = array();
			if($row){
				$resltArr['comapnyId']		=	$row->com_id;
				$resltArr['comapnyName']	=	$row->com_companyname;
				$resltArr['comapnyStatus']	=	$row->com_status;
			}
			return $resltArr;   
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getCompanyLogoutUrlByCompanyId($companyid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_logouturl'))
				   ->where('com_id = ?',$companyid);
				   
			$row = $this->getDbTable()->fetchRow($select);
			return $row->com_logouturl;   
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}