<?php
/**
*	Name			: RestaurantAlertDataMapper.php
*	Author			: snehal
*	Creation Date	: 7/15/2011
*	Path 			: application/modules/managerestaurant/models/restaurantalertDataMapper.php
*	Description		: This is the datamapper class for the restaurant alert table.
*					   	
*/
class ManageRestaurant_Model_RestaurantAlertDataMapper
{
	/**
	 * Instance variable of the restaurant alert table
	 * @var object
	 */
	protected $_dbTable;

	/**
     * @param instance of DbTable restaurant alert $dbTable
     * @return self
     */
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	/**
     * @return instance of DbTable restaurant alert
     */
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('ManageRestaurant_Model_DbTable_RestaurantAlert');
		}
		return $this->_dbTable;
	}
	
	/**
	 * function to create an restaurant alert
	 */
	public function createAlert(ManageRestaurant_Model_RestaurantAlert $alertObj, $datesArr, $resuserArr, $restArr)
	{
		$status = false;
		
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$data = array(
			'ral_userid'		=>	$alertObj->getUseridId(),
			'ral_subject'		=>	$alertObj->getSubject(),
			'ral_description'	=>	$alertObj->getMessage(),
			'ral_status'		=>	true,
			'ral_createdon'		=>	date('Y-m-d H:i:s'),
			'ral_createdby'		=>	$alertObj->getUseridId()
		);
		
		try{
			$db->beginTransaction();
			
			$alertid = $this->getDbTable()->insert($data);
			
			for ($i=0; $i<sizeof($datesArr); $i++) {
				$dateArr =  split("/",$datesArr[$i]);
				$date =  $dateArr[2].'-'.$dateArr[0].'-'.$dateArr[1];
				if(is_array($restArr)){
					for($k = 0; $k<sizeof($restArr); $k++) {
						$mapdata = array(
			  	  			'ram_alertid'		=> $alertid,
			  	  			'ram_date'			=> $date,
							'ram_resid'			=> $restArr[$k],
							'ram_status'		=> true	
			  	  		);
			  	  		$alertMapMapper = new ManageRestaurant_Model_RestaurantAlertMapDataMapper();
			  	  		$mapid = $alertMapMapper->getDbTable()->insert($mapdata);
		  	  		
			  	  		for ($j=0; $j<sizeof($resuserArr); $j++) {
				  	  		$recipentsdata = array(
				  	  			'rar_alertid'		=> $alertid,
				  	  			'rar_userid'		=> $resuserArr[$j],
				  	  			'rar_alertstatus'	=> 2,
				  	  			'rar_alertmapid'	=> $mapid	
				  	  		);
				  	  		
				  	  		$recipentsmapper = new ManageRestaurant_Model_RestaurantAlertRecipentsDataMapper();
				  	  		$recipentsmapper->getDbTable()->insert($recipentsdata);
						}
					}
				}else{
					$mapdata = array(
			  	  			'ram_alertid'		=> $alertid,
			  	  			'ram_date'			=> $date,
							'ram_resid'			=> $restArr,
							'ram_status'		=> true
			  	  		);
			  	  		$alertMapMapper = new ManageRestaurant_Model_RestaurantAlertMapDataMapper();
			  	  		$mapid = $alertMapMapper->getDbTable()->insert($mapdata);
			  	  		
						for ($j=0; $j<sizeof($resuserArr); $j++) {
				  	  		$recipentsdata = array(
				  	  			'rar_alertid'		=> $alertid,
				  	  			'rar_userid'		=> $resuserArr[$j],
				  	  			'rar_alertstatus'	=> 2,
				  	  			'rar_alertmapid'	=> $mapid	
				  	  		);
				  	  		
				  	  		$recipentsmapper = new ManageRestaurant_Model_RestaurantAlertRecipentsDataMapper();
				  	  		$recipentsmapper->getDbTable()->insert($recipentsdata);
						}
				}
			}		
			$db->commit();
			$status = true;
			return $status;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param userid ,date,restaurantid
	 * retreives the alert status for the restaurant 
	 */
	public function GetAlertStatus($userid, $date, $resid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('ral'=>'mt.restaurant_alerts'),array('ral_subject','ral_description','ral_createdon','ralid'))
				   ->join(array('rar'=>'mt.restaurant_alert_recipents'),'rar.rar_alertid = ral.ralid',array('rar_alertstatus','rarid','rar_alertmapid'))
				   ->join(array('ram'=>'mt.restaurant_alert_map'),'ram.ramid = rar.rar_alertmapid',array(''))
				   ->join(array('rown'=>'mt.restaurant_owner'),'rown.rsofk_user = ral.ral_userid',array('rsofirst_name','rsolast_name'))
				   ->where('ram.ram_resid = ?',$resid)
				   ->where('ram.ram_date = ?',$date)
				   ->where('ral.ral_userid = ?',$userid)
				   ->where('rar.rar_userid = ?',$userid)
				   ->order('ral.ralid DESC');
			$result = $table->fetchAll($select);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param userid,date,restaurantid
	 * retreives the alerts of the restaurant users
	 */
	public function GetRestuarntUserAlerts($userid, $date, $resid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('rar'=>'mt.restaurant_alert_recipents'),array('rar_alertid','rar_userid','rar_alertstatus','rarid','rar_alertmapid'))
				   ->join(array('ral'=>'mt.restaurant_alerts'),'ral.ralid = rar.rar_alertid',array('ralid','ral_subject','ral_description','ral_createdon'))
				   ->join(array('rown'=>'mt.restaurant_owner'),'rown.rsofk_user = ral.ral_userid',array('rsofirst_name','rsolast_name'))
				   ->join(array('ram'=>'mt.restaurant_alert_map'),'ram.ramid = rar.rar_alertmapid',array(''))
				   ->where('ram.ram_resid = ?',$resid)
				   ->where('ram.ram_date = ?',$date)
				   ->where('rar.rar_userid = ?',$userid)
				   ->order('ral.ralid DESC');
			$result = $table->fetchAll($select);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param userid,usertype
	 * retreives all the alerts of the user using usertype 
	 */
	public function ViewAllAlerts($userid, $usertype)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			if($usertype == 'RSO'){
				$select->from(array('ral'=>'mt.restaurant_alerts'),array('ralid','ral_subject','ral_description','ral_createdon'));
				$select->join(array('rown'=>'mt.restaurant_owner'),'rown.rsofk_user = ral.ral_userid',array('rsofirst_name as firstname','rsolast_name as lastname'));
				$select->where('ral.ral_userid = ?',$userid)
				   	   ->order('ral.ralid DESC');
			}else{
				$select->from(array('rar'=>'mt.restaurant_alert_recipents'),array('rar_alertid','rar_userid'));
				$select->distinct();
				$select->join(array('ral'=>'mt.restaurant_alerts'),'ral.ralid = rar.rar_alertid',array('ralid','ral_subject','ral_description','ral_createdon'));
				$select->join(array('rown'=>'mt.restaurant_owner'),'rown.rsofk_user = ral.ral_userid',array('rsofirst_name as firstname','rsolast_name as lastname'));
				$select->where('rar.rar_userid = ?',$userid)
					   ->order('ral.ralid DESC');
			}
			$result = $table->fetchAll($select);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param id
	 * retreives the alert details using id 
	 */
	public function getAlertDetailsById($id)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('ral_subject','ral_description'))
			       ->where('ralid = ?', $id);
			 $result = $table->fetchRow($select);
			 $resultArr = array();
			 $resultArr['subject'] = $result['ral_subject'];
			 $resultArr['desc']    = $result['ral_description'];
			return $resultArr;		  
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}