<?php
class ManageRestaurant_Model_RestaurantDealDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('ManageRestaurant_Model_DbTable_RestaurantDeal');
		}
		return $this->_dbTable;
	}

	public function saveManageDeal(ManageRestaurant_Model_restaurantDeal $restdeal)
	{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$data = array(
					'rsdfk_restaurant'		=> $restdeal->getRestaurantid(),
					'rsddeal_title'			=> $restdeal->getDealtitle(),
					'rsdfood_type'			=> $restdeal->getFoodtype(),
					'rsdstart_date'			=> $restdeal->getStartdate(),
					'rsdend_date'			=> $restdeal->getEnddate(),
					'rsdstart_time'			=> $restdeal->getStarttime(),
					'rsdend_time'			=> $restdeal->getEndtime(),
					'rsddeal_description'	=> $restdeal->getDescription(),
					'rsdstatus'				=> $restdeal->getStatus(),
					'rsdrecurencestatus'	=> $restdeal->getDealrecurence()
			);
			try{
				$db->beginTransaction();

				$deal_id = $this->getDbTable()->insert($data);
					
				$days = $restdeal->getWeekid();
				$mapper = new ManageRestaurant_Model_RestaurentDealRecurrenceDataMapper();
				foreach($days as $day){
					$weekData = array(
				'rdrfk_restaurant_deal' => $deal_id,
				'rdrdays_of_week' 		=> $day->getWeekId(),
				'rdrreccurence_type_id' => 1,
				'rdrstatus'				=> TRUE
					);
					$mapper->getDbTable()->insert($weekData);
				}
					
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}

	public function getManageDealById(ManageRestaurant_Model_RestaurantById $Id)
	{
		try{
			$table = $this->getDbTable();
			$query= $table->select();
			$query->setIntegrityCheck(false);

			$query->from(array('rsd'=>'mt.restaurant_deal'),array('rsdid','rsdfk_restaurant','rsddeal_title','rsdfood_type'))
			->join(array('rst'=>'mt.restaurant'),'rsd.rsdfk_restaurant = rst.resid',array('resid','resrestaurant_name'))
			->join(array('rtb'=>'mt.restaurant_type_bd'),'rtb.id = rsd.rsdfood_type',array('description'))
			->where('rst.resfk_user = ?',$Id->getRestaurantId())
			->where('rsdstatus = ?',TRUE);
				
			$Result = $table->fetchAll($query);
			return $Result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function getRestaurantDealById(ManageRestaurant_Model_RestaurantDealById $dealId)
	{
		try{
			$table = $this->getDbTable();
			$query= $table->select();
			$query->setIntegrityCheck(false);

			$query->from(array('rsd'=>'mt.restaurant_deal'),array('rsdid','rsdfk_restaurant','rsddeal_title','rsdfood_type','rsddeal_description','rsdstart_date','rsdend_date','rsdstart_time','rsdend_time','rsdrecurencestatus','rsdstatus'))
			->join(array('rst'=>'mt.restaurant'),'rst.resid = rsd.rsdfk_restaurant',array('resrestaurant_name'))
			->join(array('rtb'=>'mt.restaurant_type_bd'),'rtb.id = rsd.rsdfood_type',array('description'))
			->where('rsd.rsdid = ?',$dealId->getDealId());

			$result = $table->fetchRow($query);

			$recurence = new ManageRestaurant_Model_RestaurentDealRecurrenceDataMapper();
			$recurenceTable = $recurence->getDbTable();
			$selectWeeks = $recurenceTable->select();

			if($result->rsdrecurencestatus){
				$selectWeeks->from($recurenceTable,array('rdrdays_of_week'))
				->where('rdrfk_restaurant_deal = ? ',$result->rsdid);
			}
			$weekResult = $table->fetchAll($selectWeeks);

			$dealObj = new ManageRestaurant_Model_restaurantDeal();
			$dealObj->setRestaurantid($result->rsdfk_restaurant)
			->setDealtitle($result->rsddeal_title)
			->setFoodtype($result->rsdfood_type)
			->setStartdate($result->rsdstart_date)
			->setEnddate($result->rsdend_date)
			->setStarttime($result->rsdstart_time)
			->setEndtime($result->rsdend_time)
			->setDescription($result->rsddeal_description)
			->setDealrecurence($result->rsdrecurencestatus)
			->setStatus($result->rsdstatus);
			$dealWeek= array();

			foreach($weekResult as $value){
				$dealRecurenceObj = new ManageRestaurant_Model_RestaurantDealRecurence();
				$dealRecurenceObj->setWeekId($value->rdrdays_of_week);
				$dealWeek[] = $dealRecurenceObj;
					
			}
			$dealObj->setWeekid($dealWeek);
			return $dealObj;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function updateManageDeal(ManageRestaurant_Model_restaurantDeal $restdeal)
	{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
				'rsdfk_restaurant'		=> $restdeal->getRestaurantid(),
				'rsddeal_title'			=> $restdeal->getDealtitle(),
				'rsdfood_type'			=> $restdeal->getFoodtype(),
				'rsdstart_date'			=> $restdeal->getStartdate(),
				'rsdend_date'			=> $restdeal->getEnddate(),
				'rsdstart_time'			=> $restdeal->getStarttime(),
				'rsdend_time'			=> $restdeal->getEndtime(),
				'rsddeal_description'	=> $restdeal->getDescription(),
				'rsdrecurencestatus'	=> $restdeal->getDealrecurence()
			);

			try{
				$db->beginTransaction();
				$dealWhere = $db->quoteInto('rsdid = ?',$restdeal->getId());
					
				$this->getDbTable()->update($set,$dealWhere);
					
				$days = $restdeal->getWeekid();
				$mapper = new ManageRestaurant_Model_RestaurentDealRecurrenceDataMapper();
				$Where = $db->quoteInto('rdrfk_restaurant_deal = ?',$restdeal->getId());
				$mapper->getDbTable()->delete($Where);
					
				foreach($days as $day){
					$weekData = array(
				'rdrfk_restaurant_deal' => $restdeal->getId(),
				'rdrdays_of_week' 		=> $day->getWeekId(),
				'rdrreccurence_type_id' => 1,
				'rdrstatus'				=> TRUE
					);
					$mapper->getDbTable()->insert($weekData);;
				}
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}

}