<?php
class ManageRestaurant_Model_RestaurantDiningAreaDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('ManageRestaurant_Model_DbTable_RestaurantDiningArea');
		}
		return $this->_dbTable;
	}
	
	public function getDinigAreasByRestId($resId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rda_diningname','rdaid','rda_diningdisplyname','rda_status'))
			->where('rda_restid = ?',$resId)
			->where('rda_status = ?','TRUE')
			->order(array('rda_default DESC', 'rdaid'));

			$rowset = $table->fetchAll($select);

			return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getDinigAreasByRestIdfromFloor($resId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rda_diningname','rdaid','rda_diningdisplyname','rda_status'))
			->where('rda_restid = ?',$resId)
			//->where('rda_status = ?','TRUE')
			->order('rdaid');

			$rowset = $table->fetchAll($select);

			return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AddDiningArea($resId,$diningName,$displayname)
	{
		try{
			$status = false; 
			$result = array();
			$table = $this->getDbTable();
			$esistingData = $this->GetAllDiningAreasByResId($resId);
			foreach($esistingData as $row){
				if(strtolower($row->rda_diningdisplyname) == strtolower($displayname) || strtolower($row->rda_diningname) == strtolower($diningName)){
					$result = array('status'=>false);
					if(strtolower($row->rda_diningdisplyname) == strtolower($displayname)){
						$result['displayname'] = 'err';
					}else{
						$result['displayname'] = 'suc';
					}
					if(strtolower($row->rda_diningname) == strtolower($diningName)){
						$result['diningname'] = 'err';
					}else{
						$result['diningname'] = 'suc';
					}
					return $result;
				}
			}
			$data = array(
				'rda_restid'			=>	$resId,
				'rda_diningname'		=>	$diningName,
				'rda_diningdisplyname'	=>	$displayname,
				'rda_status'			=>	true,
				'rdasync_status'		=>  'C'
			);

			$id = $this->getDbTable()->insert($data);
			if($id){
				$status = true;
			}
			$result = array('status'=>true,'result'=>$status);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditDiningArea($resId,$diningid,$diningname,$displyname)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false; 
			$result = array();
			$esistingData = $this->GetAllDiningAreasByResId($resId);
			foreach($esistingData as $row){
				if($diningid != $row->rdaid){
					if(strtolower($row->rda_diningdisplyname) == strtolower($displyname) || strtolower($row->rda_diningname) == strtolower($diningname)){
						$result = array('status'=>false);
						if(strtolower($row->rda_diningdisplyname) == strtolower($displyname)){
							$result['displayname'] = 'err';
						}else{
							$result['displayname'] = 'suc';
						}
						if(strtolower($row->rda_diningname) == strtolower($diningname)){
							$result['diningname'] = 'err';
						}else{
							$result['diningname'] = 'suc';
						}
						return $result;
					}
				}
			}
			
			$set = array(
				'rda_diningname'		=>	$diningname,
				'rda_diningdisplyname'	=>	$displyname,
				'rdasync_status'		=>  'C'
			);
			
			$where = array(
					'rdaid = ?'		=>	$diningid,
					'rda_restid = ?'=>	$resId	
			);

			$id = $this->getDbTable()->update($set,$where);
			if($id){
				$status = true;
			}
			$result = array('status'=>true,'result'=>$status);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditDiningAreaStatus($diningid,$diningsts)
	{
		try{
			$status = false; 
			
			$set = array(
				'rda_status'	 =>	$diningsts,
				'rdasync_status' => 'C'
			);
			
			$where = array(
					'rdaid = ?'		=>	$diningid,
				);

			$id = $this->getDbTable()->update($set,$where);
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetAllDiningAreasByResId($resId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rda_restid','rda_diningname','rda_status','rdaid','rda_diningdisplyname','rda_createdby','rda_createdon'))
			->where('rda_restid = ?',$resId)
			->order('rdaid');

			$rowset = $table->fetchAll($select);

			return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetAllUpdatedDiningAreasByResId($resId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rda_restid','rda_diningname','rda_status','rdaid','rda_diningdisplyname','rda_createdby','rda_createdon'))
			->where('rda_restid = ?',$resId)
			->where('rdasync_status = ?', 'C')
			->order('rdaid');

			$rowset = $table->fetchAll($select);

			return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateDiningAreasSyncStatusFromNative($resId)
	{
		try{
			$set = array('rdasync_status' => 'S');			
			$where = array(
					'rda_restid = ?'	=>	$resId,
					'rdasync_status = ?'	=>	'C'
				);

			$this->getDbTable()->update($set,$where);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}
