<?php
class Payments_Model_AuthnetPaymentProfileMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_AuthnetPaymentProfile');
		}
		return $this->_dbTable;
	}
	
	public function GetAuthNetPaymentProfIdByCustProfId(Payments_Model_GetAuthNetPaymentProfId $object)
	{
		try{
			
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
		
			$select->from(array('paymntprof'=>'mt.authnet_payment_profile'),array('anppid','anpppayment_profile_id','anppcreated_date','anppcreated_time','anppstatus'))
			   	   ->join(array('custprof'=>'mt.authnet_customer_profile'),'paymntprof.anppcustomer_profile_id = custprof.ancpid',array('ancpcustomer_profile_id'))
			   	   ->join(array('prflsts'=>'mt.profilestatus_bd'),'paymntprof.anppstatus = prflsts.id',array('code as paymtstatuscode','description as paymtstatusdesc'))
			   	   ->where('custprof.ancpcustomer_profile_id = ?',$object->getancpcustomer_profile_id())
			   	   ->where('custprof.ancpstatus = ?',$object->getancpstatus())
			   	   ->where('paymntprof.anppstatus = ?',$object->getanppstatus())
			   	   ->order(array('paymntprof.anpppayment_profile_id DESC'));
			   
			$rowSet = $table->fetchAll($select);

			return $rowSet;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function SavePaymentProfiles(Payments_Model_AuthnetPaymentProfile $object)
	{
		try{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			
			$table = $this->getDbTable();
			$paymentProfileId   = $object->getanpppayment_profile_id();
			$paymentProfileType = $object->getanpppayment_type();
			 
			foreach($paymentProfileId as $paymentId){
				$profileType = $paymentProfileType[$paymentId];
				
				$data = array('anppcustomer_profile_id' => $object->getanppcustomer_profile_id(),
							  'anpppayment_profile_id'  => $paymentId,
							  'anppcreated_date'		=> $object->getanppcreated_date(),
							  'anppcreated_time'    	=> $object->getanppcreated_time(),
							  'anppstatus'				=> $object->getanppstatus(),
							  'anpppayment_type'		=> $profileType);
				
				$table->insert($data);	
			}
			$status = true;
			$db->commit();
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage());
		}
		
	}
	
	public function DeletePaymentProfiles(Payments_Model_DeletePaymentProfile $object)
	{
		try{
			$table = $this->getDbTable();
			$set = array('anppstatus'=>$object->getStatus());
			$where = array('anpppayment_profile_id IN(?)' => $object->getPayemntProfId());
			
			$rows_affected = $table->update($set,$where);			
			return $rows_affected;
			
		}catch(Exception $ex){		
			throw new Exception($ex->getMessage());
		}
	}
	
	public function searchPaymentProfiles(Payments_Model_SearchPaymentProfile $searchData){
		try {
			date_default_timezone_set('Asia/Kolkata');
			$today = date('Y-m-d');
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
		
			$select->from(array('paymntprof'=>'mt.authnet_payment_profile'),array('anppid','anpppayment_profile_id','anppcreated_date','anppcreated_time','anppstatus'))
			   	   ->join(array('custprof'=>'mt.authnet_customer_profile'),'paymntprof.anppcustomer_profile_id = custprof.ancpid',array())
			   	   ->join(array('prflsts'=>'mt.profilestatus_bd'),'paymntprof.anppstatus = prflsts.id',array('code as paymtstatuscode','description as paymtstatusdesc'))
			   	   ->where('custprof.ancpcustomer_profile_id = ?',$searchData->getsrchcustomer_profile_id())
			   	   ->where('custprof.ancpstatus = ?',1)
			   	   ->where('paymntprof.anppstatus = ?',1);
			   	   
			if($searchData->getsrchstart_date()){
				if($searchData->getsrchstart_time()){
					$select->where('paymntprof.anppcreated_date+paymntprof.anppcreated_time >= ?', $searchData->getsrchstart_date().' '.$searchData->getsrchstart_time());
				}else{
					$select->where('paymntprof.anppcreated_date >= ?', $searchData->getsrchstart_date());
				}
			} else {
				if($searchData->getsrchstart_time()){
					$select->where('paymntprof.anppcreated_date+paymntprof.anppcreated_time >= ?', $today.' '.$searchData->getsrchstart_time());
				}
			}
			if($searchData->getsrchend_date()){
				if($searchData->getsrchend_time()){
					$select->where('paymntprof.anppcreated_date+paymntprof.anppcreated_time <= ?', $searchData->getsrchend_date().' '.$searchData->getsrchend_time());
				} else {
					$select->where('paymntprof.anppcreated_date <= ?', $searchData->getsrchend_date());
				}
			} else {
				if($searchData->getsrchend_time()){
					$select->where('paymntprof.anppcreated_date+paymntprof.anppcreated_time <= ?', $today.' '.$searchData->getsrchend_time());
				}
			}
			if($searchData->getsrchpayment_profile_id()){
				$select->where('paymntprof.anpppayment_profile_id = ?', $searchData->getsrchpayment_profile_id());
			}			
			$select->order(array('paymntprof.anpppayment_profile_id DESC'));

			$rowSet = $table->fetchAll($select);
			return $rowSet;
			
		} catch (Exception $ex) {
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getPaymentProfileIDs($customerProfileId)
	{
		try {
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('paymntprof'=>'mt.authnet_payment_profile'),array('anppid','anpppayment_profile_id'))
					->join(array('custprof'=> 'mt.authnet_customer_profile'), 'paymntprof.anppcustomer_profile_id = custprof.ancpid', array())
					->where('custprof.ancpcustomer_profile_id = ?', $customerProfileId);
			$rowSet = $table->fetchAll($select);
			$paymentProfileIDs[] = array('key'=>'','value'=>'Select Payment Profile');
			foreach($rowSet as $row){
				$paymentProfileIDs[] = array('key'=>$row->anppid,'value'=>$row->anpppayment_profile_id);
			}
			return $paymentProfileIDs;
		} catch (Exception $ex) {
			throw new Exception($ex->getMessage());
		}
	}
	
	public function GetPaymentProfileByRestId(Payments_Model_GetPaymentProfileByRestId $profileByRestId)
	{
		try{
		   $table  = $this->getDbTable();
		   $select = $table->select();
		   $select->setIntegrityCheck(false);
		   $select->from(array('ancp'=>'mt.authnet_customer_profile'),array('ancpcustomer_profile_id'))
		   		  ->join(array('anpp'=>'mt.authnet_payment_profile'),'ancp.ancpid = anpp.anppcustomer_profile_id',array('anppid','anpppayment_profile_id','anpppayment_type'))
		   		  ->join(array('rapp'=>'mt.rest_authnet_payment_profile_map'),'rapp.rappmpayment_profile_id = anpp.anppid',array(''))
		   		  ->where('rapp.rappmrestaurant_id = ?',$profileByRestId->getrappmrestaurant_id())
		   		  ->where('rapp.rappmstatus = ?',$profileByRestId->getrappmstatus())
		   		  ->where('ancp.ancpstatus = ?',$profileByRestId->getancpstatus())
		   		  ->where('anpp.anppstatus = ?',$profileByRestId->getanppstatus());
		   $rowSet = $table->fetchAll($select);
		   return $rowSet;
		     	
		}catch(Exception $ex){		
			throw new Exception($ex->getMessage());
		}
	}
	
}