<?php
class Payments_Model_CustomerInvoiceMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_CustomerInvoice');
		}
		return $this->_dbTable;
	}
	
	public function CreateCustomerInvoice(Payments_Model_CustomerInvoice  $object)
	{
		try{
			$table = $this->getDbTable();
			$data = array('cusinvrestaurant_id'    => $object->getinvrestaurant_id(),
						  'cusinvcustomer_id'  	=> $object->getinvcustomer_id(),
						  'cusinvbooking_id'	    => $object->getinvbooking_id(),
						  'cusinvdescription'	    => $object->getinvdescription(),
						  'cusinvbilling_fromdate' => $object->getinvbilling_fromdate(),
						  'cusinvbilling_todate'	=> $object->getinvbilling_todate(),
						  'cusinvamount'			=> $object->getinvamount(),
						  'cusinvstatus'			=> $object->getinvstatus(),
						  'cusinvgenerated_date'	=> $object->getinvgenerated_date(),
						  'cusinvgenerated_time'	=> $object->getinvgenerated_time(),
						  'cusinvservice_tax'		=> $object->getinvservice_tax(),
						  'cusinvtxncharges'	=> $object->getinvtxncharges());
			
			$result = $table->insert($data);
			
			return $result;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function CheckCustomerInvoiceGenerated(Payments_Model_CustomerInvoice  $invoiceObj)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('cusinvid','cusinvcustomer_id','cusinvbooking_id','cusinvamount','cusinvdescription','cusinvbilling_fromdate','cusinvbilling_todate','cusinvgenerated_date','cusinvgenerated_time'))
				   ->where('cusinvrestaurant_id = ?',$invoiceObj->getinvrestaurant_id())
				   ->where('cusinvcustomer_id = ?',$invoiceObj->getinvcustomer_id())
				   ->where('cusinvbooking_id = ?',$invoiceObj->getinvbooking_id())
				   ->where('cusinvbilling_fromdate = ?',$invoiceObj->getinvbilling_fromdate())
				   ->where('cusinvbilling_todate = ?',$invoiceObj->getinvbilling_todate())
				   ->where('cusinvamount = ?',$invoiceObj->getinvamount())
				   ->where('cusinvstatus = ?',$invoiceObj->getinvstatus());
				   
		    $row = $table->fetchRow($select);
		    return $row;
							   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function UpdateCustomerInvoiceStatusById(Payments_Model_UpdateCustomerInvoiceStatusById  $invoiceStatusByIdObject)
	{
		try{
			$table = $this->getDbTable();
			$set = array('cusinvstatus' => $invoiceStatusByIdObject->getinvstatus());
			$where = array(	'cusinvid = ?' => $invoiceStatusByIdObject->getinvid(),
							'cusinvcustomer_id = ?' => $invoiceStatusByIdObject->getcusid(),
							'cusinvbooking_id = ?' => $invoiceStatusByIdObject->getbokid(),
							'cusinvrestaurant_id = ?' => $invoiceStatusByIdObject->getinvrestaurant_id());

			$rows_affected = $table->update($set,$where);
			
			return $rows_affected;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}

	public function RetrieveCustomerInvoices(Payments_Model_ManageInvoice $manageInvoiceObject)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('inv' => 'mt.customer_invoice'),array('cusinvid','cusinvrestaurant_id','cusinvcustomer_id','cusinvbooking_id','cusinvdescription','cusinvbilling_fromdate','cusinvbilling_todate','cusinvamount','cusinvstatus','cusinvservice_tax','cusinvtxncharges'))
				   ->join(array('res' => 'mt.restaurant'),'res.resid = inv.invrestaurant_id',array('resrestaurant_name'))
				   ->join(array('usr' =>'mt.user'),'usrid = res.resfk_user',array())
				   ->where('usr.usrid = ?',$manageInvoiceObject->getUserId())
				   ->join(array('invsts' => 'mt.invoicestatus_bd'),'invsts.id = inv.cusinvstatus',array('code as invcode','description as invdesc'));

				   
			if($manageInvoiceObject->getinvoicenum()){
				$select->where('inv.cusinvid = ?',$manageInvoiceObject->getinvoicenum());
			}
			
			if($manageInvoiceObject->getinvoicefromdate() && $manageInvoiceObject->getinvoicetodate()){
				
				$select->where('inv.cusinvbilling_fromdate >= ?',$manageInvoiceObject->getinvoicefromdate());
				$select->where('cusinvbilling_todate <= ?',$manageInvoiceObject->getinvoicetodate());
					
			}else if($manageInvoiceObject->getinvoicefromdate()){
				$select->where('inv.cusinvbilling_fromdate = ?',$manageInvoiceObject->getinvoicefromdate());
			}else if($manageInvoiceObject->getinvoicetodate()){
				$select->where('cusinvbilling_todate = ?',$manageInvoiceObject->getinvoicetodate());
			}
			
			if($manageInvoiceObject->getinvoicestatus()){
				$select->where('cusinvstatus = ?',$manageInvoiceObject->getinvoicestatus());
			}
			
			$rowSet = $table->fetchAll($select);

			return $rowSet;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function RetrieveCustomerInvoiceById(Payments_Model_GetInvoiceDetailsById $getInvoiceDetailsByIdObject)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('cusinvid','cusinvrestaurant_id','cusinvcustomer_id','cusinvbooking_id','cusinvdescription','cusinvbilling_fromdate','cusinvbilling_todate','cusinvamount','cusinvstatus','cusinvgenerated_date','cusinvgenerated_time','cusinvcreated_by','cusinvservice_tax','cusinvtxncharges'))
				   ->where('cusinvid = ?',$getInvoiceDetailsByIdObject->getInvoiceId())
				   ->where('cusinvstatus = ?',$getInvoiceDetailsByIdObject->getInvoiceStatus());
		    
		   $row = $table->fetchRow($select);		   
		   return $row;
		   		   			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
}

	