<?php
class Payments_Model_InvoiceMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_Invoice');
		}
		return $this->_dbTable;
	}
	
	public function CreateInvoice(Payments_Model_Invoice $object)
	{
		try{
			$table = $this->getDbTable();
			
			$data = array('invrestaurant_id'    => $object->getinvrestaurant_id(),
						  'invdescription'	    => $object->getinvdescription(),
						  'invbilling_fromdate' => $object->getinvbilling_fromdate(),
						  'invbilling_todate'	=> $object->getinvbilling_todate(),
						  'invamount'			=> $object->getinvamount(),
						  'invstatus'			=> $object->getinvstatus(),
						  'invgenerated_date'	=> $object->getinvgenerated_date(),
						  'invgenerated_time'	=> $object->getinvgenerated_time(),
						  'invservice_tax'		=> $object->getinvservice_tax(),
						  'invtxncharges'	=> $object->getinvtxncharges());
			
			if($object->getinv_discount())
			{
				$data['inv_discount'] = $object->getinv_discount();
			}
			
			$result = $table->insert($data);
			
			return $result;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function CheckInvoiceGenerated(Payments_Model_Invoice $invoiceObj)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('invid','invamount','invdescription','invbilling_fromdate','invbilling_todate','invgenerated_date','invgenerated_time'))
				   ->where('invrestaurant_id = ?',$invoiceObj->getinvrestaurant_id())
				   ->where('invbilling_fromdate = ?',$invoiceObj->getinvbilling_fromdate())
				   ->where('invbilling_todate = ?',$invoiceObj->getinvbilling_todate())
				   ->where('invamount = ?','$'.$invoiceObj->getinvamount())
				   ->where('invstatus = ?',$invoiceObj->getinvstatus());
				   
		    $row = $table->fetchRow($select);
		    
		    return $row;
							   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function UpdateInvoiceStatusById(Payments_Model_UpdateInvoiceStatusById $invoiceStatusByIdObject)
	{
		try{
			$table = $this->getDbTable();
			$set = array('invstatus' => $invoiceStatusByIdObject->getinvstatus());
			$where = array('invid = ?' => $invoiceStatusByIdObject->getinvid(),'invrestaurant_id = ?' => $invoiceStatusByIdObject->getinvrestaurant_id());

			$rows_affected = $table->update($set,$where);
			
			return $rows_affected;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}

	public function RetrieveInvoices(Payments_Model_ManageInvoice $manageInvoiceObject)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('inv' => 'mt.invoice'),array('invid','invrestaurant_id','invdescription','invbilling_fromdate','invbilling_todate','invamount','invstatus','invservice_tax','invtxncharges'))
				   ->join(array('res' => 'mt.restaurant'),'res.resid = inv.invrestaurant_id',array('resrestaurant_name'))
				   ->join(array('usr' =>'mt.user'),'usrid = res.resfk_user',array())
				   ->where('usr.usrid = ?',$manageInvoiceObject->getUserId())
				   ->join(array('invsts' => 'mt.invoicestatus_bd'),'invsts.id = inv.invstatus',array('code as invcode','description as invdesc'));

				   
			if($manageInvoiceObject->getinvoicenum()){
				$select->where('inv.invid = ?',$manageInvoiceObject->getinvoicenum());
			}
			
			if($manageInvoiceObject->getinvoicefromdate() && $manageInvoiceObject->getinvoicetodate()){
				
				$select->where('inv.invbilling_fromdate >= ?',$manageInvoiceObject->getinvoicefromdate());
				$select->where('invbilling_todate <= ?',$manageInvoiceObject->getinvoicetodate());
					
			}else if($manageInvoiceObject->getinvoicefromdate()){
				$select->where('inv.invbilling_fromdate = ?',$manageInvoiceObject->getinvoicefromdate());
			}else if($manageInvoiceObject->getinvoicetodate()){
				$select->where('invbilling_todate = ?',$manageInvoiceObject->getinvoicetodate());
			}
			
			if($manageInvoiceObject->getinvoicestatus()){
				$select->where('invstatus = ?',$manageInvoiceObject->getinvoicestatus());
			}
			
			$rowSet = $table->fetchAll($select);

			return $rowSet;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function RetrieveInvoiceById(Payments_Model_GetInvoiceDetailsById $getInvoiceDetailsByIdObject)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('invid','invrestaurant_id','invdescription','invbilling_fromdate','invbilling_todate','invamount','invstatus','invgenerated_date','invgenerated_time','invcreated_by','invservice_tax','invtxncharges'))
				   ->where('invid = ?',$getInvoiceDetailsByIdObject->getInvoiceId())
				   ->where('invstatus = ?',$getInvoiceDetailsByIdObject->getInvoiceStatus());
		    
		   $row = $table->fetchRow($select);		   
		   return $row;
		   		   			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
		
	public function UpdateInvoice(Payments_Model_Invoice $invoiceObj)
	{
		try
		{
			$table = $this->getDbTable();
			
			$set = array('invamount'			=> $invoiceObj->getinvamount(),
						 'invbilling_fromdate'	=> $invoiceObj->getinvbilling_fromdate(),
						 'invbilling_todate' 	=> $invoiceObj->getinvbilling_todate(),
						 'invupdated_date' 		=> $invoiceObj->getinvupdated_date(),
						 'invupdated_time' 		=> $invoiceObj->getinvupdated_time()
						 );
						 
			if($invoiceObj->getinv_discount())
			{
				$set['inv_discount'] = $invoiceObj->getinv_discount();
			}			 
			
			$where = array('invid = ?' => $invoiceStatusByIdObject->getinvid(),'invrestaurant_id = ?' => $invoiceStatusByIdObject->getinvrestaurant_id());

			$rows_affected = $table->update($set,$where);
			
			return $rows_affected;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
}

	