<?php
class Payments_Model_RestAuthnetPaymentProfileMapMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_RestAuthnetPaymentProfileMap');
		}
		return $this->_dbTable;
	}
	
	public function SavePaymentProfileAndSubscriptionPlanOfRestaurant(Payments_Model_RestAuthnetPaymentProfileMap $paymentProfileObject, Payments_Model_RestaurantPaymentPlanMap $paymentPlanObject)
	{
		$paymentProfileData = array('rappmrestaurant_id' 		=> $paymentProfileObject->getrappmrestaurant_id(),
			  'rappmpayment_profile_id'	=> $paymentProfileObject->getrappmpayment_profile_id(),
			  'rappmstatus'				=> $paymentProfileObject->getrappmstatus()			
		);
		
		$subscriptionPlanData = array('rppmpayment_plan_id'	=> $paymentPlanObject->getrppmpayment_plan_id(),
									  'rppmrestaurant_id'	=> $paymentPlanObject->getrppmrestaurant_id(),
									  'rppmplan_activation_date' => $paymentPlanObject->getrppmplan_activation_date(),
									  'rppmplan_activation_time' => $paymentPlanObject->getrppmplan_activation_time(),
									  'rppmstatus'	=> $paymentPlanObject->getrppmstatus()
		);
		try{
		$status = false;
		/* Add Payment profile to restaurant */
		$db = Zend_Db_Table::getDefaultAdapter();
		$db->beginTransaction();
		$table = $this->getDbTable();
		$table->insert($paymentProfileData);
		
		/* Add Payment plan to restaurant */
		$resPaymentPlanMapper = new Payments_Model_RestaurantPaymentPlanMapMapper();
		$resPaymentPlanMapper->getDbTable()->insert($subscriptionPlanData);
		
		$db->commit();
		$status = true;
		return $status;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage());
		}		
	}
	
	public function getRestPaymentProfileMap($paymentProfileId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('resppmap' => 'mt.rest_authnet_payment_profile_map'), array())
				   ->distinct()
				   ->join(array('rest' => 'mt.restaurant'), 'resppmap.rappmrestaurant_id = rest.resid', array('resid','resrestaurant_name','resimage','reslogo','resaddress'))
				   ->where('resppmap.rappmpayment_profile_id = ?', $paymentProfileId);
				   
			$rowSet = $table->fetchAll($select);
			$restNames = array();
			if($rowSet){
				foreach ($rowSet as $row){
					$restNames[] = array('resid'		=> $row->resid,
									 	 'resname'		=> $row->resrestaurant_name,
									 	 'resimage'		=> $row->resimage,
									 	 'reslogo'		=> $row->reslogo,
									 	 'resaddress'	=> $row->resaddress);
				}
			}
			return $restNames;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getRestPaymentProfiles($userid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('rappm'=>'mt.rest_authnet_payment_profile_map'),array('rappmid','rappmrestaurant_id','rappmpayment_profile_id'))
				   ->join(array('anpp'=>'mt.authnet_payment_profile'),'anpp.anppid = rappm.rappmpayment_profile_id',array('anppid','anpppayment_profile_id'))
				   ->join(array('res'=>'mt.restaurant'),'res.resid = rappm.rappmrestaurant_id',array())
				   ->where('res.resfk_user = ?',$userid)
				   ->where('rappm.rappmstatus = ?',1)
				   ->where('anpp.anppstatus = ?',1);
			$rowSet = $table->fetchAll($select);
			$result = array();
			foreach($rowSet as $row){
				$result[$row->rappmrestaurant_id] = $row;
			}	   	
			return $result; 
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function updatePaymentProfile(Payments_Model_RestAuthnetPaymentProfileMap $paymentProfileMapObject)
	{
		try{
			$table = $this->getDbTable();
			/* get previous payment profile */
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('rappm'=>'mt.rest_authnet_payment_profile_map'),array('rappmid','rappmpayment_profile_id','rappmstatus'))				  
				   ->where('rappm.rappmrestaurant_id = ?',$paymentProfileMapObject->getrappmrestaurant_id())
				   ->where('rappm.rappmstatus = ?',$paymentProfileMapObject->getrappmstatus());	
				  
				   
			$rowSet = $table->fetchAll($select);
			$updateStatus = true;
			$status = false;
			
			
			/* Check selected payment profile and new payment profiles are same
			 *  if not inactive the previous payment profile and insert new payment profile */
			
			foreach($rowSet as $row){
				$rappmid = $row->rappmid;
				if($row->rappmpayment_profile_id == $paymentProfileMapObject->getrappmpayment_profile_id()){
					
					$updateStatus = false;
				}
			}
			
			if($updateStatus){
				$db = Zend_Db_Table::getDefaultAdapter();
				$db->beginTransaction(); 
				
				if($rappmid)
				{
					$set   = array('rappmstatus' => $paymentProfileMapObject->getrappminactivestatus(),
							   	   'updateddate' => $paymentProfileMapObject->getupdateddate(),
							   	   'updatedtime' => $paymentProfileMapObject->getupdatedtime(),
							   	   'updatedby'	 => $paymentProfileMapObject->getupdatedby());
				
					$where = array('rappmid = ?'=>$rappmid);
				
					$rows_affected = $table->update($set,$where);
				}
				
				$paymentProfileData = array('rappmrestaurant_id' 		=> $paymentProfileMapObject->getrappmrestaurant_id(),
			  								'rappmpayment_profile_id'	=> $paymentProfileMapObject->getrappmpayment_profile_id(),
			  								'rappmstatus'				=> $paymentProfileMapObject->getrappmstatus(),
											'createddate'				=> $paymentProfileMapObject->getcreateddate(),
											'createdtime'				=> $paymentProfileMapObject->getcreatedtime(),
											'createdby'					=> $paymentProfileMapObject->getcreatedby()			
											);
				
				
				$result = $table->insert($paymentProfileData);
				
				$db->commit();
				$status = true;
				return $status;
			}
			
			
		}catch (Exception $ex) {
			$db->rollBack();
			throw new Exception($ex->getMessage());
		}	
	}
	
	public function getPaymentProfileById($paymentprofileid)
	{
		try{
			
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('anpp'=>'mt.authnet_payment_profile'),array('anpppayment_profile_id','anpppayment_type'))
				   ->join(array('ancp'=>'mt.authnet_customer_profile'),'ancp.ancpid= anpp.anppcustomer_profile_id',array('ancpcustomer_profile_id'))
				   ->where('anpp.anppid = ?',$paymentprofileid);

		    $row = $table->fetchRow($select);
		    
		    return $row;
			
		}catch(Exception $ex){			
			throw new Exception($ex->getMessage());
		}
	}
	
	public function InActiveRestPaymentProfile(Payments_Model_RestAuthnetPaymentProfileMap $paymentProfileMapObject)
	{
		try{
			$table = $this->getDbTable();
			
			$set   = array('rappmstatus' => $paymentProfileMapObject->getrappminactivestatus(),
					   	   'updateddate' => $paymentProfileMapObject->getupdateddate(),
					   	   'updatedtime' => $paymentProfileMapObject->getupdatedtime(),
					   	   'updatedby'	 => $paymentProfileMapObject->getupdatedby());
				
			$where = array('rappmrestaurant_id = ?'=>$paymentProfileMapObject->getrappmrestaurant_id());
				
			$rows_affected = $table->update($set,$where);
			
			return $rows_affected;
			
		}catch(Exception $ex){			
			throw new Exception($ex->getMessage());
		}
	}
}