<?php
class Payments_Model_SpecialInvoiceDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_SpecialInvoice');
		}
		return $this->_dbTable;
	}
	
	public function CreateSpecialInvoice(Payments_Model_SpecialInvoice  $object)
	{
		try{
			$table = $this->getDbTable();
			$data = array('splinvrestaurant_id'    => $object->getinvrestaurant_id(),
						  'splinvspecial_id'		=> $object->getinvspecial_id(),
						  'splinvcustomer_id'  	=> $object->getinvcustomer_id(),
						  'splinvbooking_id'	    => $object->getinvbooking_id(),
						  'splinvdescription'	    => $object->getinvdescription(),
						  'splinvbilling_fromdate' => $object->getinvbilling_fromdate(),
						  'splinvbilling_todate'	=> $object->getinvbilling_todate(),
						  'splinvamount'			=> $object->getinvamount(),
						  'splinvstatus'			=> $object->getinvstatus(),
						  'splinvgenerated_date'	=> $object->getinvgenerated_date(),
						  'splinvgenerated_time'	=> $object->getinvgenerated_time(),
						  'splinvservice_tax'		=> $object->getinvservice_tax(),
						  'splinvtxncharges'	=> $object->getinvtxncharges());
  
			$result = $table->insert($data);
			
			return $result;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function CheckSpecialInvoiceGenerated(Payments_Model_SpecialInvoice  $invoiceObj)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('splinvid','splinvcustomer_id','splinvspecial_id','splinvbooking_id','splinvamount','splinvdescription','splinvbilling_fromdate','splinvbilling_todate','splinvgenerated_date','splinvgenerated_time'))
				   ->where('splinvrestaurant_id = ?',$invoiceObj->getinvrestaurant_id())
				   ->where('splinvcustomer_id = ?',$invoiceObj->getinvcustomer_id())
				   ->where('splinvbooking_id = ?',$invoiceObj->getinvbooking_id())
				   ->where('splinvbilling_fromdate = ?',$invoiceObj->getinvbilling_fromdate())
				   ->where('splinvbilling_todate = ?',$invoiceObj->getinvbilling_todate())
				   ->where('splinvamount = ?',$invoiceObj->getinvamount())
				   ->where('splinvstatus = ?',$invoiceObj->getinvstatus());
				   
		    $row = $table->fetchRow($select);
		    return $row;
							   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function UpdateSpecialInvoiceStatusById(Payments_Model_UpdateCustomerInvoiceStatusById  $invoiceStatusByIdObject)
	{
		try{
			$table = $this->getDbTable();
			$set = array('splinvstatus' => $invoiceStatusByIdObject->getinvstatus());
			$where = array(	'splinvid = ?' => $invoiceStatusByIdObject->getinvid(),
							'splinvcustomer_id = ?' => $invoiceStatusByIdObject->getcusid(),
							'splinvbooking_id = ?' => $invoiceStatusByIdObject->getbokid(),
							'splinvrestaurant_id = ?' => $invoiceStatusByIdObject->getinvrestaurant_id());

			$rows_affected = $table->update($set,$where);
			
			return $rows_affected;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}

	public function RetrieveSpecialInvoices(Payments_Model_ManageInvoice $manageInvoiceObject)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('inv' => 'mt.customer_invoice'),array('splinvid','splinvspecial_id','splinvrestaurant_id','splinvcustomer_id','splinvbooking_id','splinvdescription','splinvbilling_fromdate','splinvbilling_todate','splinvamount','splinvstatus','splinvservice_tax','splinvtxncharges'))
				   ->join(array('res' => 'mt.restaurant'),'res.resid = inv.invrestaurant_id',array('resrestaurant_name'))
				   ->join(array('usr' =>'mt.user'),'usrid = res.resfk_user',array())
				   ->where('usr.usrid = ?',$manageInvoiceObject->getUserId())
				   ->join(array('invsts' => 'mt.invoicestatus_bd'),'invsts.id = inv.cusinvstatus',array('code as invcode','description as invdesc'));

				   
			if($manageInvoiceObject->getinvoicenum()){
				$select->where('inv.cusinvid = ?',$manageInvoiceObject->getinvoicenum());
			}
			
			if($manageInvoiceObject->getinvoicefromdate() && $manageInvoiceObject->getinvoicetodate()){
				
				$select->where('inv.cusinvbilling_fromdate >= ?',$manageInvoiceObject->getinvoicefromdate());
				$select->where('splinvbilling_todate <= ?',$manageInvoiceObject->getinvoicetodate());
					
			}else if($manageInvoiceObject->getinvoicefromdate()){
				$select->where('inv.cusinvbilling_fromdate = ?',$manageInvoiceObject->getinvoicefromdate());
			}else if($manageInvoiceObject->getinvoicetodate()){
				$select->where('splinvbilling_todate = ?',$manageInvoiceObject->getinvoicetodate());
			}
			
			if($manageInvoiceObject->getinvoicestatus()){
				$select->where('splinvstatus = ?',$manageInvoiceObject->getinvoicestatus());
			}
			
			$rowSet = $table->fetchAll($select);

			return $rowSet;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function RetrieveSpecialInvoiceById(Payments_Model_GetInvoiceDetailsById $getInvoiceDetailsByIdObject)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('splinvid','splinvrestaurant_id','splinvcustomer_id','splinvbooking_id','splinvdescription','splinvbilling_fromdate','splinvbilling_todate','splinvamount','splinvstatus','splinvgenerated_date','splinvgenerated_time','splinvcreated_by','splinvservice_tax','splinvtxncharges','splinvspecial_id'))
				   ->where('splinvid = ?',$getInvoiceDetailsByIdObject->getInvoiceId())
				   ->where('splinvstatus = ?',$getInvoiceDetailsByIdObject->getInvoiceStatus());
		    
		   $row = $table->fetchRow($select);		   
		   return $row;
		   		   			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
}