<?php
class Payments_Model_SpecialTransactionsDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_SpecialTransactions');
		}
		return $this->_dbTable;
	}
	
	public function saveTransactionDetails(array $objectArray)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			$status = false;
			
			$txnObject = $objectArray['txnObject'];			
			$data = array('spltxnfk_restaurant'	  		=> $txnObject->gettxnfk_restaurant(),
						  'spltxnfk_special_id'			=> $txnObject->gettxnfk_Special(),
						  'spltxnfk_customer_id'		=> $txnObject->gettxnfk_Customer(),
						  'spltxnfk_booking_id'			=> $txnObject->gettxnfk_booking(),
						  'spltxntransaction_id'     	=> $txnObject->gettxntransaction_id(),
						  'spltxninvoice_number'     	=> $txnObject->gettxninvoice_number(),
						  'spltxnpayment_profile_id' 	=> $txnObject->gettxnpayment_profile_id(),
						  'spltxntransaction_amount' 	=> $txnObject->gettxntransaction_amount(),
						  'spltxntransaction_date'	  	=> $txnObject->gettxntransaction_date(),
						  'spltxntransaction_time'	  	=> $txnObject->gettxntransaction_time(),
						  'spltxndescription'		  	=> $txnObject->gettxndescription(),
						  'spltxntransaction_type'   	=> $txnObject->gettxntransaction_type(),
						  'spltxnstatus'			 	=> $txnObject->gettxnstatus());

			$table = $this->getDbTable();			
			$txnid = $table->insert($data);
			
			/* Update Invoice status from unpaid to paid */
			
			$UpdateInvoiceStatusByIdObject = $objectArray['updateInveStatusObj'];
			$invoiceMapperObject = new Payments_Model_SpecialInvoiceDataMapper();
			
			$rows_affected = $invoiceMapperObject->UpdateSpecialInvoiceStatusById($UpdateInvoiceStatusByIdObject);
			
			$db->commit();
			$status = true;
			return $status;
			
		} catch (Exception $ex) {
			$db->rollBack();
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getTransactions(Payments_Model_SearchTransaction $searchData, $offset)
	{
		try {
			date_default_timezone_set('Asia/Kolkata');
			$today = date('Y-m-d');
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('txn' => 'mt.transactions'), array('spltxnid','spltxntransaction_id','spltxnpayment_profile_id','spltxntransaction_amount','spltxntransaction_date','spltxntransaction_time','spltxntransaction_type'))
				   ->join(array('paymntprof' => 'mt.authnet_payment_profile'), 'txn.boktxnpayment_profile_id = paymntprof.anppid', array())
				   ->join(array('custprof' => 'mt.authnet_customer_profile'), 'paymntprof.anppcustomer_profile_id = custprof.ancpid', array())
				   ->join(array('txntype' => 'mt.transactiontype_bd'), 'txntype.id = txn.boktxntransaction_type', array('code as txntypecode', 'description as txntypedescription'))
				   ->join(array('inv' => 'mt.customer_invoice'), 'txn.boktxninvoice_number = inv.invid', array('invid as invoice_number'))
				   ->join(array('res'=>'mt.restaurant'),'res.resid = inv.invrestaurant_id',array('resid','resfk_user','resrestaurant_name','resemail','resaddress'))
				   ->join(array('txnstatus' => 'mt.transactionstatus_bd'), 'txn.boktxnstatus = txnstatus.id', array('description as txnstatusdesc'));
			if($searchData->getcustomerprofileid()){
				$select->where('custprof.ancpcustomer_profile_id = ?', $searchData->getcustomerprofileid());
				$limit = 10;
			}else{
				$limit = 20;
			}
			if($searchData->gettxnid()){
				$select->where('txn.boktxntransaction_id = ?', $searchData->gettxnid());
			}
			if($searchData->getpaymentprofileid()){
				$select->where('txn.boktxnpayment_profile_id = ?', $searchData->getpaymentprofileid());
			}
			if ($searchData->getinvnumber()) {
				$select->where('inv.invid = ?', $searchData->getinvnumber());
			}
			if($searchData->getresName()){
				$select->where('res.resrestaurant_name Ilike ?', '%'.$searchData->getresName().'%');
			}
			if($searchData->getresId()){
				$select->where('res.resid = ?', $searchData->getresId());
			}
			
			if($searchData->getstartdate()){
				if($searchData->getstarttime()){
					$select->where('txn.boktxntransaction_date+txn.boktxntransaction_time >= ?', $searchData->getstartdate().' '.$searchData->getstarttime());
				}else{
					$select->where('txn.boktxntransaction_date >= ?', $searchData->getstartdate());
				}			
			} else {
				if($searchData->getstarttime()){
					$select->where('txn.boktxntransaction_date+txn.boktxntransaction_time >= ?', $today.' '.$searchData->getstarttime());
				}
			}
			
			if($searchData->getenddate()){
				if($searchData->getendtime()){
					$select->where('txn.boktxntransaction_date+txn.boktxntransaction_time <= ?', $searchData->getenddate().' '.$searchData->getendtime());
				}else{
					$select->where('txn.boktxntransaction_date <= ?', $searchData->getenddate());
				}			
			} else {
				if($searchData->getendtime()){
					$select->where('txn.boktxntransaction_date+txn.boktxntransaction_time <= ?', $today.' '.$searchData->getendtime());
				}
			}			
			$select->order('txn.boktxntransaction_id DESC');
			//$rowSet = $table->fetchAll($select);
			$rowSet = new Zend_Paginator(
				new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$rowSet->setItemCountPerPage($limit);
			$rowSet->setCurrentPageNumber($offset);
			
			return $rowSet;
		} catch (Exception $ex) {
			throw new Exception($ex->getMessage());
		}
	}
}