<?php
class Payments_Model_SubscriptionPlansMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_SubscriptionPlans');
		}
		return $this->_dbTable;
	}
	
	public function GetSubscriptionPlanDetailsByRestId(Payments_Model_SubscriptionPlanDetailsByRestId $object)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('plan'=>'mt.subscription_plans'),array('spid','spplan_title','spplan_description','spamount','spplan_duration'))
				   ->join(array('restplan'=>'mt.restaurant_payment_plan_map'),'plan.spid = restplan.rppmpayment_plan_id',array('rppmplan_activation_date'))
				   ->where('plan.spplan_status = ?',$object->getspplan_status())
				   ->where('restplan.rppmrestaurant_id = ?',$object->getrppmrestaurant_id())
				   ->where('restplan.rppmstatus = ?',$object->getrppmstatus());

			$rowSet = $table->fetchAll($select);
			return $rowSet; 				   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AddSubscription(Payments_Model_SubscriptionPlans $subscription)
	{
		try{
			$data = array(
							'spplan_title'				=>	$subscription->getspplan_title(),
							'spplan_description'		=>	$subscription->getspplan_description(),
							'spamount'					=>	$subscription->getspamount(),
							'spplan_duration'			=>	$subscription->getspplan_duration(),
							'spplan_status'				=>	$subscription->getspplan_status(),
							'spcreated_date'			=>	$subscription->getspcreated_date(),
							'spcreated_time'			=>	$subscription->getspcreated_time(),
							'spcreated_by'				=>	$subscription->getspcreated_by()
			);
			
			$result = $this->getDbTable()->insert($data);
			return $result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
		
	}
	
	public function EditSubscription(Payments_Model_SubscriptionPlans $subscription)
	{
		try{
			$table = $this->getDbTable();
			$set = array(
							'spplan_title'				=>	$subscription->getspplan_title(),
							'spplan_description'		=>	$subscription->getspplan_description(),
							'spupdated_date'			=>	$subscription->getspupdated_date(),
							'spupdated_time'			=>	$subscription->getspupdated_time(),
							'spupdated_by'				=>	$subscription->getspupdated_by()
			);
			$where = array('spid = ?'=>$subscription->getspid());
			
			
			$rowsEffected = $table->update($set,$where);
			return $rowsEffected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetSubscriptionPlanDetailsById($id)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('plan'=>'mt.subscription_plans'),array('spid','spplan_title','spplan_description','spamount','spplan_duration','spplan_status'))
				   ->where('plan.spid = ?',$id);

			$rowSet = $table->fetchRow($select);
			return $rowSet; 				   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getSubscriptionPlans(Payments_Model_SubscriptionPlans $subscription,$page)
	{
		try{
			$limit = 10;
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from($this->getDbTable(),array('spid','spplan_title','spplan_description','spamount','spplan_duration','spplan_status'))
				   ->join(array('mt.subscriptionplanstatus_bd'),'id = spplan_status',array('description as status'));
			if($subscription->getspplan_title()){
				$select->where('spplan_title Ilike ?','%'.$subscription->getspplan_title().'%');
			}
			if($subscription->getspamount()){
				$select->where('spamount = ?',$subscription->getspamount());
			}
			if($subscription->getspplan_duration()){
				$select->where('spplan_duration = ?',$subscription->getspplan_duration());
			}
			$select->order('spid DESC');
				   
//			$result = $this->getDbTable()->fetchAll($select);
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($page);
//			$resultSet = array();
//			foreach($result as $row){
//				$subscription = new Payments_Model_SubscriptionPlans();
//				$subscription->setspid($row->spid)
//							 ->setspplan_title($row->spplan_title)
//							 ->setspplan_description($row->spplan_description)
//							 ->setspplan_duration($row->spplan_duration)
//							 ->setspamount($row->spamount)
//							 ->setspplan_status($row->status);
//							 
//				$resultSet[] = $subscription;
//			}
			return $resultSet;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditSubscriptionStatus($id,$status)
	{
		try{
			$set = array(
							'spplan_status'				=>	$status
			);
			$where = array('spid = ?'=>$id);
			
			$row = $this->getDbTable()->update($set,$where);
			return $row;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurntsListbySubscriptionPlanId(Admin_Model_SubscriptionPlansSearch $subscription,$page)
	{
		try{
			$limit = 10;
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('plan'=>'mt.subscription_plans'),array('spid','spplan_title','spplan_description','spamount','spplan_duration'))
				   ->joinLeft(array('restplan'=>'mt.restaurant_payment_plan_map'),'plan.spid = restplan.rppmpayment_plan_id',array('rppmplan_activation_date'))
				   ->joinLeft(array('res'=>'mt.restaurant'),'res.resid = restplan.rppmrestaurant_id',array('resid','resfk_user','resrestaurant_name','resemail','resaddress'))
				   ->joinLeft(array('rso'=>'mt.restaurant_owner'),'rso.rsofk_user = res.resfk_user',array('rsofirst_name','rsolast_name'))
				   ->where('plan.spid = ?',$subscription->getId());
				   
			if($subscription->getresName()){
				$select->where('res.resrestaurant_name Ilike ?','%'.$subscription->getresName().'%');
			}
			if($subscription->getfirstName()){
				$select->where('rso.rsofirst_name Ilike ?','%'.$subscription->getfirstName().'%');
			}
			if($subscription->getlastName()){
				$select->where('rso.rsolast_name Ilike ?','%'.$subscription->getlastName().'%');
			}
			if($subscription->getEmail()){
				$select->where('res.resemail Ilike ?','%'.$subscription->getEmail().'%');
			}
			if($subscription->getActDate()){
				$select->where('restplan.rppmplan_activation_date = ?',$subscription->getActDate());
			}
				   
//			$rowSet = $table->fetchAll($select);
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($page);
			
			return $resultSet; 
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function ReterieveSubscriptionPlans($planId,$isAjaxCall)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('spid','spplan_title','spplan_description','spamount'))
				   ->where('spplan_status = ?',true);
			if($planId > 0){
				$select->where('spid = ?',$planId);
				$rowSet = $table->fetchRow($select);
			}else{	   
		    	$rowSet = $table->fetchAll($select);
		    	return $rowSet;
			}
		    $resultSet = array();
		    if($isAjaxCall){
		    	$resultSet = array(
		    						'title'				=>	$rowSet->spplan_title,
		    						'description'		=>	$rowSet->spplan_description,
		    						'amount'			=>	$rowSet->spamount
		    	);
		    	return $resultSet;
		    }    
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}	