<?php
class Payments_Model_SubscriptionRenewalMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_SubscriptionRenewal');
		}
		return $this->_dbTable;
	}
	
	public function saveSubscriptionRenewalDetails(Payments_Model_SubscriptionRenewal $subscriptionRenewalObject)
	{
		try{
			$data = array('srrestaurant_id'    => $subscriptionRenewalObject->getsrrestaurant_id(),
						  'srbilling_date'	   => $subscriptionRenewalObject->getsrbilling_date(),						  
						  'sramount'		   => $subscriptionRenewalObject->getsramount(),
						  'srplan_id'		   => $subscriptionRenewalObject->getsrplan_id(),
						  'srbilling_fromdate' => $subscriptionRenewalObject->getsrbilling_fromdate(),
						  'srbilling_todate'   => $subscriptionRenewalObject->getsrbilling_todate(),
						  'srstatus'		   => $subscriptionRenewalObject->getsrstatus()
						  );

			$table = $this->getDbTable();			  
			$srid  = $table->insert($data);						  
			return $srid;
						  
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveSubscriptionRenewalDetails(Payments_Model_GetSubscriptionRenewalDetails $getSubRenwDetailsObject)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('sr'=>'mt.subscription_renewal'),array('srid','srrestaurant_id','srbilling_date','srbilling_duedate','sramount','srplan_id','srbilling_fromdate','srbilling_todate','srstatus'))
				   ->join(array('sp'=>'mt.subscription_plans'),'sp.spid = sr.srplan_id',array('spid','spplan_title','spplan_description','spamount'))
				   ->join(array('rappm'=>'mt.rest_authnet_payment_profile_map'),'rappm.rappmrestaurant_id = sr.srrestaurant_id',array())
				   ->join(array('anpp'=>'mt.authnet_payment_profile'),'anpp.anppid = rappm.rappmpayment_profile_id',array('anppid','anpppayment_profile_id','anpppayment_type'))
				   ->join(array('ancp'=>'mt.authnet_customer_profile'),'ancp.ancpid = anpp.anppcustomer_profile_id',array('ancpprofile_description','ancpcustomer_profile_id','ancpuser_id','ancpemail'))
				   ->join(array('res'=>'mt.restaurant'),'res.resid = sr.srrestaurant_id',array())
				   ->where('sr.srbilling_fromdate = ?',$getSubRenwDetailsObject->getsrbilling_fromdate())
				   ->where('sr.srstatus = ?',$getSubRenwDetailsObject->getsrstatus())
				   ->where('rappm.rappmstatus = ?',$getSubRenwDetailsObject->getrappmstatus())
				   ->where('anpp.anppstatus = ?',$getSubRenwDetailsObject->getanppstatus())
				   ->where('ancp.ancpstatus = ?',$getSubRenwDetailsObject->getancpstatus())
				   ->where('res.resstatus = ?',1);
				   
			$rowSet = $table->fetchAll($select);
			return $rowSet;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function updateRenewalStatus(Payments_Model_UpdateSubRenewalStatus $updateSubRenewalStatusObject)
	{
		try{			
			$table  = $this->getDbTable();
			$set    = array('srstatus' => $updateSubRenewalStatusObject->getsrstatus());
			$where  = array('srid = ?' => $updateSubRenewalStatusObject->getsrid());			
			$rows_affected = $table->update($set,$where);
			return $rows_affected; 
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateSubscriptionRenewalStatusForOfflinePayments(Payments_Model_SubscriptionRenewal  $SubRenewalStatusObject)
	{
		try{			
			$table  = $this->getDbTable();
			$set    = array('srstatus' => $SubRenewalStatusObject->getsrstatus());
			$where  = array('srid = ?' => $SubRenewalStatusObject->getsrid());			
			$rows_affected = $table->update($set,$where);
			return $rows_affected; 
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkSubscriptionRenewal(Payments_Model_SubscriptionRenewal $subscriptionRenewalObject)
	{
		try
		{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('srid'))
				   ->where('srrestaurant_id = ?',$subscriptionRenewalObject->getsrrestaurant_id())
				   ->where('srbilling_date = ?', $subscriptionRenewalObject->getsrbilling_date());
				   				   
		   $row = $table->fetchRow($select);	
		   		
		   return $row;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveSubRenewalRecordForAdvPay(Payments_Model_SubscriptionRenewal $subscriptionRenewalObject)
	{
		try
		{
			
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('srid','srbilling_date'))
				   ->where('srrestaurant_id = ?',$subscriptionRenewalObject->getsrrestaurant_id())
				   ->where('srbilling_date >= ?', $subscriptionRenewalObject->getsrbilling_date())
				   ->where('srstatus = ?', 29);
				   				   
		   $rowSet = $table->fetchRow($select);	

		   return $rowSet;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}