<?php
/**
*	Name			: CityDataMapper.php
*	Author			: Zubair Ahmed
*	Creation Date	: 10/05/2010
*	Path 			: application/models/CityDataMapper.php
*	Description		: This is the DataMapper class for the city basedata table.
*					   	
*/
class Application_Model_CityDataMapper
{
	/**
	 * Instance variable of city basedata table
	 * @var object
	 */
	protected $_dbTable;

	/**
     * @param instance of DbTable City $dbTable
     * @return self
     */
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	/**
     * @return instance of DbTable City
     */
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_City');
		}
		return $this->_dbTable;
	}

	/**
	 * Fetches all the city basedata rows and saves in cache
	 */
	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$city = array();
		if(!$city = $cache->Fetch('ddcity')){
			$where = array('status = ?'=> true);
			$order = array('description');
			$records = $this->getDbTable()->fetchAll($where,$order);
			
			foreach($records as $record){
				$city[] = new Application_Model_City(
				$record->toArray());
			}
			$cache->Save($city,'ddcity');
		}else{
			$city = $cache->Fetch('ddcity');
		}

		$cache = null;
		return $city;
	}
	
	/**
	 * Get all the city basedata rows by stateid 
	 */
	public function getCityByStateId(Application_Model_City $city)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);

			$stateid = $city->getStateId();

			$select->from(array('cbd'=>'mt.city_bd'),array('id as cityid','description'))
			->join(array('scm'=>'mt.state_city_map'),'cbd.id = scm.city_id')
			->where('scm.state_id = ?',$stateid)
			->where('scm.status = ?',true)
			->where('cbd.status = ?',true)
			->order(array('cbd.description'));

			$records = $table->fetchAll($select);
			$cityList = array();
			$cityList[] = 	array("key"=>"","value"=>"Select City");
			foreach($records as $value){
				$cityList[] = array("key"=>$value->cityid,"value"=>$value->description);
			}
			$city->setCityList($cityList);
			return $city;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * Fetch limited city basedata rows by stateid 
	 */
	public function getCityByStateIdPagnitation(Application_Model_City $city,$offset)
	{
		try{
			$limit = 20;
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);

			$stateid = $city->getStateId();

			$select->from(array('cbd'=>'mt.city_bd'),array('id as cityid','code','description'))
			->join(array('scm'=>'mt.state_city_map'),'cbd.id = scm.city_id')
			->where('scm.state_id = ?',$stateid)
			->order(array('cbd.description'));	

			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
			//$records = $table->fetchAll($select);
			//$cityList = array();
			//$cityList[] = 	array("key"=>"","value"=>"Select City");
			//foreach($records as $value){
			//$cityList[] = array("key"=>$value->cityid,"value"=>$value->description);
			//}
			//$city->setCityList($cityList);
			if($resultSet){
				//$this->clearCity('city');
				return $resultSet;
			}

		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getCityByRegionId(Application_Model_City $city)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);

			$regionid = $city->getRegionId();

			$select->from(array('cbd'=>'mt.city_bd'),array('id as cityid','description'))
			->join(array('rcm'=>'mt.region_city_map'),'cbd.id = rcm.city_id')
			->where('rcm.region_id = ?',$regionid)
			->where('rcm.status = ?',true)
			->where('cbd.status = ?',true)
			->order(array('cbd.description'));

			$records = $table->fetchAll($select);
			$cityList = array();
			$cityList[] = 	array("key"=>"","value"=>"Select City");
			foreach($records as $value){
				$cityList[] = array("key"=>$value->cityid,"value"=>$value->description);
			}
			$city->setCityList($cityList);
			return $city;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function getCityByRegionIdPagnitation(Application_Model_City $city,$offset)
	{
		try{
			$limit = 20;
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);

			$regionid = $city->getRegionId();

			$select->from(array('cbd'=>'mt.city_bd'),array('id as cityid','code','description'))
			->join(array('rcm'=>'mt.region_city_map'),'cbd.id = rcm.city_id')
			->where('rcm.region_id = ?',$regionid)
			->order(array('cbd.description'));	

			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
				if($resultSet){
				return $resultSet;
			}

		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	

	/**
	 * Get city by id 
	 */
	public function getCityById(Application_Model_City $city)
	{
		$cityBd = $this->fetchAll();
		if($cityBd){
			foreach($cityBd as $item){
				if($item->getId() == $city->getId()){
					return $item;
				}
			}
		}
	}

	/**
	 * Edit city details 
	 */
	public function EditCity(Application_Model_City $city)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
		
		$set = array('code' => $city->getCode(),'description' => $city->getDescription());
		$where = $db->quoteInto('id = ?',$city->getId());

		$descStatus = false;
		$codeStatus = false;
		$codeStatus = $this->verifyCode($city->getCode(),$city->getId());
		$descStatus = $this->verifyDesc($city->getDescription(),$city->getId());
		if($descStatus && $codeStatus){
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearCity('city');
			}
		}
			$db->commit();
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
		}
	}
	
	/**
	 * Adding the city to basedata 
	 */
	public function AddCity(Application_Model_City $city)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$cityval = array( 'description' => $city->getDescription(),
						'code' => $city->getCode(),
						'status' => $city->getStatus());


			$descStatus = false;
			$codeStatus = false;
			$codeStatus = $this->verifyCode($city->getCode(),0);
			$descStatus = $this->verifyDesc($city->getDescription(),0);

			if($descStatus && $codeStatus){
				$result = $this->getDbTable()->insert($cityval);
				$mapper = new Application_Model_RegionCityMapDataMapper();
				$table = $mapper->getDbTable();
					
				$citymap = array('region_id' => $city->getRegionId(),
								 'city_id' => $result,
								 'status' => 1);

				$resultmap = $table->insert($citymap);
				if($result && $resultmap){
					$status = true;
					$this->clearCity('city');
				}
			}
			$db->commit();
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
		}

	}

	/**
	 * Update city status 
	 */
	public function UpdateStatus($request)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			if($request->status == "Activate"){
				$status = 1;
			}else{
				$status = 0;
			}
			$set = array('status'=>$status);
			$where = $db->quoteInto('id = ?',$request->city);
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$mapper = new Application_Model_RegionCityMapDataMapper();
				$table = $mapper->UpdateStatus($status,$request->city);
				
			}
			if($result && $table){
				$status = true;
				$this->clearCity('city');
			}
			$db->commit();
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
		}

	}
	/**
	 * Clear city basedata from Cache  
	 */
	public function clearCity($id)
	{
		if($id){
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}

	/**
	 * checks the city code is alredy exists   
	 */
	public function verifyCode($code,$id)
	{
		$select = $this->getDbTable()->select();
		$select->from('mt.city_bd',array('COUNT(id) as count'))
		->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;

		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	/**
	 * checks the city description is alredy exists   
	 */
	public function verifyDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();
		$select->from('mt.city_bd',array('COUNT(id) as count'))
		->where('description ILIKE ?',$desc);
			
		if($id != 0){
			$select->where('id <> ?',$id);
		}

		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}

	}
	
	public function GetCitiesByStateAndRegionId($stateid){
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$StateRegionMapDataMapper = new Application_Model_StateRegionMapDataMapper();			
			$stateRegionTable  = $StateRegionMapDataMapper->getDbTable();
			$stateRegionSelect = $stateRegionTable->select();
			
			$stateRegionSelect->from($stateRegionTable,array('region_id'))
							  ->where('state_id = ?',$stateid)
							  ->where('status = ?',true);
							  
			$regionId = array();				  
			$stateRegRowSet = $stateRegionTable->fetchAll($stateRegionSelect);	

			if($stateRegRowSet){
				foreach($stateRegRowSet as $region){
					$regionId[] = $region->region_id;
				}
			}
			if(count($regionId) > 0){
				$select->from(array('cty'=>'mt.city_bd'),array('id','code as citycode','description as citydesc'))
					   ->join(array('rcm'=>'mt.region_city_map'),'rcm.city_id = cty.id',array())
					   ->where('rcm.region_id IN(?)',$regionId)
					   ->where('cty.status = ?',true)
					   ->order(array('cty.description'));
					   
				$records = 	$table->fetchAll($select) ;  
			}
			$cityList = array();
			$cityList[] = 	array("key"=>"","value"=>"Select City");
			foreach($records as $value){
				$cityList[] = array("key"=>$value->id,"value"=>$value->citydesc);
			}
			return $cityList;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function AddCantFindCity(Application_Model_City $city,$userid)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$cityval = array( 'description' => $city->getDescription(),
						'code' => $city->getCode(),
						'status' => $city->getStatus());
			$result = $this->getDbTable()->insert($cityval);
			
			$mapper = new Application_Model_RegionCityMapDataMapper();
			$table = $mapper->getDbTable();
			
			$citymap = array('region_id' => $city->getRegionId(),
							 'city_id' => $result,
							 'status' => 1);
			$resultmap = $table->insert($citymap);
			if($result && $resultmap){
				$status = true;
				$this->clearCity('city');
				
				$ownerMapper = new User_Model_ManagerDataMapper();
				$ownerTable = $ownerMapper->getDbtable();
				$set = array('rsocityid'	=> $result,
							 'rsocantfind'	=> 0);
				$where = array('rsofk_user = ?' => $userid);
				$rows_affected = $ownerTable->update($set,$where);
			}
			
			$db->commit();
		
			$returnval = false;
		
			if($status){
			$returnval = $result;
			}
			return $returnval;
		}catch(Exception $ex){
			$db->rollBack();
		}

	}
	
	public function AddCantFindRestaurantCity(Application_Model_City $city,$resid)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$cityval = array( 'description' => $city->getDescription(),
						'code' => $city->getCode(),
						'status' => $city->getStatus());
			$result = $this->getDbTable()->insert($cityval);
			
			$mapper = new Application_Model_RegionCityMapDataMapper();
			$table = $mapper->getDbTable();
			
			$citymap = array('region_id' => $city->getRegionId(),
							 'city_id' => $result,
							 'status' => 1);
			$resultmap = $table->insert($citymap);
			if($result && $resultmap){
				$status = true;
				$this->clearCity('city');
				
				$resMapper = new FirmManagement_Model_FirmDataMapper();
				$resTable = $resMapper->getDbtable();
				$set = array('rescity_id'	=> $result);
				$where = array('resid = ?' => $resid);
				$rows_affected = $resTable->update($set,$where);
				
				$reslocMapper = new FirmManagement_Model_FirmNewLocationMapper();
				$reslocTable = $reslocMapper->getDbtable();
				$setloc = array('rnl_location_count'	=> 1);
				$whereloc = array('rnl_fk_restaurant = ?' => $resid);
				$rows_affected = $reslocTable->update($setloc,$whereloc);
			}
			
			$db->commit();
		
			$returnval = false;
		
			if($status){
			$returnval = $result;
			}
			return $returnval;
		}catch(Exception $ex){
			$db->rollBack();
		}

	}
	
	public function getCitysBycityIds($cityIds)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('id','code','description','status','state_id'))
				   ->where('id IN (?)',$cityIds);	
			$resultset = $table->fetchAll($select);
			$resultArr  = array();
			foreach($resultset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					$subArr[$key1]= $value1;
				}
				$resultArr[] = $subArr;
			}
			return $resultArr;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
}



