<?php
/**
*	Name			: StateDataMapper.php
*	Author			: mahesh 
*	Creation Date	: 9/30/2010
*	Path 			: application/models/StateDataMapper.php
*	Description		: This is the DataMapper class for the state basedata table.
*					   	
*/
class Application_Model_StateDataMapper
{
	protected $_dbTable;
	
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_State');
		}
		return $this->_dbTable;
	}
	
	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$states = array();
		if(!$states = $cache->Fetch('states')){
			$where = array('status = ?'=> true);
			$records = $this->getDbTable()->fetchAll($where);
						
			foreach($records as $record){
				$states[] = new Application_Model_State(						
					$record->toArray());	
			}
			$cache->Save($states,'states');			
		}else{
			$states = $cache->Fetch('states');
		}
		
		$cache = null;
		return $states;
	}
	
	public function getStates($offset)
	{
		$limit = 20;
		$restype = array();
		$select = $this->getDbTable()->select();
		$select->from('mt.state_bd',array('id','code','description','status'))
		       ->order(array('code','description'));		
		//$records = $this->getDbTable()->fetchAll($select);
		$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
		$resultSet->setItemCountPerPage($limit);
		$resultSet->setCurrentPageNumber($offset);			
		
		return $resultSet;
	}
	
	public function AddState(Application_Model_State $stateObj)
	{
		$state = array(
			'code'			=> $stateObj->getCode(),
			'description'	=> $stateObj->getDescription(),
			'status'		=> true
		);
		
		/* Check to see that values exist in system */
		
		$codeStatus = false;
		$descStatus = false;
		
		$codeStatus = $this->verifyCode($stateObj->getCode(),0);
		$descStatus = $this->verifyDesc($stateObj->getDescription(),0);
		
		$status = false;
		if($codeStatus && $descStatus){
			$result = $this->getDbTable()->insert($state);
			if($result){
				$status = true;
				$this->clearRestType('states');
			}	
		}		
		return $status;
	}
	
	public function EditState(Application_Model_State $stateObj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$set = array('code' 	   => $stateObj->getCode(),
					 'description' => $stateObj->getDescription()
		);
		
		$codeStatus = $this->verifyCode($stateObj->getCode(),$stateObj->getId());
		$descStatus = $this->verifyDesc($stateObj->getDescription(),$stateObj->getId());
		
		if($codeStatus && $descStatus){
			$where = $db->quoteInto('id = ?',$stateObj->getId());
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearRestType('states');
			}
		}	
		return $status;
	}
	
	public function clearRestType($id)
	{
		if($id){				
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}
	
	public function verifyCode($code,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.state_bd',array('COUNT(id) as count'))
		       ->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}		       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function verifyDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.state_bd',array('COUNT(id) as count'))
		       ->where('description ILIKE ?',$desc);
		       
		if($id != 0){
			$select->where('id <> ?',$id);
		}
				       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
		
	}
	
	public function UpdateStatus($request)
	{
		if($request->stus == 'DeActivate'){
			$data = array('status' => 0);
		}else if($request->stus == 'Activate'){
			$data = array('status' => 1);
		}
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$where = $db->quoteInto('id = ?', $request->id);
		$result = $this->getDbTable()->update($data,$where);
		if($result){
			$this->clearRestType('states');
		}
		return $result;
	}
	
	/**
	 * Get city by id 
	 */
	public function getStateById(Application_Model_State  $state)
	{
		$StateBd = $this->fetchAll();
		if($StateBd){
			foreach($StateBd as $item){
				if($item->getId() == $state->getId()){
					return $item;
				}
			}
		}
	}

}

