<?php

class Application_Model_DiscountModeDataMapper
{
	protected $_dbTable;
	
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_DiscountMode');
		}
		return $this->_dbTable;
	}
	public function getDiscountMode($offset)
	{
		$limit = 20;
		$restype = array();
		$select = $this->getDbTable()->select();
		$select->from('mt.discount_mode_bd',array('id','code','description','status'))
		       ->order(array('id'));		
		//$records = $this->getDbTable()->fetchAll($select);
		$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
		$resultSet->setItemCountPerPage($limit);
		$resultSet->setCurrentPageNumber($offset);			
		
		return $resultSet;
	}
	
	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$discount = array();
		if(!$discount = $cache->Fetch('discountmode')){
			$where = array('status = ?'=> true);
			$records = $this->getDbTable()->fetchAll($where);
						
			foreach($records as $record){
				$discount[] = new Application_Model_DiscountMode(						
					$record->toArray());	
			}
			$cache->Save($discount,'discountmode');			
		}else{
			$discount = $cache->Fetch('discountmode');
		}
		$cache = null;
		return $discount;
	}
	public function EditDiscountMode(Application_Model_DiscountMode $spclDisc)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$set = array('description' => $spclDisc->getDescription()
		);
		
		$descStatus = $this->verifyspclDesc($spclDisc->getDescription(),$spclDisc->getId());
		if($descStatus){
			$where = $db->quoteInto('id = ?',$spclDisc->getId());
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearDiscountMode('discountmode');
			}
		}	
		return $status;
	}
	public function AddDiscountMode(Application_Model_DiscountMode $spclDiscObj)
	{
		$spclDiscount = array(
			'code'			=> $spclDiscObj->getCode(),
			'description'	=> $spclDiscObj->getDescription(),
			'status'		=> 1
		);
		
		/* Check to see that values exist in system */
		
		$codeStatus = false;
		$descStatus = false;
		
		$codeStatus = $this->verifyspclCode($spclDiscObj->getCode(),0);
		$descStatus = $this->verifyspclDesc($spclDiscObj->getDescription(),0);
		
		$status = false;
		if($codeStatus && $descStatus){
			$result = $this->getDbTable()->insert($spclDiscount);
			if($result){
				$status = true;
				$this->clearDiscountMode('discountmode');
			}	
		}		
		return $status;
	}
	public function clearDiscountMode($id)
	{
		if($id){				
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}
	
	public function verifyspclCode($code,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.discount_mode_bd',array('COUNT(id) as count'))
		       ->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}		       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function verifyspclDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.discount_mode_bd',array('COUNT(id) as count'))
		       ->where('description ILIKE ?',$desc);
		       
		if($id != 0){
			$select->where('id <> ?',$id);
		}
				       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
		
	}
	public function UpdateStatus($request)
	{
		if($request->stus == 'DeActivate'){
			$data = array('status' => 0);
		}else if($request->stus == 'Activate'){
			$data = array('status' => 1);
		}
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$where = $db->quoteInto('id = ?', $request->id);
		$result = $this->getDbTable()->update($data,$where);
		if($result){
			$this->clearDiscountMode('discountmode');
		}
		return $result;
	}
}