<?php
/**
*	Name			: EmailtemplateDataMapper.php
*	Author			: Zubair Ahmed
*	Creation Date	: 11/07/2010
*	Path 			: application/models/EmailtemplateDataMapper.php
*	Description		: This is the DataMapper class for the email template basedata table.
*					   	
*/
class Application_Model_EmailtemplateDataMapper
{
	/**
	 * Instance variable of emailtemplate basedata table
	 * @var object
	 */
	protected $_dbTable;
	
	/**
     * @param instance of DbTable emailtemplate $dbTable
     * @return self
     */
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	/**
     * @return instance of DbTable emailtemplate
     */
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_Emailtemplate');
		}
		return $this->_dbTable;
	}
	
	/**
	 * Fetches all the emailtemplate basedata rows and saves in cache
	 */
	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$emailtemplates = array();
		if(!$emailtemplates = $cache->Fetch('emailtemplate')){
			$where = array('status = ?'=> true);
			$records = $this->getDbTable()->fetchAll($where);
						
			foreach($records as $record){
				$emailObj = new Application_Model_Emailtemplate();
				$emailObj->setId($record['id'])
						 ->setCode($record['code'])
						 ->setmsg_subject($record['msg_subject'])
						 ->setmsg_body($record['msg_body'])
						 ->setStatus($record['status']);	 
				$emailtemplates[] = $emailObj;	
			}
			$cache->Save($emailtemplates,'emailtemplate');			
		}else{
			$emailtemplates = $cache->Fetch('emailtemplate');
		}
		
		$cache = null;
		return $emailtemplates;
	}
	
	/**
	 *Get emailtemplate by Id 
	 */
	public function getEmailtemplateById(Application_Model_Emailtemplate $template)
	{
	$emailtemplateBd = $this->fetchAll();
		if($emailtemplateBd){
			foreach($emailtemplateBd as $item){
				if($item->getId() == $template->getId()){
					return $item;
				} 
			}
		}
	}
	
	/**
	 *Get emailtemplate by Code 
	 */
	public function getEmailTempByCode($code)
	{
		$templates = $this->fetchAll();
		if($templates){
			foreach($templates as $template){
				if($template->code == $code){
					return $template;
				}
			}
		}
	}


	public function getAllEmailTemplates($page=null,$cols=null)
	{
		try{
			$limit = 10;
			$table = $this->getDbTable();
			$select = $table->select();
			if($cols!=null)
			{
				$select = $select->from(array('mt.emailtemplate_bd'),$cols);
			}
			$select->order('code ASC');
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			if($page == null)
			{
				$page = 1;
			}
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($page);
			return $resultSet;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}

	public function getEmailTemplatesByEId($id,$cols=null)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			if($cols!=null)
			{
				$select = $select->from(array('mt.emailtemplate_bd'),$cols);
			}
			$select->where('id = ?',$id);
			$result = $select->query()->fetchAll();
			if(count($result)>0)
			{
				return $result[0];
			}
			return $result;
		}
		catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function updateEmailTemplate($details,$where)
	{
		try
		{
			$table = $this->getDbTable();
			$result = $table->update($details,$where);
			$this->clearEmailCache();
			return $result;
		}
		catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function addEmailTemplate($details)
	{
		try
		{
			$details['status'] = 1;
			$table = $this->getDbTable();
			$result = $table->insert($details);
			$this->clearEmailCache();
			return $result;
		}
		catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * UPDATE EMAIL TEMPLATE CACHE
	 */
	public function clearEmailCache()
	{
		$cache = new Uss_Helper_CacheManager();
		$cache->Clear('emailtemplate');	
		$cache = null;
	}
	
}