<?php
/**
*	Name			: NeighborhoodDataMapper.php
*	Author			: Zubair Ahmed
*	Creation Date	: 10/05/2010
*	Path 			: application/models/NeighborhoodDataMapper.php
*	Description		: This is the DataMapper class for the neighborhood basedata table.
*					   	
*/
class Application_Model_NeighborhoodDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_Neighborhood');
		}
		return $this->_dbTable;
	}

	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$neighborhood = array();
		if(!$neighborhood = $cache->Fetch('ddneighborhood')){
			$where = array('status = ?'=> true);
			$records = $this->getDbTable()->fetchAll($where);

			foreach($records as $record){
				$neighborhood[] = new Application_Model_Neighborhood(
				$record->toArray());
			}
			$cache->Save($neighborhood,'ddneighborhood');
		}else{
			$neighborhood = $cache->Fetch('ddneighborhood');
		}

		$cache = null;
		return $neighborhood;
	}
	
	public function getNghByCityId(Application_Model_Neighborhood $ngh)
	{
		try{
			$cityid = $ngh->getCityId();
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('id','description'))
			->where('city_id = ?',$cityid)
			->where('status = ?',true)
			->order(array('description'));
			
			/*$select = "select ngh.id,ngh.description from
			 mt.neighborhood_bd ngh
			 where ngh.city_id = ".$cityid."
			 and ngh.status = true";*/
			$records = $table->fetchAll($select);
			$nghList = array();
			$nghList[] = array("key"=>"","value"=>"Select Neighborhood");
			foreach($records as $value){
				$nghList[] = array("key"=>$value['id'],"value"=>$value['description']);
			}
			$ngh->setNeighborhoodList($nghList);
			return $ngh;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getNeighbourByCityId(Application_Model_Neighborhood $ngh,$offset)
	{
		try{
			$limit = 20;
			$cityid = $ngh->getCityId();
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('id','description','status'))
			->where('city_id = ?',$cityid)
			->order(array('description'));
			//$records = $table->fetchAll($select);
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
				
			$nghList = array();

			//foreach($records as $value){
			//	$nghList[] = array("key"=>$value['id'],"value"=>$value['description']."#".$value['status']);
			//}
		//	$ngh->setNeighborhoodList($nghList);
			//return $ngh;
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function EditNeighbourHood(Application_Model_Neighborhood $neighObj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$set = array('description' => $neighObj->getDescription());
		$where = $db->quoteInto('id = ?',$neighObj->getId());
		
		$descStatus = false;
		$descStatus = $this->verifyDesc($neighObj->getDescription(),$neighObj->getCityId());
		if($descStatus){
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearNeighbor('neighborhood');
			}
		}
		return $status;
	}
	
	public function UpdateStatus($request)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		if($request->status == "Activate"){
			$status = 1;
		}else{
			$status = 0;
		}
		$set = array('status'=>$status);
		$where = $db->quoteInto('id = ?',$request->neighid);
		$result = $this->getDbTable()->update($set,$where);
		if($result){
			$status = true;
			$this->clearNeighbor('neighborhood');
		} 
		return $status;
		
	}
	
	public function AddNeighbourHood(Application_Model_Neighborhood $neighObj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$neigh = array( 'description' => $neighObj->getDescription(),
						'status' => $neighObj->getStatus(),
						'city_id' => $neighObj->getCityId());

		$descStatus = false;
		$descStatus = $this->verifyDesc($neighObj->getDescription(),$neighObj->getCityId());
		
		if($descStatus){
			$result = $this->getDbTable()->insert($neigh);
			if($result){
				$status = true;
				$this->clearNeighbor('neighborhood');
			}
		}
		return $status;
	}
	
	public function clearNeighbor($id)
	{
		if($id){
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}

	public function verifyDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();
		$select->from('mt.neighborhood_bd',array('COUNT(id) as count'))
		->where('description ILIKE ?',$desc);
			
		if($id != 0){
			$select->where('city_id = ?',$id);
		}

		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function verifyCode($code,$id)
	{
		$select = $this->getDbTable()->select();
		$select->from('mt.neighborhood_bd',array('COUNT(id) as count'))
		->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;

		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function getNeighborhoodsByneighborhoodIds($neighborIds)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('id','city_id','description','status'))
				   ->where('id IN (?)',$neighborIds);	
			$resultset = $table->fetchAll($select);
			$resultArr  = array();
			foreach($resultset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					$subArr[$key1]= $value1;
				}
				$resultArr[] = $subArr;
			}
			return $resultArr;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function AddCantFindRestaurantNeighbour(Application_Model_Neighborhood  $neigh,$resid)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$neighval = array( 'description' => $neigh->getDescription(),
						'city_id' => $neigh->getCityId(),
						'status' => $neigh->getStatus());
			$result = $this->getDbTable()->insert($neighval);
			
			if($result ){
				$status = true;
				$this->clearNeighbor('neighborhood');
				
				$resMapper = new FirmManagement_Model_FirmDataMapper();
				$resTable = $resMapper->getDbtable();
				$set = array('resneighborhood_id'	=> $result);
				$where = array('resid = ?' => $resid);
				$rows_affected = $resTable->update($set,$where);
				
				$reslocMapper = new FirmManagement_Model_FirmNewLocationMapper();
				$reslocTable = $reslocMapper->getDbtable();
				$setloc = array('rnl_location_count'	=> 0,'rnl_status'=>'F');
				$whereloc = array('rnl_fk_restaurant = ?' => $resid);
				$rows_affected = $reslocTable->update($setloc,$whereloc);
			}
			
			$db->commit();
		
			$returnval = false;
		
			if($status){
			$returnval = $result;
			}
			return $returnval;
		}catch(Exception $ex){
			$db->rollBack();
		}

	}
}