<?php
/**
*	Name			: PriceDataMapper.php
*	Author			: kartheek
*	Creation Date	: 10/10/2010
*	Path 			: application/models/PriceDataMapper.php
*	Description		: This is the DataMapper class for the price basedata table.
*					   	
*/
class Application_Model_PriceDataMapper
{
	protected $_dbTable;
	
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_Price');
		}
		return $this->_dbTable;
	}
	
	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$prices = array();
		if(!$prices = $cache->Fetch('ddprices')){
			$where = array('status = ?'=> true);
			$order = array('id');
			$records = $this->getDbTable()->fetchAll($where,$order);
						
			foreach($records as $record){
				$prices[] = new Application_Model_Price(						
					$record->toArray());	
			}
			$cache->Save($prices,'ddprices');			
		}else{
			$prices = $cache->Fetch('ddprices');
		}
		
		$cache = null;
		return $prices;
	}
	
	public function getPriceTypes($offset)
	{
		$limit = 20;
		$pricetype = array();
		$select = $this->getDbTable()->select();
		$select->from('mt.price_bd',array('id','code','description','status'))
		       ->order(array('code','description'));		
		///$records = $this->getDbTable()->fetchAll($select);			
		
		$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
		$resultSet->setItemCountPerPage($limit);
		$resultSet->setCurrentPageNumber($offset);			
		
		return $resultSet;
	}
	
	public function addPrice(Application_Model_Price $priceObj)
	{
		$pricetype = array(
			'code'			=> $priceObj->getCode(),
			'description'	=> $priceObj->getDescription(),
			'status'		=> 1
		);
		
		/* Check to see that values exist in system */
		
		$codeStatus = false;
		$descStatus = false;
		
		$codeStatus = $this->verifyCode($priceObj->getCode(),0);
		$descStatus = $this->verifyDesc($priceObj->getDescription(),0);
		
		$status = false;
		if($codeStatus && $descStatus){
			$result = $this->getDbTable()->insert($pricetype);
			if($result){
				$status = true;
				$this->clearRestType('prices');
			}	
		}		
		return $status;
	}
	
	public function clearRestType($id)
	{
		if($id){				
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}
	
	public function verifyCode($code,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.price_bd',array('COUNT(id) as count'))
		       ->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}		       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function verifyDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.price_bd',array('COUNT(id) as count'))
		       ->where('description ILIKE ?',$desc);
		       
		if($id != 0){
			$select->where('id <> ?',$id);
		}
				       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function EditPrice(Application_Model_Price $priceObj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$set = array('code' 	   => $priceObj->getCode(),
					 'description' => $priceObj->getDescription()
		);
		
		$codeStatus = $this->verifyCode($priceObj->getCode(),$priceObj->getId());
		$descStatus = $this->verifyDesc($priceObj->getDescription(),$priceObj->getId());
		
		if($codeStatus && $descStatus){
			$where = $db->quoteInto('id = ?',$priceObj->getId());
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearRestType('prices');
			}
		}	
		return $status;
	}
	
	public function UpdateStatus($request)
	{
		if($request->stus == 'DeActivate'){
			$data = array('status' => 0);
		}else if($request->stus == 'Activate'){
			$data = array('status' => 1);
		}
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$where = $db->quoteInto('id = ?', $request->id);
		$result = $this->getDbTable()->update($data,$where);
		if($result){
			$this->clearRestType('prices');
		}
		return $result;
	}
}