<?php

class Application_Model_RegionDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_Region');
		}
		return $this->_dbTable;
	}

	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$region = array();
		if(!$region = $cache->Fetch('ddregion')){
			$where = array('status = ?'=> true);
			$order = array('description');
			$records = $this->getDbTable()->fetchAll($where,$order);
			
			foreach($records as $record){
				$region[] = new Application_Model_Region(
				$record->toArray());
			}
			$cache->Save($region,'ddregion');
		}else{
			$region = $cache->Fetch('ddregion');
		}

		$cache = null;
		return $region;
	}
	
	public function getRegionByStateId(Application_Model_Region $region)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);

			$stateid = $region->getStateId();

			$select->from(array('rbd'=>'mt.region_bd'),array('id as regionid','description'))
			->join(array('srm'=>'mt.state_region_map'),'rbd.id = srm.region_id')
			->where('srm.state_id = ?',$stateid)
			->where('srm.status = ?',true)
			->where('rbd.status = ?',true)
			->order(array('rbd.description'));

			$records = $table->fetchAll($select);
			$regionList = array();
			$regionList[] = 	array("key"=>"","value"=>"Select State");
			foreach($records as $value){
				$regionList[] = array("key"=>$value->regionid,"value"=>$value->description);
			}
			$region->setRegionList($regionList);
			return $region;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function getRegionByStateIdPagnitation(Application_Model_Region $region,$offset)
	{
		try{
			$limit = 20;
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);

			$stateid = $region->getStateId();

			$select->from(array('rbd'=>'mt.region_bd'),array('id as regionid','code','description'))
			->join(array('srm'=>'mt.state_region_map'),'rbd.id = srm.region_id')
			->where('srm.state_id = ?',$stateid)
			->order(array('rbd.description'));	

			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
				if($resultSet){
				
				return $resultSet;
			}

		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function getRegionById(Application_Model_Region $region)
	{
		$regionBd = $this->fetchAll();
		if($regionBd){
			foreach($regionBd as $item){
				if($item->getId() == $region->getId()){
					return $item;
				}
			}
		}
	}

	public function EditRegion(Application_Model_Region $region)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
		
		$set = array('code' => $region->getCode(),'description' => $region->getDescription());
		$where = $db->quoteInto('id = ?',$region->getId());

		$descStatus = false;
		$codeStatus = false;
		$codeStatus = $this->verifyCode($region->getCode(),$region->getId());
		$descStatus = $this->verifyDesc($region->getDescription(),$region->getId());
		if($descStatus && $codeStatus){
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearRegion('region');
			}
		}
			$db->commit();
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
		}
	}
	
	public function AddRegion(Application_Model_Region $region)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$regionval = array( 'description' => $region->getDescription(),
						'code' => $region->getCode(),
						'status' => $region->getStatus());


			$descStatus = false;
			$codeStatus = false;
			$codeStatus = $this->verifyCode($region->getCode(),0);
			$descStatus = $this->verifyDesc($region->getDescription(),0);

			if($descStatus && $codeStatus){
				$result = $this->getDbTable()->insert($regionval);
				$mapper = new Application_Model_StateRegionMapDataMapper();
				$table = $mapper->getDbTable();
					
				$regionmap = array('state_id' => $region->getStateId(),
								 'region_id' => $result,
								 'status' => 1);

				$resultmap = $table->insert($regionmap);
				if($result && $resultmap){
					$status = true;
					$this->clearRegion('region');
				}
			}
			$db->commit();
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
		}

	}

	public function UpdateStatus($request)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			if($request->status == "Activate"){
				$status = 1;
			}else{
				$status = 0;
			}
			$set = array('status'=>$status);
			$where = $db->quoteInto('id = ?',$request->region);
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$mapper = new Application_Model_StateRegionMapDataMapper();
				$table = $mapper->UpdateStatus($status,$request->region);
				
			}
			if($result && $table){
				$status = true;
				$this->clearRegion('region');
			}
			$db->commit();
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
		}

	}

	public function clearRegion($id)
	{
		if($id){
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}

	public function verifyCode($code,$id)
	{
		$select = $this->getDbTable()->select();
		$select->from('mt.region_bd',array('COUNT(id) as count'))
		->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;

		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function verifyDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();
		$select->from('mt.region_bd',array('COUNT(id) as count'))
		->where('description ILIKE ?',$desc);
			
		if($id != 0){
			$select->where('id <> ?',$id);
		}

		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}

	}

	public function AddCantFindRegion(Application_Model_Region $region,$userid)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$regionval = array( 'description' => $region->getDescription(),
						'code' => $region->getCode(),
						'status' => $region->getStatus());

			$result = $this->getDbTable()->insert($regionval);
			$mapper = new Application_Model_StateRegionMapDataMapper();
			$table = $mapper->getDbTable();
			$regionmap = array('state_id' => $region->getStateId(),
							 'region_id' => $result,
							 'status' => 1);
			$resultmap = $table->insert($regionmap);
			if($result && $resultmap){
				$status = true;
				$this->clearRegion('region');
				
				$ownerMapper = new User_Model_ManagerDataMapper();
				$ownerTable = $ownerMapper->getDbtable();
				$set = array('rsoregionid'	=> $result,
							 'rsocantfind'	=> 1);
				$where = array('rsofk_user = ?' => $userid);
				$rows_affected = $ownerTable->update($set,$where);
			}
		$db->commit();
		
		$returnval = false;
		if($status){
		$returnval = $result;
		}
		return $returnval;
		
		}catch(Exception $ex){
			$db->rollBack();
		}
	}
	
	public function AddCantFindRestaurantRegion(Application_Model_Region $region,$resid)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$regionval = array( 'description' => $region->getDescription(),
						'code' => $region->getCode(),
						'status' => $region->getStatus());

			$result = $this->getDbTable()->insert($regionval);
			$mapper = new Application_Model_StateRegionMapDataMapper();
			$table = $mapper->getDbTable();
			$regionmap = array('state_id' => $region->getStateId(),
							 'region_id' => $result,
							 'status' => 1);
			$resultmap = $table->insert($regionmap);
			if($result && $resultmap){
				$status = true;
				$this->clearRegion('region');
				
				$resMapper = new FirmManagement_Model_FirmDataMapper();
				$resTable = $resMapper->getDbtable();
				$set = array('resregion_id'	=> $result);
				$where = array('resid = ?' => $resid);
				$rows_affected = $resTable->update($set,$where);
				
				$reslocMapper = new FirmManagement_Model_FirmNewLocationMapper();
				$reslocTable = $reslocMapper->getDbtable();
				$setloc = array('rnl_location_count'	=> 2);
				$whereloc = array('rnl_fk_restaurant = ?' => $resid);
				$rows_affected = $reslocTable->update($setloc,$whereloc);
			}
		$db->commit();
		
		$returnval = false;
		if($status){
		$returnval = $result;
		}
		return $returnval;
		
		}catch(Exception $ex){
			$db->rollBack();
		}

	}
	public function getRegionsByregionIds($regionIds)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('id','code','description','status'))
				   ->where('id IN (?)',$regionIds);	
			$resultset = $table->fetchAll($select);
			$resultArr  = array();
			foreach($resultset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					$subArr[$key1]= $value1;
				}
				$resultArr[] = $subArr;
			}
			return $resultArr;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
}



