<?php
/**
*	Name			: RestaurantTypeDataMapper.php
*	Author			: snehal
*	Creation Date	: 9/30/2010
*	Path 			: application/models/RestaurantTypeDataMapper.php
*	Description		: This is the DataMapper class for the restaurant type basedata table.
*					   	
*/
class Application_Model_RestaurantTypeDataMapper
{
	protected $_dbTable;
	
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_RestaurantType');
		}
		return $this->_dbTable;
	}
	
	public function getRestauranttypeBD()
	{
		$cache = new Uss_Helper_CacheManager();
		$restype = array();
		
		if(!$restype = $cache->Fetch('restype_bd')){
			$where = array('status = ?'=> true);
			$order = array('description');
			$records = $this->getDbTable()->fetchAll($where,$order);
			
			foreach($records as $record){
				$restype[] = new Application_Model_RestaurantType(						
					$record->toArray());	
			}
			$cache->Save($restype,'restype_bd');			
		}else{
			$restype = $cache->Fetch('restype_bd');
		}
		
		$cache = null;
		return $restype;
	}
	public function getRestaurantTypes($offset)
	{
		$limit = 20;
		$restype = array();
		$select = $this->getDbTable()->select();
		$select->from('mt.restaurant_type_bd',array('id','code','description','status'))
		       ->order(array('code','description'));		
		//$records = $this->getDbTable()->fetchAll($select);
		$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
		$resultSet->setItemCountPerPage($limit);
		$resultSet->setCurrentPageNumber($offset);			
		
		return $resultSet;
	}
	public function EditRestauranttype(Application_Model_RestaurantType $resTypeObj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$set = array('code' 	   => $resTypeObj->getCode(),
					 'description' => $resTypeObj->getDescription()
		);
		
		$codeStatus = $this->verifyCode($resTypeObj->getCode(),$resTypeObj->getId());
		$descStatus = $this->verifyDesc($resTypeObj->getDescription(),$resTypeObj->getId());
		
		if($codeStatus && $descStatus){
			$where = $db->quoteInto('id = ?',$resTypeObj->getId());
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearRestType('restype_bd');
			}
		}	
		return $status;
	}
	
	public function DeleteResTypes($id)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$data = array('status' => 0);
		$where = $db->quoteInto('id = ?',$id);
		$result = $this->getDbTable()->update($data,$where);
		if($result){
			$this->clearRestType('restype_bd');
		}
		return $result;
	}
	
	public function AddResTypes(Application_Model_RestaurantType $resTypeObj)
	{
		$resType = array(
			'code'			=> $resTypeObj->getCode(),
			'description'	=> $resTypeObj->getDescription(),
			'status'		=> 1
		);
		
		/* Check to see that values exist in system */
		
		$codeStatus = false;
		$descStatus = false;
		
		$codeStatus = $this->verifyCode($resTypeObj->getCode(),0);
		$descStatus = $this->verifyDesc($resTypeObj->getDescription(),0);
		
		$status = false;
		if($codeStatus && $descStatus){
			$result = $this->getDbTable()->insert($resType);
			if($result){
				$status = true;
				$this->clearRestType('restype_bd');
			}	
		}		
		return $status;
	}
	
	public function clearRestType($id)
	{
		if($id){				
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}
	
	public function verifyCode($code,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.restaurant_type_bd',array('COUNT(id) as count'))
		       ->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}		       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function verifyDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.restaurant_type_bd',array('COUNT(id) as count'))
		       ->where('description ILIKE ?',$desc);
		       
		if($id != 0){
			$select->where('id <> ?',$id);
		}
				       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
		
	}
	
	public function UpdateStatus($request)
	{
		if($request->stus == 'DeActivate'){
			$data = array('status' => 0);
		}else if($request->stus == 'Activate'){
			$data = array('status' => 1);
		}
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$where = $db->quoteInto('id = ?', $request->id);
		$result = $this->getDbTable()->update($data,$where);
		if($result){
			$this->clearRestType('restype_bd');
		}
		return $result;
	}

}

