<?php
/**
*	Name			: RoleDataMapper.php
*	Author			: snehal
*	Creation Date	: 2/4/2011
*	Path 			: application/models/RoleDataMapper.php
*	Description		: This is the DataMapper class for the role basedata table.
*					   	
*/
class Application_Model_RoleDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_Role');
		}
		return $this->_dbTable;
	}

	public function getAllRolesByRestId($resid, $offset)
	{
		try{
			$limit = 15;
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('rol'=>'mt.role_bd'),array('id','code','description','rolfk_restaurant_id','status'))
				   ->joinLeft(array('res'=>'mt.restaurant'),'res.resid = rol.rolfk_restaurant_id',array('resrestaurant_name'))
				   ->where("rol.rolfk_typeid = 4 OR rol.rolfk_restaurant_id = ?",$resid)
				   ->order(array('rol.id'));	
			//$result = $table->fetchAll($select);
			//$roleList = array();
//			foreach($result as $roles){
//				$roleid = $roles->id;
//				$rolecode = $roles->code;
//				$roleDesc = $roles->description;
//				$rolResid = $roles->rolfk_restaurant_id;
//				$rolstatus = $roles->status;
//				$name = $roles->resrestaurant_name;
//				$rolid = (string)$roles->id;
//				$roleList[$rolid] = array(
//											'roleid'		=> $roleid,
//											'rolecode'		=> $rolecode,
//											'roleDesc'		=> $roleDesc,
//											'rolResid'		=> $rolResid,
//											'resName'		=> $name, 
//											'rolstatus'		=> $rolstatus,
//				);
//			}
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);

			return $resultSet;
			//return $roleList;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getRolesByRestId($resid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
				   
			$select->from(array('rol'=>'mt.role_bd'),array('id','code','description','rolfk_restaurant_id','status'))
				   ->joinLeft(array('res'=>'mt.restaurant'),'res.resid = rol.rolfk_restaurant_id',array('resrestaurant_name'))
				   ->where("rol.rolfk_typeid = 4 OR rol.rolfk_restaurant_id = ?",$resid)
				   ->where('rol.status = ?',true)
				   ->order(array('rol.id'));
      //$sql = $select->__toString();
      //echo "$sql\n";	exit;
			$result = $table->fetchAll($select);
			$roleList = array();
			foreach($result as $roles){
				$roleid = $roles->id;
				$rolecode = $roles->code;
				$roleDesc = $roles->description;
				$rolResid = $roles->rolfk_restaurant_id;
				$rolstatus = $roles->status;
				$name = $roles->resrestaurant_name;
				$rolid = (string)$roles->id;
				$roleList[$rolid] = array(
											'roleid'		=> $roleid,
											'rolecode'		=> $rolecode,
											'roleDesc'		=> $roleDesc,
											'rolResid'		=> $rolResid,
											'resName'		=> $name, 
											'rolstatus'		=> $rolstatus
				);
			}
			return $roleList;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getRolesByRoleId($roleid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('rol'=>'mt.role_permission_map'),array('rpm_roleid','rpm_permissiontype_id'))
				   ->join(array('rolbd'=>'mt.role_bd'),'rolbd.id = rol.rpm_roleid',array('code','description'))	   
				   ->join(array('rolper'=>'mt.permissionstype_bd'),'rolper.id = rol.rpm_permissiontype_id',array('code as permcode','description as permdesc'))
				   ->where('rol.rpm_roleid = ?',$roleid);
				   //->where('rolbd.status = ?',true);	
			$result = $table->fetchAll($select);
			$rolePermDetails = array();
			$roleDetails = array();
			$roleCode = "";
			$roleDesc = "";
			foreach($result as $role){
				if($roleCode == "" && $roleDesc == "")
				{
					$roleCode = $role->code;
					$roleDesc = $role->description;
				}
				$rolePermDetails[$role->rpm_permissiontype_id] = array(
										'rolePermCode'		=> $role->permcode,
										'rolePermDesc'		=> $role->permdesc
				);
			}
			$roleDetails = array(
								'roleid'			=> $roleid,
								'roleCode'			=> $roleCode,
								'roleDescription'	=> $roleDesc,
								'rolePermissions'	=> $rolePermDetails
			);
			return $roleDetails;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AddRole(Application_Model_Role $roleobj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$data = array(
			'rolfk_restaurant_id'	=>	$roleobj->getRestaurantId(),
			'code'					=>	$roleobj->getRoleCode(),
			'description'			=>	$roleobj->getRoleDesc(),
			'status'				=>	$roleobj->getStatus(),
			'rolfk_typeid'			=> 	$roleobj->getRoleTypeId()
		);
		try{			
			$db->beginTransaction();
				
			$role_id = $this->getDbTable()->insert($data);
				
			$permissionType = $roleobj->getPermissionId();
			$mapper = new Application_Model_RolePermissionMapDataMapper();
			foreach($permissionType as $types){
				$permissionData = array(
				'rpm_roleid' 		  	=> $role_id,
				'rpm_permissiontype_id' => $types->getPermissionTypeId()
				);

				$mapper->getDbTable()->insert($permissionData);
			}
			$status = true;
			$db->commit();
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
		return $status;
	}
	
	public function EditRole(Application_Model_Role $roleobj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$set = array(
			'rolfk_restaurant_id'	=>	$roleobj->getRestaurantId(),
			'code'					=>	$roleobj->getRoleCode(),
			'description'			=>	$roleobj->getRoleDesc(),
			'status'				=>	$roleobj->getStatus()	
		);
		$where = $db->quoteInto('id = ?',$roleobj->getId());
		try{
				$db->beginTransaction();
					
				$role_id = $this->getDbTable()->update($set,$where);
					
				$permissionType = $roleobj->getPermissionId();
				$mapper = new Application_Model_RolePermissionMapDataMapper();
				$rolwhere = $db->quoteInto('rpm_roleid = ?',$roleobj->getId());
				$rows_affected = $mapper->getDbTable()->delete($rolwhere);
				
				foreach($permissionType as $types){
					$permissionData = array(
					'rpm_roleid' 		  	=> $roleobj->getId(),
					'rpm_permissiontype_id' => $types->getPermissionTypeId()
					);
	
					$mapper->getDbTable()->insert($permissionData);
				}
				$status = true;
				$db->commit();
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
		return $status;
	}
	
	public function changeRoleStatus(Application_Model_Role $roleobj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array('status'=>$roleobj->getStatus());
			$where = $db->quoteInto('id = ?',$roleobj->getId());
			$role_id = $this->getDbTable()->update($set,$where);			
			return $role_id; 
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function deleteRolesByRoleId($resid,$roleid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array('status'=>0);
			$where = $db->quoteInto('id = ?',$roleid);
			$role_id = $this->getDbTable()->update($set,$where);
			
			return $role_id; 
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function CheckRoleAsignById($resid,$roleid)
	{
		try{
			$status = false;
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('rob'=>'mt.role_bd'),array('COUNT(id) as count'))
				   ->join(array('usr'=>'mt.user'),'usr.usrrole_id = rob.id',array('usrid'))
				   ->where('rob.id = ?',$roleid)
				   ->group(array('rob.id','usr.usrid'));
			$result = $table->fetchAll($select);
			foreach($result as $val){
				$x = $val->count;
				if($x != 0){
					$status = true;
				}
			}
			return $status; 
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkRoleName(Application_Model_Role $roleObj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$result = $db->fetchOne("select count(id) from mt.role_bd where code ilike '".$roleObj->getRoleCode()."' and rolfk_restaurant_id = ". $roleObj->getRestaurantId()." and status = ".$roleObj->getStatus());

			if((int)$result)
			{
				$status = true;
			}else{
				$status = false;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRoleIdByCode($code)
	{
		$table = $this->getDbTable();
		$select = $table->select();
		$select->from(array('mt.role_bd'),array('id','code','description','status'))
			   ->where('code = ?',$code);
		$result = $table->fetchRow($select);
		$obj = new Application_Model_Role();
		$obj->setId($result->id)
			->setRoleCode($result->code)
			->setRoleDesc($result->description)
			->setStatus($result->status);
		
		return $obj;
	}
	
	public function getAdminUserRoles()
	{
		$table = $this->getDbTable();
		$select = $table->select();
		$codearr = array('ADM','RSU','RSO','CUS','SRU');
		$select->from(array('mt.role_bd'),array('id','code','description','status'))
			   ->where('rolfk_restaurant_id IS NULL')
			   ->where('rolfk_typeid = ? ',1)	
			   ->where('code NOT IN(?)',$codearr);
		
		$result = $table->fetchAll($select);
		return $result; 
	}
	
	public function getAdminUserRolesById($roleid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('rol'=>'mt.role_permission_map'),array('rpm_roleid','rpm_permissiontype_id'))
				   ->join(array('rolbd'=>'mt.role_bd'),'rolbd.id = rol.rpm_roleid',array('code','description'))	   
				   ->join(array('rolper'=>'mt.permissionstype_bd'),'rolper.id = rol.rpm_permissiontype_id',array('code as permcode','description as permdesc'))
				   ->where('rol.rpm_roleid = ?',$roleid)
				   ->where('rolbd.status = ?',true);	
			$result = $table->fetchAll($select);
			$rolePermDetails = array();
			$roleDetails = array();
			$roleCode = "";
			$roleDesc = "";
			foreach($result as $role){
				if($roleCode == "" && $roleDesc == "")
				{
					$roleCode = $role->code;
					$roleDesc = $role->description;
				}
				$rolePermDetails[$role->rpm_permissiontype_id] = array(
										'rolePermCode'		=> $role->permcode,
										'rolePermDesc'		=> $role->permdesc
				);
			}
			$roleDetails = array(
								'roleid'			=> $roleid,
								'roleCode'			=> $roleCode,
								'roleDescription'	=> $roleDesc,
								'rolePermissions'	=> $rolePermDetails
			);
			return $roleDetails;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getRestaurantRolesByRestaurantId($restids)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			
			 $select->from($table,array('id','code','description','rolfk_restaurant_id','status','rolfk_companyid','rolfk_typeid'))
				   ->where('rolfk_restaurant_id IN (?)',$restids);	
			$resultset = $table->fetchAll($select);
			$resultArr  = array();
			$roleidsArr = array();
			$finalArr = array();
			if(count($resultset) > 0)
			{
				foreach($resultset as $key=>$value){
					$roleidsArr[] = $value->id;
					$subArr = array();
					foreach($value as  $key1=>$value1){
						$subArr[$key1]= $value1;
					}
					$resultArr[] = $subArr;
				}
				
				$finalArr['status'] 	= true;
				$finalArr['roleidsArr'] = $roleidsArr;
				$finalArr['roles'] 	    = $resultArr;
				
			}else{
				$finalArr['status'] = false;
			}
			
			return $finalArr;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function addAdminRole(Application_Model_Role $roleobj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$data = array(
			'code'					=>	$roleobj->getRoleCode(),
			'description'			=>	$roleobj->getRoleDesc(),
			'status'				=>	$roleobj->getStatus(),
			'rolfk_typeid'			=>  $roleobj->getRoleTypeId(),
			'rolfk_companyid'		=>  $roleobj->getCompanyId()
		);
		try{			
			$db->beginTransaction();
				
			$role_id = $this->getDbTable()->insert($data);
				
			$permissionType = $roleobj->getPermissionId();
			$mapper = new Application_Model_AdminRolePermissionMapDataMapper();
			foreach($permissionType as $types){
				$permissionData = array(
					'arpm_roleid' 		  	 => $role_id,
					'arpm_permissiontype_id' => $types->getPermissionTypeId(),
					'arpm_createdby'		 => $roleobj->getCreatedBy(),
					'arpm_createddatetime'	 => date('Y-m-d H:i:s')
				);

				$mapper->getDbTable()->insert($permissionData);
			}
			$status = true;
			$db->commit();
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
		return $status;
	}
	
	public function UpdateAdminRole(Application_Model_Role $roleobj)
	{
		
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
						'description'		=>	$roleobj->getRoleDesc()
					);
			$where = $db->quoteInto('id = ?',$roleobj->getId());
			try{				
				$db->beginTransaction();
					
				$role_id = $this->getDbTable()->update($set,$where);
					
				$permissionType = $roleobj->getPermissionId();
				$mapper = new Application_Model_AdminRolePermissionMapDataMapper();
				$rolwhere = $db->quoteInto('arpm_roleid = ?',$roleobj->getId());
				$rows_affected = $mapper->getDbTable()->delete($rolwhere);
				
				foreach($permissionType as $types){
					$permissionData = array(
						'arpm_roleid' 		  	 => $roleobj->getId(),
						'arpm_permissiontype_id' => $types->getPermissionTypeId(),
						'arpm_createdby'		 => $roleobj->getCreatedBy(),
						'arpm_createddatetime'	 => date('Y-m-d H:i:s')
					);
	
					$mapper->getDbTable()->insert($permissionData);
				}
				$status = true;
				$db->commit();
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
		
	}
	
	public function getRolesByCompanyId($companyid, $offset)
	{
		try{
			$limit = 15;
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('rol'=>'mt.role_bd'),array('id','code','description','status','rolfk_companyid'))
				   ->join(array('com'=>'mt.company'),'com.com_id = rol.rolfk_companyid',array('com_companyname'))
				   ->where('rol.rolfk_companyid = ?',$companyid)
				   ->order(array('rol.code'));	
			
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);

			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getRoleDetailsByRoleandCompanyid($companyid, $roleid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('rol'=>'mt.admin_role_permission_map'),array('arpm_roleid','arpm_permissiontype_id'))
				   ->join(array('rolbd'=>'mt.role_bd'),'rolbd.id = rol.arpm_roleid',array('code','description'))	   
				   ->join(array('rolper'=>'mt.admin_permissionstype_bd'),'rolper.id = arpm_permissiontype_id',array('code as permcode','description as permdesc'))
				   ->where('rol.arpm_roleid = ?',$roleid)
				   ->where('rolbd.rolfk_companyid = ?', $companyid);
				   
			$result = $table->fetchAll($select);
			$rolePermDetails = array();
			$roleDetails = array();
			$roleCode = "";
			$roleDesc = "";
			foreach($result as $role){
				if($roleCode == "" && $roleDesc == "")
				{
					$roleCode = $role->code;
					$roleDesc = $role->description;
				}
				$rolePermDetails[$role->arpm_permissiontype_id] = array(
										'rolePermCode'		=> $role->permcode,
										'rolePermDesc'		=> $role->permdesc
				);
			}
			$roleDetails = array(
								'companyid'			=> $companyid,
								'roleCode'			=> $roleCode,
								'roleDescription'	=> $roleDesc,
								'rolePermissions'	=> $rolePermDetails
			);
			return $roleDetails;			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function adminRoleNameCheck(Application_Model_Role $roleObj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$result = $db->fetchOne("select count(id) from mt.role_bd where code ilike '".$roleObj->getRoleCode()."' and rolfk_companyid = ". $roleObj->getCompanyId()." and status = ".$roleObj->getStatus());

			if((int)$result)
			{
				$status = true;
			}else{
				$status = false;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getRolesByCompany(Application_Model_Role $roleObj)
	{
		$table = $this->getDbTable();
		$select = $table->select();
		$select->from($table,array('id','code','description','status'))
			   ->where("rolfk_companyid = ?",$roleObj->getCompanyId())
			   ->where('status = ? ', true);
		
		$resultset = $table->fetchAll($select);
		
		$systemdefinedroles = $this->getAdminUserRoles();
		
		$roles = array();
		$roles[] = array('key'=>'','value'=>'Select Roles');
		foreach($systemdefinedroles as $role){
			$roles[] = array('key'=>$role->id,'value'=>$role->code);
		}
		foreach($resultset as $result){
			$roles[] = array('key'=>$result->id,'value'=>$result->code);
		}
		return $roles;
	}
}