<?php
/**
*	Name			: SpecialCategoryDataMapper.php
*	Author			: snehal
*	Creation Date	: 2/26/2011
*	Path 			: application/models/SpecialCategoryDataMapper.php
*	Description		: This is the DataMapper class for the special category basedata table.
*					   	
*/
class Application_Model_SpecialCategoryDataMapper
{
	protected $_dbTable;
	
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_SpecialCategory');
		}
		return $this->_dbTable;
	}
	public function getSpecialCategoryType($offset)
	{
		$limit = 20;
		$restype = array();
		$select = $this->getDbTable()->select();
		$select->from('mt.special_category_bd',array('id','code','description','status'))
		       ->order(array('id'));		
		//$records = $this->getDbTable()->fetchAll($select);
		$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
		$resultSet->setItemCountPerPage($limit);
		$resultSet->setCurrentPageNumber($offset);			
		
		return $resultSet;
	}
	
	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$specials = array();
		if(!$specials = $cache->Fetch('specialcategory')){
			$where = array('status = ?'=> true);
			$records = $this->getDbTable()->fetchAll($where);
						
			foreach($records as $record){
				$specials[] = new Application_Model_SpecialCategory(						
					$record->toArray());	
			}
			$cache->Save($specials,'specialcategory');			
		}else{
			$specials = $cache->Fetch('specialcategory');
		}
		$cache = null;
		return $specials;
	}
	public function EditSpecialCategory(Application_Model_SpecialCategory $spclCateObj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$set = array('description' => $spclCateObj->getDescription());
		$descStatus = $this->verifyspclDesc($spclCateObj->getDescription(),$spclCateObj->getId());
		if($descStatus){
			$where = $db->quoteInto('id = ?',$spclCateObj->getId());
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearspclCategory('specialcategory');
			}
		}	
		return $status;
	}
	public function AddSpecialCategory(Application_Model_SpecialCategory $spclCateObj)
	{
		$spclCate = array(
			'code'			=> $spclCateObj->getCode(),
			'description'	=> $spclCateObj->getDescription(),
			'status'		=> 1
		);
		
		/* Check to see that values exist in system */
		
		$codeStatus = false;
		$descStatus = false;
		
		$codeStatus = $this->verifyspclCode($spclCateObj->getCode(),0);
		$descStatus = $this->verifyspclDesc($spclCateObj->getDescription(),0);
		
		$status = false;
		if($codeStatus && $descStatus){
			$result = $this->getDbTable()->insert($spclCate);
			if($result){
				$status = true;
				$this->clearspclCategory('specialcategory');
			}	
		}		
		return $status;
	}
	public function clearspclCategory($id)
	{
		if($id){				
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}
	
	public function verifyspclCode($code,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.special_category_bd',array('COUNT(id) as count'))
		       ->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}		       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function verifyspclDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.special_category_bd',array('COUNT(id) as count'))
		       ->where('description ILIKE ?',$desc);
		       
		if($id != 0){
			$select->where('id <> ?',$id);
		}
				       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
		
	}
	public function UpdateStatus($request)
	{
		if($request->stus == 'DeActivate'){
			$data = array('status' => 0);
		}else if($request->stus == 'Activate'){
			$data = array('status' => 1);
		}
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$where = $db->quoteInto('id = ?', $request->id);
		$result = $this->getDbTable()->update($data,$where);
		if($result){
			$this->clearspclCategory('specialcategory');
		}
		return $result;
	}
}