<?php
/**
*	Name			: StateDataMapper.php
*	Author			: mahesh 
*	Creation Date	: 9/30/2010
*	Path 			: application/models/StateDataMapper.php
*	Description		: This is the DataMapper class for the state basedata table.
*					   	
*/
class Application_Model_StateDataMapper
{
	protected $_dbTable;
	
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_State');
		}
		return $this->_dbTable;
	}
	
	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$states = array();
		if(!$states = $cache->Fetch('ddstates')){
			$where = array('status = ?'=> true);
			$order = array('description');
			$records = $this->getDbTable()->fetchAll($where,$order);
			
			foreach($records as $record){
				$states[] = new Application_Model_State(						
					$record->toArray());	
			}
			$cache->Save($states,'ddstates');			
		}else{
			$states = $cache->Fetch('ddstates');
		}
		
		$cache = null;
		return $states;
	}
	
	public function getStates($offset)
	{
		$limit = 20;
		$restype = array();
		$select = $this->getDbTable()->select();
		$select->from('mt.state_bd',array('id','code','description','status'))
		       ->order(array('code','description'));		
		//$records = $this->getDbTable()->fetchAll($select);
		$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
		$resultSet->setItemCountPerPage($limit);
		$resultSet->setCurrentPageNumber($offset);			
		
		return $resultSet;
	}
	
	public function getStateIds()
	{
		$restype = array();
		$select = $this->getDbTable()->select();
		$select->from('mt.state_bd',array('id','description'))
		->where('mt.state_bd.status = ?',true)		       
		->order(array('description'));
		$records = $this->getDbTable()->fetchAll($select);
		$stateList = array();
		$stateList[] = 	array("key"=>"","value"=>"Select Country");
		foreach($records as $value){
				$stateList[] = array("key"=>$value->id, "value"=>$value->description);
			}
			//$region->setRegionList($stateList);
		//$records = $this->getDbTable()->fetchAll($select);
		
		
		return $stateList;
	}
	
	public function AddState(Application_Model_State $stateObj)
	{
		$state = array(
			'code'				=> $stateObj->getCode(),
			'description'		=> $stateObj->getDescription(),
			'currency_code'		=> $stateObj->getCurrency_code(),
			'country_flag'		=> $stateObj->getCountry_flag(),
			'country_dial_code'	=> $stateObj->getCountry_dial_code(),
			'status'			=> true
		);
		
		/* Check to see that values exist in system */
		
		$codeStatus = false;
		$descStatus = false;
		
		$codeStatus = $this->verifyCode($stateObj->getCode(),0);
		$descStatus = $this->verifyDesc($stateObj->getDescription(),0);
		
		$status = false;
		if($codeStatus && $descStatus){
			$stateid = $this->getDbTable()->insert($state);
			if($stateid){
				$timezoneMapper = new Application_Model_TimeZoneDataMapper();
				$timezone = $timezoneMapper->updateCountryIdByTimezoneId($stateid,$stateObj->getTimezone());
				$status = true;
				$this->clearRestType('states');
			}	
		}		
		return $status;
	}
	
	public function EditState(Application_Model_State $stateObj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$set = array(
			'code'				=> $stateObj->getCode(),
			'description'		=> $stateObj->getDescription(),
			'currency_code'		=> $stateObj->getCurrency_code(),
			'country_dial_code'	=> $stateObj->getCountry_dial_code()
		);
		
		if($stateObj->getCountry_flag() != null){
			$set['country_flag'] = $stateObj->getCountry_flag();
		}
		
		$codeStatus = $this->verifyeditCode($stateObj->getCode(),$stateObj->getId());
		$descStatus = $this->verifyeditDesc($stateObj->getDescription(),$stateObj->getId());
		
		if($codeStatus && $descStatus){
			$where = $db->quoteInto('id = ?',$stateObj->getId());
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearRestType('states');
			}
		}	
		return $status;
	}
	
	public function clearRestType($id)
	{
		if($id){				
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}
	
	public function verifyCode($code,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.state_bd',array('COUNT(id) as count'))
		       ->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}		       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function verifyDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.state_bd',array('COUNT(id) as count'))
		       ->where('description ILIKE ?',$desc);
		       
		if($id != 0){
			$select->where('id <> ?',$id);
		}
				       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
		
	}
	
	public function UpdateStatus($request)
	{
		if($request->stus == 'DeActivate'){
			$data = array('status' => 0);
		}else if($request->stus == 'Activate'){
			$data = array('status' => 1);
		}
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$where = $db->quoteInto('id = ?', $request->id);
		$result = $this->getDbTable()->update($data,$where);
		if($result){
			$this->clearRestType('states');
		}
		return $result;
	}
	
	/**
	 * Get city by id 
	 */
	public function getStateById(Application_Model_State  $state)
	{
		$StateBd = $this->fetchAll();
		if($StateBd){
			foreach($StateBd as $item){
				if($item->getId() == $state->getId()){
					return $item;
				}
			}
		}
	}

	public function AddCantFindState(Application_Model_State $stateObj,$userid)
	{
		$state = array(
			'code'			=> $stateObj->getCode(),
			'description'	=> $stateObj->getDescription(),
			'status'		=> true
		);
		
		
		$result = $this->getDbTable()->insert($state);
		if($result){
				$status = true;
				$this->clearRestType('states');
				
				$ownerMapper = new User_Model_ManagerDataMapper();
				$ownerTable = $ownerMapper->getDbtable();
				$set = array('rsostateid'	=> $result,
							 'rsocantfind'	=> 2);
				$where = array('rsofk_user = ?' => $userid);
				$rows_affected = $ownerTable->update($set,$where);
				
		}	
		
		$returnval = false;
		
		if($status){
		$returnval = $result;
		}
		
		return $returnval;
	}
	
	public function AddCantFindRestaurantState(Application_Model_State $stateObj,$resid)
	{
		$state = array(
			'code'			=> $stateObj->getCode(),
			'description'	=> $stateObj->getDescription(),
			'status'		=> true
		);
		
		
		$result = $this->getDbTable()->insert($state);
		if($result){
				$status = true;
				$this->clearRestType('states');
				
				$resMapper = new FirmManagement_Model_FirmDataMapper();
				$resTable = $resMapper->getDbtable();
				$set = array('resstate_id'	=> $result);
				$where = array('resid = ?' => $resid);
				$rows_affected = $resTable->update($set,$where);
				
				$reslocMapper = new FirmManagement_Model_FirmNewLocationMapper();
				$reslocTable = $reslocMapper->getDbtable();
				$setloc = array('rnl_location_count'	=> 3);
				$whereloc = array('rnl_fk_restaurant = ?' => $resid);
				$rows_affected = $reslocTable->update($setloc,$whereloc);
				
		}	
		
		$returnval = false;
		
		if($status){
		$returnval = $result;
		}
		
		return $returnval;
	}
	
	public function getStatesByStateIds($sateIds)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('id','code','description','status','country_id','currency_code','country_flag','country_dial_code','timezone'))
				   ->where('id IN (?)',$sateIds);	
			$resultset = $table->fetchAll($select);
			$resultArr  = array();
			foreach($resultset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					$subArr[$key1]= $value1;
				}
				$resultArr[] = $subArr;
			}
			return $resultArr;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function GetdetailsofStatebyid($stateid)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from('mt.state_bd',array('id','code','description','timezone','currency_code','country_flag','country_dial_code'))
					->where('mt.state_bd.id = ?',$stateid)	       
					->order('description');		       
			$records = $this->getDbTable()->fetchAll($select);	
			$dataArr = array();
			foreach($records as $record){
				$dataArr = array(
								'id'				=> $record->id,
								'code'				=> $record->code,
								'description'		=> $record->description,
								'timezone'			=> $record->timezone,
								'currency_code'		=> $record->currency_code,
								'country_flag'		=> $record->country_flag,
								'country_dial_code'	=> $record->country_dial_code,
							);
			}		
			return $dataArr;			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function verifyeditCode($code,$id)
	{
		try{		
			$stateselect = $this->getDbTable()->select();
			$stateselect->from('mt.state_bd',array('code'))
			       ->where('mt.state_bd.id = ?',$id);
			$result = $this->getDbTable()->fetchRow($stateselect);
			if($result->code == $code){
				return true;
			}else{
				$select = $this->getDbTable()->select();
				$select->from('mt.state_bd',array('COUNT(id) as count'))
				       ->where('code ILIKE ?',$code);
				if($id != 0){
					$select->where('id <> ?',$id);
				}		       		       
				$rowset = $this->getDbTable()->fetchAll($select);
				$count = 0;
				
				foreach($rowset as $row){
					$count = $row->count;
				}
				if($count == 0){
					return true;
				}else{
					return false;
				}
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function verifyeditDesc($desc,$id)
	{
		try{
			$stateselect = $this->getDbTable()->select();
			$stateselect->from('mt.state_bd',array('description'))
			       ->where('id = ?',$id);
			$result = $this->getDbTable()->fetchRow($stateselect);
			if($result->description == $desc){
				return true;
			}else{
				$select = $this->getDbTable()->select();		
				$select->from('mt.state_bd',array('COUNT(id) as count'))
				       ->where('description ILIKE ?',$desc);
				       
				if($id != 0){
					$select->where('id <> ?',$id);
				}
						       		       
				$rowset = $this->getDbTable()->fetchAll($select);
				$count = 0;		
				foreach($rowset as $row){
					$count = $row->count;
				}
				if($count == 0){
					return true;
				}else{
					return false;
				}
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getStatesforIpad()
	{
		$select = $this->getDbTable()->select();
		$select->from('mt.state_bd',array('id','code','description','timezone','currency_code','country_flag','country_dial_code'));
		$resultset = $this->getDbTable()->fetchAll($select);			
		$resultArr  = array();
		foreach($resultset as $key=>$value){
			$subArr = array();
			foreach($value as  $key1=>$value1){
				$subArr[$key1]= $value1;
			}
			$resultArr[] = $subArr;
		}
		return $resultArr;
	}
}
