<?php
/**
*	Name			: UlistCategoryDataMapper.php
*	Author			: Sairam
*	Creation Date	: 2/26/2011
*	Path 			: application/models/MarketCategoryDataMapper.php
*	Description		: This is the DataMapper class for the market category basedata table.
*					   	
*/
class Application_Model_UlistCategoryDataMapper
{
	protected $_dbTable;
	
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_UlistCategory');
		}
		return $this->_dbTable;
	}
		
	public function fetchAll()
	{
		$cache = new Uss_Helper_CacheManager();
		$ulistcategory = array();
		if(!$ulistcategory = $cache->Fetch('ulistcategory')){
			$where = array('status = ?'=> true);
			$records = $this->getDbTable()->fetchAll($where);
						
			foreach($records as $record){
				$ulistcategory[] = new Application_Model_UlistCategory(						
					$record->toArray());	
			}
			$cache->Save($ulistcategory,'ulistcategory');			
		}else{
			$ulistcategory = $cache->Fetch('ulistcategory');
		}
		
		$cache = null;
		return $ulistcategory;
	}
	
	public function GetAllCategorys()
	{
		$select = $this->getDbTable()->select();
		$select->from('mt.ulist_category_bd',array('id','code','description','status'))
		       ->order(array('code','description'));
		$records = $this->getDbTable()->fetchAll($select);
		return $records;		
	}
	
	public function UpdateStatus($request)
	{
		if($request->stus == 'DeActivate'){
			$data = array('status' => 0);
		}else if($request->stus == 'Activate'){
			$data = array('status' => 1);
		}
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$where = $db->quoteInto('id = ?', $request->id);
		$result = $this->getDbTable()->update($data,$where);
		if($result){
			$this->clearRestType('ulistcategory');
		}
		return $result;
	}
	
	public function clearRestType($id)
	{
		if($id){				
			$cache = new Uss_Helper_CacheManager();
			if($cache->Check($id)){
				$status = $cache->Clear($id);
				return $status;
			}
		}
	}
	
	public function AddCategory(Application_Model_UlistCategory $categoryObj)
	{
		$category = array(
			'code'			=> $categoryObj->getCode(),
			'description'	=> $categoryObj->getDescription(),
			'status'		=> true
		);
		
		/* Check to see that values exist in system */
		
		$codeStatus = false;
		$descStatus = false;
		
		$codeStatus = $this->verifyCode($categoryObj->getCode(),0);
		$descStatus = $this->verifyDesc($categoryObj->getDescription(),0);
		
		$status = false;
		if($codeStatus && $descStatus){
			$result = $this->getDbTable()->insert($state);
			if($result){
				$status = true;
				$this->clearRestType('ulistcategory');
			}	
		}		
		return $status;
	}
	
	public function Editcategory(Application_Model_UlistCategory $categoryObj)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		
		$set = array('code' 	   => $categoryObj->getCode(),
					 'description' => $categoryObj->getDescription()
		);
		
		$codeStatus = $this->verifyCode($categoryObj->getCode(),$categoryObj->getId());
		$descStatus = $this->verifyDesc($categoryObj->getDescription(),$categoryObj->getId());
		
		if($codeStatus && $descStatus){
			$where = $db->quoteInto('id = ?',$categoryObj->getId());
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				$status = true;
				$this->clearRestType('ulistcategory');
			}
		}	
		return $status;
	}
	
	public function verifyCode($code,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.ulist_category_bd',array('COUNT(id) as count'))
		       ->where('code ILIKE ?',$code);
		if($id != 0){
			$select->where('id <> ?',$id);
		}		       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;
		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function verifyDesc($desc,$id)
	{
		$select = $this->getDbTable()->select();		
		$select->from('mt.ulist_category_bd',array('COUNT(id) as count'))
		       ->where('description ILIKE ?',$desc);
		       
		if($id != 0){
			$select->where('id <> ?',$id);
		}
				       		       
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
		
	}
}