<?php
class Admin_Model_SponsorDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Admin_Model_DbTable_Sponsor');
		}
		return $this->_dbTable;
	}
	
	public function GetSponsors()
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('spoid','spocompany_name'))
				   ->where('spostatus = true')
				   ->where('spodelete_status = false')
				   ->order(array('spoid'));
			$records = $table->fetchAll($select);
			return $records;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AddSponsor(Admin_Model_Sponsor $sponsor)
	{
		try{
			$data = array(
							'spocompany_name'		=>	$sponsor->getCompanyName(),
							'spocontact_person'		=>	$sponsor->getEmpName(),	
							'spobilling_address'	=>	$sponsor->getAddress(),
							'spophone_no'			=>	$sponsor->getPhNo(),
							'spoemail'				=>	$sponsor->getEmail(),
							'spofax'				=>	$sponsor->getFax(),
							'spostatus'				=>	1,
							'spodelete_status'		=>	0,
							'spocreated_on'			=>	date('Y-m-d H:i:s')
			);
			$result = $this->getDbTable()->insert($data);
			if($result){
				return $result;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditSponsor(Admin_Model_Sponsor $sponsor)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
							'spocontact_person'		=>	$sponsor->getEmpName(),	
							'spobilling_address'	=>	$sponsor->getAddress(),
							'spophone_no'			=>	$sponsor->getPhNo(),
							'spoemail'				=>	$sponsor->getEmail(),
							'spofax'				=>	$sponsor->getFax()
			);
			$where = $db->quoteInto('spoid = ?',$sponsor->getId());
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				return $result;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetSponsorDetailsById($spoid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('spocompany_name','spocontact_person','spobilling_address','spophone_no','spoemail','spofax'))
				   ->where('spoid = ?',$spoid);
			$result = $table->fetchRow($select);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetAllSponsors()
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('spo'=>'mt.sponsor'),array('spoid','spocompany_name','spocontact_person','spophone_no','spostatus'))
				   ->joinLeft(array('sc'=>'mt.sponsor_campaign'),'sc.scsponsor_id = spo.spoid',array('scstatus'))
				  // ->where('spo.spostatus = ?',true)
				   ->order('spo.spoid');
				   
			$result = $table->fetchAll($select);
			$resultSet = array();
			$spid = '';
			$inactivecount = 0;
			$activecount = 0;
			foreach($result as $row){
				if($spid == ''){
					$spid = $row->spoid;
					if($row->scstatus){
						$activecount++;
					}else{
						$inactivecount++;
					}
					$value = array(
								'spoid'					=>	$row->spoid,
								'spocompany_name'		=> 	$row->spocompany_name,
								'spocontact_person'		=>  $row->spocontact_person,
								'spophone_no'			=>	$row->spophone_no,
								'inactive'				=>	$inactivecount,
								'actcount'				=>	$activecount,
								'status'				=>	$row->spostatus
					);
				}else if($spid == $row->spoid){
					if($row->scstatus){
						$activecount++;
						$value['actcount'] = $activecount;
					}else{
						$inactivecount++;
						$value['inactive'] = $inactivecount;
					}
					continue;
				}else{
					
					$resultSet[] = $value;
					$inactivecount = 0;
					$activecount = 0;
					$spid = $row->spoid;
					
					if($row->scstatus){
						$activecount++;
					}else{
						$inactivecount++;
						$value['inactive'] = $inactivecount;
					}
					$value = array(
								'spoid'					=>	$row->spoid,
								'spocompany_name'		=> 	$row->spocompany_name,
								'spocontact_person'		=>  $row->spocontact_person,
								'spophone_no'			=>	$row->spophone_no,
								'inactive'				=>	$inactivecount,
								'actcount'				=>	$activecount,
								'status'				=>	$row->spostatus
					);
					
				}
				
			}
			$resultSet[] = $value;
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetAllSponsorships()
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('spo'=>'mt.sponsor'),array('spoid','spocompany_name','spocontact_person','spophone_no','spostatus'))
				   ->joinLeft(array('sc'=>'mt.sponsor_campaign'),'sc.scsponsor_id = spo.spoid',array('scid','scad_name','scdesc','scweb_link_count','scstatus as status'))
				   ->join(array('spp'=>'mt.sponsor_price_plan'),'sc.scprice_plan = spp.sppid',array('sppplan_name','sppamount','sppintended_audience','sppplan_type','sppstate_id','sppcity_id','sppstart_date','sppend_date'))
				   ->join(array('int'=>'mt.intended_audience_bd'),'int.code = spp.sppintended_audience',array('description as Audience'))
				   ->join(array('tim'=>'mt.sponsor_time_selection_bd'),'spp.spptime_selection = tim.code',array('description as Time'))
				  // ->where('spo.spostatus = ?',true)
				   ->order('spo.spoid');
				   
			$result = $table->fetchAll($select);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditSponsorStatus($spoid,$status)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array('spostatus'=>$status);
			$where = $db->quoteInto('spoid = ?',$spoid);
			$result = $this->getDbTable()->update($set,$where);
			return $result; 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}