<?php
class Admin_Model_UreservAdvertiseMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Admin_Model_DbTable_UreservAdvertise');
		}
		return $this->_dbTable;
	}
	
	public function AddAdvertise(Admin_Model_UreservAdvertise $ad,$userData)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$table = $this->getDbTable();
			$data = array(
							'uaad_name'				=>	$ad->getadName(),
							'ua_startdate'			=>	$ad->getStartdate(),
							'ua_enddate'			=>	$ad->getEnddate(),
//						  	'uaimage'				=>	$ad->getadImage(),
						  	'uadesc'				=>	$ad->getadDesc(),
							'ua_adlink'				=>	$ad->getLink(),
  						  	'uastatus'				=>	$ad->getStatus(),
  						  	'uadelete_status'		=>	$ad->getDelStatus()
			);
			$row_insert = $table->insert($data);
			if($row_insert){
				$permMapper = new Admin_Model_AdvertisePermissionMapDataMapper();
				$permTable = $permMapper->getDbTable();
				$permissionsMapper = new Application_Model_PermissionsTypeDataMapper();
				$permArr = array('RD','BV');
				$premissions = $permissionsMapper->GetPermissionsByCode($permArr);
				foreach($premissions as $key=>$value){
					$permData = array(
										'apm_fk_uaid'				=>	$row_insert,
	  									'apm_permissiontype_id'		=>	$value->getId(),
	   									'apmcreatedby'				=>	$userData['User_Id'],
	  									'apmcreateddatetime'		=>	date('Y-m-d h:i:a')
					);
					$perm_insert = $permTable->insert($permData);
				}
			}
			$db->commit();
			return $row_insert;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditAdvertise(Admin_Model_UreservAdvertise $ad,$userData)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table = $this->getDbTable();
			$set = array(
							'uaad_name'				=>	$ad->getadName(),
//						  	'uaimage'				=>	$ad->getadImage(),
						  	'uadesc'				=>	$ad->getadDesc(),
							'ua_startdate'				=>	$ad->getStartdate(),
							'ua_enddate'				=>	$ad->getEnddate(),
							'ua_adlink'				=>	$ad->getLink()
			);
			$where = $db->quoteInto('uaid = ?',$ad->getId());
			$row_insert = $table->update($set,$where);
			return $row_insert;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetUreservAdvertise($date)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('apm'=>'mt.ureserv_advertise'),array('uaid','uaad_name','uadesc','uastatus','uadelete_status','ua_startdate','ua_enddate','ua_adlink'))
					->where('uastatus = ?','T')
					->where('uadelete_status = ?','F');
			$resultSet = $table->fetchAll($select);
			$result = array();
			$dateSplit = explode("-",$date);
			$check = date("Y-m-d", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
			$checkdate = strtotime($check);
			foreach($resultSet as $row){
				$startdate = strtotime($row->ua_startdate);
				$enddate = strtotime($row->ua_enddate);
				
				if ($startdate <= $checkdate && $checkdate <= $enddate){ 
					$result['ad-'.$row->uaid] = array(
									'adId'			=>	$row->uaid,
									'adName'		=>	$row->uaad_name,
									'adDesc'		=>	$row->uadesc,
									'adlink'		=>	$row->ua_adlink
					);
				 }
			}
			if(count($result)){
				$adMap = $this->GetAdvertiseTimer(1);
				if($adMap){
				$result['timer'] = $adMap->at_timer;
				}else{
					$result['timer']=5000;
				}
			}
			
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetUreservAdvertiseManage()
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('apm'=>'mt.ureserv_advertise'),array('uaid','uaad_name','uadesc','uastatus','uadelete_status','adcount','ua_adlink'))
					->order('uaid desc');
			$resultSet = $table->fetchAll($select);
			
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditAdStatus($ad,$stat)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array('uastatus'=>$stat);
			$where = $db->quoteInto('uaid = ?',$ad);
			$result = $this->getDbTable()->update($set,$where);
			return $result; 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getAdvertise($ad)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('apm'=>'mt.ureserv_advertise'),array('uaid','uaad_name','uadesc','uastatus','uadelete_status','ua_startdate','ua_enddate','ua_adlink'))
					->where('uaid = ?',$ad);
			$resultSet = $table->fetchRow($select);
			
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AdvertiseCount($adid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from(array('apm'=>'mt.ureserv_advertise'),array('uaid','adcount'))
					->where('uaid = ?',$adid);
			$resultSet = $this->getDbTable()->fetchRow($select);
			$count=$resultSet->adcount;
			$count=$count+1;
			
			$set = array('adcount'=>$count);
			$where = $db->quoteInto('uaid = ?',$adid);
			$result = $this->getDbTable()->update($set,$where);
			return $result; 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetAdvertiseTimer($adminid)
	{
		try{
			$timerMapper = new Admin_Model_AdvertiseTimerDataMapper();
			$table = $timerMapper->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('adt'=>'mt.advertise_timer'),array('at_id','at_fk_adminuser','at_timer','at_createdon','at_updatedon'))
					->where('at_fk_adminuser = ?',$adminid);
			$resultSet = $table->fetchRow($select);
			
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateAdvertiseTimer(Admin_Model_AdvertiseTimer $adtimer)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$timerMapper = new Admin_Model_AdvertiseTimerDataMapper;
			$table = $timerMapper->getDbTable();
			$id=$adtimer->getId();
			if(!$id)
			{
				$data = array(
							'at_fk_adminuser'	=>	$adtimer->getAdminId(),
							'at_timer'			=>	$adtimer->getTimer(),
							'at_createdon'		=>	date('Y-m-d h:i:a')
				);
				$result = $table->insert($data);
			}else{
				$set = array(
							'at_timer'			=>	$adtimer->getTimer(),
							'at_updatedon'		=>	date('Y-m-d h:i:a')
				);
				$where = $db->quoteInto('at_id = ?',$adtimer->getId());
				$result = $table->update($set,$where);
			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}