<?php
class Administrator_Model_CompanyDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Administrator_Model_DbTable_Company');
		}
		return $this->_dbTable;
	}
	
	public function addCompany(Administrator_Model_Company $company)
	{
		try{
			$data= array(
				'com_companyname'		=> $company->getCompanyname(),
				'com_description'   	=> $company->getDescription(),
				'com_email'	 			=> $company->getEmail(),
				'com_phone'		 		=> $company->getPhone(),
				'com_address' 			=> $company->getAddress(),	
				'com_website'			=> $company->getWebsite(),
				'com_status'			=> $company->getStatus(),
				'com_licensekey'		=> $company->getLicenceKey(),
				'com_logouturl'			=> $company->getLogoutUrl(),	
				'com_createdby'	 		=> $company->getCreatedby(),
				'companytype_id'	 	=> $company->getCompanyType(),
				'com_partnerwebsiteurl'	=> $company->getPartnerweburl(),
		//		'com_logo'	 			=> $company->getCompanylogo(),
				'com_createddatetime'	=> date('Y-m-d H:i:s')
            );
            if($company->getCompanyPricePerRest()){
                $data['com_price_per_restaurant'] = $company->getCompanyPricePerRest();
            }	
				
			$user_id = $this->getDbTable()->insert($data);		
			return $user_id;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	public function UpdateCompany(Administrator_Model_Company $company)
	{
		try{
			$set= array(
				'com_companyname'		=> $company->getCompanyname(),
				'com_description'   	=> $company->getDescription(),
				'com_email'	 			=> $company->getEmail(),
				'com_phone'		 		=> $company->getPhone(),
				'com_address' 			=> $company->getAddress(),
				'com_website'			=> $company->getWebsite(),	
				'com_logouturl'			=> $company->getLogoutUrl(),
				'com_partnerwebsiteurl'	=> $company->getPartnerweburl(),
				'companytype_id'	 	=> $company->getCompanyType(),
				'com_updatedby'	 		=> $company->getUpdatedBy(),
				'com_updateddatetime'	=> date('Y-m-d H:i:s')
			);	
            if($company->getCompanyPricePerRest()){
                $set['com_price_per_restaurant'] = $company->getCompanyPricePerRest();
            }
			
			if($company->getCompanylogo()){
				$set['com_logo'] = $company->getCompanylogo();
			}
			
			$where 	= array('com_id = ?' => $company->getId());
			
			$rows_affected = $this->getDbTable()->update($set,$where);				
			return $rows_affected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	public function getCompanys($offset)
	{
		try{
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			$companyid = $data['companyid'];
			$limit = 20;
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_id','com_companyname','com_email','com_phone','com_createddatetime','com_status','com_website','com_licensekey','com_price_per_restaurant'));	
			if($companyid != 1){
				$select->where('com_id = ?',$companyid);
			}else{
				$select->where('com_id <> ?',1);
			}	
            $select->order('com_id DESC');
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
			if($resultSet){
				return $resultSet;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getCompanyDetailsById($companyid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_companyname','com_email','com_phone','com_address','com_description','com_website','com_logouturl','com_partnerwebsiteurl','com_logo','companytype_id','com_price_per_restaurant'))
				   ->where('com_id = ?',$companyid);	
				   
			$result = $this->getDbTable()->fetchRow($select);
			$resultSet = "";
			if($result){
				$resultSet = array(
								'com_companyname' 		=> $result->com_companyname,
								'com_email' 			=> $result->com_email,
								'com_phone' 			=> $result->com_phone,
								'com_address' 			=> $result->com_address,
								'com_description'		=> $result->com_description,
								'com_website'			=> $result->com_website,
								'com_logouturl'			=> $result->com_logouturl,
								'com_partnerwebsiteurl'	=> $result->com_partnerwebsiteurl,
								'com_logo'	 			=> $result->com_logo,
								'companytype_id'	 	=> $result->companytype_id,
                                'com_price_per_restaurant' => $result->com_price_per_restaurant
							);
			}
			
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateStatus($request)
	{
		try{
			if($request->status == "Activate"){
				$status = 1;
			}else{
				$status = 0;
			}
			$set = array('com_status'=>$status);
			$where 	= array('com_id = ?' => $request->CompanyID);
			
			$rows_affected = $this->getDbTable()->update($set,$where);				
			return $rows_affected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getComapnyNameList($userdata)
	{
		try{
			$companyid = $userdata['companyid'];
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_id','com_companyname'))
				   ->where('com_status = ?',true);
			if($companyid != 1){
				$select->where('com_id = ?',$companyid);
			}else{
				$select->where('com_id <> ?',1);
			}	
			
			$resultset =  $table->fetchAll($select);
			$compNames = array();
			$compNames[] = array('key'=>'','value'=>'Select Company');
			foreach($resultset as $result){
				$compNames[] = array('key'=>$result->com_id,'value'=>$result->com_companyname);
			}
			return $compNames;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getAllComapnyList()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				
				$userType = $data['Usertype'];
				$companyid = $data['companyid'];
				
				$table  = $this->getDbTable();
				$select = $table->select();
				
				$select->from($table,array('com_id','com_companyname'))
					   ->where('com_status = ?',true)
					    ->order('com_id');
				if($userType == "ADU" && $companyid != 1){
					$select->where('com_id = ? ', $companyid);
				}
				
				$resultset =  $table->fetchAll($select);
				$compNames = array();
				$compNames[] = array('key'=>'','value'=>'Select Company');
				foreach($resultset as $result){
					$compNames[] = array('key'=>$result->com_id,'value'=>$result->com_companyname);
				}
				return $compNames;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getComapnyStatusById($companyid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_status'))
				   ->where('com_id = ?',$companyid);
				   
			$result = $this->getDbTable()->fetchRow($select);

			$status = $result->com_status;
			return $status;   
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkCompanyExist($company)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$result = $db->fetchRow("select com_id from mt.company where com_companyname = '".$company."'");
			
			if((int)$result)
			{
				return true;	
			}else{
				return false;
			}
			 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkLicenseKey($licensekey)
	{
		try{
			
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_id','com_companyname','com_status'))
				   ->where('com_licensekey = ?',$licensekey);
				   
			$row = $this->getDbTable()->fetchRow($select);
			$resltArr = array();
			if($row){
				$resltArr['comapnyId']		=	$row->com_id;
				$resltArr['comapnyName']	=	$row->com_companyname;
				$resltArr['comapnyStatus']	=	$row->com_status;
			}
			return $resltArr;   
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getCompanyLogoutUrlByCompanyId($companyid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('com_logouturl'))
				   ->where('com_id = ?',$companyid);
				   
			$row = $this->getDbTable()->fetchRow($select);
			return $row->com_logouturl;   
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function Updatecompanylogo($companyid,$logoRename)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$set = array('com_logo' => $logoRename);
		try
		{
	        $db->beginTransaction(); 
		    $where = array('com_id = ?'=>$companyid);
	        $this->getDbTable()->update($set,$where);
			$db->commit();
			$status = true;
			return $status;
		} catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
    
    public function getSubscriptionDetailsofCompany($request,$userData)
	{
		try{
			
			$restList	= array();
//            $subscrMapper = new ManageRenumeration_Model_CompanySubscriptionRenewalMapper();
//            $subscriptionDetails = $subscrMapper->getSubscriptionRenewalByCompany();
            $compDM = new Administrator_Model_CompanyDataMapper();
            $compSel = $compDM->getDbTable()->select();
            $compSel->setIntegrityCheck(false);
            $compSel->from(array('com'=>'mt.company'),array('com_id','com_companyname','com_email','com_phone','com_createddatetime','com_status','com_website','com_licensekey','com_price_per_restaurant'))
                    ->join(array('sub'=>'mt.company_subscription_renewal'),'sub.csrcompany_id = com.com_id',array('csrid','csrcompany_id','csrbilling_date','csrbilling_duedate','csramount','csrrestaurant_count','csramount_per_restaurant','csrbilling_fromdate','csrbilling_todate','csrstatus'))
                    ->join(array('sta'=>'mt.transactionstatus_bd'),'sta.id = sub.csrstatus',array('code as statCode','description as status'))
                    ->where('com.com_status = ?',true)
                    ->order('csrid DESC');
            if(isset($request->subscr)){
                $compSel->where('csrid = ?',$request->subscr);
            }else if($userData['Usertype'] == 'ADU'){
                $compSel->where('com_id = ?',$userData['companyid']);
            }
            $compResult = $compDM->getDbTable()->fetchAll($compSel);
            $resultSet = array();
            foreach($compResult as $company){
                $resultSet[] = array(
                                    'count'=>$company->csrrestaurant_count,
                                    'comid'=>$company->com_id,
                                    'subscrpid'=>$company->csrid,
                                    'comname'=>$company->com_companyname,
                                    'billingdate'=>$company->csrbilling_date,
                                    'duedate'=>$company->csrbilling_duedate,
                                    'amount'=>$company->csramount,
                                    'fromdate'=>$company->csrbilling_fromdate,
                                    'todate'=>$company->csrbilling_todate,
                                    'status'=>$company->status,
                                    'priceperunit'=>$company->csramount_per_restaurant
                                );
            }
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
    
    public function getMonthlySubscriptionDetailsofCompany($userData)
	{
		try{
			
			$restList	= array();
            $compDM = new Administrator_Model_CompanyDataMapper();
            $compSel = $this->getDbTable()->select();
            $compSel->from($this->getDbTable(),array('com_id','com_companyname','com_email','com_phone','com_createddatetime','com_status','com_website','com_licensekey','com_price_per_restaurant'))
                    ->where('com_id <> ?',1)
                    ->order('com_id');
            if($userData['Usertype'] == 'ADU'){
                $compSel->where('com_id = ?',$userData['companyid']);
            }
            $compResult = $this->getDbTable()->fetchAll($compSel);
            $resultSet = array();
            foreach($compResult as $company){
                $table = $this->getDbTable();
                $select = $table->select();
                $select->setIntegrityCheck(false);
                $select->from(array('rest'=>'mt.restaurant'),array('count(resid) as rescount'))
                        ->where('res_companyid = ?',$company->com_id)
                        ->where('rest.resstatus NOT IN (?) ',array(3,2))
                        ->where('rest.resapprovalstatus NOT IN (?) ',array(3,2));
                $result =  $table->fetchRow($select);
                $subscription = new ManageRenumeration_Model_CompanySubscriptionRenewal();
                if($company->com_price_per_restaurant){
                    $priceperunit = $company->com_price_per_restaurant;
                }else{
                    $priceperunit = 50;
                }
                $subscription->setcsramount($result->rescount * $company->com_price_per_restaurant)
                            ->setcsramount_per_restaurant($company->com_price_per_restaurant)
                            ->setcsrbilling_date(date('Y-m-d'))
                            ->setcsrbilling_duedate(date('Y-m-d', strtotime("+10 days")))
                            ->setcsrbilling_fromdate(date('Y-m-d', strtotime("-1 month")))
                            ->setcsrbilling_todate(date('Y-m-d'))
                            ->setcsrcompany_id($company->com_id)
                            ->setcsrrestaurant_count($result->rescount)
                            ->setcsrstatus(29);
                $resultSet[] = $subscription;
            }
            $subscriptionMapper = new ManageRenumeration_Model_CompanySubscriptionRenewalMapper();
            $result = $subscriptionMapper->SaveSubscriptionRenewal($resultSet);
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}