<?php
class Communication_Model_EmailMessageDataMapper
{	
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Communication_Model_DbTable_EmailMessage');
		}
		return $this->_dbTable;
	}
	
	public function SaveMessageDetails(Communication_Model_EmailMessage $message)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$data = array(
					'emsg_subject'		=>	$message->getTitle(),
					'emsg_body'			=>	$message->getDescription(),
					'emsg_sentby'		=>	$message->getSentby(),
					'emsg_emailtype'	=>	$message->getEmailtype(),
					'emsg_priority'		=>	$message->getPriority(),
					'emsg_senton'		=>	date('Y-m-d H:i:s'),
					'emsg_notificationtype'=> 1,
					'emsg_signature'	=>  $message->getSignature(),
					'emsg_docpath'		=>  $message->getDocpath(),
					'emsg_msg_phrase'	=>	$message->getPhrase()
				);
		if($message->getBokid()){
			$data['emsg_fk_bokid'] = $message->getBokid();
		}
		if($message->getUsertype()){
			$data['emsg_email_users'] = $message->getUsertype();
		}
		try{
			$msgTable = $this->getDbTable();
			$msgid = $msgTable->insert($data);
			return $msgid;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetTitleandMessageById($msgid)
	{
		try{
			$resttable = $this->getDbTable();
			$select = $resttable->select();

			$select->from($resttable,array('emsg_subject','emsg_body','emsg_signature'));
			$select->where('emsg_id = ?',$msgid);
			$result = $resttable->fetchRow($select);
			return $result;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetMessageDetailsById($id)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('emsg_subject','emsg_body','emsg_emailtype','emsg_priority','emsg_email_users','emsg_campaignid','emsg_signature','emsg_fk_bokid'))
				   ->where('emsg_id = ?',$id);
			$result = $table->fetchRow($select);
			return $result;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdatemessageDeatils(Communication_Model_EmailMessage $message)
	{
		try{
			$set   =  array(
					'emsg_subject'		=>	$message->getTitle(),
					'emsg_body'			=>	$message->getDescription(),
					'emsg_emailtype'	=>	$message->getEmailtype(),
					'emsg_priority'		=>	$message->getPriority(),
					'emsg_signature'	=>  $message->getSignature()
				);
			$where = array('emsg_id = ?'=>$message->getId());
			$status = $this->getDbTable()->update($set,$where);
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	
	}
	
	public function GetEmailIdsById($stateid,$cityid,$usertype)
	{
		try{
			$resArr = array();
			if($usertype == 'RES'){
				$resmapper = new FirmManagement_Model_FirmDataMapper();
				$select = $resmapper->getDbTable()->select();
				$select->setIntegrityCheck(false);
				$select->from(array('rest'=>'mt.restaurant'),array('resid','resemail','resrestaurant_name'));
				$select->join(array('restown'=>'mt.restaurant_owner'),'restown.rsofk_user = rest.resfk_user',array('rsofirst_name','rsolast_name'));
				$select->where('rest.resemail != ?','');
				if($stateid && $cityid){
					$select->where('rest.resstate_id = ?',$stateid);
					$select->where('rest.rescity_id = ?',$cityid);
				}else if($stateid){
					$select->where('rest.resstate_id = ?',$stateid);
				}
				$select->where('rest.rescategory_id = ?',2);
				$select->where('rest.resstatus = ?',1);
				
				$resultSet = $resmapper->getDbTable()->fetchAll($select);
				
				foreach($resultSet as $row){
					$resArr[] = $row->resemail;
				}
			}else if($usertype == 'CUS'){
				$cusmapper = new User_Model_GuestDataMapper();
				$cusselect = $cusmapper->getDbTable()->select();
				$cusselect->setIntegrityCheck(false);
				$cusselect->from(array('cus'=>'mt.customer'),array('cusfirst_name','cuslast_name'))
						  ->join(array('usr'=>'mt.user'),'usr.usrid = cus.cusfk_user',array('usremail'));
				if($stateid && $cityid){
					$cusselect->where('cus.cusstate_id = ?',$stateid);
					$cusselect->where('cus.cuscity_id = ?',$cityid);
				}else if($stateid){
					$cusselect->where('cus.cusstate_id = ?',$stateid);
				}
				$resultSet = $cusmapper->getDbTable()->fetchAll($cusselect);
				
				foreach($resultSet as $row){
					$resArr[] = $row->usremail;
				}
			}
			return $resArr;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getAllNotifications()
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('emsg_id','emsg_subject','emsg_senton'))
				   ->where('emsg_notificationtype =?',true)
				   //->where('emsg_email_users !=?','')
				   ->order('emsg_id DESC');
			$result = $table->fetchAll($select);
			return $result;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetCampaignSentToDetails($camId,$usrtype)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			if($usrtype == 'CUS'){
				$select->from(array('emsg'=>'mt.email_message'),array('emsg_id','emsg_senton','emsg_subject','emsg_email_users'))
					   ->distinct()
//					   ->join(array('res'=>'mt.email_restaurant_recipents'),'res.err_msgid = emsg.emsg_id',array('err_emailid as Restaurant'))
					   ->join(array('cus'=>'mt.email_customer_recipents'),'cus.ecr_msgid = emsg.emsg_id',array('ecr_emailid as Email'))
					   ->where('emsg.emsg_campaignid = ?',$camId)
					   ->order('emsg.emsg_id');
			}else if($usrtype == 'RES'){
				$select->from(array('emsg'=>'mt.email_message'),array('emsg_id','emsg_senton','emsg_subject','emsg_email_users'))
					   ->distinct()
					   ->join(array('res'=>'mt.email_restaurant_recipents'),'res.err_msgid = emsg.emsg_id',array('err_emailid as Email'))
//					   ->join(array('cus'=>'mt.email_customer_recipents'),'cus.ecr_msgid = emsg.emsg_id',array('ecr_emailid as Customer'))
					   ->where('emsg.emsg_campaignid = ?',$camId)
					   ->order('emsg.emsg_id');
			}
			$result = $table->fetchAll($select);
			$sentDetails = array();
			foreach($result as $row){
				$sentDetails[] = array(
										'Id'			=>	$row->emsg_id,
										'Email'			=>	$row->Email,
										'sent'			=>	$row->emsg_senton,
										'User'			=>	$row->emsg_email_users
				);
			}
			return $sentDetails;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetMsgIdByPhrase($phrase)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('emsg_id'))
					->where('emsg_msg_phrase = ?',$phrase);
			$result = $this->getDbTable()->fetchRow($select);
			return $result->emsg_id;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function CheckEmailMsgStatusByBokid($bokid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('emsg_id','emsg_subject','emsg_body','emsg_emailtype','emsg_priority','emsg_email_users','emsg_campaignid','emsg_signature','emsg_fk_bokid'))
					->where('emsg_fk_bokid = ?',$bokid)
					->where('emsg_subject = ? ','BookConf');
			$result = $table->fetchRow($select);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}