<?php
class Communication_Model_SmsMessageMapper
{	
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Communication_Model_DbTable_SmsMessage');
		}
		return $this->_dbTable;
	}
	
	public function SaveMessageDetails(Communication_Model_SmsMessage $message)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$data = array(
		
					'smsmsg_subject'		=>	$message->getTitle(),
					'smsmsg_body'			=>	$message->getDescription(),
					'smsmsg_sentby'			=>	$message->getSentby(),
  					'smsmsg_sentto'			=>	str_replace("-","",$message->getSentTo()),
					'smsmsg_smstype'		=>	$message->getSmstype(),
					'smsmsg_priority'		=>	$message->getPriority(),
					'smsmsg_senton'			=>	date('Y-m-d H:i:s'),
					'smsmsg_sms_to_users'	=>	$message->getSentToUser(),
  					'smsmsg_sms_from_users'	=>	$message->getSentFromUser(),
					'smsmsg_msg_phrase'		=>	$message->getPhrase()
				);
		if($message->getBokid()){
			$data['smsmsg_fk_bokid'] = $message->getBokid();
		}
		if($message->getReference()){
			$data['smsmsg_reference'] = $message->getReference();
		}
		try{
			$msgTable = $this->getDbTable();
			$msgid = $msgTable->insert($data);
			return $msgid;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function UpdateMessageDetails(Communication_Model_SmsMessage $message)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table  = $this->getDbTable();
			$set = array(		
						'smsmsg_sms_trans_id'		=>	$message->getTransId()
					);
			$where = $db->quoteInto('smsmsg_msg_phrase = ?',$message->getPhrase());
			$table->update($set,$where);
		
			return true;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	public function getBookingIdBySmsId($sms)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('smsmsg_fk_bokid','smsmsg_subject','smsmsg_body','smsmsg_sentby','smsmsg_sentto','smsmsg_smstype','smsmsg_priority','smsmsg_senton','smsmsg_sms_to_users','smsmsg_sms_from_users','smsmsg_msg_phrase'))
					->where('smsmsg_msg_phrase = ?',$sms);
			$result = $this->getDbTable()->fetchRow($select);
			return $result;		
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getSmsHistoryByBookingId(Communication_Model_SmsMessage $message)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('smsmsg_fk_bokid','smsmsg_subject','smsmsg_body','smsmsg_sentby','smsmsg_sentto','smsmsg_smstype','smsmsg_priority','smsmsg_senton','smsmsg_sms_to_users','smsmsg_sms_from_users','smsmsg_msg_phrase'))
					->where('smsmsg_fk_bokid = ?',$message->getBokid())
					->order('smsmsg_id DESC');
			$result = $this->getDbTable()->fetchAll($select);
			$resultArr = array();
			foreach($result as $row){
				$body = $row->smsmsg_body;
				$subject = $row->smsmsg_subject;
				if($subject == 'WaitingReady'){
					$subject = 'TableReady';
				}
				switch($row->smsmsg_body){
					case 'BP':	
						$body = $row->smsmsg_body.' ( '.$row->smsmsg_subject.' )';
					break;
					case 'CB':	
						$body = $row->smsmsg_body.' ( '.$row->smsmsg_subject.' )';
					break;
					case 'CL':	
						$body = $row->smsmsg_body.' ( '.$row->smsmsg_subject.' )';
					break;
				}
				$resultArr[] = array(
									'smsmsg_subject'		=>	$subject,
									'smsmsg_body'			=>	$body,
									'smsmsg_sentby'			=>	$row->smsmsg_sentby,
				  					'smsmsg_sentto'			=>	$row->smsmsg_sentto,
									'smsmsg_smstype'		=>	$row->smsmsg_smstype,
									'smsmsg_priority'		=>	$row->smsmsg_priority,
									'smsmsg_senton'			=>	date('m-d-Y h:i A',strtotime($row->smsmsg_senton)),
									'smsmsg_sms_to_users'	=>	$row->smsmsg_sms_to_users,
				  					'smsmsg_sms_from_users'	=>	$row->smsmsg_sms_from_users,
									'smsmsg_msg_phrase'		=>	$row->smsmsg_msg_phrase,
									'smsmsg_fk_bokid'		=>	$row->smsmsg_fk_bokid,
									'smsmsg_reference' 		=>	$row->smsmsg_msg_phrase
				);
			}
			return $resultArr;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateBulkMessageDetails($messageArray,$buffer,$smscampid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table  = $this->getDbTable();
			$i = 0;
			$j = 1;
			$usedsmscount = null;
			$campaignMapper = new FirmManagement_Model_CampaignDetailsDataMapper();	
			$camptable = $campaignMapper->getDbTable();
			foreach($messageArray as $message){
				$data = array(
							'campd_smsid' 		  	=> $smscampid,
							'campd_phone'		  	=> $message->getSentTo(),
							'campd_createdby'	  	=> $message->getUsertype(),
							'campd_createddatetime'	=> date('Y-m-d H:i:s'),
					);
				if(is_array($buffer)){
					$set = array(		
							'smsmsg_sms_trans_id'		=>	$buffer[$i]
						);
					$data['campd_sentstatus'] = 1;
					$data['campd_transid'] = $buffer[$i];
					$status = 1;
				}else{
					if(strlen($buffer) > 48){
						$limit = substr($buffer,0,45)."....";
					}else{
						$limit = $buffer;	
					}
					$set = array(		
							'smsmsg_sms_trans_id' =>	$limit
						);
					$data['campd_sentstatus'] = 0;
					$data['campd_transid'] = $buffer;
					$status = 0;
				}
				$where = $db->quoteInto('smsmsg_msg_phrase = ?',$message->getPhrase());
				$table->update($set,$where);
					
				$result = $camptable->insert($data);
				if($result){					
					if($status == 1){
						$usedsmscount = $j;
						$j++; 
					}
				}
				
				$i++;
			}
			if($usedsmscount){
				$smsCampCountMapper = new FirmManagement_Model_SmsRestaurantCampCountDataMapper();
				$CountTable  = $smsCampCountMapper->getDbTable();
				$select = $CountTable->select();
				$select->from($CountTable,array('rescamp_usedsms'))
		    			->where('rescamp_resid = ?', $message->getid());
				$smsused = $CountTable->fetchRow($select);
				if($smsused){
					$UsedSms = $smsused->rescamp_usedsms + $usedsmscount;
				}
				$set = array(		
							'rescamp_usedsms'			=>	$UsedSms,
							'rescamp_updatedby'			=>  $message->getUsertype(),
							'rescamp_updateddatetime'	=>	date('Y-m-d H:i:s'),
						);
				$where = array('rescamp_resid = ?' => $message->getid());	
				$resultset = $CountTable->update($set,$where);
			}
			return true;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateArrMessageDetails($messageArr,$buffer)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table  = $this->getDbTable();
			$i = 0;
			foreach($messageArr as $message){
				if(is_array($buffer)){
					$set = array(		
							'smsmsg_sms_trans_id'		=>	$buffer[$i]
						);
				}else{
					if(strlen($buffer) > 48){
						$limit = substr($buffer,0,45)."....";
					}else{
						$limit = $buffer;	
					}
					$set = array(		
							'smsmsg_sms_trans_id' =>	$limit
						);
				}
				
				$where = $db->quoteInto('smsmsg_msg_phrase = ?',$message->getPhrase());
				$table->update($set,$where);
				$i++;
			}
			
			return true;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function CheckSmsMsgStatusByBokid($bokid)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('smsmsg_fk_bokid','smsmsg_subject','smsmsg_body','smsmsg_sentby','smsmsg_sentto','smsmsg_smstype','smsmsg_priority','smsmsg_senton','smsmsg_sms_to_users','smsmsg_sms_from_users','smsmsg_msg_phrase'))
					->where('smsmsg_fk_bokid = ?',$bokid)
					->where('smsmsg_subject =  ? ','BookConf');
			$result = $this->getDbTable()->fetchRow($select);
			return $result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}