<?php
class Deals_Model_RestaurantSpecialDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Deals_Model_DbTable_RestaurantSpecial');
		}
		return $this->_dbTable;
	}

	public function SaveSpecial(Deals_Model_RestaurantSpecial $restSpl)
	{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$data = array(
					'rspfk_restaurant'				=>	$restSpl->getRestaurantid(),
					'rspspecial_type'				=>	$restSpl->getSpecialtypeid(),
					'rspspecial_title'				=>	$restSpl->getSpecialtitle(),
					'rspspecial_image'				=>	$restSpl->getSpecialimage(),
					'rspfood_type'					=>	$restSpl->getFoodtype(),
//					'rspkidsstatus'					=>	$restSpl->getKidsstatus(),
//					'rspkids_eat_free'				=>	$restSpl->getKidsinfo(),
					'rspstart_date'					=>	$restSpl->getStartdate(),
					'rspend_date'					=>	$restSpl->getEnddate(),					
					'rspstart_time'					=>	$restSpl->getStarttime(),
					'rspend_time'					=>	$restSpl->getEndtime(),
					'rsprecurencestatus'			=>	$restSpl->getSpecialrecurence(),
					'rspdescription'				=>	$restSpl->getDescription(),
					'rspstatus'						=>	$restSpl->getStatus(),
					'rspcategory'					=>  $restSpl->getSpecialCategoryType(),
					'rspdeletestatus'				=>	$restSpl->getDeleteStatus()

			);
			if($restSpl->getSpecialCategoryType() != 3 || $restSpl->getSpecialCategoryType() != 2){				
				$data['rspregular_price']				=	$restSpl->getRegprice();
				$data['rspdiscount_percentage_point']	=	$restSpl->getDispercentage();
				$data['rspprice_with_discount']			=	$restSpl->getPricewithdiscount();
				$data['rspdiscount_mode']				=	$restSpl->getDiscountMode();
				$data['rsptype_of_occurance']			=	$restSpl->getSpecialCount();
				$data['rspno_of_dishes']				=	$restSpl->getNoofdishes();
				$data['rsppricetype']					=	$restSpl->getSpecialpricetype();				
			}

			try{
				$db->beginTransaction();

				$spl_id = $this->getDbTable()->insert($data);
				$days = $restSpl->getWeekids();
				$mapper = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
				foreach($days as $day){
					$weekData = array(
					'rsrfk_restaurant_special'	=>	$spl_id,
					'rsrday_of_week'			=>	$day->getWeekId(),
					'rsrreccurence_type_id'		=>	1
					);
					$mapper->getDbTable()->insert($weekData);
				}
				$db->commit();
				$status = true;
				return $spl_id;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
	}

	public function RetrieveSpecialsByRestId(Deals_Model_SpecialsByRestId $Id,$offset)
	{
		try{
			$table = $this->getDbTable();
			$query= $table->select();
			$query->setIntegrityCheck(false);
			
			$query->from(array('rsp'=>'mt.restaurant_special'),array('rspid',
						   										   'rspfk_restaurant',
						   										   'rspno_of_dishes',
						   										   'rspspecial_title',
						   										   'rspregular_price',
																   'rspspecial_image',
																   'rspdiscount_percentage_point',
																   'rspprice_with_discount',
																   'rspkids_eat_free',
																   'rspstart_date',
																   'rspend_date',
																   'rspstart_time',
																   'rspend_time',
																   'rspdescription',
																   'rspfood_type',
																   'rspspecial_type',
																   'rsprecurencestatus',
																   'rspstatus',
																   'rspkidsstatus',
																   'rspcategory',
																   'rsptype_of_occurance',
																   'rspdiscount_mode',
																   'rspdeletestatus'))
			->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name','resaddress','resphone'))
			->join(array('spb'=>'mt.special_type_bd'),'spb.id = rsp.rspspecial_type',array('description as special'))
			->join(array('spcat'=>'mt.special_category_bd'),'spcat.id = rsp.rspcategory',array('description as splCategory'))
			->joinLeft(array('count'=>'mt.rest_special_counter'),'count.rsc_fk_special_id = rsp.rspid',array('rsc_spl_counter as counter'))
			->join(array('st'=>'mt.state_bd'),'st.id = rest.resstate_id',array('code as countrycode','description as countrydesc','currency_code'))
			->joinLeft(array('resfb'=>'mt.restaurant_fb_event'),'resfb.rfbe_fk_deal_id = rsp.rspid',array('rfbe_event_fb_id','rfbe_fk_deal_id','rfbe_start_date','rfbe_start_time','rfbe_end_date','rfbe_end_time','rfbe_created_fb_by','rfbe_status','rfbe_created_fb_for'))
			->joinLeft(array('splcnt'=>'mt.special_count_type_bd'),'splcnt.id = rsp.rsptype_of_occurance',array('description as splCount'))
			->joinLeft(array('discmod'=>'mt.discount_mode_bd'),'discmod.id = rsp.rspdiscount_mode',array('description as discMode'))
			->joinLeft(array('disctyp'=>'mt.discount_type_bd'),'disctyp.id = rsp.rsptype_of_occurance',array('code as discTypeCode' ,'description as discTypeDisc'))
			->joinLeft(array('pricetype'=>'mt.special_price_type_bd'),'pricetype.id = rsp.rsppricetype',array('description as splpricetype','code as splpriceCode'))
			->where('rest.resfk_user = ?',$Id->getUserId())
			->order('rsp.rspid');

			if($Id->getDelStatus() == 3){
				$query->where('rsp.rspdeletestatus = ?','F');
			}else if($Id->getDelStatus() == 2){
				$query->where('rsp.rspstatus = ?','F');
				$query->where('rsp.rspdeletestatus = ?','T');
			}else{
				$query->where('rsp.rspstatus = ?','T');
				$query->where('rsp.rspdeletestatus = ?','T');
			}

			if($Id->getRestaurantId()){
				$query->where('rest.resid = ?',$Id->getRestaurantId());
			}
			if(!$Id->getStartDate() && !$Id->getEndDate()){
				if($Id->getDelStatus() == 'ell'){
					$query->where('rsp.rspstart_date <= ?',date('Y-m-d'));
					$query->where('rsp.rspend_date <= ?',date('Y-m-d'));
				}else{
					$query->where('rsp.rspend_date >= ?',date('Y-m-d'));
				}
				
			}else{
				if($Id->getStartDate()){
					$query->where('rsp.rspstart_date >= ?',$Id->getStartDate());
				}
				if($Id->getEndDate()){
					$query->where('rsp.rspend_date <= ?',$Id->getEndDate());
				}				
			}
			if($Id->getStartTime()){
					$query->where('rsp.rspstart_time >= ?',$Id->getStartTime());
			}
			if($Id->getEndTime()){
				$query->where('rsp.rspend_time <= ?',$Id->getEndTime());
			}
			
//			$rowSet = $table->fetchAll($query);
			$rowSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($query)
			);
			$rowSet->setItemCountPerPage(10);
			$rowSet->setCurrentPageNumber($offset);
			
			$resDet = array();
			foreach($rowSet as $row){
				if($row->rsprecurencestatus){
					$reoccMapper = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
					$reTable = $reoccMapper->getDbTable();
					$reoccSelect = $reTable->select();
					$reoccSelect->setIntegrityCheck(false);
					$reoccSelect->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
								->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
								->where('rsr.rsrfk_restaurant_special = ? ',$row->rspid);
					$rowResult = $reTable->fetchAll($reoccSelect);
				}else{
					$rowResult = "";
				}
				$resInvitee = '';
				if($row->rfbe_event_fb_id){
					$resInviteeMapper = new Deals_Model_RestaurantFbEventInviteeDataMapper();
					$select = $resInviteeMapper->getDbTable()->select();
					$select->from($resInviteeMapper->getDbTable(),array('count(rfei_fb_user) as invitCnt','rfei_fb_invite_status'))
							->where('rfei_fk_event = ?',$row->rfbe_event_fb_id)
							->group('rfei_fb_invite_status');
					$resInvitee = $resInviteeMapper->getDbTable()->fetchAll($select);
				}	
				if(strlen($row->rspdescription) > 200){
					$description = substr($row->rspdescription, 0, 200)." ...";
				}else{
					$description = $row->rspdescription;
				}
				$splObj = new Deals_Model_RestaurantSpecial();
				$splObj->setId($row->rspid)
					   ->setRestaurantname($row->resrestaurant_name)
						->setAddress($row->resaddress)
						->setRestaurantid($row->rspfk_restaurant)
						->setNoofdishes($row->rspno_of_dishes)
						->setSpecialtypename($row->special)
						->setSpecialtypeid($row->rspspecial_type)
						->setSpecialtitle($row->rspspecial_title)
						->setSpecialimage($row->rspspecial_image)
						->setStartdate($row->rspstart_date)
						->setEnddate($row->rspend_date)
						->setStarttime($row->rspstart_time)
						->setEndtime($row->rspend_time)
						->setDescription($description)
						->setSpecialrecurence($row->rsprecurencestatus)
						->setKidsinfo($row->rspkids_eat_free)
						->setKidsstatus($row->rspkidsstatus)
						->setSpecialCount($row->rsptype_of_occurance)
						->setSpecialCategoryType($row->rspcategory)
						->setSpecialCategoryTypeName($row->splCategory)
						->setSpecialCountName($row->splCount)
						->setDiscountMode($row->discMode)
						->setRegprice(str_replace('$','',$row->rspregular_price))
						->setDispercentage($row->rspdiscount_percentage_point)
						->setPricewithdiscount(str_replace('$','',$row->rspprice_with_discount))
						->setStatus($row->rspstatus)
						->setPhone($row->resphone)
						->setCounter($row->counter)
						->setDeleteStatus($row->rspdeletestatus)
						->setSpecialpricetype($row->splpricetype)
						->setSpecialpricetypeCode($row->splpriceCode)
						->setRescurrency($row->currency_code)
					    ->setCountry($row->countrydesc)
					    ->setFbInvitees($resInvitee);
				$splWeek = array();
				if($rowResult){
					foreach($rowResult as $value){
						$splRecurenceObj = new Deals_Model_RestaurantSpecialRecurence();
						$splRecurenceObj->setWeekId($value->rsrday_of_week);
						$splRecurenceObj->setWeekDesc($value->day);
						$splWeek[] = $splRecurenceObj;
					}
				}
				$splObj->setWeekids($splWeek);
				$resDet[$row->rspid] = $splObj;
			}
			return array('resDet'=> $resDet,'result'=>$rowSet);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function RetrieveSpecialDetailsById(Deals_Model_RestaurantSpecialById $splid,$isAjaxCall)
	{
		try{
			$table = $this->getDbTable();
			$cuisinemapper = new FirmManagement_Model_FirmCuisineDataMapper();

			$restcuisinetable = $cuisinemapper->getDbTable();

			$query= $table->select();
			$selectRestCuisine = $restcuisinetable->select();
			$query->setIntegrityCheck(false);
			$query->from(array('rsp'=>'mt.restaurant_special'),array('rspid',
						   										   'rspfk_restaurant',
						   										   'rspno_of_dishes',
						   										   'rspspecial_title',
						   										   'rspregular_price',
																   'rspspecial_image',
																   'rspdiscount_percentage_point',
																   'rspprice_with_discount',
																   'rspkids_eat_free',
																   'rspstart_date',
																   'rspend_date',
																   'rspstart_time',
																   'rspend_time',
																   'rspdescription',
																   'rspfood_type',
																   'rspspecial_type',
																   'rsprecurencestatus',
																   'rspstatus',
																   'rspkidsstatus',
																   'rspcategory',
																   'rsptype_of_occurance',
																   'rspdiscount_mode','rsppricetype'))

			->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name','resaddress','resgoogleimage','resphone','resdescription'))
			->join(array('cty'=>'mt.city_bd'),'cty.id = rest.rescity_id',array('code as citycode','description as citydesc'))
			->join(array('st'=>'mt.state_bd'),'st.id = rest.resstate_id',array('code as countrycode','description as countrydesc','currency_code'))
			->join(array('neigh'=>'mt.neighborhood_bd'),'neigh.id = rest.resneighborhood_id',array('description as neighdesc'))
			->join(array('spb'=>'mt.special_type_bd'),'spb.id = rsp.rspspecial_type',array('description as special'))
			->join(array('spcat'=>'mt.special_category_bd'),'spcat.id = rsp.rspcategory',array('description as splCategory','code as catCode'))
			->joinLeft(array('splcnt'=>'mt.special_count_type_bd'),'splcnt.id = rsp.rsptype_of_occurance',array('description as splCount'))
			->joinLeft(array('discmod'=>'mt.discount_mode_bd'),'discmod.id = rsp.rspdiscount_mode',array('description as discMode'))
			->joinLeft(array('pricetype'=>'mt.special_price_type_bd'),'pricetype.id = rsp.rsppricetype',array('description as splpricetype','code as splpriceCode'))
			->where('rsp.rspid = ?',$splid->getSpecialId())
			->where('rsp.rspdeletestatus = ?',TRUE);
				
			$result = $table->fetchRow($query);
				
			if($isAjaxCall){
				$recurence = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
				$recurenceTable = $recurence->getDbTable();
				$selectWeeks = $recurenceTable->select();
				$selectWeeks->setIntegrityCheck(false);
				$selectWeeks->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
					->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
					->where('rsr.rsrfk_restaurant_special = ? ',$result->rspid);
				$weekResult = $table->fetchAll($selectWeeks);
				
				
				$splWeek= array();
					
				foreach($weekResult as $value){
					$splRecurenceObj = new Deals_Model_RestaurantSpecialRecurence();
					$splRecurenceObj->setWeekId($value->rsrday_of_week);
					$splRecurenceObj->setWeekDesc($value->day);
					$splWeek[] = $splRecurenceObj;
				}
				//$splObj->setWeekids($splWeek);
			//	$formatstartDate = date('m-d-Y',strtotime($result->rspstart_date));
				$startDate = date('d M Y ',strtotime($result->rspstart_date));
			//	$formatendDate = date('m-d-Y',strtotime($result->rspend_date));
				$endDate = date('d M Y',strtotime($result->rspend_date));
				$startTime = date("h:i A",strtotime($result->rspstart_time));
				$endTime = date("h:i A",strtotime($result->rspend_time));
				$weekIds = "";
				foreach($splWeek as $week){
					$weekIds[] = $week->getWeekId();
				}
				$specialDetails = array();
				$specialDetails = array(
										'specialStartDate'			=>	$startDate,
										'specialEndDate'			=>	$endDate,
										'specialStartTime'			=>	$startTime,
									    'specialEndTime'			=>	$endTime,
										'specialRecurrence' 		=>  $result->rsprecurencestatus,
										'weeks'						=>	$weekIds,
								//		'specialFormatStartDate'	=>	$formatstartDate,
								//		'specialFormatEndDate'		=>	$formatendDate,
				
				);
				return $specialDetails;
			}else{
				$recurence = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
				$recurenceTable = $recurence->getDbTable();
				$selectWeeks = $recurenceTable->select();
				$selectWeeks->setIntegrityCheck(false);
				$selectWeeks->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
					->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
					->where('rsr.rsrfk_restaurant_special = ? ',$result->rspid);
				$weekResult = $table->fetchAll($selectWeeks);
			    	$imageArray = explode(',', $result['rspspecial_image']);
				
				$splObj = new Deals_Model_RestaurantSpecial();
				$splObj->setRestaurantname($result->resrestaurant_name)
				->setRestaurantid($result->rspfk_restaurant)
				->setNoofdishes($result->rspno_of_dishes)
				->setSpecialtypename($result->special)
				->setSpecialtypeid($result->rspspecial_type)
				->setSpecialtitle($result->rspspecial_title)
				->setSpecialimage($imageArray)
//			->setSpecialimage($result->rspspecial_image)
				->setStartdate($result->rspstart_date)
				->setEnddate($result->rspend_date)
				->setStarttime($result->rspstart_time)
				->setEndtime($result->rspend_time)
				->setDescription($result->rspdescription)
				->setSpecialrecurence($result->rsprecurencestatus)
				->setKidsinfo($result->rspkids_eat_free)
				->setKidsstatus($result->rspkidsstatus)
				->setSpecialCount($result->rsptype_of_occurance)
				->setSpecialCategoryType($result->rspcategory)
				->setSpecialCategoryTypeName($result->splCategory)
				->setCatTypeCode($result->catCode)
				->setSpecialCountName($result->splCount)
				->setDiscountMode($result->discMode)
				->setRestaurantaddress($result->resaddress)
				->setRestaurantgoogleimage($result->resgoogleimage)
				->setRestaurantphone($result->resphone)
				->setRestaurantcity($result->citydesc)
				->setRestaurantneigh($result->neighdesc)
				->setRestaurantdesc($result->resdescription)
				->setSpecialpricetype($result->splpricetype)
				->setSpecialpricetypeCode($result->splpriceCode)
				->setSpecialpricetypeid($result->rsppricetype)
				->setRegprice(str_replace('$','',$result->rspregular_price))
				->setDispercentage($result->rspdiscount_percentage_point)
				->setPricewithdiscount(str_replace('$','',$result->rspprice_with_discount))
				->setStatus($result->rspstatus)
				->setRescurrency($result->currency_code)
			   ->setCountry($result->countrydesc);
				
					
				$selectRestCuisine->setIntegrityCheck(false);
				$selectRestCuisine->from(array('cuis'=>'mt.restaurant_cuisine'),array('rscid','rscfk_restauranttype_id'))
				->join(array('resttyp'=>'mt.restaurant_type_bd'),'resttyp.id = cuis.rscfk_restauranttype_id',array('code','description'))
				->where('cuis.rcsfk_restaurant = ?',$splid->getRestId());
				$cuisineResult = $restcuisinetable->fetchAll($selectRestCuisine);
	
				$restCuisines = array();
	
				foreach($cuisineResult as $cuisRes){
					$restCuisObj = new FirmManagement_Model_FirmCuisine();
					$restCuisObj->setId($cuisRes->rscid);
					$restCuisObj->setRestaurantTypeId($cuisRes->rscfk_restauranttype_id);
					$restCuisObj->setRestCuisineCode($cuisRes->code);
					$restCuisObj->setRestCuisineDesc($cuisRes->description);
					$restCuisines[] = $restCuisObj;
				}
	
				/* Setting restaurant types to Restaurant objects restauranttype id property. */
				$splObj->setFoodtype($restCuisines);
	
				$splWeek= array();
					
				foreach($weekResult as $value){
					$splRecurenceObj = new Deals_Model_RestaurantSpecialRecurence();
					$splRecurenceObj->setWeekId($value->rsrday_of_week);
					$splRecurenceObj->setWeekDesc($value->day);
					$splWeek[] = $splRecurenceObj;
				}
				$splObj->setWeekids($splWeek);
				return $splObj;
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function updateRestSpecial(Deals_Model_RestaurantSpecial $restSpl)
	{
		
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
					'rspregular_price'				=>	$restSpl->getRegprice(),
					'rspdiscount_percentage_point'	=>	$restSpl->getDispercentage(),
					'rspprice_with_discount'		=>	$restSpl->getPricewithdiscount(),
					'rspdiscount_mode'				=>	$restSpl->getDiscountMode(),
					'rsppricetype'					=>	$restSpl->getSpecialpricetypeid()
			);
			try{
				$db->beginTransaction();
				$splWhere = $db->quoteInto('rspid = ?',$restSpl->getId());
				$this->getDbTable()->update($set,$splWhere);
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}
	
	public function updateRestSpecialDesc(Deals_Model_RestaurantSpecial $restSpl)
	{
		
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
					'rspdescription' =>	$restSpl->getDescription(),
			);
			try{
				$db->beginTransaction();
				$splWhere = $db->quoteInto('rspid = ?',$restSpl->getId());
				$this->getDbTable()->update($set,$splWhere);
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}
	
	public function updateRestSpecialSchedule(Deals_Model_RestaurantSpecial $restSpl)
	{
		
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
					'rspstart_date'					=>	$restSpl->getStartdate(),
					'rspend_date'					=>	$restSpl->getEnddate(),
					'rspstart_time'					=>	$restSpl->getStarttime(),
					'rspend_time'					=>	$restSpl->getEndtime(),
					'rsprecurencestatus'			=>	$restSpl->getSpecialrecurence()
					
			);	
			try{
				$db->beginTransaction();
				$splWhere = $db->quoteInto('rspid = ?',$restSpl->getId());
				$this->getDbTable()->update($set,$splWhere);
				$days = $restSpl->getWeekids();
				
				$mapper = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
				$weekwhere = $db->quoteInto('rsrfk_restaurant_special = ?',$restSpl->getId());
				$rows_affected = $mapper->getDbTable()->delete($weekwhere);
				foreach($days as $day){
					$weekData = array(
							'rsrfk_restaurant_special'	=>	$restSpl->getId(),
							'rsrday_of_week'			=>	$day->getWeekId(),
							'rsrreccurence_type_id'		=>	1
					);
					$mapper->getDbTable()->insert($weekData);
				}
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}

	public function updateRestaurantSpecialImage(Deals_Model_RestaurantSpecial $restSpl)
	{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array('rspspecial_image' => $restSpl->getSpecialimage());
			try{
				$db->beginTransaction();

				/* Update Restaurant */

				$restWhere = $db->quoteInto('rspid = ?',$restSpl->getId());

				$this->getDbTable()->update($set,$restWhere);
				$db->commit();
				$status = true;
				return $status;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
	}
	
	public function updateSpecialTitle($title,$count,$splid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array('rspspecial_title'		=>	$title);
			if($count != ''){
				$set['rspno_of_dishes'] = $count;
			}
			$where = $db->quoteInto('rspid = ?',$splid);
			$result = $this->getDbTable()->update($set,$where);
			return $result;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function updateManageSpecial(Deals_Model_RestaurantSpecial $restSpl)
	{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
					'rspfk_restaurant'				=>	$restSpl->getRestaurantid(),
					'rspspecial_type'				=>	$restSpl->getSpecialtypeid(),
					'rspno_of_dishes'				=>	$restSpl->getNoofdishes(),
					'rspspecial_title'				=>	$restSpl->getSpecialtitle(),
					'rspspecial_image'				=>	$restSpl->getSpecialimage(),
					'rspfood_type'					=>	$restSpl->getFoodtype(),
					'rspkids_eat_free'				=>	$restSpl->getKidsinfo(),
					'rspstart_date'					=>	$restSpl->getStartdate(),
					'rspend_date'					=>	$restSpl->getEnddate(),
					'rspstart_time'					=>	$restSpl->getStarttime(),
					'rspend_time'					=>	$restSpl->getEndtime(),
					'rsprecurencestatus'			=>	$restSpl->getSpecialrecurence(),
					'rspdescription'				=>	$restSpl->getDescription(),
					'rspstatus'						=>	$restSpl->getStatus(),
					'rspregular_price'				=>	$restSpl->getRegprice(),
					'rspdiscount_percentage_point'	=>	$restSpl->getDispercentage(),
					'rspprice_with_discount'		=>	$restSpl->getPricewithdiscount(),
					'rspdiscount_type'				=>	$restSpl->getDistypeid()
			);

			try{
				$db->beginTransaction();
				$splWhere = $db->quoteInto('rspid = ?',$restSpl->getId());
				$this->getDbTable()->update($set,$splWhere);
					
				$days = $restSpl->getWeekids();
				$mapper = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
				$Where = $db->quoteInto('rsrfk_restaurant_special = ?',$restSpl->getId());
				$mapper->getDbTable()->delete($Where);
				foreach($days as $day){
					$weekData = array(
					'rsrfk_restaurant_special'	=>	$restSpl->getId(),
					'rsrday_of_week'			=>	$day->getWeekId(),
					'rsrreccurence_type_id'		=>	1
					);
					$mapper->getDbTable()->insert($weekData);
				}
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}

	public function getSpecialStatus(Deals_Model_RestaurantSpecial $obj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$qry = "select count(rspspecial_title) from mt.restaurant_special where rspspecial_title = '". $obj->getSpecialtitle() ."' and rspfk_restaurant = ". $obj->getRestaurantid();
			$result = $db->fetchOne("select count(rspspecial_title) from mt.restaurant_special where rspspecial_title = '". $obj->getSpecialtitle() ."' and rspfk_restaurant = ". $obj->getRestaurantid());

			if((int)$result)
			{
				$status = true;
			}else{
				$status = false;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateRestSpecialStatus($splid,$status)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			if($status == 'active'){
				$stat = 0;
				$set = array('rspstatus'=>$stat);
			}else if($status == "cancel"){
				$stat = 0;
				$set = array('rspdeletestatus'=>$stat);
			}else if($status == 'unDel'){
				$stat = 1;
				$set = array('rspdeletestatus'=>$stat);
			}else{
				$stat = 1;
				$set = array('rspstatus'=>$stat);
			}
			$where = $db->quoteInto('rspid = ?',$splid);
			$rows_effected = $this->getDbTable()->update($set,$where);
			return $rows_effected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getRestaurantSpecialByDate($resid,$date)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('spl'=>'mt.restaurant_special'),array('count(rspid) as count'))
				   ->where('spl.rspfk_restaurant = ?',$resid)
				   ->where('spl.rspstart_date <= ?',$date)
				   ->where('spl.rspend_date >= ?',$date)
				   ->where('spl.rspstatus = ?',true)
				   ->where('spl.rspdeletestatus = ?',true);
				   
			$result = $this->getDbTable()->fetchAll($select);
			$count = 0;
			foreach($result as $rowCount){
				$count = $rowCount->count;
			}	
			return $count;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getRestaurantSplByBookingId($bokid,$isAjaxCall)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant'))
				   ->join(array('boktype'=>'mt.booking_type_bd'),'bok.bokbooking_type_id = boktype.id',array('code','description as desc'))
				   ->join(array('splbok'=>'mt.booking_special'),'bok.bokid = splbok.bksfk_booking',array('bksspecial_id','bksamount'))
				   ->where('bok.bokid = ?',$bokid)
				   ->where("boktype.code ='SPL' OR boktype.code = 'SPLPAID'");
				   
			$rowset = $table->fetchRow($select);
			
			$restid = $rowset->bokfk_restaurant;
			$splid = $rowset->bksspecial_id;
			
			$cuisinemapper = new FirmManagement_Model_FirmCuisineDataMapper();

			$restcuisinetable = $cuisinemapper->getDbTable();

			$query= $table->select();
			$selectRestCuisine = $restcuisinetable->select();
			$query->setIntegrityCheck(false);
			$query->from(array('rsp'=>'mt.restaurant_special'),array('rspid',
						   										   'rspfk_restaurant',
						   										   'rspno_of_dishes',
						   										   'rspspecial_title',
						   										   'rspregular_price',
																   'rspspecial_image',
																   'rspdiscount_percentage_point',
																   'rspprice_with_discount',
																   'rspkids_eat_free',
																   'rspstart_date',
																   'rspend_date',
																   'rspstart_time',
																   'rspend_time',
																   'rspdescription',
																   'rspfood_type',
																   'rspspecial_type',
																   'rsprecurencestatus',
																   'rspstatus',
																   'rspkidsstatus',
																   'rspcategory',
																   'rsptype_of_occurance',
																   'rspdiscount_mode'))

			->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name','resaddress','resgoogleimage','resphone','resdescription'))
			->join(array('cty'=>'mt.city_bd'),'cty.id = rest.rescity_id',array('code as citycode','description as citydesc'))
			->join(array('neigh'=>'mt.neighborhood_bd'),'neigh.id = rest.resneighborhood_id',array('description as neighdesc'))
			->join(array('spb'=>'mt.special_type_bd'),'spb.id = rsp.rspspecial_type',array('description as special'))
			->join(array('spcat'=>'mt.special_category_bd'),'spcat.id = rsp.rspcategory',array('description as splCategory'))
			->joinLeft(array('splcnt'=>'mt.special_count_type_bd'),'splcnt.id = rsp.rsptype_of_occurance',array('code as splCode','description as splCount'))
			->joinLeft(array('discmod'=>'mt.discount_mode_bd'),'discmod.id = rsp.rspdiscount_mode',array('description as discMode','code as discCode'))
			->joinLeft(array('pricetype'=>'mt.special_price_type_bd'),'pricetype.id = rsp.rsppricetype',array('description as splpricetype','code as splpriceCode'))
			->where('rsp.rspid = ?',$splid);
//			->where('rsp.rspdeletestatus = ?',TRUE);
				
			$result = $table->fetchRow($query);
				
			if($isAjaxCall){
				$recurence = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
				$recurenceTable = $recurence->getDbTable();
				$selectWeeks = $recurenceTable->select();
				$selectWeeks->setIntegrityCheck(false);
				$selectWeeks->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
					->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
					->where('rsr.rsrfk_restaurant_special = ? ',$result->rspid);
				$weekResult = $table->fetchAll($selectWeeks);
				
				
				$splWeek= array();
					
				foreach($weekResult as $value){
					$splRecurenceObj = new Deals_Model_RestaurantSpecialRecurence();
					$splRecurenceObj->setWeekId($value->rsrday_of_week);
					$splRecurenceObj->setWeekDesc($value->day);
					$splWeek[] = $splRecurenceObj;
				}
				//$splObj->setWeekids($splWeek);
				$startDate = date('Y-m-d',strtotime($result->rspstart_date));
				$endDate = date('Y-m-d',strtotime($result->rspend_date));
				$startTime = date("h:i A",strtotime($result->rspstart_time));
				$endTime = date("h:i A",strtotime($result->rspend_time));
				$weekIds = "";
				foreach($splWeek as $week){
					$weekIds[] = $week->getWeekId();
				}
				$specialDetails = array();
				$specialDetails = array(
								
								'Id'						=>	$result->rspid,
								'Restaurant Name'			=>	$result->resrestaurant_name,
								'Special Name'				=>	$result->rspspecial_title,
								'Number of Dishes'			=>	$result->rspno_of_dishes.' '.$result->splCount,
								'Speical Type'				=>	$result->special,
								'Start Date'				=>	date('m-d-Y',strtotime($startDate)),
								'End Date'					=>	date('m-d-Y',strtotime($endDate)),
								'Start Time'				=>	$startTime,
								'End Time'					=>	$endTime,
								'Recurrence' 				=>  $result->rsprecurencestatus,
								'weeks'						=>	$weekIds,
								'Img'						=>	$result->rspspecial_image,
								'Desc'						=>	$result->rspdescription,
								'kidsStatus'				=>	$result->rspkidsstatus,
								'kids Info'					=>	$result->rspkids_eat_free,
								'Special Category'			=>	$result->splCategory,
								'Discount Mode'				=>	$result->discMode,
								'Discountcode'				=>	$result->discCode,
								'Regular Price'				=>	str_replace('$','',$result->rspregular_price),
								'Discount Percentage'		=>	$result->rspdiscount_percentage_point,
								'Price with Discount'		=>	str_replace('$','',$result->rspprice_with_discount),
								'PriceType'					=>	$result->splpricetype,
								'PriceCode'					=>	$result->splpriceCode,
								'Status'					=>	$result->rspstatus
										
				);
				return $specialDetails;
			}else{
				$recurence = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
				$recurenceTable = $recurence->getDbTable();
				$selectWeeks = $recurenceTable->select();
				$selectWeeks->setIntegrityCheck(false);
				$selectWeeks->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
					->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
					->where('rsr.rsrfk_restaurant_special = ? ',$result->rspid);
				$weekResult = $table->fetchAll($selectWeeks);
				$splObj = new Deals_Model_RestaurantSpecial();
				$splObj->setRestaurantname($result->resrestaurant_name)
				->setRestaurantid($result->rspfk_restaurant)
				->setNoofdishes($result->rspno_of_dishes)
				->setSpecialtypename($result->special)
				->setSpecialtypeid($result->rspspecial_type)
				->setSpecialtitle($result->rspspecial_title)
				->setSpecialimage($result->rspspecial_image)
				->setStartdate($result->rspstart_date)
				->setEnddate($result->rspend_date)
				->setStarttime($result->rspstart_time)
				->setEndtime($result->rspend_time)
				->setDescription($result->rspdescription)
				->setSpecialrecurence($result->rsprecurencestatus)
				->setKidsinfo($result->rspkids_eat_free)
				->setKidsstatus($result->rspkidsstatus)
				->setSpecialCount($result->rsptype_of_occurance)
				->setSpecialCategoryType($result->rspcategory)
				->setSpecialCategoryTypeName($result->splCategory)
				->setSpecialCountName($result->splCount)
				->setDiscountMode($result->discMode)
				->setRestaurantaddress($result->resaddress)
				->setRestaurantgoogleimage($result->resgoogleimage)
				->setRestaurantphone($result->resphone)
				->setRestaurantcity($result->citydesc)
				->setRestaurantneigh($result->neighdesc)
				->setRestaurantdesc($result->resdescription)
	
				->setRegprice(str_replace('$','',$result->rspregular_price))
				->setDispercentage($result->rspdiscount_percentage_point)
				->setPricewithdiscount(str_replace('$','',$result->rspprice_with_discount))
				->setStatus($result->rspstatus);
					
				$selectRestCuisine->setIntegrityCheck(false);
				$selectRestCuisine->from(array('cuis'=>'mt.restaurant_cuisine'),array('rscid','rscfk_restauranttype_id'))
				->join(array('resttyp'=>'mt.restaurant_type_bd'),'resttyp.id = cuis.rscfk_restauranttype_id',array('code','description'))
				->where('cuis.rcsfk_restaurant = ?',$restid);
				$cuisineResult = $restcuisinetable->fetchAll($selectRestCuisine);
	
				$restCuisines = array();
	
				foreach($cuisineResult as $cuisRes){
					$restCuisObj = new FirmManagement_Model_FirmCuisine();
					$restCuisObj->setId($cuisRes->rscid);
					$restCuisObj->setRestaurantTypeId($cuisRes->rscfk_restauranttype_id);
					$restCuisObj->setRestCuisineCode($cuisRes->code);
					$restCuisObj->setRestCuisineDesc($cuisRes->description);
					$restCuisines[] = $restCuisObj;
				}
	
				/* Setting restaurant types to Restaurant objects restauranttype id property. */
				$splObj->setFoodtype($restCuisines);
	
				$splWeek= array();
					
				foreach($weekResult as $value){
					$splRecurenceObj = new Deals_Model_RestaurantSpecialRecurence();
					$splRecurenceObj->setWeekId($value->rsrday_of_week);
					$splRecurenceObj->setWeekDesc($value->day);
					$splWeek[] = $splRecurenceObj;
				}
				$splObj->setWeekids($splWeek);
				return $splObj;
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetSpecialInfoById($specialid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('rsp'=>'mt.restaurant_special'),array('rspid','rspspecial_title'))
				   ->join(array('price'=>'mt.special_price_type_bd'),'price.id = rsp.rsppricetype',array('code as pricetype'))
				   ->where('rspid = ?',$specialid);
			$row = $table->fetchRow($select);
			
			return $row;
				   
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveSpecialDetailsBysplid(Deals_Model_RestaurantSpecialById $splid)
	{
		try{
			$table = $this->getDbTable();
			$cuisinemapper = new FirmManagement_Model_FirmCuisineDataMapper();

			$restcuisinetable = $cuisinemapper->getDbTable();

			$query= $table->select();
			$selectRestCuisine = $restcuisinetable->select();
			$query->setIntegrityCheck(false);
			$query->from(array('rsp'=>'mt.restaurant_special'),array('rspid',
						   										   'rspfk_restaurant',
						   										   'rspno_of_dishes',
						   										   'rspspecial_title',
						   										   'rspregular_price',
																   'rspspecial_image',
																   'rspdiscount_percentage_point',
																   'rspprice_with_discount',
																   'rspkids_eat_free',
																   'rspstart_date',
																   'rspend_date',
																   'rspstart_time',
																   'rspend_time',
																   'rspdescription',
																   'rspfood_type',
																   'rspspecial_type',
																   'rsprecurencestatus',
																   'rspstatus',
																   'rspkidsstatus',
																   'rspcategory',
																   'rsptype_of_occurance',
																   'rspdiscount_mode','rsppricetype'))

			->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name','resaddress','resgoogleimage','resphone','resdescription'))
			->join(array('cty'=>'mt.city_bd'),'cty.id = rest.rescity_id',array('code as citycode','description as citydesc'))
			->join(array('neigh'=>'mt.neighborhood_bd'),'neigh.id = rest.resneighborhood_id',array('description as neighdesc'))
			->join(array('spb'=>'mt.special_type_bd'),'spb.id = rsp.rspspecial_type',array('description as special'))
			->join(array('spcat'=>'mt.special_category_bd'),'spcat.id = rsp.rspcategory',array('description as splCategory','code as catCode'))
			->joinLeft(array('splcnt'=>'mt.special_count_type_bd'),'splcnt.id = rsp.rsptype_of_occurance',array('description as splCount'))
			->joinLeft(array('discmod'=>'mt.discount_mode_bd'),'discmod.id = rsp.rspdiscount_mode',array('description as discMode'))
			->joinLeft(array('pricetype'=>'mt.special_price_type_bd'),'pricetype.id = rsp.rsppricetype',array('description as splpricetype','code as splpriceCode'))
			->where('rsp.rspid = ?',$splid->getSpecialId());
				
			$result = $table->fetchRow($query);				
			
			$recurence = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
			$recurenceTable = $recurence->getDbTable();
			$selectWeeks = $recurenceTable->select();
			$selectWeeks->setIntegrityCheck(false);
			$selectWeeks->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
				->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
				->where('rsr.rsrfk_restaurant_special = ? ',$result->rspid);
			$weekResult = $table->fetchAll($selectWeeks);
			$splObj = new Deals_Model_RestaurantSpecial();
			$splObj->setRestaurantname($result->resrestaurant_name)
			->setRestaurantid($result->rspfk_restaurant)
			->setNoofdishes($result->rspno_of_dishes)
			->setSpecialtypename($result->special)
			->setSpecialtypeid($result->rspspecial_type)
			->setSpecialtitle($result->rspspecial_title)
			->setSpecialimage($result->rspspecial_image)
			->setStartdate($result->rspstart_date)
			->setEnddate($result->rspend_date)
			->setStarttime($result->rspstart_time)
			->setEndtime($result->rspend_time)
			->setDescription($result->rspdescription)
			->setSpecialrecurence($result->rsprecurencestatus)
			->setKidsinfo($result->rspkids_eat_free)
			->setKidsstatus($result->rspkidsstatus)
			->setSpecialCount($result->rsptype_of_occurance)
			->setSpecialCategoryType($result->rspcategory)
			->setSpecialCategoryTypeName($result->splCategory)
			->setCatTypeCode($result->catCode)
			->setSpecialCountName($result->splCount)
			->setDiscountMode($result->discMode)
			->setRestaurantaddress($result->resaddress)
			->setRestaurantgoogleimage($result->resgoogleimage)
			->setRestaurantphone($result->resphone)
			->setRestaurantcity($result->citydesc)
			->setRestaurantneigh($result->neighdesc)
			->setRestaurantdesc($result->resdescription)
			->setSpecialpricetype($result->splpricetype)
			->setSpecialpricetypeCode($result->splpriceCode)
			->setSpecialpricetypeid($result->rsppricetype)
			->setRegprice(str_replace('$','',$result->rspregular_price))
			->setDispercentage($result->rspdiscount_percentage_point)
			->setPricewithdiscount(str_replace('$','',$result->rspprice_with_discount))
			->setStatus($result->rspstatus);
			
			if($splid->getRestId()){	
				$selectRestCuisine->setIntegrityCheck(false);
				$selectRestCuisine->from(array('cuis'=>'mt.restaurant_cuisine'),array('rscid','rscfk_restauranttype_id'))
				->join(array('resttyp'=>'mt.restaurant_type_bd'),'resttyp.id = cuis.rscfk_restauranttype_id',array('code','description'))
				->where('cuis.rcsfk_restaurant = ?',$splid->getRestId());
				$cuisineResult = $restcuisinetable->fetchAll($selectRestCuisine);
	
				$restCuisines = array();
	
				foreach($cuisineResult as $cuisRes){
					$restCuisObj = new FirmManagement_Model_FirmCuisine();
					$restCuisObj->setId($cuisRes->rscid);
					$restCuisObj->setRestaurantTypeId($cuisRes->rscfk_restauranttype_id);
					$restCuisObj->setRestCuisineCode($cuisRes->code);
					$restCuisObj->setRestCuisineDesc($cuisRes->description);
					$restCuisines[] = $restCuisObj;
				}
	
				/* Setting restaurant types to Restaurant objects restauranttype id property. */
				$splObj->setFoodtype($restCuisines);
			}
			$splWeek= array();
				
			foreach($weekResult as $value){
				$splRecurenceObj = new Deals_Model_RestaurantSpecialRecurence();
				$splRecurenceObj->setWeekId($value->rsrday_of_week);
				$splRecurenceObj->setWeekDesc($value->day);
				$splWeek[] = $splRecurenceObj;
			}
			$splObj->setWeekids($splWeek);
			return $splObj;
			
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveAllActiveSpecialsByRestId(Deals_Model_SpecialsByRestId $Id, $request,$limit)
	{
		try{
			$table = $this->getDbTable();
			$query= $table->select();
			$query->setIntegrityCheck(false);
			
			$count = null;
			if($Id->getRestaurantId()){
				$count = $this->RetrieveAllActiveSpecialsCountByRestId($Id->getRestaurantId());
			}
			$offset = 0;

			/* Reteriving the previous offset */
			if($request->offset && $request->offset != 0){
				$offset = $request->offset;
			}
			/* If next link or arrow is clicked this if condition is executed. */
			if($request->event == 'next'){

				if($count >= $offset + $limit){

					$offset = $offset + $limit;

					if($offset + $limit >= $count){
						$result['next'] = false;
					}else{
						$result['next'] = true;
					}
				}
				if($offset >= $limit){
					$result['prev'] = true;
				}

			}/* if previous link is clicked this if condition is executed. */
			elseif($request->event == 'prev'){

				$offset = $offset - $limit;

				if($offset == 0 || $offset < $limit){
					$result['prev'] = false;
				}else{
					$result['prev'] = true;
				}
				if($count > $offset){

					$result['next'] = true;
				}

			}/* This else part is executed on first call of this function. */
			else{
				if($request->prev ||  $request->next){
					if($request->prev && $request->next){
						$result['next'] = true;
						$result['prev'] = true;
					}else if($request->prev){
						$result['next'] = false;
						$result['prev'] = true;
					}else if($request->next){
						$result['next'] = true;
						$result['prev'] = false;
					}else{
						$result['next'] = false;
						$result['prev'] = false;
					}
				}else{
					if($count > $limit){
						/* if count is greater than 9 show the next link */
						$result['next'] = true;
						$result['prev'] = false;
					}else{
						/* if count is less than 9 then no links are shown. */
						$result['next'] = false;
						$result['prev'] = false;
					}
				}
			}
			
			$result['offset'] = $offset;
			
			$query->from(array('rsp'=>'mt.restaurant_special'),array('rspid',
						   										   'rspfk_restaurant',
						   										   'rspno_of_dishes',
						   										   'rspspecial_title',
						   										   'rspregular_price',
																   'rspspecial_image',
																   'rspdiscount_percentage_point',
																   'rspprice_with_discount',
																   'rspkids_eat_free',
																   'rspstart_date',
																   'rspend_date',
																   'rspstart_time',
																   'rspend_time',
																   'rspdescription',
																   'rspfood_type',
																   'rspspecial_type',
																   'rsprecurencestatus',
																   'rspstatus',
																   'rspkidsstatus',
																   'rspcategory',
																   'rsptype_of_occurance',
																   'rspdiscount_mode',
																   'rspdeletestatus'))

			->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name','resaddress','resphone'))
			->join(array('cty'=>'mt.city_bd'),'cty.id = rest.rescity_id',array('code as citycode','description as citydesc'))
			->join(array('neigh'=>'mt.neighborhood_bd'),'neigh.id = rest.resneighborhood_id',array('description as neighdesc'))
			->join(array('spb'=>'mt.special_type_bd'),'spb.id = rsp.rspspecial_type',array('description as special'))
			->join(array('spcat'=>'mt.special_category_bd'),'spcat.id = rsp.rspcategory',array('description as splCategory'))
			->joinLeft(array('count'=>'mt.rest_special_counter'),'count.rsc_fk_special_id = rsp.rspid',array('rsc_spl_counter as counter'))
			->joinLeft(array('splcnt'=>'mt.special_count_type_bd'),'splcnt.id = rsp.rsptype_of_occurance',array('description as splCount'))
			->joinLeft(array('discmod'=>'mt.discount_mode_bd'),'discmod.id = rsp.rspdiscount_mode',array('description as discMode'))
			->joinLeft(array('disctyp'=>'mt.discount_type_bd'),'disctyp.id = rsp.rsptype_of_occurance',array('code as discTypeCode' ,'description as discTypeDisc'))
			->joinLeft(array('pricetype'=>'mt.special_price_type_bd'),'pricetype.id = rsp.rsppricetype',array('description as splpricetype','code as splpriceCode'))
			->where('rest.resid = ?',$Id->getRestaurantId())
			->where('rsp.rspstatus = ?',true)
			->where('rsp.rspdeletestatus = ?',true)
			->where('rest.resapprovalstatus = ?',1)
			->where('rest.resstatus = ?',1)
			->order('rsp.rspid');

			$query->limit($limit,$offset);
			
			$rowSet = $table->fetchAll($query);
			
			$resDet = array();
			foreach($rowSet as $row){
				if($row->rsprecurencestatus){
					$reoccMapper = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
					$reTable = $reoccMapper->getDbTable();
					$reoccSelect = $reTable->select();
					$reoccSelect->setIntegrityCheck(false);
					$reoccSelect->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
								->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
								->where('rsr.rsrfk_restaurant_special = ? ',$row->rspid);
					$rowResult = $reTable->fetchAll($reoccSelect);
				}else{
					$rowResult = "";
				}
				if(strlen($row->rspdescription) > 200){
					$description = substr($row->rspdescription, 0, 200)." ...";
				}else{
					$description = $row->rspdescription;
				}
				$splObj = new Deals_Model_RestaurantSpecial();
				$splObj->setId($row->rspid)
					   ->setRestaurantname($row->resrestaurant_name)
						->setAddress($row->resaddress)
						->setRestaurantid($row->rspfk_restaurant)
						->setNoofdishes($row->rspno_of_dishes)
						->setSpecialtypename($row->special)
						->setSpecialtypeid($row->rspspecial_type)
						->setSpecialtitle($row->rspspecial_title)
						->setSpecialimage($row->rspspecial_image)
						->setStartdate($row->rspstart_date)
						->setEnddate($row->rspend_date)
						->setStarttime($row->rspstart_time)
						->setEndtime($row->rspend_time)
						->setDescription($description)
						->setSpecialrecurence($row->rsprecurencestatus)
						->setKidsinfo($row->rspkids_eat_free)
						->setKidsstatus($row->rspkidsstatus)
						->setSpecialCount($row->rsptype_of_occurance)
						->setSpecialCategoryType($row->rspcategory)
						->setSpecialCategoryTypeName($row->splCategory)
						->setSpecialCountName($row->splCount)
						->setDiscountMode($row->discMode)
						->setRegprice(str_replace('$','',$row->rspregular_price))
						->setDispercentage($row->rspdiscount_percentage_point)
						->setPricewithdiscount(str_replace('$','',$row->rspprice_with_discount))
						->setStatus($row->rspstatus)
						->setPhone($row->resphone)
						->setCounter($row->counter)
						->setDeleteStatus($row->rspdeletestatus)
						->setSpecialpricetype($row->splpricetype)
						->setSpecialpricetypeCode($row->splpriceCode);
				$splWeek = array();
				if($rowResult){
					foreach($rowResult as $value){
						$splRecurenceObj = new Deals_Model_RestaurantSpecialRecurence();
						$splRecurenceObj->setWeekId($value->rsrday_of_week);
						$splRecurenceObj->setWeekDesc($value->day);
						$splWeek[] = $splRecurenceObj;
					}
				}
				$splObj->setWeekids($splWeek);
				$resDet[$row->rspid] = $splObj;
			}
			$result['list'] = $resDet;
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveAllActiveSpecialsCountByRestId($resid)
	{
		try{
			$count = "";
			$table = $this->getDbTable();
			$query= $table->select();
			$query->setIntegrityCheck(false);
			
			$query->from(array('rsp'=>'mt.restaurant_special'),array('count(rspid) as search_count'))
			->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name'))
			->where('rest.resid = ?',$resid)
			->where('rsp.rspstatus = ?',true)
			->where('rsp.rspdeletestatus = ?',true)
			->where('rest.resapprovalstatus = ?',1)
			->where('rest.resstatus = ?',1)
			->group(array("rest.resrestaurant_name"));
			
			$rowset = $table->fetchAll($query);
			foreach($rowset as $row){
				$count = $row->search_count;
			}
			
			return $count;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function Updateimgpath($splTitle,$imageRename)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();
		$set = array('rspspecial_image'   => $imageRename);
		try
		{
	        $db->beginTransaction(); 
		    $restWhere = array('rspid = ?'=> $splTitle);
	        $this->getDbTable()->update($set,$restWhere);
			$db->commit();
			$status = true;
			return $status;
		} catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getImagePathById($splid)
	{
			$table = $this->getDbTable();
			$query= $table->select();
			$query->from(array('rsp'=>'mt.restaurant_special'),array('rspspecial_image'))
				  ->where('rspid = ?',$splid);
		    $resultSet = $table->fetchRow($query);
		 //   $result = array('dbimpagepath'=> $resultSet);
		    return $resultSet; 
	}
	
	public function getSpecialDetailsByBookingId($bokid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant'))
				   ->join(array('boktype'=>'mt.booking_type_bd'),'bok.bokbooking_type_id = boktype.id',array('code','description as desc'))
				   ->join(array('splbok'=>'mt.booking_special'),'bok.bokid = splbok.bksfk_booking',array('bksspecial_id','bksamount'))
				   ->where('bok.bokid = ?',$bokid)
				   ->where("boktype.code ='SPL' OR boktype.code = 'SPLPAID'");
					   
			$rowset = $table->fetchRow($select);
				
			$restid = $rowset->bokfk_restaurant;
			$splid = $rowset->bksspecial_id;
			
			$cuisinemapper = new FirmManagement_Model_FirmCuisineDataMapper();
			$restcuisinetable = $cuisinemapper->getDbTable();
	
			$query= $table->select();
			$selectRestCuisine = $restcuisinetable->select();
			$query->setIntegrityCheck(false);
			$query->from(array('rsp'=>'mt.restaurant_special'),array('rspid','rspfk_restaurant','rspno_of_dishes','rspspecial_title','rspregular_price','rspspecial_image','rspdiscount_percentage_point','rspprice_with_discount','rspkids_eat_free',
																	   'rspstart_date','rspend_date','rspstart_time','rspend_time','rspdescription','rspfood_type','rspspecial_type','rsprecurencestatus','rspstatus','rspkidsstatus','rspcategory',
																	   'rsptype_of_occurance','rspdiscount_mode'))
				->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name','resaddress','resgoogleimage','resphone','resdescription'))
				->join(array('cty'=>'mt.city_bd'),'cty.id = rest.rescity_id',array('code as citycode','description as citydesc'))
				->join(array('neigh'=>'mt.neighborhood_bd'),'neigh.id = rest.resneighborhood_id',array('description as neighdesc'))
				->join(array('spb'=>'mt.special_type_bd'),'spb.id = rsp.rspspecial_type',array('description as special'))
				->join(array('spcat'=>'mt.special_category_bd'),'spcat.id = rsp.rspcategory',array('description as splCategory'))
				->joinLeft(array('resfb'=>'mt.restaurant_fb_event'),'resfb.rfbe_fk_deal_id = rsp.rspid',array('rfbe_event_fb_id','rfbe_fk_deal_id','rfbe_start_date','rfbe_start_time','rfbe_end_date','rfbe_end_time','rfbe_created_fb_by','rfbe_status','rfbe_created_fb_for'))
				->joinLeft(array('splcnt'=>'mt.special_count_type_bd'),'splcnt.id = rsp.rsptype_of_occurance',array('code as splCode','description as splCount'))
				->joinLeft(array('discmod'=>'mt.discount_mode_bd'),'discmod.id = rsp.rspdiscount_mode',array('description as discMode','code as discCode'))
				->joinLeft(array('pricetype'=>'mt.special_price_type_bd'),'pricetype.id = rsp.rsppricetype',array('description as splpricetype','code as splpriceCode'))
				->where('rsp.rspid = ?',$splid);
			$result = $table->fetchRow($query);
			
			$recurence = new Deals_Model_RestaurantSpecialRecurenceDataMapper();
			$recurenceTable = $recurence->getDbTable();
			$selectWeeks = $recurenceTable->select();
			$selectWeeks->setIntegrityCheck(false);
			$selectWeeks->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
				->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
				->where('rsr.rsrfk_restaurant_special = ? ',$result->rspid);
			$weekResult = $table->fetchAll($selectWeeks);
			$splWeek= array();
			foreach($weekResult as $value){
				$splRecurenceObj = new Deals_Model_RestaurantSpecialRecurence();
				$splRecurenceObj->setWeekId($value->rsrday_of_week);
				$splRecurenceObj->setWeekDesc($value->day);
				$splWeek[] = $splRecurenceObj;
			}
			$FbInvitesArry = array('accepted' 	=> 0,
									'notreplayed'	=> 0,
									'declined'		=> 0,
									'unsure'		=> 0);
			if($result->rfbe_event_fb_id){
				$resInviteeMapper = new Deals_Model_RestaurantFbEventInviteeDataMapper();
				$select = $resInviteeMapper->getDbTable()->select();
				$select->from($resInviteeMapper->getDbTable(),array('count(rfei_fb_user) as invitCnt','rfei_fb_invite_status'))
						->where('rfei_fk_event = ?',$result->rfbe_event_fb_id)
						->group('rfei_fb_invite_status');
				$resInvitee = $resInviteeMapper->getDbTable()->fetchAll($select);
				foreach($resInvitee as $fbinvitee){
					if($fbinvitee->rfei_fb_invite_status == 'not_replied'){
						$FbInvitesArry['notreplayed'] = $fbinvitee->invitCnt;
					}else if($fbinvitee->rfei_fb_invite_status == 'declined'){
						$FbInvitesArry['declined'] = $fbinvitee->invitCnt;
					}else if($fbinvitee->rfei_fb_invite_status == 'attending'){
						$FbInvitesArry['accepted'] = $fbinvitee->invitCnt;
					}else if($fbinvitee->rfei_fb_invite_status == 'unsure'){
						$FbInvitesArry['unsure'] = $fbinvitee->invitCnt;
					}
				}
			}
			
			$startDate = date('Y-m-d',strtotime($result->rspstart_date));
			$endDate = date('Y-m-d',strtotime($result->rspend_date));
			$startTime = date("h:i A",strtotime($result->rspstart_time));
			$endTime = date("h:i A",strtotime($result->rspend_time));
			$weekIds = "";
			foreach($splWeek as $week){
				$weekIds[] = $week->getWeekId();
			}
			$specialDetails = array();
			$specialDetails = array(
							
							'Id'						=>	$result->rspid,
							'Restaurant Name'			=>	$result->resrestaurant_name,
							'Special Name'				=>	$result->rspspecial_title,
							'Number of Dishes'			=>	$result->rspno_of_dishes.' '.$result->splCount,
							'Speical Type'				=>	$result->special,
							'Start Date'				=>	date('m-d-Y',strtotime($startDate)),
							'End Date'					=>	date("d M Y",strtotime($endDate)),
							'Start Time'				=>	$startTime,
							'End Time'					=>	$endTime,
							'Recurrence' 				=>  $result->rsprecurencestatus,
							'weeks'						=>	$weekIds,
							'Img'						=>	$result->rspspecial_image,
							'Desc'						=>	$result->rspdescription,
							'kidsStatus'				=>	$result->rspkidsstatus,
							'kids Info'					=>	$result->rspkids_eat_free,
							'Special Category'			=>	$result->splCategory,
							'Discount Mode'				=>	$result->discMode,
							'Discountcode'				=>	$result->discCode,
							'Regular Price'				=>	str_replace('$','',$result->rspregular_price),
							'Discount Percentage'		=>	$result->rspdiscount_percentage_point,
							'Price with Discount'		=>	str_replace('$','',$result->rspprice_with_discount),
							'PriceType'					=>	$result->splpricetype,
							'PriceCode'					=>	$result->splpriceCode,
							'Status'					=>	$result->rspstatus,
							'fbinvites'					=>	$FbInvitesArry);
			return $specialDetails;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetDealDetails($resid,$splid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('rsp'=>'mt.restaurant_special'),array('rspid','rspfk_restaurant','rspno_of_dishes','rspspecial_title','rspregular_price','rspspecial_image','rspdiscount_percentage_point','rspprice_with_discount','rspkids_eat_free',
																	   'rspstart_date','rspend_date','rspstart_time','rspend_time','rspdescription','rspfood_type','rspspecial_type','rsprecurencestatus','rspstatus','rspkidsstatus','rspcategory',
																	   'rsptype_of_occurance','rspdiscount_mode'))
					->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name','resaddress','resgoogleimage','resphone','resdescription'))
					->join(array('cty'=>'mt.city_bd'),'cty.id = rest.rescity_id',array('code as citycode','description as citydesc'))
					->join(array('neigh'=>'mt.neighborhood_bd'),'neigh.id = rest.resneighborhood_id',array('description as neighdesc'))
					->where('rspid = ?',$splid);					   
			$rowset = $table->fetchRow($select);
			return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}
