<?php
class FirmManagement_Model_EmailMarketingTemplateDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_EmailMarketingTemplate');
		}
		return $this->_dbTable;
	}
	
	public function SaveEmailTemplateDetails(Communication_Model_EmailMessage $message)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$data = array(
					'emt_subject'		=>	$message->getTitle(),
					'emt_body'			=>	$message->getDescription(),
					'emt_sentby'		=>	$message->getSentby(),
					'emt_priority'		=>	$message->getPriority(),
					'emt_signature'		=>  $message->getSignature(),
					'emt_createdby'		=>	$message->getCreatedBy(),
					'emt_createdon'		=>	$message->getCreatedOn(),
					'emt_contacttype'	=>	$message->getContactType(),
					'emt_restid'		=>  $message->getRestId(),
		
				);

		try{
			$msgTable = $this->getDbTable();
			$msgid = $msgTable->insert($data);
			return $msgid;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	public function getAllRestaurantEmailMarketDetails($offset,$data = array(),$restid = null)
	{
		try{
			$limit = 20;
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false); 
			
			$select->from(array('emt' => 'mt.emailmarketingtemplate'),array('emt_id','emt_subject','emt_body','emt_sentby','emt_createdon','emt_priority','emt_contacttype','emt_restid','emt_emailstatus','emt_excelpath'))
					->join(array('res'=>'mt.restaurant'),'res.resid = emt.emt_restid',array('resrestaurant_name'))
					->joinLeft(array('embd'=>'mt.email_market_status_bd'),'embd.id = emt.emt_emailstatus',array('description'));
			if($restid != null){
				$select->where('emt.emt_restid= ?',$restid);		   
			}else if(isset($data['restid']) &&  is_numeric($data['restid'] )){
				$select->where('emt.emt_restid= ?',$data['restid']);
			}
			if(isset($data['restname'])  && $data['restname'] != '' ){
				$select->where('res.resrestaurant_name Ilike ?','%'.trim($data['restname']).'%');
			}
			if(isset($data['startDate']) && $data['startDate'] != ''){
				$select->where('emt.emt_createdon >= ?',$data['startDate']);	
				if($data['endDate']){
					$select->where('emt_createdon <= ?',$data['endDate']);	
				}	
			}
			if(isset($data['status']) && $data['status'] == 4){
				$select->where('emt.emt_emailstatus IS NULL');	
			}else if(isset($data['status']) && $data['status'] != ''){
				$select->where('emt.emt_emailstatus = ?',$data['status']);	
			}
			
			$select->order('emt_id DESC');			   
			$Result = "";
			$Result = new Zend_Paginator(
				new Zend_Paginator_Adapter_DbTableSelect($select)
				);
			$Result->setItemCountPerPage($limit);
			$Result->setCurrentPageNumber($offset);
			return $Result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateExcelContactsPath($excelpath,$tempid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array('emt_excelpath'	=>	$excelpath);
			$where = $db->quoteInto('emt_id = ?',$tempid);
			$result = $this->getDbTable()->update($set,$where);
			return $result;
		 }catch (Exception $ex){
				throw new Exception($ex->getMessage()) ;
		 }
	}
	
	
	public function GetExcelPathByTempid($tempid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$Result = false;
			$select->from(array('emt' => 'mt.emailmarketingtemplate'),array('emt_excelpath'))
				   ->where('emt.emt_id = ?',$tempid);		   
			$result = $table->fetchRow($select);
			if($result){
				$Result	= $result->emt_excelpath;
			}
			return $Result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}