<?php
class FirmManagement_Model_FeedbackQuestionsMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_FeedbackQuestions');
		}
		return $this->_dbTable;
	}
	
	public function feedbackQuestions($restaurantid)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			
			$select->from($this->getDbTable(),array('COUNT(fbq_id) as count'))
				   ->where("fbqfk_restaurantid = ?",$restaurantid);
				   
			$resultSet = $this->getDbTable()->fetchAll($select);

			$count = 0;
			foreach($resultSet as $row){
				$count = $row->count;
			}
			if($count == 0){
				$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
				$timezone = "";
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$timezone = $mapper->GetRestaurantTimeZone($restaurantid);
				date_default_timezone_set($timezone);
				
				$storage = new Zend_Auth_Storage_Session();
				$userdata = $storage->read();
				$db->beginTransaction();
				$que1 = array('fbq_question'		=> 'How easy was it to make a reservation?',
						  'fbqfk_restaurantid'	=> $restaurantid,
						  'fbq_question_type'	=> 1,
						  'fbq_status'			=> 1,
						  'fbq_createdby'		=> $userdata['User_Id'],
						  'fbq_createddatetime'=> date('Y-m-d H:i:s')
						);
				$questionid1 = $this->getDbTable()->insert($que1);	
				$anwserArry = array('1'=>'Excellent','2'=>'Good','3'=>'Average','4'=>'Poor','5'=>'Very Poor');			
				$ansMapper->insertAnwsersByQuestionId($questionid1,$anwserArry);
				
				$que2 = array('fbq_question'		=> 'How was the food?',
						  'fbqfk_restaurantid'	=> $restaurantid,
						  'fbq_question_type'	=> 1,
						  'fbq_status'			=> 1,
						  'fbq_createdby'		=> $userdata['User_Id'],
						  'fbq_createddatetime'=> date('Y-m-d H:i:s')
						);
				$questionid2 = $this->getDbTable()->insert($que2);
				//$anwserArry = array('1'=>'Delighted','2'=>'Happy','3'=>'Ok','4'=>'Not Great','5'=>'Bad','6'=>'No Answer');
				$ansMapper->insertAnwsersByQuestionId($questionid2,$anwserArry);
				
				$que3 = array('fbq_question'		=> 'How was the Service?',
						  'fbqfk_restaurantid'	=> $restaurantid,
						  'fbq_question_type'	=> 1,
						  'fbq_status'			=> 1,
						  'fbq_createdby'		=> $userdata['User_Id'],
						  'fbq_createddatetime'=> date('Y-m-d H:i:s')
						);
				$questionid3 = $this->getDbTable()->insert($que3);
				//$anwserArry = array('1'=>'Excellent','2'=>'Good','3'=>'Average','4'=>'Not Good','5'=>'Needs improvement','6'=>'No Answer');	
				$ansMapper->insertAnwsersByQuestionId($questionid3,$anwserArry);
				
				$que4 = array('fbq_question'		=> 'How was the Ambience?',
						  'fbqfk_restaurantid'	=> $restaurantid,
						  'fbq_question_type'	=> 1,
						  'fbq_status'			=> 1,
						  'fbq_createdby'		=> $userdata['User_Id'],
						  'fbq_createddatetime'=> date('Y-m-d H:i:s')
						);
				$questionid4 = $this->getDbTable()->insert($que4);
				//$anwserArry = array('1'=>'Excellent','2'=>'Good','3'=>'Average','4'=>'Needs improvement','5'=>'Bad','6'=>'No Answer');
				$ansMapper->insertAnwsersByQuestionId($questionid4,$anwserArry);
				
				$que5 = array('fbq_question'		=> 'How was your overall experience?',
						  'fbqfk_restaurantid'	=> $restaurantid,
						  'fbq_question_type'	=> 1,
						  'fbq_status'			=> 1,
						  'fbq_createdby'		=> $userdata['User_Id'],
						  'fbq_createddatetime'=> date('Y-m-d H:i:s')
						);
				$questionid5 = $this->getDbTable()->insert($que5);
				//$anwserArry = array('1'=>'Excellent','2'=>'Good','3'=>'Average','4'=>'Needs improvement','5'=>'Bad','6'=>'No Answer');	
				$ansMapper->insertAnwsersByQuestionId($questionid5,$anwserArry);
				
				$db->commit();
			}
			$questions = $this->GetFeedbackQuestionsByRestaurantId($restaurantid);
			return $questions;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFeedbackQuestionsByRestaurantId($restaurantid)
	{
		try{
			$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
			$table= $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('fbq'=>'mt.feedback_questions'),array('fbq_id','fbq_question','fbq_question_type'))
				   ->joinLeft(array('fbqtybd'=>'mt.feedback_questions_type_bd'),'fbqtybd.id = fbq.fbq_question_type',array('code as feedType'))
				   ->join(array('fbqsbd'=>'mt.feedback_questions_status_bd'),'fbqsbd.id = fbq.fbq_status',array('description as status'))
				   ->where('fbq.fbqfk_restaurantid = ?',$restaurantid)
				   ->where('fbq.fbq_status != 3')
				   ->order('fbq_id');
				   
			$resultSet = $this->getDbTable()->fetchAll($select);
			$finalArray = array();
			foreach($resultSet as $row){
				$ansselect = $ansMapper->getDbTable()->select();
				$ansselect->from(array('mt.feedback_answers'),array('fba_answer'))
						  ->where('fba_questionid = ?',$row->fbq_id)
						  ->where('fba_status = ?',true);
				$tempArr = array();		  
				$ansSet = $ansMapper->getDbTable()->fetchAll($ansselect);
				foreach($ansSet as $ansrow){
					$tempArr[] = $ansrow->fba_answer;
				}
				//$finalArray[$row->fbq_question] = $tempArr;
				$finalArray[] = array(
									'questionid'	=> $row->fbq_id,
									'questiontype'	=> $row->feedType,
									'question'		=> $row->fbq_question,
									'answers'		=> $tempArr,
									'status'		=> $row->status 
								);
			}
			return $finalArray;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getFeedbackQuestionAndAnswerById($questionId)
	{
		try{
			$finalArray = array();
			$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
			
			$queselect = $this->getDbTable()->select();			
			$queselect->from($this->getDbTable(),array('fbq_question','fbq_question_type'))
				   ->where('fbq_id = ?',$questionId);				   
			$questionSet = $this->getDbTable()->fetchRow($queselect);
			
			$ansselect = $ansMapper->getDbTable()->select();
			$ansselect->from(array('mt.feedback_answers'),array('fba_id','fba_answer'))
						  ->where('fba_questionid = ?',$questionId)
						  ->where('fba_status = ?',true);
			$tempArr = array();		  
			$answerSet = $ansMapper->getDbTable()->fetchAll($ansselect);
			foreach($answerSet as $ansrow){
				$tempArr[$ansrow->fba_id] = $ansrow->fba_answer;
			}
			
			if($questionSet->fbq_question_type == 1){
				$finalArray['question'] = $questionSet->fbq_question;
				$finalArray['questiontype'] = 'OPT';
				$finalArray['answers'] = $tempArr;
			}else{
				$finalArray['question'] = $questionSet->fbq_question;
				$finalArray['questiontype'] = 'TEXT';
				$finalArray['answers'] = $tempArr;
			}
			return $finalArray;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateFeedbackQuestionAndAnswerById($request)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
		
		try{
			$db->beginTransaction();
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($request->restaurantid);
			date_default_timezone_set($timezone);
			
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			if(trim($request->questiontypeid) == 'TEXT'){
				$answerArr = $request->answer;
				$queset = array(
								'fbq_question' 		=> trim($request->question),
								'fbq_question_type' => 2,
								'fbq_updatedby'		=> $userdata['User_Id'],
								'fbq_updateddatetime'=> date('Y-m-d H:i:s')
							);
				$quewhere = $db->quoteInto('fbq_id = ?',$request->questionid);
				$this->getDbTable()->update($queset,$quewhere);
				
				$answerIdsArr = $request->answerid;
				for($i = 1; $i <= count($answerArr) ; $i++){
					$ansset = array(
								'fba_answer' 		=> trim($answerArr[$i]),
								'fba_updatedby'		=> $userdata['User_Id'],
								'fba_updateddatetime'=> date('Y-m-d H:i:s')
							);
				
					$answhere = $db->quoteInto('fba_id = ?',$answerIdsArr[$i]);
					$ansMapper->getDbTable()->update($ansset,$answhere);	
				}
			}else if(trim($request->questiontypeid) == 'OPT'){
				$answerArr = $request->answer;
				$queset = array(
							'fbq_question'		=> trim($request->question),
							'fbq_question_type' => 1,
							'fbq_updatedby'	=> $userdata['User_Id'],
							'fbq_updateddatetime'=> date('Y-m-d H:i:s')
						);
				$quewhere = $db->quoteInto('fbq_id = ?',$request->questionid);
				$this->getDbTable()->update($queset,$quewhere);
				
				$answerIdsArr = $request->answerid;
				for($i = 1; $i <= count($answerArr) ; $i++){
					$ansdata = array(
							'fba_answer'	 => trim($answerArr[$i]),
							'fba_status'	 => true,
							'fba_updatedby'	 => $userdata['User_Id'],
							'fba_updateddatetime'=> date('Y-m-d H:i:s')
						   );
					$answhere = $db->quoteInto('fba_id = ?',$answerIdsArr[$i]);
					$ansMapper->getDbTable()->update($ansdata,$answhere);
				}				
			}			
			$db->commit();
			return true;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function addFeedbackQuestionAndAnswer($request)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
		try{
			$db->beginTransaction();
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($request->restaurantid);
			date_default_timezone_set($timezone);
			
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			$data = array(
						'fbq_question'			=> trim($request->question),
						'fbqfk_restaurantid'	=> $request->restaurantid,
						'fbq_status'			=> true,
						'fbq_createdby'			=> $userdata['User_Id'],
						'fbq_createddatetime'	=> date('Y-m-d H:i:s')
					);
			if(isset($request->answer)){
				$data['fbq_question_type'] = 1;
			}else{
				$data['fbq_question_type'] = 2;
			}
			$questionid = $this->getDbTable()->insert($data);
				
			if(isset($request->answer)){	
				$answerArr = $request->answer;
				for($i = 1; $i <= count($answerArr) ; $i++){
					$ansdata = array(
							'fba_questionid' => $questionid,
							'fba_answer'	 => trim($answerArr[$i]),
							'fba_status'	 => true,
							'fba_createdby'	 => $userdata['User_Id'],
							'fba_createddatetime'=> date('Y-m-d H:i:s')
						   );
					$ansMapper->getDbTable()->insert($ansdata);
				}
			}
			$db->commit();
			return true;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function changeFeedbackQuestionStatus($questionid, $status, $restaurantid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restaurantid);
			date_default_timezone_set($timezone);
			
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			$set = array(
						'fbq_status' 		=> $status,
						'fbq_updatedby'	=> $userdata['User_Id'],
					    'fbq_updateddatetime'=> date('Y-m-d H:i:s')
					);
			
			$where = $db->quoteInto('fbq_id = ?',$questionid);
			$row_affected = $this->getDbTable()->update($set,$where);
			return $row_affected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getFeedbackQuestionsAndAnswersByRestaurantId($restaurantid)
	{
		try{
			$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
			$table= $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('fbq'=>'mt.feedback_questions'),array('fbq_id','fbq_question','fbq_question_type'))
				   ->joinLeft(array('fba'=>'mt.feedback_questions_type_bd'),'fba.id = fbq.fbq_question_type',array('code as feedType'))
				   ->where('fbq.fbqfk_restaurantid = ?',$restaurantid)
				   ->where('fbq.fbq_status = 1')
				   ->order('fbq_id');
				   
			$resultSet = $this->getDbTable()->fetchAll($select);
			$finalArray = array();
			foreach($resultSet as $row){
				if($row->fbq_question_type != 2){
					$ansselect = $ansMapper->getDbTable()->select();
					$ansselect->from(array('mt.feedback_answers'),array('fba_id','fba_answer'))
							  ->where('fba_questionid = ?',$row->fbq_id)
							  ->where('fba_status = ?',true);
					$tempArr = array();		  
					$ansSet = $ansMapper->getDbTable()->fetchAll($ansselect);
					foreach($ansSet as $ansrow){
						$tempArr[$ansrow->fba_id] = $ansrow->fba_answer;
					}
				}else{
					$tempArr	=	false;
				}
				$finalArray[] = array(
									'questionid'=> $row->fbq_id,
									'question'	=> $row->fbq_question,
									'answers'	=> $tempArr,
									'feedType'	=> $row->feedType 
								);	
			}
			return $finalArray;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function saveCustomerFeedback($request)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
		$cusMapper = new FirmManagement_Model_CustomerFeedbackMapper();
		$commentsMapper = new FirmManagement_Model_CustomerFeedbackCommentsMapper();
		
		$cusWordsMapper = new FirmManagement_Model_CustomerFeedbackWordsDataMapper();
		
		$timezone = "";
		$mapper = new FirmManagement_Model_FirmDataMapper();
		$timezone = $mapper->GetRestaurantTimeZone($request->restaurantid);
		date_default_timezone_set($timezone);
		
		$questionsArr = $request->questionids;
		$answersArr = $request->answerids;
		//$commquestionsArr = $request->commquestionids;
		//$commanswersArr = $request->commanswerids;
		$addiComments = $request->addiComments;
		$rating = 0;
		if($request->rating){
			$rating = $request->rating;
		}
		$result = 0;		
		$frm = $request->guestForm;
		if($request->guestForm){
			$firmServ = new FirmManagement_Model_FirmGroupUsersDataMapper();
			$cusData = new FirmManagement_Model_FirmGroupUsers();
			$cusData->setRestaurantId($request->restaurantid)
					->setGroupId(3)
					->setFirstName($frm[0]['value'])
					->setLastName($frm[1]['value'])
					->setEmail($frm[4]['value'])
					->setcountry_code($frm[2]['value'])
					->setPhone($frm[3]['value'])
					->setStatus(TRUE);
			if($frm[6]['value']){         
				$cusData->setrgu_birthday($frm[6]['value']);
			}
			if($frm[8]['value']){
				$cusData->setrgu_anniversary($frm[8]['value']);
			}
			$customerAdd = $firmServ->addUserContact($cusData);			
		}
		try{
			$db->beginTransaction();
			$dateandTime = date('Y-m-d H:i:s');
			$negFeedQuesArr = array();
			for($i = 1; $i <= count($questionsArr) ; $i++){
				$question = "";
				$queselect = $this->getDbTable()->select();			
				$queselect->from($this->getDbTable(),array('fbq_question'))
					      ->where('fbq_id = ?',$questionsArr[$i]);				   
				$questionSet = $this->getDbTable()->fetchRow($queselect);
				if($questionSet){
					$question = $questionSet->fbq_question;
				}
				$answer = "";
				$ansselect = $ansMapper->getDbTable()->select();
				$ansselect->from($ansMapper->getDbTable(),array('fba_answer'))
						  ->where('fba_id = ?',$answersArr[$i]);
							  
				$answerSet = $ansMapper->getDbTable()->fetchRow($ansselect);
				if($answerSet){
					$answer = $answerSet->fba_answer;
				}
				if($question != "" && $answer != ""){
					$data = array(
							'fbcm_restaurantid'	=> $request->restaurantid,
							'fbcm_questionid'	=> $questionsArr[$i],
							'fbcm_question'		=> $question,
							'fbcm_anwser'		=> $answer,
							'fbcm_answerid'		=> $answersArr[$i],
							'fbcm_createddatetime'=> $dateandTime
							);
					if($request->bookingid){
						$data['fbcm_bookingid']	= $request->bookingid;
						$data['fbcm_guestid']	= $customerAdd;
					}else{
						$data['fbcm_guestid']	= $customerAdd;
					}	
                                        if($request->botableid){
                                            $data['fbcm_tableid']	= $request->botableid;
                                        }
					
					$result = $cusMapper->getDbTable()->insert($data);
					$negFeedQuesArr[] = $questionsArr[$i];
					$negFeedAnsArr[] = $answersArr[$i];
				}
			}
			if($addiComments == ""){
				$addiComments = "No Description";
			}
			$comments = array(
						'fbcc_restaurantid'	=> $request->restaurantid,							
						'fbcc_comment'		=> $addiComments,
						'fbcm_createddatetime'=> $dateandTime,
						'fbcc_rating'		=>	$rating
						);
			if($request->bookingid){
				$comments['fbcc_bookingid']	= $request->bookingid;
				$comments['fbcc_guestid']	= $customerAdd;
			}else{
				$comments['fbcc_guestid']	= $customerAdd;
			}
                        if($request->botableid){
                                 $comments['fbcc_tableid']	= $request->botableid;
                                }
			$result = $commentsMapper->getDbTable()->insert($comments);
			if($result != 0 && $request->bookingid){
				$bookMapper = new Reservation_Model_ReservationDataMapper();
				$bookMapper->updateFeedbackStatusByBookingId($request->bookingid);
			}
			if($rating == 1 || $rating == 2){
				$commArr = array('commentId'=>$result, 'comments'=>$comments,'negFeedQuesArr'=>$negFeedQuesArr,'negFeedAnsArr'=>$negFeedAnsArr,'custDet'=>$cusData);
				$commServ = new Application_Service_Communication();
				$negFeedSend = $commServ->SendNegativeFeedNotification($commArr);
			}
			$db->commit();
			return true;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkFeedbackAlredyGiven($request)
	{
		try{
			$count = 0; 
			$cusMapper = new FirmManagement_Model_CustomerFeedbackMapper();
			$select = $cusMapper->getDbTable()->select();			
			$select->from($cusMapper->getDbTable(),array('COUNT(fbcm_id) as count'))
				      //->where('fbcm_restaurantid = ?',$request->restaurantid)
				      ->where('fbcm_bookingid = ?',$request->bookingid);				   
			$rowSet = $cusMapper->getDbTable()->fetchRow($select);
			if($rowSet){
				$count = $rowSet->count;
			}
			if($count == 0){
				$select = "";
				$commentsMapper = new FirmManagement_Model_CustomerFeedbackCommentsMapper();
				$select = $commentsMapper->getDbTable()->select();			
				$select->from($commentsMapper->getDbTable(),array('COUNT(fbcc_id) as count'))
					      //->where('fbcc_restaurantid = ?',$request->restaurantid)
					      ->where('fbcc_bookingid = ?',$request->bookingid);				   
				$rowset = $commentsMapper->getDbTable()->fetchRow($select);
				if($rowset){
					$count = $rowset->count;
				}
			}
			if($count == 0){
				return false;
			}else{
				return true;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getFeedbackDeatilsByBookingId($bookingArr)
	{
		try{
			$finalArr = array();
			for($i = 0; $i < count($bookingArr); $i++){
				$cusMapper = new FirmManagement_Model_CustomerFeedbackMapper();
				$select = $cusMapper->getDbTable()->select();			
				$select->from($cusMapper->getDbTable(),array('fbcm_question','fbcm_answer'))
					      ->where('fbcm_bookingid = ?',$bookingArr[$i]);				   
				$resultSet = $cusMapper->getDbTable()->fetchAll($select);
				$resultArr = array();
				foreach($resultSet as $row){
					$resultArr[$row->fbcm_question] = $row->fbcm_answer;
				}
				$comment = "";
				$commentsMapper = new FirmManagement_Model_CustomerFeedbackCommentsMapper();
				$commentselect = $commentsMapper->getDbTable()->select();			
				$commentselect->from($commentsMapper->getDbTable(),array('fbcc_comment'))
					      ->where('fbcc_bookingid = ?',$bookingArr[$i]);				   
				$rowset = $commentsMapper->getDbTable()->fetchRow($commentselect);
				if($rowset){
					$comment = $rowset->fbcc_comment;
				}
				if($comment != "" || !empty($resultArr)){
					$finalArr[$bookingArr[$i]] = array(
							'questionandanswers' => $resultArr,
							'comment'			 => $comment
							);
				}
			}
			return $finalArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFeedbackHistoryofBookingId($bookingId)
	{
		try{
			$finalArr = array();
			$cusMapper = new FirmManagement_Model_CustomerFeedbackMapper();
			$select = $this->getDbTable()->select();	
			$select->setIntegrityCheck(false);		
			$select->from(array('mt.feedback_customer_map'),array(''))
				   ->join(array('mt.feedback_questions'),'fbq_id = fbcm_questionid',array('fbq_question as question'))
				   ->join(array('mt.feedback_answers'),'fba_id = fbcm_answerid',array('fba_answer as answer'))
				  ->where('fbcm_bookingid = ?',$bookingId);	
	    	$resultSet = $this->getDbTable()->fetchAll($select);
	    	if($resultSet){
		    	$optionArr = array();
		    	foreach($resultSet as $result){
		    		$optionArr[$result->question] = $result->answer;
		    	}
			}
			$select = $this->getDbTable()->select();	
			$select->setIntegrityCheck(false);		
			$select->from(array('mt.feedback_customer_words_map'),array('fbcwm_anwser as answer'))
				  ->join(array('mt.feedback_questions'),'fbcwm_questionid = fbq_id',array('fbq_question as question')) 
				  ->where('fbcwm_bookingid = ?',$bookingId);	
			$resultSet = $this->getDbTable()->fetchAll($select);
	    	if($resultSet){
		    	$textArr = array();
		    	foreach($resultSet as $result){
		    		$textArr[$result->question] = $result->answer;
		    	}
			} 
			
			$comment = "";
			$commentsMapper = new FirmManagement_Model_CustomerFeedbackCommentsMapper();
			$commentselect = $commentsMapper->getDbTable()->select();			
			$commentselect->from($commentsMapper->getDbTable(),array('fbcc_comment','fbcc_rating'))
				      ->where('fbcc_bookingid = ?',$bookingId);				   
			$rowset = $commentsMapper->getDbTable()->fetchRow($commentselect);
			$commentsArr = array();
			if($rowset){
				$commentsArr['comment'] = $rowset->fbcc_comment;
				$commentsArr['rating'] = $rowset->fbcc_rating;				
			}			
			$finalArr = array('options' => $optionArr,'text'=>$textArr,'comments'=>$commentsArr);
			return $finalArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFeedbackReportHistoryofRestaurant($restid,$from,$to)
	{
		try{
			$finalArr = array();
			$cusMapper = new FirmManagement_Model_CustomerFeedbackMapper();
			$select = $this->getDbTable()->select();	
			$select->setIntegrityCheck(false);	
			$joinStr = " and fbcm_createddatetime >= '$from' and fbcm_createddatetime <= '$to'";
			$select->from(array('mt.feedback_questions'),array('fbq_question as question','fbq_id'))
				   ->join(array('mt.feedback_answers'),'fba_questionid = fbq_id',array('fba_answer as answer'))
				   ->joinLeft(array('mt.feedback_customer_map'),'fbq_id = fbcm_questionid and fbcm_answerid = fba_id'.$joinStr,array('count(fbcm_id) as count','fbcm_answerid'))
				  ->where('fbqfk_restaurantid = ?',$restid)
				  ->where('fbq_status = 1')
				  ->group(array('fbq_id','fbcm_answerid','fbq_question','fba_answer'))
				  ->order('fbq_id');	
	    	$resultSet = $this->getDbTable()->fetchAll($select);
	    	$i = 0;
	    	$resultArr = array();
			foreach($resultSet as $resSet){
				$resultArr[$resSet->fbq_id][] = array('ansDesc'=>$resSet->answer,'ansId'=>$resSet->fbcm_answerid,'quesDesc'=>$resSet->question,'count'=>$resSet->count);
			}
			$comment = "";
			$commentsMapper = new FirmManagement_Model_CustomerFeedbackCommentsMapper();
			$commentselect = $commentsMapper->getDbTable()->select();	
			$commentselect->setIntegrityCheck(false);		
			$commentselect->from($commentsMapper->getDbTable(),array('fbcc_id','fbcc_comment','fbcc_rating','fbcm_createddatetime'))
						->join(array('gues'=>'mt.restaurant_group_users'),'rguid = fbcc_guestid',array('rgufirst_name','rgulast_name','rguemail','rguphone'))
						->where('fbcm_createddatetime >= ?',$from)
				  		->where('fbcm_createddatetime <= ?',$to)
				      ->where('fbcc_restaurantid = ?',$restid);				   
			$rowset = $commentsMapper->getDbTable()->fetchAll($commentselect);
			$sumofrating = 0;
			$k = 0;
			$rowsetArr = array();
			foreach($rowset as $row){
				$rowsetArr[] = $row;
				$sumofrating += $row->fbcc_rating; 
				$k++;
			}
			if($k){
				$avgRating = $sumofrating/$k;
			}else{
				$avgRating = 0;
			}
			$ratingSel = $commentsMapper->getDbTable()->select();	
			$ratingSel->setIntegrityCheck(false);		
			$ratingSel->from($commentsMapper->getDbTable(),array('count(fbcc_id) as userRev','fbcc_rating'))
						->where('fbcm_createddatetime >= ?',$from)
				  		->where('fbcm_createddatetime <= ?',$to)
				      ->where('fbcc_restaurantid = ?',$restid)
				      ->group('fbcc_rating')
				      ->order('fbcc_rating desc');
			$rateSet = $commentsMapper->getDbTable()->fetchAll($ratingSel);
			$rateArr = array();
			$sumofcount = 0;
			foreach($rateSet as $rate){
				$rateArr[$rate->fbcc_rating] = $rate->userRev;
				$sumofcount += $rate->userRev;
			}
			$finalArr = array('options' => $resultArr,'comments'=>$rowsetArr,'total'=>count($rowsetArr),'avgRat'=>round($avgRating,1),'userRev'=>$rateArr,'sumofcount'=>$sumofcount);
			return $finalArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFeedbackReviewsHistoryofRestaurant($restid,$from,$to)
	{
		try{
			$finalArr = array();
			$feedSelect = $this->getDbTable()->select();	
			$feedSelect->setIntegrityCheck(false);	
			$feedSelect->from(array('cm'=>'mt.feedback_customer_map'),array('fbcm_restaurantid as restaurant','array_agg(fbcm_id) as idarr','array_agg(fbcm_questionid) as quesarr','array_agg(fbcm_answerid) as ansarr','cc.fbcm_createddatetime as feedcreatedtime','fbcm_guestid as guest'))
						->joinLeft(array('cc'=>'mt.feedback_customer_comments'),'fbcc_guestid = fbcm_guestid and cm.fbcm_createddatetime = cc.fbcm_createddatetime',array('fbcc_id as commentid','cc.fbcm_createddatetime','fbcc_comment as comment','fbcc_rating as rating')) 
						->join(array('mt.restaurant'),'fbcm_restaurantid = resid',array('resrestaurant_name'))
						->join(array('gues'=>'mt.restaurant_group_users'),'rguid = fbcm_guestid',array('rgufirst_name','rgulast_name','rguemail','rguphone'))
						->where('fbcm_restaurantid = ?',$restid)
						->where('cm.fbcm_createddatetime >= ?',$from)
				  		->where('cm.fbcm_createddatetime <= ?',$to)
				  		->group(array('cm.fbcm_createddatetime','fbcm_guestid','resrestaurant_name','fbcm_restaurantid','cc.fbcm_createddatetime','fbcc_id','fbcc_comment','fbcc_rating','rgufirst_name','rgulast_name','rguemail','rguphone'))
						->order('cm.fbcm_createddatetime desc');		
			$resultSet = $this->getDbTable()->fetchAll($feedSelect);
			foreach($resultSet as $row){
				$idArr= str_getcsv(trim($row->idarr, '{}'));
				$quesArr= str_getcsv(trim($row->quesarr, '{}'));
				$ansArr= str_getcsv(trim($row->ansarr, '{}'));
				$quesSelect = $this->getDbTable()->select();	
				$quesSelect->setIntegrityCheck(false);	
				$quesSelect->from(array('mt.feedback_questions'),array('fbq_question'))
						->where('fbq_id IN (?)',$quesArr);
				$quesResult = $this->getDbTable()->fetchAll($quesSelect);
				$queResArr = array();
				foreach($quesResult as $querow){
					$queResArr[] = $querow->fbq_question;
				}
				$feedCommResult = array();
				if($row->commentid){
					$feedCommMapper = new FirmManagement_Model_FeedbackCommunicationMapper();
					$feedCommSel = $feedCommMapper->getDbTable()->select();
					$feedCommSel->setIntegrityCheck(false);
					$feedCommSel->from($feedCommMapper->getDbTable(),array('fbco_id','fbco_fk_feedback','fbco_feedback_desc','fbco_feedback_created','fbco_feedback_created_by','fbco_created_user'))
					->join(array('utb'=>'mt.usertype_bd'),'utb.id = fbco_feedback_created_by',array('code'))
					->where('fbco_fk_feedback = ?',$row->commentid)
					->order('fbco_feedback_created');
					$feedCommResult = $feedCommMapper->getDbTable()->fetchAll($feedCommSel)->toArray();
				}
				$ansSelect = $this->getDbTable()->select();	
				$ansSelect->setIntegrityCheck(false);	
				$ansSelect->from(array('mt.feedback_answers'),array('fba_answer'))
						->where('fba_id IN (?)',$ansArr);
				$ansResult = $this->getDbTable()->fetchAll($ansSelect);
				$ansResArr = array();
				foreach($ansResult as $ansrow){
					$ansResArr[] = $ansrow->fba_answer;
				}
				$finalArr[] = array('idArr'=>$idArr,'quesArr'=>$queResArr,'ansArr'=>$ansResArr,'feedCommResult'=>$feedCommResult,'restaurant_name'=>$row->resrestaurant_name,'restaurant'=>$row->restaurant,'guest'=>$row->guest,'commentid'=>$row->commentid,'comment'=>$row->comment,'rating'=>$row->rating,'created'=>$row->feedcreatedtime,'fname'=>$row->rgufirst_name,'lname'=>$row->rgulast_name,'email'=>$row->rguemail,'phone'=>$row->rguphone);
			}
			return $finalArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFeedbackReviewsById($ID)
	{
		try{
			$finalArr = array();
			$feedSelect = $this->getDbTable()->select();
			$feedSelect->setIntegrityCheck(false);
			$feedSelect->from(array('cm'=>'mt.feedback_customer_map'),array('fbcm_restaurantid as restaurant','array_agg(fbcm_id) as idarr','array_agg(fbcm_questionid) as quesarr','array_agg(fbcm_answerid) as ansarr','cc.fbcm_createddatetime as feedcreatedtime','fbcm_guestid as guest'))
			->joinLeft(array('cc'=>'mt.feedback_customer_comments'),'fbcc_guestid = fbcm_guestid and cm.fbcm_createddatetime = cc.fbcm_createddatetime',array('fbcc_id as commentid','cc.fbcm_createddatetime','fbcc_comment as comment','fbcc_rating as rating'))
			->join(array('res'=>'mt.restaurant'),'fbcm_restaurantid = resid',array('resrestaurant_name','resemail'))
			->join(array('gues'=>'mt.restaurant_group_users'),'rguid = fbcm_guestid',array('rgufirst_name','rgulast_name','rguemail','rguphone'))
			->where('fbcc_id = ?',$ID)
			->group(array('cm.fbcm_createddatetime','fbcm_guestid','resrestaurant_name','resemail','fbcm_restaurantid','cc.fbcm_createddatetime','fbcc_id','fbcc_comment','fbcc_rating','rgufirst_name','rgulast_name','rguemail','rguphone'))
			->order('cm.fbcm_createddatetime desc');
			$row = $this->getDbTable()->fetchRow($feedSelect);
				
			$idArr= str_getcsv(trim($row->idarr, '{}'));
			$quesArr= str_getcsv(trim($row->quesarr, '{}'));
			$ansArr= str_getcsv(trim($row->ansarr, '{}'));
			$quesSelect = $this->getDbTable()->select();
			$quesSelect->setIntegrityCheck(false);
			$quesSelect->from(array('mt.feedback_questions'),array('fbq_question'))
			->where('fbq_id IN (?)',$quesArr);
			$quesResult = $this->getDbTable()->fetchAll($quesSelect);
			$queResArr = array();
			$feedCommMapper = new FirmManagement_Model_FeedbackCommunicationMapper();
			$feedCommSel = $feedCommMapper->getDbTable()->select();
			$feedCommSel->setIntegrityCheck(false);
			$feedCommSel->from($feedCommMapper->getDbTable(),array('fbco_id','fbco_fk_feedback','fbco_feedback_desc','fbco_feedback_created','fbco_feedback_created_by','fbco_created_user'))
						->join(array('utb'=>'mt.usertype_bd'),'utb.id = fbco_feedback_created_by',array('code'))
						->where('fbco_fk_feedback = ?',$row->commentid)
						->order('fbco_feedback_created');
			$feedCommResult = $feedCommMapper->getDbTable()->fetchAll($feedCommSel);
			foreach($quesResult as $querow){
				$queResArr[] = $querow->fbq_question;
			}
			$ansSelect = $this->getDbTable()->select();
			$ansSelect->setIntegrityCheck(false);
			$ansSelect->from(array('mt.feedback_answers'),array('fba_answer'))
			->where('fba_id IN (?)',$ansArr);
			$ansResult = $this->getDbTable()->fetchAll($ansSelect);
			$ansResArr = array();
			foreach($ansResult as $ansrow){
				$ansResArr[] = $ansrow->fba_answer;
			}
			$finalArr[] = array('idArr'=>$idArr,'quesArr'=>$queResArr,'ansArr'=>$ansResArr,'feedCommResult'=>$feedCommResult,'restaurant_name'=>$row->resrestaurant_name,'resemail'=>$row->resemail,'restaurant'=>$row->restaurant,'guest'=>$row->guest,'commentid'=>$row->commentid,'comment'=>$row->comment,'rating'=>$row->rating,'created'=>$row->feedcreatedtime,'fname'=>$row->rgufirst_name,'lname'=>$row->rgulast_name,'email'=>$row->rguemail,'phone'=>$row->rguphone);
			return $finalArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestQuestionsByRestId($restid)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('fbq_id','fbq_question','fbq_question_type','fbq_status','fbq_createdby','fbq_createddatetime','fbq_updatedby','fbq_updateddatetime','fbqfk_restaurantid'))
				   ->where('fbqfk_restaurantid = ?',$restid);
		    
			$rowSet = $table->fetchAll($select);
			
			$result = array();
			$questions = array();
			$answers = array();
			$question_id =  array();
			
			if(count($rowSet)){
				
				foreach($rowSet as $row){
					
					$question_id[] = $row->fbq_id;					
					$questions[] = array('fbq_id'		       => $row->fbq_id,
									     'fbq_question'		   => $row->fbq_question,
									     'fbq_question_type'   => $row->fbq_question_type,
										 'fbq_status'		   => $row->fbq_status,
									     'fbq_createdby' 	   => $row->fbq_createdby,
									     'fbq_createddatetime' => $row->fbq_createddatetime,
									     'fbq_updatedby'       => $row->fbq_updatedby,
									     'fbq_updateddatetime' => $row->fbq_updateddatetime,
									     'fbqfk_restaurantid'  => $row->fbqfk_restaurantid);
				}
				
				$result['Questions'] = $questions;
				
				/* Get Answers for Questions */
				
				$FeedbackAnswersMapper = new FirmManagement_Model_FeedbackAnswersMapper();
				$answers = $FeedbackAnswersMapper->GetFeedbackQuestAnsByQuestId($question_id);
				$result['Answers'] = $answers;
				
			}else{
				$result['Questions'] = false;
				$result['Answers'] = false;
			}
			
			return $result;
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}		
	}

	public function SaveTabletFeedBack($customerfeedback)
	{
		try
		{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			
			$restid 	 = $customerfeedback->restaurantid;						
			$contactsArr = $customerfeedback->contacts;				
			$feedbackArr = $customerfeedback->feedbacks;
			$commentsArr = $customerfeedback->comments;
                                                			
			$timezone = "";
			$firmDataMapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $firmDataMapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			
			$firmServ 		= new FirmManagement_Model_FirmGroupUsersDataMapper();
			$cusMapper 		= new FirmManagement_Model_CustomerFeedbackMapper();
			$commentsMapper = new FirmManagement_Model_CustomerFeedbackCommentsMapper();
			
			$result = array();
			$contactidarr = array();
			$cusDataArr = array();
			$commArr = array();
			$i=0;
			/* Save Contact details */
			foreach($contactsArr as $contact)			
			{
					
				$cusData = new FirmManagement_Model_FirmGroupUsers();
				$cusData->setRestaurantId($restid)
						->setGroupId(3)
						->setFirstName($contact->rgufirst_name)
						->setLastName($contact->rgulast_name)
						->setEmail($contact->rguemail)
						->setcountry_code($contact->rgucountrycode)
						->setPhone($contact->rguphone)
						->setStatus(TRUE);
						
				if($contact->rgu_birthday)
				{
					$cusData->setrgu_birthday($contact->rgu_birthday);
				}
						
				if($contact->rgu_anniversary)
				{
					$cusData->setrgu_anniversary($contact->rgu_anniversary);
				}	

				$guestid = $firmServ->addUserContact($cusData);
				$commArr[$contact->rgulocid]['custDet'] = $cusData;
				$i++;
				$contactidarr[$contact->rgulocid] = $guestid;		
			}
			
			/* Save Feedbacks */
			$negFeedQuesArr = array();
			$negFeedAnsArr = array();
			$i=0;
			foreach($feedbackArr as $feedback)
			{
				
				$data = array(
						'fbcm_restaurantid'	   => $restid,
						'fbcm_questionid'	   => $feedback->fbcm_questionid,							
						'fbcm_answerid'		   => $feedback->fbcm_answerid,
					        'fbcm_createdby'       => $feedback->fbcm_createdby,
						'fbcm_createddatetime' => $feedback->fbcm_createddatetime,
						'fbcm_guestid'		   => $contactidarr[$feedback->fbcm_locguestid]
						);
                                if($feedback->bookingid){
                                    $data['fbcm_bookingid']	= $feedback->bookingid;
                                }
                                if($feedback->tableid){
                                    $data['fbcm_tableid']	= $feedback->tableid;
                                }
				$commArr[$feedback->fbcm_locguestid]['negFeedQuesArr'][] = $feedback->fbcm_questionid;
				$commArr[$feedback->fbcm_locguestid]['negFeedAnsArr'][] = $feedback->fbcm_answerid;	
				$i++;	
				$feedback_result = $cusMapper->getDbTable()->insert($data);
			}
			
			/* Save Comments and Ratings */
			$commentResArr = array();
			$i=0;
			foreach($commentsArr as $comment)
			{
				
				$data = array(
							'fbcc_restaurantid'	   => $restid,							
							'fbcc_comment'		   => $comment->fbcc_comment,
							'fbcc_rating'		   => $comment->fbcc_rating,
							'fbcm_createdby'	   => $comment->fbcc_createdby,
							'fbcm_createddatetime' => $comment->fbcc_createddatetime,
							'fbcc_guestid'         => $contactidarr[$comment->fbcc_locguestid]
							);
                                if($comment->bookingid){
                                    $data['fbcc_bookingid']	= $comment->bookingid;
                                }
                                if($comment->tableid){
                                    $data['fbcc_tableid']	= $comment->tableid;
                                }
							
				$comment_result = $commentsMapper->getDbTable()->insert($data);
				$commArr[$comment->fbcc_locguestid]['comments']= $data; 
				if($comment->fbcc_rating == 1 || $comment->fbcc_rating == 2){
					$commArrVar = array('commentId'=>$comment_result,'comments'=>$data,'negFeedQuesArr'=>$commArr[$comment->fbcc_locguestid]['negFeedQuesArr'],'negFeedAnsArr'=>$commArr[$comment->fbcc_locguestid]['negFeedAnsArr'],'custDet'=>$cusData);
					$commServ = new Application_Service_Communication();
					$negFeedSend = $commServ->SendNegativeFeedNotification($commArrVar);
				}
				$i++;
			}		
			
			$db->commit();
			$result["status"] 	   = true;
			$result["webcontacts"] = $contactidarr;
			return $result;
			
		}catch (Exception $ex){
			Uss_Logger_FileLogger::info($ex->getMessage());			
			$db->rollBack();
			$result["status"] = false;
			return $result;
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestQuestionsByRestIdIos($restid)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('fbq_id','fbq_question','fbq_question_type','fbq_status','fbq_createdby','fbq_createddatetime','fbq_updatedby','fbq_updateddatetime','fbqfk_restaurantid'))
				   ->where('fbqfk_restaurantid = ?',$restid);
		    
			$rowSet = $table->fetchAll($select);
			
			$result = array();
			$questions = array();
			$answers = array();
			$question_id =  array();
			
			if(count($rowSet)){
				
				foreach($rowSet as $row){
					
					$question_id[] = $row->fbq_id;					
					$questions[] = array('fbq_id'		       => $row->fbq_id,
									     'fbq_question'		   => $row->fbq_question,
									     'fbq_question_type'   => $row->fbq_question_type,
										 'fbq_status'		   => $row->fbq_status,
									     'fbq_createdby' 	   => $row->fbq_createdby,
									     'fbq_createddatetime' => $row->fbq_createddatetime,
									     'fbq_updatedby'       => $row->fbq_updatedby,
									     'fbq_updateddatetime' => $row->fbq_updateddatetime,
									     'fbqfk_restaurantid'  => $row->fbqfk_restaurantid);
				}
				
				$result['Questions'] = $questions;
				
				/* Get Answers for Questions */
				
				$FeedbackAnswersMapper = new FirmManagement_Model_FeedbackAnswersMapper();
				$answers = $FeedbackAnswersMapper->GetFeedbackQuestAnsByQuestId($question_id);
				$result['Answers'] = $answers;
				
			}else{
				$result['Questions'] = array();
				$result['Answers'] = array();
			}
			
			return $result;
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}		
	}
}
