<?php
class FirmManagement_Model_FirmDayPartySettingsMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_FirmDayPartySettings');
		}
		return $this->_dbTable;
	}
	
	public function GetDayPartySize(FirmManagement_Model_FirmDayPartySettings $object)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rdpsid','rdps_res_max_size','rdps_min_size','rdps_max_size','rdps_status','rdps_week_day'));
			$select->where('rdpsfk_restaurants = ?',$object->getrdpsfk_restaurants());
			//$select->where('rntstatus = ?',true);
			
			$resultSet = $table->fetchAll($select);
			$tempArr = array();
			$resultArr = array();
			$finalArr =  array();
			$dayArr = array();
			
			$restMapper = new FirmManagement_Model_FirmDataMapper();
			$resResult = $restMapper->GetRestMaxPartyAllowed($object->getrdpsfk_restaurants());
			$maxAllowed = $resResult->resmaxpax;
			
			
			foreach($resultSet as $row){
				
				$tempArr['Id'] = $row->rdpsid;
				$resultArr['ressize'] = $maxAllowed;
				$tempArr['minsize'] = $row->rdps_min_size;
				$tempArr['maxsize'] = $row->rdps_max_size;
				$tempArr['daystatus'] = $row->rdps_status;
				$tempArr['day'] = $row->rdps_week_day;
				$dayArr[$row->rdps_week_day] = $tempArr;
			}
			if($dayArr){
				$weekdayArr = array('mon','tue','wed','thu','fri','sat','sun');
				for($i= 0; $i<7;$i++){
					if(isset($dayArr[$weekdayArr[$i]])){
						$finalArr[$weekdayArr[$i]] =$dayArr[$weekdayArr[$i]];
					}else{					
						$finalArr[$weekdayArr[$i]] =array('Id'=>"",'minsize'=>"",'maxsize'=>"",'day'=>"");
					}
				}
				$resultArr['times'] = $finalArr;
			}else{
				$weekdayArr = array('mon','tue','wed','thu','fri','sat','sun');
				for($i= 0; $i<7;$i++){
						$finalArr[$weekdayArr[$i]] =array('Id'=>"",'minsize'=>"",'maxsize'=>"",'day'=>"");
				}
				$resultArr['ressize'] = $maxAllowed;
				$resultArr['times'] = $finalArr;
			}
			return $resultArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdatePartySizeRange(array $dayArr)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			if($dayArr){
				foreach($dayArr as $day){
					if($day->getrdpsid()){
						if($day->getrdps_status()){
							$set = array('rdps_res_max_size' 	=>	$day->getrrdps_res_max_size(),
								 'rdps_min_size'	=>	$day->getrdps_min_size(),
								 'rdps_max_size'	=>	$day->getrdps_max_size(),
								 'rdps_status' 			=>	$day->getrdps_status()
							);
						}else{
							$set = array('rdps_res_max_size' 	=>	$day->getrrdps_res_max_size(),
								 'rdps_min_size'	=>	$day->getrdps_min_size(),
								 'rdps_max_size'	=>	$day->getrdps_max_size(),
								 'rdps_status' 			=>	'false'
							);
						}						
						$where = array('rdpsid = ?'=>$day->getrdpsid());
							
						$id = $this->getDbTable()->update($set,$where);
					}else{
						$data = array('rdpsfk_restaurants'	=>	$day->getrdpsfk_restaurants(),
						  'rdps_res_max_size'			=>	$day->getrrdps_res_max_size(),
						  'rdps_min_size'	=>	$day->getrdps_min_size(),
						  'rdps_max_size'	=>	$day->getrdps_max_size(),
						  'rdps_status'			=>  $day->getrdps_status(),
						  'rdps_week_day'	=>	$day->getrdps_week_day()	
						);
						$id = $this->getDbTable()->insert($data);
					}
				}
			}
			$db->commit();
			if($id){
				return true;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdatePartySizeRangeFromNativeApp(array $dayArr)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$webidArr = array();
		try{
			$db->beginTransaction();
			if($dayArr){
				foreach($dayArr as $day){
					if($day->getrdpsid()){
						if($day->getrdps_status()){
							$set = array('rdps_res_max_size' 	=>	$day->getrrdps_res_max_size(),
								 'rdps_min_size'	=>	$day->getrdps_min_size(),
								 'rdps_max_size'	=>	$day->getrdps_max_size(),
								 'rdps_status' 			=>	$day->getrdps_status()
							);
						}else{
							$set = array('rdps_res_max_size' 	=>	$day->getrrdps_res_max_size(),
								 'rdps_min_size'	=>	$day->getrdps_min_size(),
								 'rdps_max_size'	=>	$day->getrdps_max_size(),
								 'rdps_status' 			=>	'false'
							);
						}						
						$where = array('rdpsid = ?'=>$day->getrdpsid());
							
						$id = $this->getDbTable()->update($set,$where);
					}else{
						$data = array('rdpsfk_restaurants'	=>	$day->getrdpsfk_restaurants(),
						  'rdps_res_max_size'			=>	$day->getrrdps_res_max_size(),
						  'rdps_min_size'	=>	$day->getrdps_min_size(),
						  'rdps_max_size'	=>	$day->getrdps_max_size(),
						  //'rdps_status'			=>  $day->getrdps_status(),
						  'rdps_week_day'	=>	$day->getrdps_week_day()	
						);
						if($day->getrdps_status() == 0){
							$data['rdps_status'] = 'false'; 
						}else{
							$data['rdps_status'] = 'true';
						}
						$id = $this->getDbTable()->insert($data);
						$webidArr[$day->getrdps_week_day()] = $id;
					}
				}
			}
			$db->commit();
			return $webidArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}