<?php
class FirmManagement_Model_FirmDiningAreaDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_FirmDiningArea');
		}
		return $this->_dbTable;
	}
	
	public function getDinigAreasByRestId($resId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rda_diningname','rdaid','rda_diningdisplyname','rda_status'))
			->where('rda_restid = ?',$resId)
			->where('rda_status = ?','TRUE')
			->order('rdaid');

			$rowset = $table->fetchAll($select);

			return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getDinigAreasByRestIdfromFloor($resId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rda_diningname','rdaid','rda_diningdisplyname','rda_status'))
			->where('rda_restid = ?',$resId)
			//->where('rda_status = ?','TRUE')
			->order('rdaid');

			$rowset = $table->fetchAll($select);

			return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AddDiningArea($resId,$diningName,$displayname)
	{
		try{
			$status = false; 
			$result = array();
			$table = $this->getDbTable();
			$esistingData = $this->GetAllDiningAreasByResId($resId);
			foreach($esistingData as $row){
				if(strtolower($row->rda_diningdisplyname) == strtolower($displayname) || strtolower($row->rda_diningname) == strtolower($diningName)){
					$result = array('status'=>false);
					if(strtolower($row->rda_diningdisplyname) == strtolower($displayname)){
						$result['displayname'] = 'err';
					}else{
						$result['displayname'] = 'suc';
					}
					if(strtolower($row->rda_diningname) == strtolower($diningName)){
						$result['diningname'] = 'err';
					}else{
						$result['diningname'] = 'suc';
					}
					return $result;
				}
			}
			$data = array(
				'rda_restid'			=>	$resId,
				'rda_diningname'		=>	$diningName,
				'rda_diningdisplyname'	=>	$displayname,
				'rda_status'			=>	true
			);

			$id = $this->getDbTable()->insert($data);
			if($id){
				$status = true;
			}
			$result = array('status'=>$status,'diningid'=>$id);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditDiningArea($resId,$diningid,$diningname,$displyname)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false; 
			$result = array();
			$esistingData = $this->GetAllDiningAreasByResId($resId);
			foreach($esistingData as $row){
				if($diningid != $row->rdaid){
					if(strtolower($row->rda_diningdisplyname) == strtolower($displyname) || strtolower($row->rda_diningname) == strtolower($diningname)){
						$result = array('status'=>false);
						if(strtolower($row->rda_diningdisplyname) == strtolower($displyname)){
							$result['displayname'] = 'err';
						}else{
							$result['displayname'] = 'suc';
						}
						if(strtolower($row->rda_diningname) == strtolower($diningname)){
							$result['diningname'] = 'err';
						}else{
							$result['diningname'] = 'suc';
						}
						return $result;
					}
				}
			}
			
			$set = array(
				'rda_diningname'		=>	$diningname,
				'rda_diningdisplyname'	=>	$displyname
			);
			
			$where = array(
					'rdaid = ?'		=>	$diningid,
					'rda_restid = ?'=>	$resId	
			);

			$id = $this->getDbTable()->update($set,$where);
			if($id){
				$status = true;
			}
	//		$result = array('status'=>true,'result'=>$status);
			$result = array('status'=>true,'diningname'=>$diningname,'displyname' => $displyname);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditDiningAreaStatus($diningid,$diningsts)
	{
		try{
			$status = false; 
			
			$set = array(
				'rda_status'=>	$diningsts
			);
			
			$where = array(
					'rdaid = ?'		=>	$diningid,
				);

			$id = $this->getDbTable()->update($set,$where);
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetAllDiningAreasByResId($resId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rda_restid','rda_diningname','rda_status','rdaid','rda_diningdisplyname','rda_createdby','rda_createdon'))
			->where('rda_restid = ?',$resId)
			->order('rdaid');

			$rowset = $table->fetchAll($select);

			return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function getDinigAreasStatusById($resId,$diningid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rda_diningname','rdaid','rda_diningdisplyname','rda_status'))
			->where('rda_restid = ?',$resId)
			->where('rdaid = ?',$diningid);
			//->where('rda_status = ?','TRUE')		

			$rowset = $table->fetchAll($select);
			foreach($rowset as $value){
				$resultset[] = array(
							 'diningname'  	   => $value['rda_diningname'],
							 'diningid' 	   => $value['rdaid'],
							 'displayname' 	   => $value['rda_diningdisplyname'],
							 'status' 		   => $value['rda_status'],
							 
				);				
			}

			$result = $resultset;
	//		$result['status'] = array('diningname'=>$rowset->rda_diningname,'diningid'=>$rowset->rdaid,'displayname'=>$rowset->rda_diningdisplyname,'status'=>$rowset->rda_status);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetAllUpdatedDiningAreasByResId($resId)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rda_restid','rda_diningname','rda_status','rdaid','rda_diningdisplyname','rda_createdby','rda_createdon'))
			->where('rda_restid = ?',$resId)
			//->where('rdasync_status = ?', 'C')
			->order('rdaid');

			$rowset = $table->fetchAll($select);

			return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
}