<?php
class FirmManagement_Model_FirmFeedbackMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_FirmFeedbackMap');
		}
		return $this->_dbTable;
	}
	
	public function feedbackQuestionsMapToRestaurant($restaurantid)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			
			$select->from($this->getDbTable(),array('COUNT(fbrm_id) as count'))
				   ->where("fbrm_restaurantid = ?",$restaurantid);
				   
			$resultSet = $this->getDbTable()->fetchAll($select);

			$count = 0;
			foreach($resultSet as $row){
				$count = $row->count;
			}
			if($count == 0){
				$quetionsMapper = new FirmManagement_Model_FeedbackQuestionsMapper();
				$select = $quetionsMapper->getDbTable()->select();
				$select->from(array('mt.feedback_questions'),array('fbq_id'))
				       ->where('fbq_type = ?',1);

				$result = $quetionsMapper->getDbTable()->fetchAll($select);
				
				$timezone = "";
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$timezone = $mapper->GetRestaurantTimeZone($restaurantid);
				date_default_timezone_set($timezone);
				
				$storage = new Zend_Auth_Storage_Session();
				$userdata = $storage->read();
				$db->beginTransaction();
				$quetionIds = array();
				foreach($result as $row){					
					$data = array(
							  'fbrm_restaurantid'	=> $restaurantid,
							  'fbrm_questionid'		=> $row->fbq_id,
							  'fbrm_status'			=> 1,
							  'fbrm_createdby'		=> $userdata['User_Id'],
							  'fbrm_createddatetime'=> date('Y-m-d H:i:s')
							);
					
					$this->getDbTable()->insert($data);
				}
				$db->commit();
			}
			$questions = $this->GetFeedbackQuestionsByRestaurantId($restaurantid);
			return $questions;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFeedbackQuestionsByRestaurantId($restaurantid)
	{
		try{
			$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
			$table= $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('fbrm'=>'mt.feedback_restaurant_map'),array('fbrm_id','fbrm_status'))
				   ->join(array('fbq'=>'mt.feedback_questions'),'fbq.fbq_id = fbrm.fbrm_questionid',array('fbq_id','fbq_question','fbq_type','fbq_question_type'))
				   ->joinLeft(array('fba'=>'mt.feedback_questions_type_bd'),'fba.id = fbq.fbq_question_type',array('code as feedType'))
				   ->join(array('fbs'=>'mt.feedback_restaurant_map_status_bd'),'fbs.id = fbrm.fbrm_status',array('description as status'))
				   ->where('fbrm.fbrm_restaurantid = ?',$restaurantid)
				   ->where('fbrm.fbrm_status != 3');
				   
			$resultSet = $this->getDbTable()->fetchAll($select);
			$finalArray = array();
			foreach($resultSet as $row){
				$ansselect = $ansMapper->getDbTable()->select();
				$ansselect->from(array('mt.feedback_answers'),array('fba_answer'))
						  ->where('fba_questionid = ?',$row->fbq_id)
						  ->where('fba_status = ?',true);
				$tempArr = array();		  
				$ansSet = $ansMapper->getDbTable()->fetchAll($ansselect);
				foreach($ansSet as $ansrow){
					$tempArr[] = $ansrow->fba_answer;
				}
				//$finalArray[$row->fbq_question] = $tempArr;
				$finalArray[] = array(
									'questiontype'=> $row->fbq_type,
									'questionid'=> $row->fbq_id,
									'questionmapid'=> $row->fbrm_id,
									'questiontype'=> $row->feedType,
									'question'	=> $row->fbq_question,
									'answers'	=> $tempArr,
									'status'	=> $row->status 
								);
			}
			return $finalArray;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function changeFeedbackQuestionStatus($questionmapId, $status, $restaurantid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restaurantid);
			date_default_timezone_set($timezone);
			
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			$set = array(
						'fbrm_status' 		=> $status,
						'fbrm_updatedby'	=> $userdata['User_Id'],
					    'fbrm_updateddatetime'=> date('Y-m-d H:i:s')
					);
			
			$where = $db->quoteInto('fbrm_id = ?',$questionmapId);
			$row_affected = $this->getDbTable()->update($set,$where);
			return $row_affected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getFeedbackQuestionAndAnswerById($questionId)
	{
		try{
			$finalArray = array();
			$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
			$queMapper = new FirmManagement_Model_FeedbackQuestionsMapper();
			
			$queselect = $queMapper->getDbTable()->select();			
			$queselect->from($queMapper->getDbTable(),array('fbq_question','fbq_type','fbq_question_type'))
				   ->where('fbq_id = ?',$questionId);				   
			$questionSet = $this->getDbTable()->fetchRow($queselect);
			
			$ansselect = $ansMapper->getDbTable()->select();
			$ansselect->from(array('mt.feedback_answers'),array('fba_id','fba_answer'))
						  ->where('fba_questionid = ?',$questionId)
						  ->where('fba_status = ?',true);
			$tempArr = array();		  
			$answerSet = $ansMapper->getDbTable()->fetchAll($ansselect);
			foreach($answerSet as $ansrow){
				$tempArr[$ansrow->fba_id] = $ansrow->fba_answer;
			}
			if(COUNT($tempArr) > 0){
				$finalArray[$questionSet->fbq_question] = $tempArr;
			}else{
				$finalArray[$questionSet->fbq_question] = 'TEXT';
			}
			return $finalArray;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateFeedbackQuestionAndAnswerById($request)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
		$queMapper = new FirmManagement_Model_FeedbackQuestionsMapper();
		
		try{
			$db->beginTransaction();
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($request->restaurantid);
			date_default_timezone_set($timezone);
			
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			$quesTypeMapper = new Application_Model_FeedbackQuestionsTypeDataMapper();
			$questionType = $quesTypeMapper->GetQuestionTypeByCode(array($request->questiontypeid));
			if($questionType[$request->questiontypeid]->getCode() == 'TEXT'){
				$answerArr = $request->answer;
				$queset = array(
								'fbq_question' 		=> trim($request->question),
								'fbq_updatedby'		=> $userdata['User_Id'],
								'fbq_updateddatetime'=> date('Y-m-d H:i:s')
							);
				if(count($answerArr)){
					$data['fbq_question_type'] = 1;
				}else{
					$data['fbq_question_type'] = 2;
				}
				$quewhere = $db->quoteInto('fbq_id = ?',$request->questionid);
				$queMapper->getDbTable()->update($queset,$quewhere);
				
				
				$answerIdsArr = $request->answerid;
				for($i = 1; $i <= count($answerArr) ; $i++){
					$ansset = array(
								'fba_answer' 		=> trim($answerArr[$i]),
								'fba_updatedby'		=> $userdata['User_Id'],
								'fba_updateddatetime'=> date('Y-m-d H:i:s')
							);
				
					$answhere = $db->quoteInto('fba_id = ?',$answerIdsArr[$i]);
					$ansMapper->getDbTable()->update($ansset,$answhere);	
				}
			}else if($questionType[$request->questiontypeid]->getCode() == 'OPT'){
				
				$queset = array(
								'fbrm_status' 		=> 2,
								'fbrm_updatedby'		=> $userdata['User_Id'],
								'fbrm_updateddatetime'=> date('Y-m-d H:i:s')
							);
				
				$quewhere = $db->quoteInto('fbrm_questionid = ?',$request->questionid);
				$this->getDbTable()->update($queset,$quewhere);
				$answerArr = $request->answer;
				$data = array(
							'fbq_question'		=> trim($request->question),
							'fbq_type'			=> 2,
							'fbq_createdby'	=> $userdata['User_Id'],
							'fbq_createddatetime'=> date('Y-m-d H:i:s')
						);
				if(count($answerArr)){
					$data['fbq_question_type'] = 1;
				}else{
					$data['fbq_question_type'] = 2;
				}
				$questionid = $queMapper->getDbTable()->insert($data);
				
				$quemapdata = array(
							  'fbrm_restaurantid'	=> $request->restaurantid,
							  'fbrm_questionid'		=> $questionid,
							  'fbrm_status'			=> 1,
							  'fbrm_createdby'		=> $userdata['User_Id'],
							  'fbrm_createddatetime'=> date('Y-m-d H:i:s')
							);
					
				$this->getDbTable()->insert($quemapdata);
				
				$answerArr = $request->answer;
				for($i = 1; $i <= count($answerArr) ; $i++){
					$ansdata = array(
							'fba_questionid' => $questionid,
							'fba_answer'	 => trim($answerArr[$i]),
							'fba_status'	 => true,
							'fba_createdby'	 => $userdata['User_Id'],
							'fba_createddatetime'=> date('Y-m-d H:i:s')
						   );
					$ansMapper->getDbTable()->insert($ansdata);
				}
				
			}			
			$db->commit();
			return true;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkFeedbackQuestionsActiveCountByrestId($restaurantid)
	{
		try{
			$table= $this->getDbTable();
			$select = $table->select();
			$count = 0;
			$select->from($table,array('COUNT(fbrm_id) as count'))
				   ->where('fbrm_restaurantid = ?',$restaurantid)
				   ->where('fbrm_status = 1');
				   
			$resultSet = $this->getDbTable()->fetchAll($select);
			foreach($resultSet as $row){
				$count = $row->count;
			}
			return $count;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function addFeedbackQuestionAndAnswer($request)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
		$queMapper = new FirmManagement_Model_FeedbackQuestionsMapper();
		
		try{
			$db->beginTransaction();
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($request->restaurantid);
			date_default_timezone_set($timezone);
			
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			$data = array(
						'fbq_question'		=> trim($request->question),
						'fbq_type'			=> 2,
						'fbq_createdby'	=> $userdata['User_Id'],
						'fbq_createddatetime'=> date('Y-m-d H:i:s')
					);
			if(isset($request->answer)){
				$data['fbq_question_type'] = 1;
			}else{
				$data['fbq_question_type'] = 2;
			}
			$questionid = $queMapper->getDbTable()->insert($data);
				
			$quemapdata = array(
							  'fbrm_restaurantid'	=> $request->restaurantid,
							  'fbrm_questionid'		=> $questionid,
							  'fbrm_status'			=> 1,
							  'fbrm_createdby'		=> $userdata['User_Id'],
							  'fbrm_createddatetime'=> date('Y-m-d H:i:s')
							);
					
			$this->getDbTable()->insert($quemapdata);
			if(isset($request->answer)){	
				$answerArr = $request->answer;
				for($i = 1; $i <= count($answerArr) ; $i++){
					$ansdata = array(
							'fba_questionid' => $questionid,
							'fba_answer'	 => trim($answerArr[$i]),
							'fba_status'	 => true,
							'fba_createdby'	 => $userdata['User_Id'],
							'fba_createddatetime'=> date('Y-m-d H:i:s')
						   );
					$ansMapper->getDbTable()->insert($ansdata);
				}
			}
			$db->commit();
			return true;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getFeedbackQuestionsAndAnswersByRestaurantId($restaurantid)
	{
		try{
			$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
			$table= $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('fbrm'=>'mt.feedback_restaurant_map'),array('fbrm_status'))
				   ->join(array('fbq'=>'mt.feedback_questions'),'fbq.fbq_id = fbrm.fbrm_questionid',array('fbq_id','fbq_question','fbq_type','fbq_question_type'))
				   ->joinLeft(array('fba'=>'mt.feedback_questions_type_bd'),'fba.id = fbq.fbq_question_type',array('code as feedType'))
				   ->where('fbrm.fbrm_restaurantid = ?',$restaurantid)
				   ->where('fbrm.fbrm_status = 1')
				   ->order('fbq_id');
				   
			$resultSet = $this->getDbTable()->fetchAll($select);
			$finalArray = array();
			foreach($resultSet as $row){
				$ansselect = $ansMapper->getDbTable()->select();
				$ansselect->from(array('mt.feedback_answers'),array('fba_id','fba_answer'))
						  ->where('fba_questionid = ?',$row->fbq_id)
						  ->where('fba_status = ?',true);
				$tempArr = array();		  
				$ansSet = $ansMapper->getDbTable()->fetchAll($ansselect);
				foreach($ansSet as $ansrow){
					$tempArr[$ansrow->fba_id] = $ansrow->fba_answer;
				}
				$finalArray[] = array(
									'questionid'=> $row->fbq_id,
									'question'	=> $row->fbq_question,
									'answers'	=> $tempArr,
									'feedType'	=> $row->feedType 
								);
			}
			return $finalArray;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function saveCustomerFeedback($request)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$ansMapper = new FirmManagement_Model_FeedbackAnswersMapper();
		$queMapper = new FirmManagement_Model_FeedbackQuestionsMapper();
		$cusMapper = new FirmManagement_Model_CustomerFeedbackMapper();
		$commentsMapper = new FirmManagement_Model_CustomerFeedbackCommentsMapper();
		
		$timezone = "";
		$mapper = new FirmManagement_Model_FirmDataMapper();
		$timezone = $mapper->GetRestaurantTimeZone($request->restaurantid);
		date_default_timezone_set($timezone);
		
		$questionsArr = $request->questionids;
		$answersArr = $request->answerids;
		$commquestionsArr = $request->commquestionids;
		$commanswersArr = $request->commanswerids;
		$result = 0;		
		$frm = $request->guestForm;
		if(!$request->bookingid){
			$firmServ = new FirmManagement_Model_FirmGroupUsersDataMapper();
			$cusData = new FirmManagement_Model_FirmGroupUsers();
			$cusData->setRestaurantId($request->restaurantid)
					->setGroupId(3)
					->setFirstName($frm[0]['value'])
					->setLastName($frm[1]['value'])
					->setEmail($frm[3]['value'])
					->setPhone($frm[2]['value'])
					->setStatus(TRUE);
			if($formData['birthday']){
				$user->setrgu_birthday($frm[4]['value']);
			}
			if($formData['anniversary']){
				$user->setrgu_anniversary($frm[5]['value']);
			}
			$customerAdd = $firmServ->addUserContact($cusData);			
		}
		try{
			$db->beginTransaction();
			for($i = 1; $i <= count($questionsArr) ; $i++){
				$question = "";
				$queselect = $queMapper->getDbTable()->select();			
				$queselect->from($queMapper->getDbTable(),array('fbq_question'))
					      ->where('fbq_id = ?',$questionsArr[$i]);				   
				$questionSet = $queMapper->getDbTable()->fetchRow($queselect);
				if($questionSet){
					$question = $questionSet->fbq_question;
				}
				$answer = "";
				$ansselect = $ansMapper->getDbTable()->select();
				$ansselect->from($ansMapper->getDbTable(),array('fba_answer'))
						  ->where('fba_id = ?',$answersArr[$i]);
							  
				$answerSet = $ansMapper->getDbTable()->fetchRow($ansselect);
				if($answerSet){
					$answer = $answerSet->fba_answer;
				}
				if($question != "" && $answer != ""){
					$data = array(
							'fbcm_restaurantid'	=> $request->restaurantid,
							'fbcm_questionid'	=> $questionsArr[$i],
							'fbcm_question'		=> $question,
							'fbcm_answer'		=> $answer,
							'fbcm_createddatetime'=> date('Y-m-d H:i:s')
							);
					if($request->bookingid){
						$data['fbcm_bookingid']	= $request->bookingid;
					}else{
						$data['fbcm_guestid']	= $customerAdd;
					}		
					
					$result = $cusMapper->getDbTable()->insert($data);
				}
			}
			for($i = 1; $i <= count($commquestionsArr) ; $i++){
				$question = "";
				$queselect = $queMapper->getDbTable()->select();			
				$queselect->from($queMapper->getDbTable(),array('fbq_question'))
					      ->where('fbq_id = ?',$commquestionsArr[$i]);				   
				$questionSet = $queMapper->getDbTable()->fetchRow($queselect);
				if($questionSet){
					$question = $questionSet->fbq_question;
				}
				
				if($question != "" && $answer != ""){
					$data = array(
							'fbcm_restaurantid'	=> $request->restaurantid,
							'fbcm_questionid'	=> $commquestionsArr[$i],
							'fbcm_question'		=> $question,
							'fbcm_answer'		=> $commanswersArr[$i],
							'fbcm_createddatetime'=> date('Y-m-d H:i:s')
							);
					if($request->bookingid){
						$data['fbcm_bookingid']	= $request->bookingid;
					}else{
						$data['fbcm_guestid']	= $customerAdd;
					}		
					
					$result = $cusMapper->getDbTable()->insert($data);
				}
			}			
			if($request->comment){
				$comments = array(
							'fbcc_restaurantid'	=> $request->restaurantid,							
							'fbcc_comment'		=> $frm[6]['value'],
							'fbcm_createddatetime'=> date('Y-m-d H:i:s')
							);
				if($request->bookingid){
					$comments['fbcc_bookingid']	= $request->bookingid;
				}else{
					$comments['fbcc_guestid']	= $customerAdd;
				}
				$result = $commentsMapper->getDbTable()->insert($comments);
			}
			if($result != 0 && $request->bookingid){
				$bookMapper = new Reservation_Model_ReservationDataMapper();
				$bookMapper->updateFeedbackStatusByBookingId($request->bookingid);
			}
			
			$db->commit();
			return true;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkFeedbackAlredyGiven($request)
	{
		try{
			$count = 0; 
			$cusMapper = new FirmManagement_Model_CustomerFeedbackMapper();
			$select = $cusMapper->getDbTable()->select();			
			$select->from($cusMapper->getDbTable(),array('COUNT(fbcm_id) as count'))
				      //->where('fbcm_restaurantid = ?',$request->restaurantid)
				      ->where('fbcm_bookingid = ?',$request->bookingid);				   
			$rowSet = $cusMapper->getDbTable()->fetchRow($select);
			if($rowSet){
				$count = $rowSet->count;
			}
			if($count == 0){
				$select = "";
				$commentsMapper = new FirmManagement_Model_CustomerFeedbackCommentsMapper();
				$select = $commentsMapper->getDbTable()->select();			
				$select->from($commentsMapper->getDbTable(),array('COUNT(fbcc_id) as count'))
					      //->where('fbcc_restaurantid = ?',$request->restaurantid)
					      ->where('fbcc_bookingid = ?',$request->bookingid);				   
				$rowset = $commentsMapper->getDbTable()->fetchRow($select);
				if($rowset){
					$count = $rowset->count;
				}
			}
			if($count == 0){
				return false;
			}else{
				return true;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getFeedbackDeatilsByBookingId($bookingArr)
	{
		try{
			$finalArr = array();
			for($i = 0; $i < count($bookingArr); $i++){
				$cusMapper = new FirmManagement_Model_CustomerFeedbackMapper();
				$select = $cusMapper->getDbTable()->select();			
				$select->from($cusMapper->getDbTable(),array('fbcm_question','fbcm_answer'))
					      ->where('fbcm_bookingid = ?',$bookingArr[$i]);				   
				$resultSet = $cusMapper->getDbTable()->fetchAll($select);
				$resultArr = array();
				foreach($resultSet as $row){
					$resultArr[$row->fbcm_question] = $row->fbcm_answer;
				}
				$comment = "";
				$commentsMapper = new FirmManagement_Model_CustomerFeedbackCommentsMapper();
				$commentselect = $commentsMapper->getDbTable()->select();			
				$commentselect->from($commentsMapper->getDbTable(),array('fbcc_comment'))
					      ->where('fbcc_bookingid = ?',$bookingArr[$i]);				   
				$rowset = $commentsMapper->getDbTable()->fetchRow($commentselect);
				if($rowset){
					$comment = $rowset->fbcc_comment;
				}
				if($comment != "" || !empty($resultArr)){
					$finalArr[$bookingArr[$i]] = array(
							'questionandanswers' => $resultArr,
							'comment'			 => $comment
							);
				}
			}
			return $finalArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}
