<?php
class FirmManagement_Model_FirmFloorSepratorMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_FirmFloorSeprator');
		}
		return $this->_dbTable;
	}
	
	public function saveRestFloorSeprators(array $resFloorSepArr)
	{
		try{
			$sepratorid = '';
			$table = $this->getDbTable();
			foreach($resFloorSepArr as $floorsep){				
				if($floorsep->getrfsid()){
					
					$set = array('rfscoordinates' => $floorsep->getrfscoordinates(),
								 'rfsdimensions'  => $floorsep->getrfsdimensions(),
								 'rfsupdatedby'	  => $floorsep->getrfsupdatedby(),
								 'rfsupdateddate' => $floorsep->getrfsupdateddate(),
								 'rfsstatus'	  => $floorsep->getrfsstatus());					
					$where = array('rfsid = ?'		      => $floorsep->getrfsid(),
								   'rfsfk_restaurant = ?' => $floorsep->getrfsfk_restaurant());
					$table->update($set,$where);
					
				}else{
					
					$data = array('rfsfk_restaurant' 			 => $floorsep->getrfsfk_restaurant(),
								  'rfsfk_restaurant_dining_area' => $floorsep->getrfsfk_restaurant_dining_area(),
								  'rfscoordinates'				 => $floorsep->getrfscoordinates(),
								  'rfsdimensions'				 => $floorsep->getrfsdimensions(),
								  'rfsseprator_style'			 => $floorsep->getrfsseprator_style(),
								  'rfsseprator_handles'			 => $floorsep->getrfsseprator_handles(),
								  'rfsstatus'					 => $floorsep->getrfsstatus(),
								  'rfscreatedby'				 => $floorsep->getrfscreatedby(),
								  'rfscreateddate'				 => $floorsep->getrfscreateddate());
					$sepratorid = $table->insert($data);					
					
				}
			}
			return $sepratorid;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());		
		}
	}
	
	public function retrieveFloorSeprators(FirmManagement_Model_FirmFloorSeprator $sepFloorSep)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rfsid','rfsfk_restaurant_dining_area','rfscoordinates','rfsdimensions','rfsseprator_style','rfsseprator_handles'))
				   ->where('rfsstatus = ?',true)
				   ->where('rfsfk_restaurant = ?',$sepFloorSep->getrfsfk_restaurant())
				   ->where('rfsfk_restaurant_dining_area = ?',$sepFloorSep->getrfsfk_restaurant_dining_area());
				   
			$rowset = $table->fetchAll($select);
			
			$sepResultArr = array();
			if($rowset){
						foreach($rowset as $row){
						$sepResultArr[] = array('sepid' 	       => $row->rfsid,
												'coordinates'      => $row->rfscoordinates,
												'diningid'	       => $row->rfsfk_restaurant_dining_area,
												'dimensions'       => $row->rfsdimensions,
												'seprator_style'   => $row->rfsseprator_style,
												'seprator_handles' => $row->rfsseprator_handles);
					}
			}
	
			return $sepResultArr;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());		
		}
	}
	
	public function deleteFloorSeprator(FirmManagement_Model_FirmFloorSeprator $sepFloorSep)
	{
		try{
			$table = $this->getDbTable();
			$set = array('rfsstatus' => 'N');
			$where = array('rfsid = ?' => $sepFloorSep->getrfsid(),
						   'rfsfk_restaurant = ?' => $sepFloorSep->getrfsfk_restaurant());
			$rows_affected = $table->update($set,$where);
			return $rows_affected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());		
		}
	}
	
	public function GetFloorSepratorsByRestaurantid($restaurantid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rfsid',
									   'rfsfk_restaurant',
									   'rfsfk_restaurant_dining_area',
									   'rfscoordinates',
									   'rfsdimensions',
									   'rfsseprator_style',
									   'rfsseprator_handles',
									   'rfsstatus',
									   'rfscreatedby',
									   'rfscreateddate',
									   'rfsupdatedby',
									   'rfsupdateddate'))
				   ->where('rfsfk_restaurant = ?',$restaurantid)
				   ->where('rfsstatus = ?',true);
				   				   
			$rowset = $table->fetchAll($select);
			
			$sepResultArr = array();
			foreach($rowset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					if($key1 == 'rfscreatedby' || $key1 == 'rfsupdatedby'){
						$subArr[$key1]= null;
					}else{
						$subArr[$key1]= $value1;
					}
				}
				$sepResultArr[] = $subArr;
			}
			return $sepResultArr;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());		
		}
	}

	public function GetUpdatedFloorSepratorsByRestaurantid($restaurantid)
	{
		try{
			
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rfsid',
									   'rfsfk_restaurant',
									   'rfsfk_restaurant_dining_area',
									   'rfscoordinates',
									   'rfsdimensions',
									   'rfsseprator_style',
									   'rfsseprator_handles',
									   'rfsstatus',
									   'rfscreatedby',
									   'rfscreateddate',
									   'rfsupdatedby',
									   'rfsupdateddate'))
				   ->where('rfsfk_restaurant = ?',$restaurantid);
				   //->where('rfssync_status = ?','C');
				   				   
			$rowset = $table->fetchAll($select);
			
			$sepResultArr = array();
			foreach($rowset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					if($key1 == 'rfscreatedby' || $key1 == 'rfsupdatedby'){
						$subArr[$key1]= null;
					}else{
						$subArr[$key1]= $value1;
					}
				}
				$sepResultArr[] = $subArr;
			}
			return $sepResultArr;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());		
		}
	}
}