<?php

class FirmManagement_Model_FirmMealTypeDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_FirmMealType');
		}
		return $this->_dbTable;
	}
	
	public function AddRestaurantMealType(FirmManagement_Model_FirmMealType $meal)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_start_time','rmt_end_time'))
					->join(array('type'=>'mt.meal_type_bd'),'meal.rmt_meal_type = type.id',array('id as mealid','code as meal','description as mealtype'))
					->where('meal.rmt_restaurant = ?',$meal->getResId())
					->where('meal.rmt_start_time <= ?',$meal->getStartTime())
					->where('meal.rmt_end_time >= ?',$meal->getEndTime())
					->where('meal.rmt_status = ?','Y');
			$row = $this->getDbTable()->fetchRow($select);
			if(!$row){
				$db = Zend_Db_Table::getDefaultAdapter();
				$rowSet = $db->fetchOne("select count(rmt_id) from mt.restaurant_meal_type where rmt_restaurant = '". $meal->getResId() ."'and rmt_meal_type = '". $meal->getMealType()."'");
				if(!$rowSet){
					$data = array(
									'rmt_restaurant'		=>	$meal->getResId(),
									'rmt_meal_type'			=>	$meal->getMealType(),
									'rmt_start_time'		=>	$meal->getStartTime(),
									'rmt_end_time'			=>	$meal->getEndTime(),
									'rmt_status'			=>	'Y'
					);
					$result = $this->getDbTable()->insert($data);
					$resultSet = $this->GetRestaurantMealTypes($meal,'settings');
					return $resultSet;
				}else{
					return false;
				}
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditRestaurantMealType(FirmManagement_Model_FirmMealType $meal)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_start_time','rmt_end_time'))
					->join(array('type'=>'mt.meal_type_bd'),'meal.rmt_meal_type = type.id',array('id as mealid','code as meal','description as mealtype'))
					->where('meal.rmt_restaurant = ?',$meal->getResId())
					->where('meal.rmt_id <> ?', $meal->getMealType())
					->where('meal.rmt_start_time <= ?',$meal->getStartTime())
					->where('meal.rmt_end_time >= ?',$meal->getEndTime())
					->where('meal.rmt_status = ?','Y');
			$row = $this->getDbTable()->fetchRow($select);
			if(!$row){
				$set = array(
								'rmt_start_time'		=>	$meal->getStartTime(),
								'rmt_end_time'			=>	$meal->getEndTime()
				);
				$where = array('rmt_restaurant = ?' => $meal->getResId(),
								'rmt_id = ?' => $meal->getMealType()
				);
				$result = $this->getDbTable()->update($set,$where);
				$resultSet = $this->GetRestaurantMealTypes($meal,'settings');
				return $resultSet;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateMealStattus(FirmManagement_Model_FirmMealType $meal)
	{
		try{
			$set = array(
							'rmt_status'	=>	$meal->getStatus()
			);
			$where = array('rmt_restaurant = ?' => $meal->getResId(),
							'rmt_id = ?' => $meal->getId()
			);
			$result = $this->getDbTable()->update($set,$where);
			$resultSet = $this->GetRestaurantMealTypes($meal,'settings');
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantMealTypes(FirmManagement_Model_FirmMealType $meal,$from = 'widget')
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_start_time','rmt_end_time','rmt_status'))
				   ->join(array('type'=>'mt.meal_type_bd'),'meal.rmt_meal_type = type.id',array('code as meal','description as mealtype'))
				   ->where('meal.rmt_restaurant = ?',$meal->getResId());
			if($from == 'widget'){
				$select->where('meal.rmt_status = ?','Y');
			}	
			$select->order('meal.rmt_start_time');
			$resultSet = $this->getDbTable()->fetchAll($select);
			$result = array();
			foreach($resultSet as $row){
				$start = date("h:i A",strtotime($row->rmt_start_time));
				$end = date("h:i A",strtotime($row->rmt_end_time));
				$data = array('id'			=>	$row->rmt_id,
							  'meal'		=>	$row->meal,
							  'desc'		=>	$row->mealtype,
							  'starttime'	=>	$start,
							  'endtime'		=>	$end,
							  'status'		=>	$row->rmt_status);
				$result[$row->rmt_id] = $data;
			}
			$result['count'] = count($result);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrievePartnerRestMealTypes(FirmManagement_Model_FirmMealType $meal)
	{
	try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_start_time','rmt_end_time','rmt_status'))
				   ->join(array('type'=>'mt.meal_type_bd'),'meal.rmt_meal_type = type.id',array('code as meal','description as mealtype'))
				   ->where('meal.rmt_restaurant = ?',$meal->getResId())
				   ->where('meal.rmt_status = ?','Y');
				   
			$select->order('meal.rmt_start_time');			
			$resultSet = $this->getDbTable()->fetchAll($select);
			$result = array();
                        $resultset =array();
			foreach($resultSet as $row){
				$result['mealtype'][$row->meal] = $row->mealtype;
                                $resultset[] = array(
                                                'code' => $row->meal,
                                                'title' => $row->mealtype,
                                                'start' => date("g:i a", strtotime($row->rmt_start_time)),                                               
                                                'end' => date("g:i a", strtotime($row->rmt_end_time)),
                                );                                                                                                
			}
			$result['data']=$resultset;
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantMealByTime(FirmManagement_Model_FirmMealType $meal)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_start_time','rmt_end_time'))
					->join(array('type'=>'mt.meal_type_bd'),'meal.rmt_meal_type = type.id',array('id as mealid','code as meal','description as mealtype'))
					->where('meal.rmt_restaurant = ?',$meal->getResId())
					->where('meal.rmt_start_time <= ?',$meal->getTime())
					->where('meal.rmt_end_time >= ?',$meal->getTime())
					->where('meal.rmt_status = ?','Y');
			$resultSet = $this->getDbTable()->fetchRow($select);
			$result = array();
			
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantMealByType(FirmManagement_Model_FirmMealType $meal)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_start_time','rmt_end_time'));
			$select->join(array('type'=>'mt.meal_type_bd'),'meal.rmt_meal_type = type.id',array('id as mealid','code as meal','description as mealtype'));
			$select->where('meal.rmt_restaurant = ?',$meal->getResId());
			$select->where('meal.rmt_status = ?','Y');
			$select->where('type.code = ?',$meal->getMealType());
			
			$resultSet = $this->getDbTable()->fetchRow($select);
			$result = array();
			
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantAllMealType(FirmManagement_Model_FirmMealType $meal)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_start_time','rmt_end_time'));
			$select->join(array('type'=>'mt.meal_type_bd'),'meal.rmt_meal_type = type.id',array('id as mealid','code as meal','description as mealtype'));
			$select->where('meal.rmt_restaurant = ?',$meal->getResId());
			$select->where('meal.rmt_status = ?','Y');
			if($meal->getMealType() != ""){		
				$select->where('type.code = ?',$meal->getMealType());
			}
			$select->order('meal.rmt_start_time');
			$resultSet = $this->getDbTable()->fetchAll($select);
	//		$resultSet = $this->getDbTable()->fetchRow($select);
			$result = array();
			
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetMealSettingsByRestId($restid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_restaurant','rmt_meal_type','rmt_start_time','rmt_end_time','rmt_status'))
			       ->join(array('typ'=>'mt.meal_type_bd'),'typ.id = meal.rmt_meal_type',array('code as mealcode','description as mealdesc'))
			       ->where('rmt_restaurant = ?',$restid)
			       ->where('rmt_status = ?',true);
			 
      //$sql = $select->__toString();
      //echo "$sql\n";      
			$rowset = $table->fetchAll($select);
			$mealSettingsArr = array();
			
			/* Break Fast */			
			foreach($rowset as $row){
				if($row->mealcode == "BRE"){
					$mealSettingsArr[] = $row->mealdesc;
				}
			}
						
			/* Lunch */			
			foreach($rowset as $row){
				if($row->mealcode == "LUN"){
					$mealSettingsArr[] = $row->mealdesc;
				}
			}
			
			/* Brunch */			
			foreach($rowset as $row){
				if($row->mealcode == "BRU"){
					$mealSettingsArr[] = $row->mealdesc;
				}
			}
			
			/* Dinner */			
			foreach($rowset as $row){
				if($row->mealcode == "DIN"){
					$mealSettingsArr[] = $row->mealdesc;
				}
			}
			//echo '<pre>'; print_r($mealSettingsArr); exit;
			return $mealSettingsArr;	
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetMealSettingsWebServiceByRestId($restid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);		
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_restaurant','rmt_meal_type','rmt_start_time','rmt_end_time','rmt_status'))
			       ->join(array('typ'=>'mt.meal_type_bd'),'typ.id = meal.rmt_meal_type',array('code as mealcode','description as mealdesc'))
			       ->where('rmt_restaurant = ?',$restid);
			       
			$rowset = $table->fetchAll($select);
			$result = array();
			$mealSettingsArr = array();
			if(count($rowset) > 0)
			{
				$result["status"] = true;
				
				foreach($rowset as $row){
					
					$mealSettingsArr[] = array(	'rmt_id'			=>	$row->rmt_id,
												'rmt_restaurant'	=>	$row->rmt_restaurant,
												'rmt_meal_type'		=>	$row->rmt_meal_type,
												'rmt_start_time'	=>	$row->rmt_start_time,
												'rmt_end_time'		=>	$row->rmt_end_time,
												'rmt_status'		=>	$row->rmt_status
												);				
					
				}
				
				$result["mealsettings"] = $mealSettingsArr;
			}else{
				$result["status"] = false;
			}
			
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantMealSettingsByRestId($resid,$mealType)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_start_time','rmt_end_time'))
					->join(array('type'=>'mt.meal_type_bd'),'meal.rmt_meal_type = type.id',array('id as mealid','code as meal','description as mealtype'))
					->where('meal.rmt_restaurant = ?',$resid)
					->where('meal.rmt_status = ?','Y');
			if($mealType != 'ALL' && $mealType != ''){
				$select->where('type.code = ?',$mealType);
			}
			$resultSet = $this->getDbTable()->fetchAll($select);
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getMealDetailsByMealId(FirmManagement_Model_FirmMealType $meal)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_start_time','rmt_end_time','rmt_status'))
					->join(array('type'=>'mt.meal_type_bd'),'meal.rmt_meal_type = type.id',array('id as mealid','code as meal','description as mealtype'))
					->where('meal.rmt_restaurant = ?',$meal->getResId())
					->where('meal. rmt_id = ?',$meal->getId());
			$resultSet = $this->getDbTable()->fetchRow($select);
			$result = array();
			if($resultSet){
				$start = date("h:i A",strtotime($resultSet->rmt_start_time));
				$end = date("h:i A",strtotime($resultSet->rmt_end_time));
				$result['starttime'] = $start;
				$result['endtime'] = $end;
				$result['desc'] = $resultSet->mealtype;
				$result['status'] = $resultSet->rmt_status;
			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetMealSettingsByRestIdForIpad($restid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('meal'=>'mt.restaurant_meal_type'),array('rmt_id','rmt_restaurant','rmt_meal_type','rmt_start_time','rmt_end_time','rmt_status'))
			       ->join(array('typ'=>'mt.meal_type_bd'),'typ.id = meal.rmt_meal_type',array('code as mealcode','description as mealdesc'))
			       ->where('rmt_restaurant = ?',$restid)
			       ->where('rmt_status = ?',true);
			       
			$rowset = $table->fetchAll($select);
			$mealSettingsArr = array();
			
			/* Break Fast */			
			foreach($rowset as $row){
				$mealSettingsArr[] = $row->mealdesc;
			}
						
			$mealSettingsArr[] = 'Select All';	
			return $mealSettingsArr;	
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}