<?php
class FirmManagement_Model_FirmSpecialDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_FirmSpecial');
		}
		return $this->_dbTable;
	}

	public function saveManageSpecial(FirmManagement_Model_FirmSpecial $restSpl)
	{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$data = array(
					'rspfk_restaurant'				=>	$restSpl->getRestaurantid(),
					'rspspecial_type'				=>	$restSpl->getSpecialtypeid(),
					'rspno_of_dishes'				=>	$restSpl->getNoofdishes(),
					'rspspecial_title'				=>	$restSpl->getSpecialtitle(),
					'rspspecial_image'				=>	$restSpl->getSpecialimage(),
					'rspfood_type'					=>	$restSpl->getFoodtype(),
					'rspkidsstatus'					=>	$restSpl->getKidsstatus(),
					'rspkids_eat_free'				=>	$restSpl->getKidsinfo(),
					'rspstart_date'					=>	$restSpl->getStartdate(),
					'rspend_date'					=>	$restSpl->getEnddate(),
					'rspstart_time'					=>	$restSpl->getStarttime(),
					'rspend_time'					=>	$restSpl->getEndtime(),
					'rsprecurencestatus'			=>	$restSpl->getSpecialrecurence(),
					'rspdescription'				=>	$restSpl->getDescription(),
					'rspstatus'						=>	$restSpl->getStatus(),
					'rspregular_price'				=>	$restSpl->getRegprice(),
					'rspdiscount_percentage_point'	=>	$restSpl->getDispercentage(),
					'rspprice_with_discount'		=>	$restSpl->getPricewithdiscount(),
					'rspcategory'					=>  $restSpl->getSpecialCategoryType(),
					'rsptype_of_occurance'			=>	$restSpl->getSpecialCount(),
					'rspdiscount_mode'				=>	$restSpl->getDiscountMode()

			);

			try{
				$db->beginTransaction();

				$spl_id = $this->getDbTable()->insert($data);
				$days = $restSpl->getWeekids();
				$mapper = new FirmManagement_Model_FirmSpecialRecurenceDataMapper();
				foreach($days as $day){
					$weekData = array(
					'rsrfk_restaurant_special'	=>	$spl_id,
					'rsrday_of_week'			=>	$day->getWeekId(),
					'rsrreccurence_type_id'		=>	1
					);
					$mapper->getDbTable()->insert($weekData);
				}
				$db->commit();
				$status = true;
				return $spl_id;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
	}

	public function getManageSpecialById(FirmManagement_Model_FirmById $Id)
	{
		try{
			$table = $this->getDbTable();
			$query= $table->select();
			$query->setIntegrityCheck(false);

			$query->from(array('rsp'=>'mt.restaurant_special'),array('rspid',
						   										   'rspfk_restaurant',
						   										   'rspno_of_dishes',
						   										   'rspspecial_title',
						   										   'rspregular_price',
																   'rspspecial_image',
																   'rspdiscount_percentage_point',
																   'rspprice_with_discount',
																   'rspkids_eat_free',
																   'rspstart_date',
																   'rspend_date',
																   'rspstart_time',
																   'rspend_time',
																   'rspdescription',
																   'rspfood_type',
																   'rspspecial_type',
																   'rsprecurencestatus',
																   'rspstatus',
																   'rspkidsstatus',
																   'rspcategory',
																   'rsptype_of_occurance',
																   'rspdiscount_mode'))

			->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name','resaddress','resphone'))
			->join(array('spb'=>'mt.special_type_bd'),'spb.id = rsp.rspspecial_type',array('description as special'))
			->join(array('spcat'=>'mt.special_category_bd'),'spcat.id = rsp.rspcategory',array('description as splCategory'))
			->join(array('splcnt'=>'mt.special_count_type_bd'),'splcnt.id = rsp.rsptype_of_occurance',array('description as splCount'))
			->join(array('discmod'=>'mt.discount_mode_bd'),'discmod.id = rsp.rspdiscount_mode',array('description as discMode'))
			->where('rest.resfk_user = ?',$Id->getRestaurantId());
			
			$rowSet = $table->fetchAll($query);
			$resDet = array();
			foreach($rowSet as $row){
				if($row->rsprecurencestatus){
					$reoccMapper = new FirmManagement_Model_FirmSpecialRecurenceDataMapper();
					$reTable = $reoccMapper->getDbTable();
					$reoccSelect = $reTable->select();
					$reoccSelect->setIntegrityCheck(false);
					$reoccSelect->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
								->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
								->where('rsr.rsrfk_restaurant_special = ? ',$row->rspid);
					$rowResult = $reTable->fetchAll($reoccSelect);
				}else{
					$rowResult = "";
				}
				if(strlen($row->rspdescription) > 200){
					$description = substr($row->rspdescription, 0, 200)." ...";
				}else{
					$description = $row->rspdescription;
				}
				$splObj = new FirmManagement_Model_FirmSpecial();
				$splObj->setId($row->rspid)
				->setRestaurantname($row->resrestaurant_name)
				->setAddress($row->resaddress)
				->setRestaurantid($row->rspfk_restaurant)
				->setNoofdishes($row->rspno_of_dishes)
				->setSpecialtypename($row->special)
				->setSpecialtypeid($row->rspspecial_type)
				->setSpecialtitle($row->rspspecial_title)
				->setSpecialimage($row->rspspecial_image)
				->setStartdate($row->rspstart_date)
				->setEnddate($row->rspend_date)
				->setStarttime($row->rspstart_time)
				->setEndtime($row->rspend_time)
				->setDescription($description)
				->setSpecialrecurence($row->rsprecurencestatus)
				->setKidsinfo($row->rspkids_eat_free)
				->setKidsstatus($row->rspkidsstatus)
				->setSpecialCount($row->rsptype_of_occurance)
				->setSpecialCategoryType($row->rspcategory)
				->setSpecialCategoryTypeName($row->splCategory)
				->setSpecialCountName($row->splCount)
				->setDiscountMode($row->discMode)
				->setRegprice($row->rspregular_price)
				->setDispercentage($row->rspdiscount_percentage_point)
				->setPricewithdiscount($row->rspprice_with_discount)
				->setStatus($row->rspstatus)
				->setPhone($row->resphone);
				$splWeek = array();
				if($rowResult){
					foreach($rowResult as $value){
						$splRecurenceObj = new FirmManagement_Model_FirmSpecialRecurence();
						$splRecurenceObj->setWeekId($value->rsrday_of_week);
						$splRecurenceObj->setWeekDesc($value->day);
						$splWeek[] = $splRecurenceObj;
					}
				}
				$splObj->setWeekids($splWeek);
				$resDet[$row->rspid] = $splObj;
			}
			return $resDet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function getRestaurantSplById(FirmManagement_Model_FirmSpecialById $splid)
	{
		try{
			$table = $this->getDbTable();
			$cuisinemapper = new FirmManagement_Model_FirmCuisineDataMapper();

			$restcuisinetable = $cuisinemapper->getDbTable();

			$query= $table->select();
			$selectRestCuisine = $restcuisinetable->select();
			$query->setIntegrityCheck(false);
			$query->from(array('rsp'=>'mt.restaurant_special'),array('rspid',
						   										   'rspfk_restaurant',
						   										   'rspno_of_dishes',
						   										   'rspspecial_title',
						   										   'rspregular_price',
																   'rspspecial_image',
																   'rspdiscount_percentage_point',
																   'rspprice_with_discount',
																   'rspkids_eat_free',
																   'rspstart_date',
																   'rspend_date',
																   'rspstart_time',
																   'rspend_time',
																   'rspdescription',
																   'rspfood_type',
																   'rspspecial_type',
																   'rsprecurencestatus',
																   'rspstatus',
																   'rspkidsstatus',
																   'rspcategory',
																   'rsptype_of_occurance',
																   'rspdiscount_mode'))

			->join(array('rest'=>'mt.restaurant'),'rest.resid = rsp.rspfk_restaurant',array('resrestaurant_name','resaddress','resgoogleimage','resphone','resdescription'))
			->join(array('cty'=>'mt.city_bd'),'cty.id = rest.rescity_id',array('code as citycode','description as citydesc'))
			->join(array('neigh'=>'mt.neighborhood_bd'),'neigh.id = rest.resneighborhood_id',array('description as neighdesc'))
			->join(array('spb'=>'mt.special_type_bd'),'spb.id = rsp.rspspecial_type',array('description as special'))
			->join(array('spcat'=>'mt.special_category_bd'),'spcat.id = rsp.rspcategory',array('description as splCategory'))
			->join(array('splcnt'=>'mt.special_count_type_bd'),'splcnt.id = rsp.rsptype_of_occurance',array('description as splCount'))
			->join(array('discmod'=>'mt.discount_mode_bd'),'discmod.id = rsp.rspdiscount_mode',array('description as discMode'))
			->where('rsp.rspid = ?',$splid->getSpecialId());
				
			$result = $table->fetchRow($query);
				
				
			$recurence = new FirmManagement_Model_FirmSpecialRecurenceDataMapper();
			$recurenceTable = $recurence->getDbTable();
			$selectWeeks = $recurenceTable->select();
			$selectWeeks->setIntegrityCheck(false);
			if($result->rspstatus){
				$selectWeeks->from(array('rsr'=>'mt.restaurant_special_reccurence'),array('rsrid','rsrday_of_week'))
				->join(array('wrb'=>'mt.weekly_recurence_bd'),'wrb.id = rsr.rsrday_of_week',array('description as day'))
				->where('rsr.rsrfk_restaurant_special = ? ',$result->rspid);
			}
			$weekResult = $table->fetchAll($selectWeeks);
			$splObj = new FirmManagement_Model_FirmSpecial();
			$splObj->setRestaurantname($result->resrestaurant_name)
			->setRestaurantid($result->rspfk_restaurant)
			->setNoofdishes($result->rspno_of_dishes)
			->setSpecialtypename($result->special)
			->setSpecialtypeid($result->rspspecial_type)
			->setSpecialtitle($result->rspspecial_title)
			->setSpecialimage($result->rspspecial_image)
			->setStartdate($result->rspstart_date)
			->setEnddate($result->rspend_date)
			->setStarttime($result->rspstart_time)
			->setEndtime($result->rspend_time)
			->setDescription($result->rspdescription)
			->setSpecialrecurence($result->rsprecurencestatus)
			->setKidsinfo($result->rspkids_eat_free)
			->setKidsstatus($result->rspkidsstatus)
			->setSpecialCount($result->rsptype_of_occurance)
			->setSpecialCategoryType($result->rspcategory)
			->setSpecialCategoryTypeName($result->splCategory)
			->setSpecialCountName($result->splCount)
			->setDiscountMode($result->discMode)
			->setRestaurantaddress($result->resaddress)
			->setRestaurantgoogleimage($result->resgoogleimage)
			->setRestaurantphone($result->resphone)
			->setRestaurantcity($result->citydesc)
			->setRestaurantneigh($result->neighdesc)
			->setRestaurantdesc($result->resdescription)

			->setRegprice($result->rspregular_price)
			->setDispercentage($result->rspdiscount_percentage_point)
			->setPricewithdiscount($result->rspprice_with_discount)
			->setStatus($result->rspstatus);
				
			$selectRestCuisine->setIntegrityCheck(false);
			$selectRestCuisine->from(array('cuis'=>'mt.restaurant_cuisine'),array('rscid','rscfk_restauranttype_id'))
			->join(array('resttyp'=>'mt.restaurant_type_bd'),'resttyp.id = cuis.rscfk_restauranttype_id',array('code','description'))
			->where('cuis.rcsfk_restaurant = ?',$splid->getRestId());
			$cuisineResult = $restcuisinetable->fetchAll($selectRestCuisine);

			$restCuisines = array();

			foreach($cuisineResult as $cuisRes){
				$restCuisObj = new FirmManagement_Model_FirmCuisine();
				$restCuisObj->setId($cuisRes->rscid);
				$restCuisObj->setRestaurantTypeId($cuisRes->rscfk_restauranttype_id);
				$restCuisObj->setRestCuisineCode($cuisRes->code);
				$restCuisObj->setRestCuisineDesc($cuisRes->description);
				$restCuisines[] = $restCuisObj;
			}

			/* Setting restaurant types to Restaurant objects restauranttype id property. */
			$splObj->setFoodtype($restCuisines);

			$splWeek= array();
				
			foreach($weekResult as $value){
				$splRecurenceObj = new FirmManagement_Model_FirmSpecialRecurence();
				$splRecurenceObj->setWeekId($value->rsrday_of_week);
				$splRecurenceObj->setWeekDesc($value->day);
				$splWeek[] = $splRecurenceObj;
			}
			$splObj->setWeekids($splWeek);
			return $splObj;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function updateRestSpecial(FirmManagement_Model_FirmSpecial $restSpl)
	{
		
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
					'rspregular_price'				=>	$restSpl->getRegprice(),
					'rspdiscount_percentage_point'	=>	$restSpl->getDispercentage(),
					'rspprice_with_discount'		=>	$restSpl->getPricewithdiscount(),
					'rspdiscount_mode'				=>	$restSpl->getDiscountMode()
			);
			try{
				$db->beginTransaction();
				$splWhere = $db->quoteInto('rspid = ?',$restSpl->getId());
				$this->getDbTable()->update($set,$splWhere);
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}
	
	public function updateRestSpecialDesc(FirmManagement_Model_FirmSpecial $restSpl)
	{
		
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
					'rspdescription'				=>	$restSpl->getDescription(),
			);
			try{
				$db->beginTransaction();
				$splWhere = $db->quoteInto('rspid = ?',$restSpl->getId());
				$this->getDbTable()->update($set,$splWhere);
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}
	
	public function updateRestSpecialSchedule(FirmManagement_Model_FirmSpecial $restSpl)
	{
		
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
					'rspstart_date'					=>	$restSpl->getStartdate(),
					'rspend_date'					=>	$restSpl->getEnddate(),
					'rspstart_time'					=>	$restSpl->getStarttime(),
					'rspend_time'					=>	$restSpl->getEndtime(),
					'rsprecurencestatus'			=>	$restSpl->getSpecialrecurence()
					
			);	
			try{
				$db->beginTransaction();
				$splWhere = $db->quoteInto('rspid = ?',$restSpl->getId());
				$this->getDbTable()->update($set,$splWhere);
				$days = $restSpl->getWeekids();
				
				$mapper = new FirmManagement_Model_FirmSpecialRecurenceDataMapper();
				$weekwhere = $db->quoteInto('rsrfk_restaurant_special = ?',$restSpl->getId());
				$rows_affected = $mapper->getDbTable()->delete($weekwhere);
				foreach($days as $day){
					$weekData = array(
							'rsrfk_restaurant_special'	=>	$restSpl->getId(),
							'rsrday_of_week'			=>	$day->getWeekId(),
							'rsrreccurence_type_id'		=>	1
					);
					$mapper->getDbTable()->insert($weekData);
				}
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}

	public function updateRestaurantSpecialImage(FirmManagement_Model_FirmSpecial $restSpl)
	{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array('rspspecial_image' => $restSpl->getSpecialimage());
			try{
				$db->beginTransaction();

				/* Update Restaurant */

				$restWhere = $db->quoteInto('rspid = ?',$restSpl->getId());

				$this->getDbTable()->update($set,$restWhere);
				$db->commit();
				$status = true;
				return $status;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
	}

	public function updateManageSpecial(FirmManagement_Model_FirmSpecial $restSpl)
	{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
					'rspfk_restaurant'				=>	$restSpl->getRestaurantid(),
					'rspspecial_type'				=>	$restSpl->getSpecialtypeid(),
					'rspno_of_dishes'				=>	$restSpl->getNoofdishes(),
					'rspspecial_title'				=>	$restSpl->getSpecialtitle(),
					'rspspecial_image'				=>	$restSpl->getSpecialimage(),
					'rspfood_type'					=>	$restSpl->getFoodtype(),
					'rspkids_eat_free'				=>	$restSpl->getKidsinfo(),
					'rspstart_date'					=>	$restSpl->getStartdate(),
					'rspend_date'					=>	$restSpl->getEnddate(),
					'rspstart_time'					=>	$restSpl->getStarttime(),
					'rspend_time'					=>	$restSpl->getEndtime(),
					'rsprecurencestatus'			=>	$restSpl->getSpecialrecurence(),
					'rspdescription'				=>	$restSpl->getDescription(),
					'rspstatus'						=>	$restSpl->getStatus(),
					'rspregular_price'				=>	$restSpl->getRegprice(),
					'rspdiscount_percentage_point'	=>	$restSpl->getDispercentage(),
					'rspprice_with_discount'		=>	$restSpl->getPricewithdiscount(),
					'rspdiscount_mode'				=>	$restSpl->getDistypeid()
			);

			try{
				$db->beginTransaction();
				$splWhere = $db->quoteInto('rspid = ?',$restSpl->getId());
				$this->getDbTable()->update($set,$splWhere);
					
				$days = $restSpl->getWeekids();
				$mapper = new FirmManagement_Model_FirmSpecialRecurenceDataMapper();
				$Where = $db->quoteInto('rsrfk_restaurant_special = ?',$restSpl->getId());
				$mapper->getDbTable()->delete($Where);
				foreach($days as $day){
					$weekData = array(
					'rsrfk_restaurant_special'	=>	$restSpl->getId(),
					'rsrday_of_week'			=>	$day->getWeekId(),
					'rsrreccurence_type_id'		=>	1
					);
					$mapper->getDbTable()->insert($weekData);
				}
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}

	public function getSpecialStatus(FirmManagement_Model_FirmSpecial $obj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$qry = "select count(rspspecial_title) from mt.restaurant_special where rspspecial_title = '". $obj->getSpecialtitle() ."' and rspfk_restaurant = ". $obj->getRestaurantid();
			$result = $db->fetchOne("select count(rspspecial_title) from mt.restaurant_special where rspspecial_title = '". $obj->getSpecialtitle() ."' and rspfk_restaurant = ". $obj->getRestaurantid());

			if((int)$result)
			{
				$status = true;
			}else{
				$status = false;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}
