<?php
class FirmManagement_Model_FirmSpecialScheduleMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {

			$this->setDbTable('FirmManagement_Model_DbTable_FirmSpecialSchedule');
		}
		return $this->_dbTable;
	}
	
	public function SaveSpecialScheduleDetails(FirmManagement_Model_FirmSpecialSchedule $restSpecialSchObject)
	{
		try{
			$data = array('rseseventname' 		 => $restSpecialSchObject->getrseseventname(),
						  'rseseventdescription' => $restSpecialSchObject->getrseseventdescription(),
						  'rseseventdate' 		 => $restSpecialSchObject->getrseseventdate(),
						  'rsesfk_restaurant'	 => $restSpecialSchObject->getrsesfk_restaurant(),
					      'rsesstatus'			 => $restSpecialSchObject->getrsesstatus(),
						  'rsescreateddate'		 => $restSpecialSchObject->getrsescreateddate(),
						  'rsescreatedtime'		 => $restSpecialSchObject->getrsescreatedtime(),
						  'rsescreatedby'		 => $restSpecialSchObject->getrsescreatedby(),
						  );
						  
			$table = $this->getDbTable();
			$id = $table->insert($data);

			return $id;
			
		}catch(Exception $ex){				
			throw new Exception($ex->getMessage());				
		}
	}
	
	public function CheckSpecialScheduleAvilable(FirmManagement_Model_FirmSpecialSchedule $restSpecialSchObject)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsesid','rseseventname','rseseventdate','rsesfk_restaurant','rsesstatus'))
				   ->where('rseseventdate = ?',$restSpecialSchObject->getrseseventdate())
				   ->where('rsesfk_restaurant = ?',$restSpecialSchObject->getrsesfk_restaurant())
				   ->where('rsesstatus = true');
		    $row = $table->fetchRow($select);
		    
		    return $row;
		     
		}catch(Exception $ex){				
			throw new Exception($ex->getMessage());				
		}
	}
	
	public function getSpecialSchedulesByRestid($resids, FirmManagement_Model_FirmSpecialSchedule $restsplObj, $offset)
	{
		try{
			$limit = 10;
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('splsch'=>'mt.restaurant_special_event_schedule'),array('rsesid','rseseventname','rseseventdescription','rseseventdate','rsesfk_restaurant','rsesstatus'));
			$select->join(array('rest'=>'mt.restaurant'),'rest.resid = splsch.rsesfk_restaurant',array('resrestaurant_name'));
			if($restsplObj->getrseseventname()){
				$select->where('splsch.rseseventname ILIKE (?)','%'.$restsplObj->getrseseventname().'%');
			}
			if($restsplObj->getrseseventdate()){
				$select->where('splsch.rseseventdate = ?',$restsplObj->getrseseventdate());
			}
			if($restsplObj->getrsesstatus()){
				if($restsplObj->getrsesstatus() == 2){
					$select->where('splsch.rsesstatus = ?','false');
				}
				if($restsplObj->getrsesstatus() == 1){
					$select->where('splsch.rsesstatus = ?','true');
				}
			}
			$select->where('rest.resid IN(?)',$resids);
			$select->order('splsch.rsesid DESC');
			//$rowset = $table->fetchAll($select);
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
			
			return $resultSet;
		}catch(Exception $ex){				
			throw new Exception($ex->getMessage());				
		}
	}
	
	public function getSpecialSchedulesById($id)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from(array('splsch'=>'mt.restaurant_special_event_schedule'),array('rsesid','rseseventname','rseseventdescription','rseseventdate','rsesfk_restaurant'));
			$select->where('splsch.rsesid = ?',$id);
			$rowset = $table->fetchRow($select);
			return $rowset;
		}catch(Exception $ex){				
			throw new Exception($ex->getMessage());				
		}	
	}
	
	public function UpdateSpecialScheduleDesc(FirmManagement_Model_FirmSpecialSchedule $obj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$set 	= array('rseseventdescription' => $obj->getrseseventdescription());
			$where	= $db->quoteInto('rsesid = ?',$obj->getrsesid());
			
			$rows_affected = $this->getDbTable()->update($set,$where);
			if($rows_affected){
				return true;
			}else{
				return false;
			}
		}catch(Exception $ex){				
			throw new Exception($ex->getMessage());				
		}
	}
	
	public function UpdateSplScheduleStatus($id, $status)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$inventoryArr = array();
			$statusId    = array();
			if($status == 'ACT'){
				$set = array('rsesstatus' => 'true');
				$where = $db->quoteInto('rsesid = ?',$id);
				$rows_affected = $this->getDbTable()->update($set,$where);
				return true;
			}else{
				$table  = $this->getDbTable();
				$select = $table->select();
				$select->setIntegrityCheck(false);
				
				$select->from(array('rses'=>'mt.restaurant_special_event_schedule'),array('rsesid'))
				       ->join(array('sch'=>'mt.restaurant_schedule'),'sch.rssfk_special_event_schedule = rses.rsesid',array('rssid'))
					   ->join(array('rst'=>'mt.restaurant_schedule_table'),'rst.rstfk_restaurant_schedule = sch.rssid',array('rstid'))
					   ->where('sch.rssstatus = ?',true)
					   ->where('rses.rsesid = ?',$id);
				$resultset = $table->fetchAll($select);
				foreach($resultset as $value){
					$inventoryArr[] = $value->rstid; 
				}
				
				$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
				$bookStatus = array('CAN','COM','RES','WAL');
				$bookStatusRes = $bookStatusMapper->GetBookingStatusByCode($bookStatus);
				foreach($bookStatusRes as $key=>$value){
					$statusId[] = $value->getId();
				}
				$status = false;
				if($inventoryArr){
					$status = true;
					$bokmapper = new Reservation_Model_ReservationDataMapper();
					$boktable = $bokmapper->getDbTable();
					$selectinventory = $boktable->select();
					$selectinventory->from($boktable,array('bokid'))
					->where('bokfk_rest_sch_table IN(?)',$inventoryArr)
					->where("bokbooking_status_id NOT IN(?)",$statusId);
					$result = $table->fetchAll($selectinventory);
				}
				
				if($status &&  $result['bokid'] != ""){
					return false;
				}else{
					$set = array('rsesstatus' => 'false');
					$where = $db->quoteInto('rsesid = ?',$id);
					$rows_affected = $this->getDbTable()->update($set,$where);
					return true;
				}
			}
		}catch(Exception $ex){				
			throw new Exception($ex->getMessage());				
		}
	}
	
	public function checkSplScheduleByDate($resid, $date)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$result = $db->fetchOne("select count(rsesid) from mt.restaurant_special_event_schedule where rseseventdate = '".$date."'and rsesfk_restaurant = ".$resid);
			if((int)$result)
			{
				$status = true;
			}else{
				$status = false;
			}
			return $status;
		}catch(Exception $ex){				
			throw new Exception($ex->getMessage());				
		}
	}
	
	public function getSplScheduleDescription($id)
	{
		try{
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rseseventdescription'))
				   ->where('rsesid = ?',$id);
		    $row = $table->fetchRow($select);
		    $result = array('desc' => $row->rseseventdescription);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getSplScheduleDatesByResId($resid)
	{
		try{
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rseseventdate'))
				   ->where('rsesfk_restaurant = ?',$resid)
				   ->where('rsesstatus = ?',true);
			$row = $table->fetchAll($select);
			return $row;				   			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getSplScheduleId($resid, $date)
	{
		try{
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsesid'))
				   ->where('rsesfk_restaurant = ?',$resid)
				   ->where('rseseventdate = ?',$date);
		    $result = $table->fetchRow($select);
		    return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantSpecialSchedulesByRestaurantid($restaurantid)
	{
		try{
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsesid',
									   'rseseventname',
									   'rseseventdescription',
									   'rseseventdate',
									   'rsesfk_restaurant',
									   'rsesstatus',
									   'rsescreateddate',
									   'rsescreatedtime',
									   'rsescreatedby',
									   'rsesupdateddate',
									   'rsesupdatedtime',
									   'rsesupdatedby'
								))
				   ->where('rsesfk_restaurant = ?',$restaurantid);
		    $result = $table->fetchAll($select);
		    
		    $splSchArr = array();
			foreach($result as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					if($key1 == 'rsescreatedby' || $key1 == 'rsesupdatedby'){
						$subArr[$key1]= null;
					}else{
						$subArr[$key1]= $value1;
					}					
				}
				$splSchArr[] = $subArr;
			}
			return $splSchArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetUpdatedRestaurantSpecialSchedulesByRestaurantid($restaurantid)
	{
		try{
			
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsesid',
									   'rseseventname',
									   'rseseventdescription',
									   'rseseventdate',
									   'rsesfk_restaurant',
									   'rsesstatus',
									   'rsescreateddate',
									   'rsescreatedtime',
									   'rsescreatedby',
									   'rsesupdateddate',
									   'rsesupdatedtime',
									   'rsesupdatedby'
								))
				   ->where('rsesfk_restaurant = ?',$restaurantid);
				   //>where('rsesync_status = ?', 'C');
		    $result = $table->fetchAll($select);
		    
		    $splSchArr = array();
			foreach($result as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					if($key1 == 'rsescreatedby' || $key1 == 'rsesupdatedby'){
						$subArr[$key1]= null;
					}else{
						$subArr[$key1]= $value1;
					}					
				}
				$splSchArr[] = $subArr;
			}
			return $splSchArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}