<?php
class FirmManagement_Model_MenuFirmDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_MenuFirm');
		}
		return $this->_dbTable;
	}
	
	public function addMenuHeader($request)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$menu_id = '';
	    	$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
	    	if($request->menuid){
	    		$menu_id = $request->menuid;
	    		$set = array(
		    		'mr_title'			=>	$request->menutitle,
		    		'mr_description'	=>	$request->menudesc,
		    		'mr_updatedby'		=>	$userdata['User_Id'],
		    		'mr_updateddatetime'=>	date('Y-m-d H:i:s')
		    	);
		    	$where = $db->quoteInto('mrid = ?',$menu_id);
				$row_affected = $this->getDbTable()->update($set,$where);
				
	    	}else{
	    		$data = array(
		    		'mrfk_restaurantid'	=>	$request->restaurantid,
		    		'mr_title'			=>	$request->menutitle,
		    		'mr_description'	=>	$request->menutitle,
		    		'mr_status'			=>	true,
		    		'mr_createdby'		=>	$userdata['User_Id'],
		    		'mr_createddatetime'=>	date('Y-m-d H:i:s')
		    	);
				
		    	$menu_id = $this->getDbTable()->insert($data);
	    	}
			return $menu_id;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getMenuHeader($request)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('mr_title','mr_description','mrfk_restaurantid','mr_status'))
				   ->where('mrid = ?',$request->menuid);
		
			$rowSet = $table->fetchRow($select);
			$resultArr = array();
	    	if($rowSet){
				$resultArr['menutitle'] = $rowSet->mr_title;
				$resultArr['menudesc'] = $rowSet->mr_description;
				$resultArr['menustatus'] = $rowSet->mr_status;
	    	}
	    	return $resultArr;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function changeMenuStatus($menuid, $status)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$set = array('mr_status' => $status);
			
			$where = $db->quoteInto('mrid = ?',$menuid);
			$row_affected = $this->getDbTable()->update($set,$where);
			return $row_affected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestauramtMenuByRestId($restid)
	{
		try
		{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('mrid','mrfk_restaurantid','mr_title','mr_description','mr_status','mr_createdby','mr_createddatetime','mr_updatedby','mr_updateddatetime'))
				   ->where('mrfk_restaurantid = ?',$restid);
				   
			$rowSet = $table->fetchAll($select); 
			
			$result 	 = array();
			$menu_names  = array();
			$menu_cat 	 = array();
			$menu_item 	 = array();
			$menu_id 	 = array();
			$menu_cat_id = array();
			
			if(count($rowSet) > 0)
			{
				foreach($rowSet as $row)
				{
					$menu_id[] = $row->mrid;
					$menu_names[] = array('mrid' 			   => $row->mrid,
										  'mrfk_restaurantid'  => $row->mrfk_restaurantid,
										  'mr_title'		   => $row->mr_title,
										  'mr_description' 	   => $row->mr_description,
										  'mr_status' 		   => $row->mr_status,
										  'mr_createdby' 	   => $row->mr_createdby,
										  'mr_createddatetime' => $row->mr_createddatetime,
										  'mr_updatedby' 	   => $row->mr_updatedby,
										  'mr_updateddatetime' => $row->mr_updateddatetime);
				}
				if(count($menu_names) > 0){
					$result["MenuNames"] = $menu_names;
				}else{
					$result["MenuNames"] = false;
				}
				
				/* Get Menu Category */
				if(count($menu_id) > 0){
					
						$menuCatMapper = new FirmManagement_Model_MenuCategoryDataMapper();
						$tableMenuCat = $menuCatMapper->getDbTable();
						$selectMenuCat = $tableMenuCat->select();
						$selectMenuCat->from($tableMenuCat,array('mcid','mcfk_restaurantid','mc_name','mc_description','mc_image','mc_status','mc_createdby','mc_createddatetime','mc_updatedby','mc_updateddatetime','mcfk_menu_restaurantid','mc_catcolor'))
									  ->where('mcfk_menu_restaurantid IN(?)',$menu_id);
						
						$menuCatRowSet = $tableMenuCat->fetchAll($selectMenuCat);
										
						if($menuCatRowSet)
						{
							foreach($menuCatRowSet as $catrow){
								
								$menu_cat_id[] = $catrow->mcid; 
								$menu_cat[] = array('mcid' 				     => $catrow->mcid,
													'mcfk_restaurantid'      => $catrow->mcfk_restaurantid,
													'mc_name' 			     => $catrow->mc_name,
													'mc_description' 	     => $catrow->mc_description,
													'mc_image' 			     => $catrow->mc_image,
													'mc_status' 		     => $catrow->mc_status,
													'mc_createdby' 		     => $catrow->mc_createdby,
													'mc_createddatetime' 	 => $catrow->mc_createddatetime,
													'mc_updatedby' 		 	 => $catrow->mc_updatedby,
													'mc_updateddatetime' 	 => $catrow->mc_updateddatetime,
													'mcfk_menu_restaurantid' => $catrow->mcfk_menu_restaurantid,
                                                    'mc_catcolor'            => $catrow->mc_catcolor);
								}
						}
						if(count($menu_cat) > 0){
							$result["MenuCategory"] = $menu_cat;
						}else{
							$result["MenuCategory"] = false;
						}
						
					}else{
						$result["MenuCategory"] = false;
					}
									
					/* Get Menu Items */
					if(count($menu_cat_id) > 0){
						
						$menuItemsMapper = new FirmManagement_Model_MenuItemsDataMapper();
						$tableMenuItem = $menuItemsMapper->getDbTable();
						$selectMenuItem = $tableMenuItem->select();
						$selectMenuItem->from($tableMenuItem,array('miid','mifk_categoryid','mi_name','mi_description','mi_price','mi_type','mi_image','mi_status','mi_createdby','mi_createddatetime','mi_updatedby','mi_updateddatetime','mi_ordersequence','mi_itemcolor','mi_modifier_status'))
									   ->where('mifk_categoryid IN(?)',$menu_cat_id);
									   
						$rowSetMenuItem = $tableMenuItem->fetchAll($selectMenuItem);
					
						if($rowSetMenuItem)
						{
							foreach($rowSetMenuItem as $rowMenuItem){
                                $modResultSet = array();
                                if($rowMenuItem->mi_modifier_status){
                                    $modifierMap = new FirmManagement_Model_MenuItemsAddonDataMapper();
                                    $modSelect = $modifierMap->getDbTable()->select();
                                    $modSelect->from($modifierMap->getDbTable(),array('mia_id','mia_fk_restaurant','mia_fk_item','mia_name','mia_description','mia_type','mia_price','mia_image','mia_status','mia_createdby','mia_updatedby','mia_colorcode','mia_createddatetime','mia_updateddatetime','mia_ordersequence','mia_pricetype','mia_fk_menu'))
                                                ->where('mia_fk_item = ?',$rowMenuItem->miid);
                                    $modResult = $modifierMap->getDbTable()->fetchAll($modSelect);
                               
                                    foreach($modResult as $modRow){
                                    	
                                        $modResultSet[] = array('mia_id' => $modRow->mia_id,
                                                                'mia_fk_restaurant' => $modRow->mia_fk_restaurant,
                                                                'mia_fk_item' => $modRow->mia_fk_item,
                                                                'mia_name' => $modRow->mia_name,
                                                                'mia_description' => $modRow->mia_description,
                                                                'mia_type' => $modRow->mia_type,
                                                                'mia_price' => $modRow->mia_price,
                                                                'mia_image' => $modRow->mia_image,
                                                                'mia_status' => $modRow->mia_status,
                                                                'mia_createdby' => $modRow->mia_createdby,
                                                                'mia_updatedby' => $modRow->mia_updatedby,
                                                                'mia_colorcode' => $modRow->mia_colorcode,
                                                                'mia_createddatetime' => $modRow->mia_createddatetime,
                                                                'mia_updateddatetime' => $modRow->mia_updateddatetime,
                                                                'mia_ordersequence' => $modRow->mia_ordersequence,
                                                                'mia_pricetype' => $modRow->mia_pricetype,
                                                                'mia_fk_menu' => $modRow->mia_pricetype);
                                    }                                    
                                }
                                
								$menu_item[] = array('miid' 			  => $rowMenuItem->miid,
													 'mifk_categoryid' 	  => $rowMenuItem->mifk_categoryid,
													 'mi_name' 			  => $rowMenuItem->mi_name,
													 'mi_description' 	  => $rowMenuItem->mi_description,
													 'mi_price' 		  => $rowMenuItem->mi_price,
													 'mi_type' 			  => $rowMenuItem->mi_type,
										 		 	 'mi_image' 		  => $rowMenuItem->mi_image,
													 'mi_status' 		  => $rowMenuItem->mi_status,
													 'mi_createdby' 	  => $rowMenuItem->mi_createdby,
													 'mi_createddatetime' => $rowMenuItem->mi_createddatetime,
													 'mi_updatedby' 	  => $rowMenuItem->mi_updatedby,
													 'mi_updateddatetime' => $rowMenuItem->mi_updateddatetime,
													 'mi_ordersequence'   => $rowMenuItem->mi_ordersequence,
                                                     'mi_itemcolor'       => $rowMenuItem->mi_itemcolor,
                                                     'mi_modifier_status' => $rowMenuItem->mi_modifier_status,
                                                     'mi_tags'	=> $this->getItemTagsByItemId($rowMenuItem->miid),
                                                     'menu_modifiers'     => $modResultSet);
                                
							}
							if(count($menu_item) > 0){
								$result["MenuItem"] = $menu_item;
							}else{
								$result["MenuItem"] = array();
							}
						}
					}else{
						$result["MenuItem"] = array();
					}				
				}else{
					$result["MenuNames"]  = array();
				}
			
			return $result;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getItemTagsByItemId($itemId)
	{
		try
		{
			$db = new FirmManagement_Model_DbTable_MenuItemTags();
			$select = $db->select()
						 ->from($db,array('mit_id','mit_fk_itemid','mit_tag_title'))
						 ->where('mit_fk_itemid = ?',$itemId)
						 ->order('mit_id')
						 ->setIntegrityCheck(false);
			$data = $select->query()->fetchAll();
			return $data;
		}
		catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	public function postgresArrayToPhp($postgresArray)
	{
		try
		{

			$data = str_replace(array("\r\n", "\r", "\n"), "", trim($postgresArray,'{}'));
			$result = array();
			if(strlen($data)>0)
			{
				if (strpos($data, '"') === 0) {
			    $data = '[' . $data . ']';
			    $result = json_decode($data);
				} else {
				    $result = explode(',', $data);

				}
			}
			return $result;
		}
		catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	public function setMobileMenuViewType($restid, $viewtype)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$set = array('mr_viewtype' => $viewtype);
			
			$where = $db->quoteInto('mrfk_restaurantid = ?',$restid);
			$row_affected = $this->getDbTable()->update($set,$where);
			return $row_affected;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
        /*Upload restaurant menus via csv files */
        public function uploadCsvMenu($restid , $arraydata, $menuid)
        {            
            try{ 
                        
                        $updateRows='';
                        $errorString='';
                        $storage = new Zend_Auth_Storage_Session();
		        $userdata = $storage->read();
                        $menucatogrymapper = new FirmManagement_Model_MenuCategoryDataMapper();
                        $mctable =  $menucatogrymapper->getDbTable();
                        $select = $mctable->select();			
			$select->from($mctable, array('mcid', 'mc_name'))				   
                                   ->where('mcfk_menu_restaurantid = ?',$menuid);                                                                           
                        $menuitemmapper = new FirmManagement_Model_MenuItemsDataMapper();
                        $mi =  $menuitemmapper->getDbTable();                                                                        
                        foreach($arraydata as $menusdetails){
                            $rowSet = $mctable->fetchAll($select); 
                            $status=true;
                            $menucatogry="";
                            $mcstring="";
                            foreach($menusdetails as $menu){
                                $menucatogry[] = $menu;                                                                                                                                                                                           
                            }
                            $menurowstr = implode(" ",$menucatogry);
                            if(mb_check_encoding($menurowstr, 'UTF-8')){
                            $mcstring = trim($menucatogry[0]);
                            $data = array(
                                'mcfk_restaurantid'      =>$restid,
                                'mc_name'                =>$mcstring,
                                'mc_description'         => '',
                                'mc_status'              =>true,
                                'mcfk_menu_restaurantid' => $menuid,
                                'mc_createddatetime'=>	date('Y-m-d H:i:s'),
                                'mc_createdby'	=>$userdata['User_Id']
                            );                                                         
                            foreach ($rowSet as $row){
                                if($row->mc_name == $mcstring){                             
                                    $status = false;
                                    break;
                                }
                            }                                                        
                        if($status){                           
                          $updateRows = $mctable->insert($data);                                                    
                        }    
                        if($updateRows){                            
                            $itemdata = array(
                                'mifk_categoryid' => $updateRows,
                                'mi_name' => $menucatogry[1],
                                'mi_type' => (int)$menucatogry[2],
                                'mi_description' => $menucatogry[3],
                                'mi_price' => $menucatogry[4],
                                'mi_status' =>true,
                                'mi_createdby'	=> $userdata['User_Id'],
                                'mi_createddatetime'=>	date('Y-m-d H:i:s'),
                                 
                            );
                          $insertitem =  $mi->insert($itemdata);
                        }
                        }
                        else {
                            $errorString .= $menurowstr. ":";
                        }
                    }      
                        if($errorString){
                            return $errorString;
                        }else{
                            return true;
                        }                            
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
            
        }
        
}