<?php

class FirmManagement_Model_PosRestaurantOrdersMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_PosOrders');
		}
		return $this->_dbTable;
	}
	
	/**
	 * MIGRATE POS ORDERS TO SERVER FROM IPAD
	 */
	public function migratePosOrderFromIpad($orders)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		try {
			$ordersDb = $this->getDbTable();
			$orderDetailsMapper = new FirmManagement_Model_PosOrderDetailsMapper();
			$orderDetailsDb = $orderDetailsMapper->getDbTable();
			$orderAddonsMapper = new FirmManagement_Model_PosOderAddonMapper();
			$orderAddonDb = $orderAddonsMapper->getDbTable();
			$response = array();
			if(count($orders)>0)
			{
				foreach ($orders as $orderKey => $order) {
					$db->beginTransaction();
					//TRANSACTION CODE STARTS
					$orderArr = array();
					$orderArr['pro_booking_fk_id'] = $order['booking_id'];
					$orderArr['pro_cus_fk_id'] = $order['customer_id'];
					$pro_discount = 0;
					if($order['discount']!='')
					{
						$pro_discount = $order['discount'];
					}
					$orderArr['pro_discount'] = $pro_discount;
					$pro_discount_amount = 0;
					if($order['discount_amount']!='')
					{
						$pro_discount_amount = $order['discount_amount'];
					}
					$orderArr['pro_discount_amount'] = $pro_discount_amount;

					$pro_net_amount = 0;
					if($order['net_amount']!='')
					{
						$pro_net_amount = $order['net_amount'];
					}
					$orderArr['pro_net_amount'] = $pro_net_amount;
					$orderArr['pro_order_status'] = true;
					$orderArr['pro_ordercreatedby'] = $order['order_createdby'];
					$orderArr['pro_ordercreateddatetime'] = $order['order_created_date_time'];
					$orderArr['pro_orderupdatedby'] = $order['order_updatedby'];
					$orderArr['pro_orderupdateddatetime'] = $order['order_updated_date_time'];
					$orderArr['pro_restaurant_fk_id'] = $order['restaurant_id'];

					$pro_roundoffamount = 0;
					if($order['round_off_amount']!='')
					{
						$pro_roundoffamount = $order['round_off_amount'];
					}
					$orderArr['pro_roundoffamount'] = $pro_roundoffamount;
					$orderArr['pro_server_fk_id'] = $order['server_id'];
					$orderArr['pro_servername'] = $order['server_name'];
					$orderArr['pro_tableno'] = $order['table_no'];

					$pro_tax = 0;
					if($order['tax']!='')
					{
						$pro_tax = $order['tax'];
					}
					$orderArr['pro_tax'] = $pro_tax;
					//INSERT ORDER
					$order_id = $ordersDb->insert($orderArr);
					$mainDetailsArr = $order['order_details'];
					$respOrderDetails = array();
					if(count($mainDetailsArr)>0)
					{
						foreach ($mainDetailsArr as $detailKey => $details) {
							$orderDetailArr = array();
							$orderDetailsArr['prod_order_fk_id'] = $order_id;
							$orderDetailsArr['prod_item_fk_id'] = $details['item_id'];
							$orderDetailsArr['prod_item_name'] = $details['item_name'];
							$netAmnt = 0;
							if($details['net_amount']!='')
							{
								$netAmnt = $details['net_amount'];
							}
							$orderDetailsArr['prod_netamt'] = $netAmnt;
							$itemBasePice = 0;
							if($details['item_base_price']!='')
							{
								$itemBasePice = $details['item_base_price'];
							}
							$orderDetailsArr['prod_item_base_price'] = $itemBasePice;
							
							$item_categoryid = 0;
							if($details['item_categoryid']!='')
							{
								$item_categoryid = $details['item_categoryid'];
							}
							$orderDetailsArr['prod_item_categoryid'] = $item_categoryid;
							$tax = 0;
							if($details['tax']!='')
							{
								$tax = $details['tax'];
							}
							$orderDetailsArr['prod_tax'] = $tax;
							$prod_discount = 0;
							if($details['discount']!='')
							{
								$prod_discount = $details['discount'];
							}

							$orderDetailsArr['prod_discount'] = $prod_discount;

							$prod_discountamt = 0;
							if ($details['discount_amount']!='') {
								$prod_discountamt = $details['discount_amount'];
							}
							$orderDetailsArr['prod_discountamt'] = $prod_discountamt;
							//INSERT ORDER DETAILS ROW
							$order_detail_id = $orderDetailsDb->insert($orderDetailsArr);
							$modifiersArr = $details['modifiers'];
							$respModArr = array();
							if(count($modifiersArr)>0)
							{
								foreach ($modifiersArr as $modKey => $modifier) {
									$modArr = array();
									$modArr['poa_orderdetial_fk_id'] = $order_detail_id;
									$modArr['poa_order_fk_id'] = $order_id;
									$modArr['poa_modifier_fk_id'] = $modifier['modifier_id'];
									$modArr['poa_item_fk_id'] = $modifier['item_id'];
									$modArr['poa_modifier_name'] = $modifier['modifier_name'];
									$modPrice = 0;
									if($modifier['modifier_price']!="")
									{
										$modPrice = $modifier['modifier_price'];
									}
									$modArr['poa_modifier_price'] = $modPrice;
									$modArr['poa_status'] = true;
									//INSERT MODIFIERS
									$newModId = $orderAddonDb->insert($modArr);
									$respModArr[] = array('local_mod_id'=>$modifier['ipad_id'],'server_mod_id'=>$newModId);
								}
							}

							$respOrderDetails[] = array('local_order_id'=>$details['ipad_id'],'server_order_detail_id'=>$order_detail_id,'order_modifiers'=>$respModArr);
						}
					}
					//TRANSACTION CODE ENDS
				$db->commit();
				$resArr = array('local_id'=>$order['ipad_id'],'server_order_id'=>$order_id,'order_details'=>$respOrderDetails);
				$response[] = $resArr;
				}
			}
			return $response;
		} catch (Exception $e) {
			$db->rollBack();
			throw new Exception($e->getMessage());
			
		}
	}
	
	/**
	 * FETCH ALL ORDERS FOR THE IPAD
	 */
	public function fetchOrdersForIpad($conditionArray)
	{
		try
		{
			$db = $this->getDbTable();
			$select = $db->select()
						->from(array('mt.pos_restaurant_orders'))
						->where('pro_order_status = ?',true)
						->setIntegrityCheck(false);
			if(is_array($conditionArray))
			{
				if(count($conditionArray)>0)
				{
					foreach ($conditionArray as $condition => $value) {
						$select->where($condition,$value);
					}
				}
			}
			$data = $select->query()->fetchAll();
			$response = array();
			$response['orders'] = array();
			$ordersArray = array();
			$orderDetailsMapper = new FirmManagement_Model_PosOrderDetailsMapper();
			if(count($data)>0)
			{
				
				foreach ($data as $key => $row) {
					$tempOrder = array();
					$tempOrder['orderid'] = $row['pro_id'];
					$tempOrder["bookingid"] = $row['pro_booking_fk_id'];
					$tempOrder["customerid"] = $row['pro_cus_fk_id'];
					$tempOrder["discount"] = $row['pro_discount'];
					$tempOrder["discountamt"] = $row['pro_discount_amount'];
					$tempOrder["netamt"] = $row['pro_net_amount'];
					$tempOrder["ordercreatedby"] = $row['pro_ordercreatedby'];
					$tempOrder["order_status"] = $row['pro_order_status'];
					$tempOrder["ordercreateddatetime"] = $row['pro_ordercreateddatetime'];
					$tempOrder["orderupdatedby"] = $row['pro_orderupdatedby'];
					$tempOrder["orderupdateddatetime"] = $row['pro_orderupdateddatetime'];
					$tempOrder["restaurant"] = $row['pro_restaurant_fk_id'];
					$tempOrder["roundoffamount"] = $row['pro_roundoffamount'];
					$tempOrder["serverid"] = $row['pro_server_fk_id'];
					$tempOrder["servername"] = $row['pro_servername'];
					$tempOrder["tableno"] = $row['pro_tableno'];
					$tempOrder["tax"] = $row['pro_tax'];
					$tempOrder['order_details'] = $orderDetailsMapper->getOrderDetailsByOderId($row['pro_id']);
					$tempOrder['order_hash_identifier'] = md5(json_encode($tempOrder)); 
					$ordersArray[]  = $tempOrder;
				}
			}
			$response['orders'] = $ordersArray;
			$response['main_hash_identifier'] = md5(json_encode($ordersArray));
			return $response;
		}
		catch (Exception $e) {
			throw new Exception($e->getMessage());
			
		}
	}
}
