<?php

class FirmManagement_Model_SmsRestaurantSubscriptionDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_SmsRestaurantSubscription');
		}
		return $this->_dbTable;
	}
	
	public function PostCreditsOnRequest($request)
	{
		try{
			$status = false;
			$timemapper = new FirmManagement_Model_FirmDataMapper();
			$timeZone = $timemapper->GetRestaurantTimeZone($request->resid);		
			date_default_timezone_set($timeZone);
			$date = date('M Y');
			$credits = (int)$request->credits;
			$db = Zend_Db_Table::getDefaultAdapter();
			$data = array('subcamp_resid' 				=>	$request->resid,
						  'subcamp_createddatetime' 	=>	date("Y-m-d H:i:s"),
						  'subcamp_credit_type' 		=>	'Paid',
						  'subcamp_totalcredits'		=>	$credits,
						  'subcamp_currentmonth'		=>	$date
					);
			$db->beginTransaction();
			$result = $this->getDbTable()->insert($data);
			if($result){
				$resCampCountMapper = new FirmManagement_Model_SmsRestaurantCampCountDataMapper();
		    	$resCampCount = $resCampCountMapper->getDbTable();	
		    	$select = $resCampCount->select();
		    	$select->from($resCampCount,array('rescamp_totalsms'))
		    			->where('rescamp_resid = ?', $request->resid);
				$totalsms = $resCampCount->fetchRow($select);
				if($totalsms){
					$TotalSms = $totalsms->rescamp_totalsms + $credits;
				}
		    	$campset = array('rescamp_totalsms'			=> 	$TotalSms,
		    				 'rescamp_updateddatetime'  	=>  date("Y-m-d H:i:s"),
							 'rescamp_updatedby'			=> 	1					 
				);
				$where = array('rescamp_resid = ?'=> $request->resid);
				$campupdatestatus = $resCampCount->update($campset,$where);
				if($campupdatestatus){
					$reqCreditsMapper = new FirmManagement_Model_SmsRestaurantRequestCreditsDataMapper();
					$reqCredits = $reqCreditsMapper->getDbTable();	
					$set = array('reqcre_status' 			=> 1,
								 'reqcre_updatedby' 		=> 1,
								 'reqcre_updateddatetime' 	=> date("Y-m-d H:i:s"),
					);
					$where = array('reqcre_id = ?'=> $request->reqid);
					$reqCreditstatus = $reqCredits->update($set,$where);
				}
			}
			
			$db->commit();		
			$status = true;
			return $status;	
		}catch(Exception $ex){
			$db->rollBack();
			Uss_Logger_FileLogger::info($ex->getMessage());
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestCreditsAccountDetails($data,$offset)
	{
		try{
			$limit = 5;
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from($table,array('subcamp_id','subcamp_createddatetime','subcamp_credit_type','subcamp_totalcredits' ))
				   ->where('subcamp_resid = ?', $data['RestId'])
				   ->order('subcamp_id DESC');	
		   	$Result = "";
			$Result = new Zend_Paginator(
				new Zend_Paginator_Adapter_DbTableSelect($select)
				);
			$Result->setItemCountPerPage($limit);
			$Result->setCurrentPageNumber($offset);
			return $Result;
			
		}catch(Exception $ex){
		Uss_Logger_FileLogger::info($ex->getMessage());
		throw new Exception($ex->getMessage()) ;		
		}
	}

	/**
	 * POST CREDITS FROM ADMIN
	 */
	public function PostCreditsFromAdmin($request)
	{
		try{
			$status = false;
			$timemapper = new FirmManagement_Model_FirmDataMapper();
			$timeZone = $timemapper->GetRestaurantTimeZone($request->resid);		
			date_default_timezone_set($timeZone);
			$date = date('M Y');
			$credits = (int)$request->credits;
			$db = Zend_Db_Table::getDefaultAdapter();
			$data = array('subcamp_resid' 				=>	$request->resid,
						  'subcamp_createddatetime' 	=>	date("Y-m-d H:i:s"),
						  'subcamp_credit_type' 		=>	'Free',
						  'subcamp_totalcredits'		=>	$credits,
						  'subcamp_currentmonth'		=>	$date
					);
			$db->beginTransaction();
			$result = $this->getDbTable()->insert($data);
			if($result){
				$resCampCountMapper = new FirmManagement_Model_SmsRestaurantCampCountDataMapper();
		    	$resCampCount = $resCampCountMapper->getDbTable();	
		    	$select = $resCampCount->select();
		    	$select->from($resCampCount,array('rescamp_totalsms'))
		    			->where('rescamp_resid = ?', $request->resid);
				$totalsms = $resCampCount->fetchRow($select);
				if($totalsms){
					$TotalSms = $totalsms->rescamp_totalsms + $credits;

					$campset = array('rescamp_totalsms'			=> 	$TotalSms,
		    				 'rescamp_updateddatetime'  	=>  date("Y-m-d H:i:s"),
							 'rescamp_updatedby'			=> 	1					 
				);
				$where = array('rescamp_resid = ?'=> $request->resid);
				$campupdatestatus = $resCampCount->update($campset,$where);
				}

				else {
					$now =  date("Y-m-d H:i:s");
					$campset = array('rescamp_totalsms'			=> 	 $credits,
		    				 'rescamp_updateddatetime'  	=> $now,
							 'rescamp_updatedby'			=> 	1,
							 'rescamp_createddatetime'		=> $now,
							 'rescamp_createdby'				  =>  1,
							 'rescamp_usedsms' => 0,
							 'rescamp_resid' => $request->resid,
				);
					 $resCampCount->insert($campset);
				}
		    	
			}
			
			$db->commit();		
			$status = true;
			return $status;	
		}catch(Exception $ex){
			$db->rollBack();
			Uss_Logger_FileLogger::info($ex->getMessage());
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestCreditsAccountDetailsforTablet($restaurantid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from($table,array('subcamp_id','subcamp_createddatetime','subcamp_credit_type','subcamp_totalcredits' ))
				   ->where('subcamp_resid = ?', $restaurantid)
				   ->order('subcamp_id DESC');	
		   	$resultset = $table->fetchAll($select);	
		  	$tablesArr = array();
			foreach($resultset as $key=>$value){
				$subArray = array();
				foreach($value as  $key1=>$value1){
					$subArray[$key1]= $value1;
				}
				$tablesArr[] = $subArray;
			}
			return $tablesArr;
			
		}catch(Exception $ex){
		Uss_Logger_FileLogger::info($ex->getMessage());
		throw new Exception($ex->getMessage()) ;		
		}
	}
	
}
