<?php
/**
* Created By : Sai
* Date : 30-Jan-2017
* Purpose : Handles mapper class for taxation rule
* 
*/
class FirmManagement_Model_TaxationRuleDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('FirmManagement_Model_DbTable_TaxationRules');
		}
		return $this->_dbTable;
	}

	/**
	 * [getTaxRulesByResid taxation Rule Returns an object of FirmManagement_Model_TaxationRule]
	 * @param array $conditions [is a set of array including the condtions]
	 */
	public function getTaxRules(array $conditions = null)
	{
		try {
				$db = $this->getDbTable();
				$select = $db->select()
							->from(array('mt.taxation_rules'))
							->joinLeft(array('mt.taxation_rule_tags'),'trt_fk_trid = tr_id',array('trt_id','trt_tag_title','trt_fk_trid'))
							->order('tr_id ASC')
							->setIntegrityCheck(false);
				if($conditions!=null)
				{
					if(count($conditions)>0)
					{
						foreach ($conditions as $key => $condition) {
							$select->where($key,$condition);
						}
					}
				}
				$rawData = $select->query()->fetchAll();
				$response = array();
				if(count($rawData)>0)
				{
					$formatedData = array();	
					foreach ($rawData as $key => $row) {
						$index = $row['tr_id'];
						if(!array_key_exists($index, $formatedData))
						{
							$formatedData[$index] = $row;
						}
						$tag = $row['trt_tag_title'];
						unset($row['trt_tag_title']);	
						if(!array_key_exists('tags', $formatedData[$index]))
						{
							$formatedData[$index]['tags'] = array();
						}
						if(strlen($tag)>0)
						{
							$formatedData[$index]['tags'][] = $tag;
						}
						if(!array_key_exists('tr_tags', $formatedData[$index]))
						{
							$formatedData[$index]['tr_tags'] = array();
						}
						if(strlen($tag)>0)
						{
							$formatedData[$index]['tr_tags'][] = array('trt_id'=>$row['trt_id'],'trt_fk_trid'=>$row['trt_fk_trid'],'trt_tag_title'=>$tag);
						}
						
					}
					$response = array_map(function($arr)
						{
							$obj = new FirmManagement_Model_TaxationRule();
							$obj = $obj->setTrId($arr['tr_id']);
							$obj = $obj->setTrTittle(trim($arr['tr_title']));
							$obj = $obj->setTrPercent($arr['tr_percent']);
							$obj = $obj->setTrType(trim($arr['tr_type']));
							$obj = $obj->setTrRestaurantId($arr['tr_fk_restaurantid']);
							$obj = $obj->setTrStatus($arr['tr_status']);
							$obj = $obj->setTrCreatedOn($arr['tr_createdon']);
							$obj = $obj->setTrCreatedBy($arr['tr_createdby']);
							$obj = $obj->setTrUpdatedOn($arr['tr_updatedon']);
							$obj = $obj->setTrUpdatedBy($arr['tr_updatedby']);
							$obj = $obj->setTrIgnoreToTotal($arr['tr_ignore_to_total']);
							$obj = $obj->setTrAlreadyIncluded($arr['tr_already_included']);
							$obj = $obj->setTrTags($arr['tags']);
							$obj = $obj->setRuleTags($arr['tr_tags']);
							return $obj;
						}, $formatedData);
					return $response;
				}

		} catch (Exception $e) {
			throw new Exception($e->getMessage());
			
		}
	}

	/**
	 * [addTaxRulr appends a new rule to the database, also calls the addtag method if any tags are associated to the rule]
	 * @param FirmManagement_Model_TaxationRule $obj 
	 */
	public function addTaxRule(FirmManagement_Model_TaxationRule $obj)
	{
		try
		{
			$arr = array();
			$arr['tr_title'] = $obj->getTrTittle();
			$arr['tr_percent'] = $obj->getTrPercent();
			$arr['tr_type'] = $obj->getTrType();
			$arr['tr_fk_restaurantid'] = $obj->getTrRestaurantId();
			$arr['tr_status'] = $obj->getTrStatus();
			$arr['tr_createdon'] = $obj->getTrCreatedOn();
			$arr['tr_createdby'] = $obj->getTrCreatedBy();
			$arr['tr_updatedon'] = $obj->getTrUpdatedOn();
			$arr['tr_updatedby'] = $obj->getTrUpdatedBy();
			$arr['tr_ignore_to_total'] = $obj->getTrIgnoreToTotal();
			$arr['tr_already_included'] = $obj->getTrAlreadyIncluded();
			$db = $this->getDbTable();
			$ruleId = $db->insert($arr);
			$tags = $obj->getTrTags();
			if(count($tags)>0)
			{
				$this->addRuleTagsByRuleId($ruleId,$tags);
			}
			return $ruleId;
		}
		catch (Exception $e) {
			throw new Exception($e->getMessage());
			
		}
	}

	/**
	 * [addRuleTagsByRuleId Add new tags to the rule by using tagid]
	 * @param [type] $ruleId [rule id]
	 * @param array  $tags   [tags as array]
	 */
	public function addRuleTagsByRuleId($ruleId,array $tags)
	{
		try
		{
			$tagsBd = new FirmManagement_Model_DbTable_TaxationRuleTags();
			foreach ($tags as $key => $tag) {
				$temp = array();
				$temp['trt_fk_trid'] = $ruleId;
				$temp['trt_tag_title'] = $tag;
				$tagsBd->insert($temp);
			}
		}
		catch (Exception $e) {
			throw new Exception($e->getMessage());
			
		}
	}

	/**
	 * [deleteAllTagsByRuleId deletes all tags of a ]
	 * @param  [type] $ruleId [description]
	 * @return [type]         [description]
	 */
	public function deleteAllTagsByRuleId($ruleId)
	{
		try
		{
			$tagsBd = new FirmManagement_Model_DbTable_TaxationRuleTags();
			$where = array('trt_fk_trid = ? '=>$ruleId);
			$tagsBd->delete($where);
		}
		catch (Exception $e) {
			throw new Exception($e->getMessage());
			
		}
	}

	/**
	 * [updateRuleById updates the rule details and also tags for a rule]
	 * @param  [FirmManagement_Model_TaxationRule] $obj [Object of taxationRule]
	 * @return [type]         [description]
	 */
	public function updateRuleById(FirmManagement_Model_TaxationRule $obj)
	{
		try
		{
			$ruleId = $obj->getTrId();
			$arr = array();
			$arr['tr_title'] = $obj->getTrTittle();
			$arr['tr_percent'] = $obj->getTrPercent();
			$arr['tr_type'] = $obj->getTrType();
			$arr['tr_fk_restaurantid'] = $obj->getTrRestaurantId();
			$arr['tr_status'] = $obj->getTrStatus();
			$arr['tr_createdby'] = $obj->getTrCreatedBy();
			$arr['tr_updatedon'] = date('Y-m-d H:i:s');
			$arr['tr_updatedby'] = $obj->getTrUpdatedBy();
			$arr['tr_ignore_to_total'] = $obj->getTrIgnoreToTotal();
			$arr['tr_already_included'] = $obj->getTrAlreadyIncluded();
			$data = array();
			foreach ($arr as $key => $value) {
				if($value!=null)
				{
					$data[$key] = $value;
				}
			}
			$db = $this->getDbTable();
			$where = 'tr_id = '.$ruleId;
			$updatedRow = $db->update($data,$where);
			
			/**UPDATING THE TAGS **/

			$tags = $obj->getTrTags();
			if(count($tags)>0)
			{
				$this->deleteAllTagsByRuleId($ruleId);
				$this->addRuleTagsByRuleId($ruleId,$tags);
			}
			return $updatedRow;

		}
		catch (Exception $e) {
			throw new Exception($e->getMessage());
		}
	}
	
}