<?php
class ManageRenumeration_Model_CompanyTwoCheckoutSubscriptionMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('ManageRenumeration_Model_DbTable_CompanyTwoCheckoutSubscription');
		}
		return $this->_dbTable;
	}
	
	public function SaveTwoCheckSubscriptionDetails(ManageRenumeration_Model_CompanyTwoCheckoutSubscription $TwoCheckoutSubscription)
	{
		try
		{
			
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();			
			$db->beginTransaction();
			/* Save Two Check Out Subscription Details */
            $table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('tcoms_id','tcoms_order_id','tcoms_credit_card_processed'))
				   ->where('tcoms_order_id =?',$TwoCheckoutSubscription->gettcoms_order_id());
				   
		    $rowset = $table->fetchRow($select);
            if($rowset){
                return true;
            }else{
                $table = $this->getDbTable();
                $data = array('tcoms_order_id'              => $TwoCheckoutSubscription->gettcoms_order_id(),
                              'tcoms_fk_company'            => $TwoCheckoutSubscription->gettcoms_fk_company(),
                              'tcoms_credit_card_processed' => $TwoCheckoutSubscription->gettcoms_credit_card_processed(),
                              'tcoms_status'				=> $TwoCheckoutSubscription->gettcoms_status(),
                              'tcoms_created_date'          => $TwoCheckoutSubscription->gettcoms_created_date());
                $id = $table->insert($data);

                $db->commit();
                $status = true;
                return $status;
            }
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveSubscriptionDetails(ManageRenumeration_Model_CompanyTwoCheckoutSubscription $TwoCheckoutSubscription)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('tcoms_id','tcoms_order_id','tcoms_credit_card_processed'))
				   ->where('tcoms_fk_company =?',$TwoCheckoutSubscription->gettcoms_fk_company())
				   ->where('tcoms_status = ?',$TwoCheckoutSubscription->gettcoms_status());
				   
		    $rowset = $table->fetchAll($select);
		    
		    $result = array();
		    
		    foreach($rowset as $row){		    	
		    	$result['order_id'] 	  = $row->tcoms_order_id;
		    	$result['card_processed'] = $row->tcoms_credit_card_processed;	
		    }
		    
		    return $result;
			
		}catch(Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function RetrieveRenumerationDetailsByCompanyId($restid)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('tcs'=>'mt.twocheckout_subscription'),array('tcoms_id','tcoms_order_id','tcoms_fk_company','tcoms_credit_card_processed','tcoms_status','tcoms_created_date','tcoms_updated_date','tcoms_twocheck_status'))
				   ->join(array('res'=>'mt.company'),'tcs.tcoms_fk_company = res.com_id',array('com_id','com_companyname'))
				   ->join(array('plan'=>'mt.company_subscription_renewal'),'plan.csrcompany_id = res.com_id',array('csrid','csrbilling_date','csrbilling_duedate','csramount','csrrestaurant_count','csramount_per_restaurant','csrbilling_fromdate','csrbilling_todate','csrstatus'))
				   ->where('tcs.tcoms_fk_company = ?',$restid);
				   
			$rowSet = $table->fetchAll($select);
			$result = array();
			if(count($rowSet) > 0){
				foreach($rowSet as $row){
					$result['tcoms_id'] 				      = $row->tcoms_id;
					$result['tcoms_order_id'] 		      = $row->tcoms_order_id;
					$result['tcoms_fk_company'] 		  = $row->tcoms_fk_company;
					$result['resrestaurant_name'] 		  = $row->com_companyname;
					$result['tcoms_credit_card_processed'] = $row->tcoms_credit_card_processed;
					$result['tcoms_status'] 				  = $row->tcoms_status;
					$result['tcoms_created_date']          = $row->tcoms_created_date;
					$result['tcoms_updated_date']          = $row->tcoms_updated_date;
					$result['tcoms_twocheck_status']   	  = $row->tcoms_twocheck_status;					
					
					if($row->spid > 4)
					{
						$result['spplan_description']  = str_replace("$","INR",$row->spplan_description);
					}else
					{
						$result['spplan_description']  = $row->spplan_description;
					}
					  	 
					$result['spamount']   	  			  = $row->spamount;
					$result['spplan_duration']   	  	  = $row->spplan_duration;
				} 	
			}
			
			return $result;
			
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function UpdateTwoCheckSubscriptionStatus(ManageRenumeration_Model_CompanyTwoCheckoutSubscription $TwoCheckoutSubscription)
	{
		try
		{
			$table = $this->getDbTable();
			
			$set = array('tcoms_twocheck_status' => $TwoCheckoutSubscription->gettcoms_twocheck_status(),
						 'tcoms_status' 			=> $TwoCheckoutSubscription->gettcoms_status(),
						 'tcoms_updated_date' 	=> $TwoCheckoutSubscription->gettcoms_updated_date());
			
			$where = array('tcoms_order_id = ?' => $TwoCheckoutSubscription->gettcoms_order_id());
						
			$row_affected = $table->update($set,$where);	
					
			return $row_affected;
		}
		catch(Exception $ex)
		{
			throw new Exception($ex->getMessage()) ;
		}
	}

}