<?php
class ManageRenumeration_Model_TwoCheckoutSubscriptionMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('ManageRenumeration_Model_DbTable_TwoCheckoutSubscription');
		}
		return $this->_dbTable;
	}
	
	public function SaveTwoCheckSubscriptionDetails(ManageRenumeration_Model_TwoCheckoutSubscription $TwoCheckoutSubscription)
	{
		try
		{
			
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();			
			$db->beginTransaction();
			/* Save Two Check Out Subscription Details */
			
			$table = $this->getDbTable();
			$data = array('tcos_order_id'			   => $TwoCheckoutSubscription->gettcos_order_id(),
						  'tcos_fk_restaurant'		   => $TwoCheckoutSubscription->gettcos_fk_restaurant(),
						  'tcos_credit_card_processed' => $TwoCheckoutSubscription->gettcos_credit_card_processed(),
						  'tcos_status'				   => $TwoCheckoutSubscription->gettcos_status(),
						  'tcos_created_date'		   => $TwoCheckoutSubscription->gettcos_created_date());
			$id = $table->insert($data);
			
			/* Update Subscription Date */
			$RenumerationPlanMap = new ManageRenumeration_Model_RenumerationPlanMap();
			$RenumerationPlanMap->setrmpmrestaurant_id($TwoCheckoutSubscription->gettcos_fk_restaurant());
			$RenumerationPlanMap->setrmpmplan_activation_date($TwoCheckoutSubscription->gettcos_created_date());
			$RenumerationPlanMap->setrmpmpayment_plan_id($TwoCheckoutSubscription->getplan_id());
			
			$RenumerationPlanMapMapper = new ManageRenumeration_Model_RenumerationPlanMapMapper();
			
			$rows_affected = $RenumerationPlanMapMapper->UpdatePlanActivationDate($RenumerationPlanMap);
			
			/* Update Payments Status in restaurant table */
			
			$FirmDataMapper = new  FirmManagement_Model_FirmDataMapper();
			$resttable = $FirmDataMapper->getDbTable();
			$set = array('respaymentstatus' => True,
						 'resupdateddatetime' => $TwoCheckoutSubscription->gettcos_created_date());
			
			$where = array('resid = ?' => $TwoCheckoutSubscription->gettcos_fk_restaurant());
			
			$rows_affected = $resttable->update($set,$where);
			
			$db->commit();
			$status = true;
			return $status;
			
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveSubscriptionDetails(ManageRenumeration_Model_TwoCheckoutSubscription $TwoCheckoutSubscription)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('tcos_id','tcos_order_id','tcos_credit_card_processed'))
				   ->where('tcos_fk_restaurant =?',$TwoCheckoutSubscription->gettcos_fk_restaurant())
				   ->where('tcos_status = ?',$TwoCheckoutSubscription->gettcos_status());
				   
		    $rowset = $table->fetchAll($select);
		    
		    $result = array();
		    
		    foreach($rowset as $row){		    	
		    	$result['order_id'] 	  = $row->tcos_order_id;
		    	$result['card_processed'] = $row->tcos_credit_card_processed;	
		    }
		    
		    return $result;
			
		}catch(Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function RetrieveRenumerationDetailsByRestId($restid)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('tcs'=>'mt.twocheckout_subscription'),array('tcos_id','tcos_order_id','tcos_fk_restaurant','tcos_credit_card_processed','tcos_status','tcos_created_date','tcos_updated_date','tcos_twocheck_status'))
				   ->join(array('res'=>'mt.restaurant'),'tcs.tcos_fk_restaurant = res.resid',array('resid','resrestaurant_name'))
				   ->join(array('map'=>'mt.restaurant_membership_plan_map'),'map.rmpmrestaurant_id = tcs.tcos_fk_restaurant',array('rmpmpayment_plan_id','rmpmplan_activation_date'))
				   ->join(array('plan'=>'mt.subscription_plans'),'plan.spid = map.rmpmpayment_plan_id',array('spid','spplan_title','spplan_description','spamount','spplan_duration'))
				   ->where('tcs.tcos_fk_restaurant = ?',$restid);
				   
			$rowSet = $table->fetchAll($select);
			$result = array();
			if(count($rowSet) > 0){
				foreach($rowSet as $row){
					$result['tcos_id'] 				      = $row->tcos_id;
					$result['tcos_order_id'] 		      = $row->tcos_order_id;
					$result['tcos_fk_restaurant'] 		  = $row->tcos_fk_restaurant;
					$result['resrestaurant_name'] 		  = $row->resrestaurant_name;
					$result['tcos_credit_card_processed'] = $row->tcos_credit_card_processed;
					$result['tcos_status'] 				  = $row->tcos_status;
					$result['tcos_created_date']          = $row->tcos_created_date;
					$result['tcos_updated_date']          = $row->tcos_updated_date;
					$result['rmpmplan_activation_date']   = $row->rmpmplan_activation_date;
					$result['spplan_title']   			  = $row->spplan_title;
					$result['tcos_twocheck_status']   	  = $row->tcos_twocheck_status;					
					
					if($row->spid > 4)
					{
						$result['spplan_description']  = str_replace("$","INR",$row->spplan_description);
					}else
					{
						$result['spplan_description']  = $row->spplan_description;
					}
					  	 
					$result['spamount']   	  			  = $row->spamount;
					$result['spplan_duration']   	  	  = $row->spplan_duration;
				} 	
			}
			
			return $result;
			
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function UpdateTwoCheckSubscriptionStatus(ManageRenumeration_Model_TwoCheckoutSubscription $TwoCheckoutSubscription)
	{
		try
		{
			$table = $this->getDbTable();
			
			$set = array('tcos_twocheck_status' => $TwoCheckoutSubscription->gettcos_twocheck_status(),
						 'tcos_status' 			=> $TwoCheckoutSubscription->gettcos_status(),
						 'tcos_updated_date' 	=> $TwoCheckoutSubscription->gettcos_updated_date());
			
			$where = array('tcos_order_id = ?' => $TwoCheckoutSubscription->gettcos_order_id());
						
			$row_affected = $table->update($set,$where);	
					
			return $row_affected;
		}
		catch(Exception $ex)
		{
			throw new Exception($ex->getMessage()) ;
		}
	}

}