<?php
class ManageRestaurant_Model_RestaurantGroupDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
				
			$this->setDbTable('ManageRestaurant_Model_DbTable_RestaurantGroup');
		}
		return $this->_dbTable;
	}

	public function getRestaurantsGroup(ManageRestaurant_Model_RestaurantGroup $restid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rsgid','rsggroup','rsgfk_restaurant','rsgdescription'))
			->where('rsgfk_restaurant = ?',$restid->getRestaurantId())
			->where('rsgstatus = ?',TRUE)
			->orwhere('rsggroup_type_id = ?',1);

			$rowset = $table->fetchAll($select);
			$restaurantGroup = array();
			$restaurantGroup[] = array('key'=>'','value'=>'Select Group');
			foreach($rowset as $row){
				$restaurantGroup[] = array('key'=>$row['rsgid'],'value'=>$row['rsggroup'],'resid'=>$row['rsgfk_restaurant'],'desc'=>$row['rsgdescription']);
			}
			return $restaurantGroup;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function AddUserDefindgroup(ManageRestaurant_Model_RestaurantGroup $restgroup)
	{
			$db = Zend_Db_Table::getDefaultAdapter();
			$data = array(
			'rsggroup_type_id'	=>	$restgroup->getGroupTypeId(),
			'rsgfk_restaurant'	=>	$restgroup->getRestaurantId(),
			'rsggroup'			=>	$restgroup->getRestaurantGroup(),
			'rsgdescription'	=>	$restgroup->getGroupDesc(),
			'rsgcreated_date'	=>	$restgroup->getCreatedDate(),
			'rsgstatus'			=>	$restgroup->getStatus()
			);

			try{
				$db->beginTransaction();
				$this->getDbTable()->insert($data);
				$db->commit();
				$status = true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}

	public function getUserGroupById(ManageRestaurant_Model_RestaurantGroup $userid)
	{
		try{
			$table = $this->getDbTable();
			$query= $table->select();
			$query->setIntegrityCheck(false);

			$query->from($table,array('rsgfk_restaurant','rsggroup','rsgdescription'))
			->where('rsgid = ?',$userid->getId());
				
			$Result = $table->fetchRow($query);
			$obj = new ManageRestaurant_Model_RestaurantGroup();
			$obj->setRestaurantId($Result->rsgfk_restaurant)
			->setRestaurantGroup($Result->rsggroup)
			->setGroupDesc($Result->rsgdescription);

			return $obj;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function UpdateGroupDetails(ManageRestaurant_Model_RestaurantGroup $restgroup)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$set = array(
			'rsgfk_restaurant'	=>	$restgroup->getRestaurantId(),
			'rsggroup'			=>	$restgroup->getRestaurantGroup(),
			'rsgdescription'	=>	$restgroup->getGroupDesc()
			);
			$where = $db->quoteInto('rsgid = ?',$restgroup->getId());
			$rows_affected = $this->getDbTable()->update($set,$where);

			if($rows_affected)
			{
				return true;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function deleteUserGroup($id)
	{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$mapper = new ManageRestaurant_Model_RestaurantGroupUsersDataMapper();
			try{
				$db->beginTransaction();
				$set1 = array('rsgstatus' => 0);
				$this->getDbTable()->update($set1,array('rsgid = ?'=>$id));
					
				$set2 = array('rgustatus' => 0);
				$mapper->getDbTable()->update($set2,array('rgufk_rsgid =?'=>$id));
				$db->commit();
				$status =true;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;
			}
			return $status;
	}

	public function checkGroupName(ManageRestaurant_Model_RestaurantGroup $restgroup)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			//$qry = "select count(rsggroup) from mt.restaurant_group where rsggroup = '". $restgroup->getRestaurantGroup() ."' and rsgfk_restaurant = ". $restgroup->getRestaurantId();
			$result = $db->fetchOne("select count(rsggroup) from mt.restaurant_group where rsggroup ilike '". $restgroup->getRestaurantGroup() ."' and rsgfk_restaurant = ". $restgroup->getRestaurantId()." and rsgstatus = ".$restgroup->getStatus());

			if((int)$result)
			{
				$status = true;
			}else{
				$status = false;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getRestaurantGroupsByRestid($restaurantid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();

			$select->from($table,array('rsgid','rsggroup_type_id','rsgfk_restaurant','rsggroup','rsgdescription','rsgstatus','rsgcreated_date','rsgupdated_date'))
				   ->where('rsgfk_restaurant = ?',$restaurantid);
			
			$rowset = $table->fetchAll($select);
		   	$RestGroups = array();
			foreach($rowset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					$subArr[$key1]= $value1;
				}
				$RestGroups[] = $subArr;
			}
			return $RestGroups;	 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}