<?php
class Notification_Model_SmsMessageMapper
{	
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Notification_Model_DbTable_SmsMessage');
		}
		return $this->_dbTable;
	}
	
	public function SaveMessageDetails(Notification_Model_SmsMessage $message)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$data = array(
		
					'smsmsg_subject'		=>	$message->getTitle(),
					'smsmsg_body'			=>	$message->getDescription(),
					'smsmsg_sentby'			=>	$message->getSentby(),
  					'smsmsg_sentto'			=>	str_replace("-","",$message->getSentTo()),
					'smsmsg_smstype'		=>	$message->getSmstype(),
					'smsmsg_priority'		=>	$message->getPriority(),
					'smsmsg_senton'			=>	date('Y-m-d H:i:s'),
					'smsmsg_sms_to_users'	=>	$message->getSentToUser(),
  					'smsmsg_sms_from_users'	=>	$message->getSentFromUser(),
					'smsmsg_msg_phrase'		=>	$message->getPhrase()
				);
		if($message->getBokid()){
			$data['smsmsg_fk_bokid'] = $message->getBokid();
		}
		if($message->getReference()){
			$data['smsmsg_reference'] = $message->getReference();
		}
		try{
			$msgTable = $this->getDbTable();
			$msgid = $msgTable->insert($data);
			return $msgid;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getBookingIdBySmsId($sms)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('smsmsg_fk_bokid','smsmsg_subject','smsmsg_body','smsmsg_sentby','smsmsg_sentto','smsmsg_smstype','smsmsg_priority','smsmsg_senton','smsmsg_sms_to_users','smsmsg_sms_from_users','smsmsg_msg_phrase'))
					->where('smsmsg_msg_phrase = ?',$sms);
			$result = $this->getDbTable()->fetchRow($select);
			return $result;		
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getSmsHistoryByBookingId(Notification_Model_SmsMessage $message)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('smsmsg_fk_bokid','smsmsg_subject','smsmsg_body','smsmsg_sentby','smsmsg_sentto','smsmsg_smstype','smsmsg_priority','smsmsg_senton','smsmsg_sms_to_users','smsmsg_sms_from_users','smsmsg_msg_phrase'))
					->where('smsmsg_fk_bokid = ?',$message->getBokid())
					->order('smsmsg_id DESC');
			$result = $this->getDbTable()->fetchAll($select);
			$resultArr = array();
			foreach($result as $row){
				$body = $row->smsmsg_body;
				$subject = $row->smsmsg_subject;
				if($subject == 'WaitingReady'){
					$subject = 'TableReady';
				}
				switch($row->smsmsg_body){
					case 'BP':	
						$body = $row->smsmsg_body.' ( '.$row->smsmsg_subject.' )';
					break;
					case 'CB':	
						$body = $row->smsmsg_body.' ( '.$row->smsmsg_subject.' )';
					break;
					case 'CL':	
						$body = $row->smsmsg_body.' ( '.$row->smsmsg_subject.' )';
					break;
				}
				$resultArr[] = array(
									'smsmsg_subject'		=>	$subject,
									'smsmsg_body'			=>	$body,
									'smsmsg_sentby'			=>	$row->smsmsg_sentby,
				  					'smsmsg_sentto'			=>	$row->smsmsg_sentto,
									'smsmsg_smstype'		=>	$row->smsmsg_smstype,
									'smsmsg_priority'		=>	$row->smsmsg_priority,
									'smsmsg_senton'			=>	date('m-d-Y h:i A',strtotime($row->smsmsg_senton)),
									'smsmsg_sms_to_users'	=>	$row->smsmsg_sms_to_users,
				  					'smsmsg_sms_from_users'	=>	$row->smsmsg_sms_from_users,
									'smsmsg_msg_phrase'		=>	$row->smsmsg_msg_phrase,
									'smsmsg_fk_bokid'		=>	$row->smsmsg_fk_bokid,
									'smsmsg_reference' 		=>	$row->smsmsg_msg_phrase
				);
			}
			return $resultArr;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getSmsMessagesByBookingIds($bookingIds)
	{
		try{
			$smsMessagesArr = array();
			if(count($bookingIds) > 0){
				$select = $this->getDbTable()->select();
				$select->from($this->getDbTable(),array('smsmsg_id','smsmsg_subject','smsmsg_body','smsmsg_sentby','smsmsg_sentto','smsmsg_senton','smsmsg_sms_to_users','smsmsg_sms_from_users','smsmsg_smstype','smsmsg_priority','smsmsg_fk_bokid','smsmsg_msg_phrase','smsmsg_reference'))
						->where('smsmsg_fk_bokid IN (?)',$bookingIds);
				$resultset = $this->getDbTable()->fetchAll($select);

				foreach($resultset as $key=>$value){
					$subArr = array();
					$bokid = $value['smsmsg_fk_bokid'];
					foreach($value as  $key1=>$value1){
						$subArr[$key1]= $value1;
					}
					$smsMessagesArr[] = $subArr;
				}
			}
			return $smsMessagesArr;	
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
}