<?php
class Payments_Model_RestaurantPaymentSettingsMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_RestaurantPaymentSettings');
		}
		return $this->_dbTable;
	}
	
	public function addPaymentSettings(Payments_Model_RestaurantPaymentSettings $payment)
	{
		try{
			$select = $this->getDbTable()->select();
			$stDate = $payment->getSettingDate();
			$endDate = $payment->getSettingEndDate();
			$select->from($this->getDbTable(),array('rpsid','rpsfk_restaurant','rpsreservation_amount','rpsreservation_pax','rpsstatus'));
			if($payment->getSettingType() == 'DEF'){
				$select->where('rpsfk_restaurant = ?',$payment->getRestaurantId())
				       ->where('rpssetting_type = ?',$payment->getSettingType());
				$row = $this->getDbTable()->fetchRow($select);
			}else if($payment->getSettingType() == 'SPL'){
				$select->where('rpsfk_restaurant = ?',$payment->getRestaurantId())
					   ->where('rpssetting_date <= ?',$payment->getSettingDate())
					   ->where('rpssetting_date_end >= ?',$payment->getSettingDate());
				$row = $this->getDbTable()->fetchRow($select);
			}else if($payment->getSettingType() == 'RANGE'){
				$select->where('rpsfk_restaurant = ?',$payment->getRestaurantId())
					   ->where("(rpssetting_date <= '$stDate' AND rpssetting_date_end >= '$stDate') OR (rpssetting_date <= '$endDate' AND rpssetting_date_end >= '$endDate')");
				$row = $this->getDbTable()->fetchRow($select);
			}
			if($row && $row->rpsid){
				$result = false;
			}else{
				$data = array(
								'rpsfk_restaurant'			=>	$payment->getRestaurantId(),
								'rpsreservation_amount'		=>	$payment->getAmount(),
								'rpsstatus'					=>	$payment->getStatus(),
								'rpscreatedby'				=>	$payment->getCreatedBy(),
								'rpsupdatedby'				=>	$payment->getUpdatedBy(),
								'rpsupdateddatetime'		=>	$payment->getUpdatedOn(),
								'rpsname'					=>	$payment->getSettingName(),
								'rpssetting_type'			=>	$payment->getSettingType(),
								'rpscreateddatetime'		=>	$payment->getCreatedOn(),
								'rpsnoshow_type'			=>	$payment->getNoShowType()
				);
				$data['rpsreservation_pax']	= $payment->getReservationPax();
				if($payment->getDescription()){
					$data['rpsdesc'] = $payment->getDescription();
				}
				if($payment->getSettingType() == 'SPL'){
					$data['rpssetting_date'] = $payment->getSettingDate();
					$data['rpssetting_date_end'] = $payment->getSettingDate();
				}
				if($payment->getSettingType() == 'RANGE'){
					$data['rpssetting_date'] = $payment->getSettingDate();
					$data['rpssetting_date_end'] = $payment->getSettingEndDate();
				}
				$result = $this->getDbTable()->insert($data);
			}
			return $result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function EditPaymentSettings(Payments_Model_RestaurantPaymentSettings $payment)
	{
		try{
			$set = array(
								'rpsreservation_amount'		=>	$payment->getAmount(),
								'rpsupdatedby'				=>	$payment->getUpdatedBy(),
								'rpsupdateddatetime'		=>	$payment->getUpdatedOn(),
								'rpsname'					=>	$payment->getSettingName()
				);
			$set['rpsreservation_pax'] = $payment->getReservationPax();
			//if($payment->getDescription()){
				$set['rpsdesc']	=	$payment->getDescription();
			//}
			if($payment->getSettingType() == 'Special'){
				$set['rpssetting_date'] = $payment->getSettingDate();
				$set['rpssetting_date_end'] = $payment->getSettingDate();
			}
			if($payment->getSettingType() == 'Range'){
				$set['rpssetting_date'] = $payment->getSettingDate();
				$set['rpssetting_date_end'] = $payment->getSettingEndDate();
			}
			$where = array('rpsid = ?'=>$payment->getId(),'rpsfk_restaurant = ?'=>$payment->getRestaurantId());
			$result = $this->getDbTable()->update($set,$where);
			return $result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function GetPaymentSettings($restIds)
	{
		try{
			$restIdArr = array();
			foreach($restIds as $row){
				$restIdArr[] = $row->resid;
			}
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from($this->getDbTable(),array('rpsid','rpsname','rpssetting_type','rpssetting_date','rpsfk_restaurant','rpsreservation_amount','rpsreservation_pax','rpsstatus','rpscreateddatetime','rpsnoshow_type','rpsdesc','rpssetting_date_end'))
					->join(array('res'=>'mt.restaurant'),'res.resid = rpsfk_restaurant',array('resrestaurant_name as resName'))
					->where('rpsfk_restaurant IN (?)',$restIdArr)
					->order('res.resid')
					->order('rpsid ASC');
			$rowSet = $this->getDbTable()->fetchAll($select);
			$resultArray = array();
			foreach($rowSet as $value){
				$payment = new Payments_Model_RestaurantPaymentSettings();
				$payment->setId($value->rpsid)
						->setRestaurantName($value->resName)
						->setRestaurantId($value->rpsfk_restaurant)
						->setAmount($value->rpsreservation_amount)
						->setReservationPax($value->rpsreservation_pax)
						->setStatus($value->rpsstatus)
						->setCreatedOn($value->rpscreateddatetime)
						->setSettingType($value->rpssetting_type)
						->setSettingName($value->rpsname)
						->setSettingDate($value->rpssetting_date)
						->setSettingEndDate($value->rpssetting_date_end)
						->setNoShowType($value->rpsnoshow_type)
						->setDescription($value->rpsdesc);
						
				$resultArray[] = $payment;
			}
			return $resultArray;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function GetPaymentSettingsByResId($restId,$date)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$split = explode('-',$date);
			$select->from($this->getDbTable(),array('rpsid','rpsname','rpssetting_type','rpssetting_date','rpsfk_restaurant','rpsreservation_amount','rpsreservation_pax','rpsstatus','rpscreateddatetime','rpsnoshow_type','rpsdesc','rpssetting_date_end'))
					->join(array('res'=>'mt.restaurant'),'res.resid = rpsfk_restaurant',array('resrestaurant_name as resName'))
					->where('rpsfk_restaurant = ?',$restId);
			if($split[0] > 12){
				$select->where('rpssetting_date <=?',$split[0].'-'.$split[1].'-'.$split[2])
						->where('rpssetting_date_end >=?',$split[0].'-'.$split[1].'-'.$split[2]);	
			}else{
				$select->where('rpssetting_date <=?',$split[2].'-'.$split[0].'-'.$split[1])
						->where('rpssetting_date_end >=?',$split[2].'-'.$split[0].'-'.$split[1]);
			}
			
					
			$select->where('rpssetting_type <> ?','DEF')
					->where('rpsstatus = ?',true);
					
			$rowSet = $this->getDbTable()->fetchRow($select);
			if($rowSet){
				$payment = array(
								'rspid'				=>	$rowSet->rpsid,
								'payresName'		=>	$rowSet->resName,
								'resid'				=>	$rowSet->rpsfk_restaurant,
								'payamount'			=>	$rowSet->rpsreservation_amount,
								'paypax'			=>	$rowSet->rpsreservation_pax,
								'rpsname'			=>  $rowSet->rpsname,
								'rpstype'			=>	$rowSet->rpssetting_type,
								'rpsdate'			=>	$rowSet->rpssetting_date,
								'rpsend'			=>	$rowSet->rpssetting_date_end,
								'rpsnoshow_type'	=>	$rowSet->rpsnoshow_type,
								'rpsdesc'			=>	$rowSet->rpsdesc
				);
			}else{
				$select = $this->getDbTable()->select();
				$select->setIntegrityCheck(false);
				
				$select->from($this->getDbTable(),array('rpsid','rpsname','rpssetting_type','rpssetting_date','rpsfk_restaurant','rpsreservation_amount','rpsreservation_pax','rpsstatus','rpscreateddatetime','rpsnoshow_type','rpsdesc','rpssetting_date_end'))
						->join(array('res'=>'mt.restaurant'),'res.resid = rpsfk_restaurant',array('resrestaurant_name as resName'))
						->where('rpsfk_restaurant = ?',$restId)
						->where("rpssetting_type = 'DEF' OR rpssetting_type ISNULL")
						->where('rpsstatus = ?',true);
				$rowSet = $this->getDbTable()->fetchRow($select);
				if($rowSet){
				$payment = array(
								'rspid'				=>	$rowSet->rpsid,
								'payresName'		=>	$rowSet->resName,
								'resid'				=>	$rowSet->rpsfk_restaurant,
								'payamount'			=>	$rowSet->rpsreservation_amount,
								'paypax'			=>	$rowSet->rpsreservation_pax,
								'rpsname'			=>  $rowSet->rpsname,
								'rpstype'			=>	$rowSet->rpssetting_type,
								'rpsdate'			=>	$rowSet->rpssetting_date,
								'rpsend'			=>	$rowSet->rpssetting_date_end,
								'rpsnoshow_type'	=>	$rowSet->rpsnoshow_type,
								'rpsdesc'			=>	$rowSet->rpsdesc
				);
				}else{
					$payment = false;
				}
			}
							
			
			return $payment;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function UpdatePaymentSettingStatus(Payments_Model_RestaurantPaymentSettings $payment)
	{
		try{
			$set = array('rpsstatus' => $payment->getStatus());
			$where = array('rpsfk_restaurant = ?'=>$payment->getRestaurantId(),'rpsid = ?'=>$payment->getId());
			$rows = $this->getDbTable()->update($set,$where);
			return $rows;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
		
}