<?php
class Payments_Model_TransactionsMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Payments_Model_DbTable_Transactions');
		}
		return $this->_dbTable;
	}
	
	public function saveTransactionDetails(array $objectArray)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			$status = false;
			
			$txnObject = $objectArray['txnObject'];			
			$data = array('txnfk_restaurant'	  => $txnObject->gettxnfk_restaurant(),
						  'txntransaction_id'     => $txnObject->gettxntransaction_id(),
						  'txninvoice_number'     => $txnObject->gettxninvoice_number(),
						  'txnpayment_profile_id' => $txnObject->gettxnpayment_profile_id(),
						  'txntransaction_amount' => $txnObject->gettxntransaction_amount(),
						  'txntransaction_date'	  => $txnObject->gettxntransaction_date(),
						  'txntransaction_time'	  => $txnObject->gettxntransaction_time(),
						  'txndescription'		  => $txnObject->gettxndescription(),
						  'txntransaction_type'   => $txnObject->gettxntransaction_type(),
						  'txnstatus'			  => $txnObject->gettxnstatus());

			$table = $this->getDbTable();			
			$txnid = $table->insert($data);
			
			/* Save Subscription Paid Details */
			$subscriptionPaidObject = $objectArray['subPaidObj'];
			$subscriptionPaidObject->setsubptransaction_id($txnid);
			$subscriptionPaidMapperObject = new Payments_Model_SubscriptionPaidMapper();
			$subpid = $subscriptionPaidMapperObject->saveSubscriptionPaidDetails($subscriptionPaidObject);
			
			/* Create New Subscription Renewal Record */
			
			$subscriptionRenewalObject = $objectArray['subRenewalObj'];
			
			$subscriptionRenewalMapperObject = new Payments_Model_SubscriptionRenewalMapper();
			$srid = $subscriptionRenewalMapperObject->saveSubscriptionRenewalDetails($subscriptionRenewalObject);
			
			/* Update Invoice status from unpaid to paid */
			
			$UpdateInvoiceStatusByIdObject = $objectArray['updateInveStatusObj'];
			$invoiceMapperObject = new Payments_Model_InvoiceMapper();
			
			$rows_affected = $invoiceMapperObject->UpdateInvoiceStatusById($UpdateInvoiceStatusByIdObject);
			
			/* Updated Sub Renewal Status if transaction is from Sub Renewal */
			
			 if(isset($objectArray['updateSubRenewalStatusObj'])){
			 	
			 	$updateSubRenewalStatusObj = $objectArray['updateSubRenewalStatusObj']; 
			 	$subRenewalMapper = new Payments_Model_SubscriptionRenewalMapper();
			 	$rows_affected    = $subRenewalMapper->updateRenewalStatus($updateSubRenewalStatusObj);
			 }
			
			/* Update restaurant payment status */
			$restaurantMapper = new ManageRestaurant_Model_RestaurantDataMapper();
			$set = array('respaymentstatus' => true);
			$where = array('resid = ?' => $subscriptionPaidObject->getsubprestaurant_id());
			$restRows_affected = $restaurantMapper->getDbTable()->update($set, $where);
			
			$db->commit();
			$status = true;
			return $status;
			
		} catch (Exception $ex) {
			$db->rollBack();
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getTransactions(Payments_Model_SearchTransaction $searchData, $offset)
	{
		try {
			date_default_timezone_set('Asia/Kolkata');
			$today = date('Y-m-d');
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('txn' => 'mt.transactions'), array('txnid','txntransaction_id','txnpayment_profile_id','txntransaction_amount','txntransaction_date','txntransaction_time','txntransaction_type'))
				   ->join(array('paymntprof' => 'mt.authnet_payment_profile'), 'txn.txnpayment_profile_id = paymntprof.anppid', array())
				   ->join(array('custprof' => 'mt.authnet_customer_profile'), 'paymntprof.anppcustomer_profile_id = custprof.ancpid', array())
				   ->join(array('txntype' => 'mt.transactiontype_bd'), 'txntype.id = txn.txntransaction_type', array('code as txntypecode', 'description as txntypedescription'))
				   ->join(array('inv' => 'mt.invoice'), 'txn.txninvoice_number = inv.invid', array('invid as invoice_number'))
				   ->join(array('res'=>'mt.restaurant'),'res.resid = inv.invrestaurant_id',array('resid','resfk_user','resrestaurant_name','resemail','resaddress'))
				   ->join(array('txnstatus' => 'mt.transactionstatus_bd'), 'txn.txnstatus = txnstatus.id', array('description as txnstatusdesc'));
			if($searchData->getcustomerprofileid()){
				$select->where('custprof.ancpcustomer_profile_id = ?', $searchData->getcustomerprofileid());
				$limit = 10;
			}else{
				$limit = 20;
			}
			if($searchData->gettxnid()){
				$select->where('txn.txntransaction_id = ?', $searchData->gettxnid());
			}
			if($searchData->getpaymentprofileid()){
				$select->where('txn.txnpayment_profile_id = ?', $searchData->getpaymentprofileid());
			}
			if ($searchData->getinvnumber()) {
				$select->where('inv.invid = ?', $searchData->getinvnumber());
			}
			if($searchData->getresName()){
				$select->where('res.resrestaurant_name Ilike ?', '%'.$searchData->getresName().'%');
			}
			if($searchData->getresId()){
				$select->where('res.resid = ?', $searchData->getresId());
			}
			
			if($searchData->getstartdate()){
				if($searchData->getstarttime()){
					$select->where('txn.txntransaction_date+txn.txntransaction_time >= ?', $searchData->getstartdate().' '.$searchData->getstarttime());
				}else{
					$select->where('txn.txntransaction_date >= ?', $searchData->getstartdate());
				}			
			} else {
				if($searchData->getstarttime()){
					$select->where('txn.txntransaction_date+txn.txntransaction_time >= ?', $today.' '.$searchData->getstarttime());
				}
			}
			
			if($searchData->getenddate()){
				if($searchData->getendtime()){
					$select->where('txn.txntransaction_date+txn.txntransaction_time <= ?', $searchData->getenddate().' '.$searchData->getendtime());
				}else{
					$select->where('txn.txntransaction_date <= ?', $searchData->getenddate());
				}			
			} else {
				if($searchData->getendtime()){
					$select->where('txn.txntransaction_date+txn.txntransaction_time <= ?', $today.' '.$searchData->getendtime());
				}
			}			
			$select->order('txn.txntransaction_id DESC');
			//$rowSet = $table->fetchAll($select);
			$rowSet = new Zend_Paginator(
				new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$rowSet->setItemCountPerPage($limit);
			$rowSet->setCurrentPageNumber($offset);
			
			return $rowSet;
		} catch (Exception $ex) {
			throw new Exception($ex->getMessage());
		}
	}
	
	public function saveTransactionDetailsForOfflinePayments(Payments_Model_Transactions $txnObject)
	{
		try{					
			$data = array('txnfk_restaurant'	  => $txnObject->gettxnfk_restaurant(),
						  'txntransaction_id'     => $txnObject->gettxntransaction_id(),
						  'txninvoice_number'     => $txnObject->gettxninvoice_number(),
						  'txnpayment_profile_id' => $txnObject->gettxnpayment_profile_id(),
						  'txntransaction_amount' => $txnObject->gettxntransaction_amount(),
						  'txntransaction_date'	  => $txnObject->gettxntransaction_date(),
						  'txntransaction_time'	  => $txnObject->gettxntransaction_time(),
						  'txndescription'		  => $txnObject->gettxndescription(),
						  'txntransaction_type'   => $txnObject->gettxntransaction_type(),
						  'txnstatus'			  => $txnObject->gettxnstatus());
			
			$table = $this->getDbTable();			
			$txnid = $table->insert($data);		
			return $txnid;
			
		}catch (Exception $ex) {			
			throw new Exception($ex->getMessage());
		}
	}
	
	Public function SaveSubRenewalRecords(array $objectArray)
	{
		try{
			
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			$status = false;
			
			/* Create New Subscription Renewal Record */
			
			$subscriptionRenewalObject = $objectArray['subRenewalObj'];
			$subscriptionRenewalMapperObject = new Payments_Model_SubscriptionRenewalMapper();
      
			foreach($subscriptionRenewalObject as $renewalObjet)
			{
				$row = $subscriptionRenewalMapperObject->checkSubscriptionRenewal($renewalObjet);
				if($row)
				{
					$renewalObjet->setsrid($row->srid);
					$srid = $subscriptionRenewalMapperObject->updateSubscriptionRenewalStatusForOfflinePayments($renewalObjet);
				}else
				{
					$srid = $subscriptionRenewalMapperObject->saveSubscriptionRenewalDetails($renewalObjet);
				}			
			}
			
			/* Save Subscription Paid Details */
			$subscriptionPaidObject = $objectArray['subPaidObj'];
			$subscriptionPaidMapperObject = new Payments_Model_SubscriptionPaidMapper();
			foreach($subscriptionPaidObject as $paidObject)
			{				
				$subpid = $subscriptionPaidMapperObject->saveSubscriptionPaidDetails($paidObject);
			}
			/* Update Invoice status from unpaid to paid */
			
			$UpdateInvoiceStatusByIdObject = $objectArray['updateInveStatusObj'];
			$invoiceMapperObject = new Payments_Model_InvoiceMapper();			
			$rows_affected = $invoiceMapperObject->UpdateInvoiceStatusById($UpdateInvoiceStatusByIdObject);
			//echo '<pre>'; print_r($rows_affected); exit;
			$db->commit();
			$status = true;
			return $status;
		}catch (Exception $ex) {			
			throw new Exception($ex->getMessage());
		}	
	}
}	