<?php
class Reservation_Model_ReservationInvitedGuestDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Reservation_Model_DbTable_ReservationInvitedGuest');
		}
		return $this->_dbTable;
	}
	
	public function saveBookingInvitedGuests($request,$guestIdArr,$setIds)
	{
		
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$table = $this->getDbTable();
			for($i = 0; $i < count($guestIdArr); $i++ )
			{
				$data = array('big_bookingid' => $request->bookingid,
					  		  'big_guestid'   => $guestIdArr[$i],
					  		  'big_status' 	  => 3);
				
				if (in_array($guestIdArr[$i], $setIds)) {
					$data['big_mailsent_status'] = true;
				}else{
					$data['big_mailsent_status'] = false;
				}				
				$table->insert($data);
			}
			$db->commit();
			return true;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getBookEmailEventStatus($bookingid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bokin'=>'mt.booking_invitedguests'),array('big_guestid','big_status'))
				   ->where('big_bookingid = ?',$bookingid);
			$resultSet = $table->fetchRow($select);
			if($resultSet){
				return $resultSet->big_status;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getBookEventStatusForGuest($bookingid,$guestid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bokin'=>'mt.booking_invitedguests'),array('big_guestid','big_status'))
				   ->where('big_bookingid = ?',$bookingid)
				   ->where('big_guestid = ?',$guestid);
			$resultSet = $table->fetchRow($select);
			if($resultSet){
				return $resultSet->big_status;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getInvitedGuestInfo($bookingid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bokin'=>'mt.booking_invitedguests'),array('big_guestid','big_status'))
				   ->join(array('stbd'=>'mt.booking_invitedguests_statusbd'),'stbd.id = bokin.big_status',array('description as status'))
				   ->where('big_bookingid = ?',$bookingid);
			$resultSet = $table->fetchAll($select);
			$guestids = array();
			$inviteStaus = array();
			foreach($resultSet as $row){
				$guestids[] = $row->big_guestid;
				$inviteStaus[$row->big_guestid] = $row->status;
			}
			$resultArr = array();
			if(count($guestids) > 0){
				$guestmapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
				$guestSet = $guestmapper->getGuestDetailsByIdsArr($guestids);
				foreach($guestSet as $guestrow){
					$resultArr[] = array('id' => $guestrow->rguid,
						'firstname'		=>	$guestrow->rgufirst_name,
						'lastname'		=>	$guestrow->rgulast_name,
					   	'email'			=>	$guestrow->rguemail,
						'status'		=>  $inviteStaus[$guestrow->rguid]
					);		
				}				
			}
			return $resultArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateInvitationStatus($guestid,$bookingid,$status)
	{
		try
		{
			$resstatus = 0;
			$db = Zend_Db_Table::getDefaultAdapter();
			$table  = $this->getDbTable();
			if($status == 1){
				$set = array('big_status' 	=> 1 );
			}else{
				$set = array('big_status' 	=> 2 );
			}
								
			$where 	= array('big_bookingid = ?' => $bookingid,
							'big_guestid = ?'=> $guestid
						);
			$resstatus = $table->update($set,$where);
			return $resstatus; 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveInvitedGuestList($book_id_arr)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('bigid','big_bookingid','big_guestid','big_status','big_mailsent_status','big_createdby','big_createddatetime'))
			       ->where('big_bookingid IN(?)',$book_id_arr);
			       
	       	$rowset = $table->fetchAll($select);
	       	$result = array();
	       	foreach($rowset as $row)
	       	{
	       		$result[] = array('bigid'=>$row->bigid,'big_bookingid'=>$row->big_bookingid,'big_status'=>$row->big_status,'big_mailsent_status'=>$row->big_mailsent_status,'big_createdby'=>$row->big_createdby,'big_createddatetime'=>$row->big_createddatetime);
	       	}
	       	
	       	return $result;
			       
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
}