<?php
class Reservation_Model_ReservationMenuItemsDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Reservation_Model_DbTable_ReservationMenuItems');
		}
		return $this->_dbTable;
	}
	
	public function saveItemsByOrderId(Reservation_Model_ReservationMenuItems $itemsObj)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('bmi_id'))
				   ->where('bmi_booking_menu_orderid = ?',$itemsObj->getbmi_booking_menu_orderid())
				   ->where('bmi_itemid = ?',$itemsObj->getbmi_itemid());
			$row = $table->fetchRow($select);
			if($row){
				$set = array(
						'bmi_count'		=> $itemsObj->getbmi_count(),
						'bmi_item_price'=> $itemsObj->getbmi_item_price(),
						'bmi_status'	=> true
					);
				$where = array('bmi_id = ?' => $row->bmi_id);
							
				$status = $table->update($set,$where);
			}else{
				$data = array(
						'bmi_booking_menu_orderid' => $itemsObj->getbmi_booking_menu_orderid(),
						'bmi_itemid'			   => $itemsObj->getbmi_itemid(),
						'bmi_count'				   => $itemsObj->getbmi_count(),
						'bmi_item_price'		   => $itemsObj->getbmi_item_price(),
						'bmi_status'			   => true
					);
				$status =  $table->insert($data);
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateItemsStatusByOrderId($orederid)
	{
		try{
			$table  = $this->getDbTable();
			$set = array('bmi_status' => 0);
			$where = array('bmi_booking_menu_orderid = ?' => $orederid);
							
			$status = $table->update($set,$where);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getItemDetailsByOrderid($orederid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bmi'=>'mt.booking_menu_items'),array('bmi_count','bmi_item_price','bmi_itemid'))
				   ->join(array('mi'=>'mt.menu_items'),'mi.miid = bmi.bmi_itemid',array('mi_name'))
				   ->where('bmi.bmi_booking_menu_orderid = ?',$orederid)
				   ->where('bmi.bmi_status = ?',true);
			$rowSet = $table->fetchAll($select);
			$menuItems = array();
			foreach($rowSet as $row){
				$menuItems[] = array(
						'itemid'    =>  $row->bmi_itemid,				
						'itemname'	=>	$row->mi_name,
						'itemprice'	=>	$row->bmi_item_price,
						'itemcount' =>	$row->bmi_count	
					);
			}
			return $menuItems;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveMenuItems($menu_id_arr)
	{
		try
		{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('bmi_id','bmi_booking_menu_orderid','bmi_itemid','bmi_count','bmi_status','bmi_status','bmi_createddatetime','bmi_item_price'))
			       ->where('bmi_booking_menu_orderid IN(?)',$menu_id_arr);
			       
			$rowset = $table->fetchAll($select);
			$result = array();
			foreach($rowset as $row)
			{
				$result[] = array('bmi_id'=>$row->bmi_id,'bmi_booking_menu_orderid'=>$row->bmi_booking_menu_orderid,'bmi_itemid'=>$row->bmi_itemid,'bmi_count'=>$row->bmi_count,'bmi_status'=>$row->bmi_status,'bmi_createddatetime'=>$row->bmi_createddatetime,'bmi_item_price');
			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}