<?php
class Reservation_Model_ReservationMenuOrderDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Reservation_Model_DbTable_ReservationMenuOrder');
		}
		return $this->_dbTable;
	}
	
	public function saveOrderDetails($request)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('bmo_id'))
				   ->where('bmo_bookingid = ?',trim($request->bookingid));
			$row = $table->fetchRow($select);
			if($row){
				$set = array('bmo_price' => trim($request->totalprice));
				$where = array('bmo_id = ?' => $row->bmo_id);
				$table->update($set,$where);
				$orderid = $row->bmo_id;
			}else{
				$data = array(
					'bmo_bookingid' => trim($request->bookingid),
					'bmo_price'		=> trim($request->totalprice)
				);
				$orderid = $table->insert($data);
			}
			
			$itemIds = $request->itemid;
			$itemPrices = $request->itemprice;
			$itemCounts = $request->itemcount;
			
			$itemsDataMapper = new Reservation_Model_ReservationMenuItemsDataMapper();
			$itemsDataMapper->updateItemsStatusByOrderId($orderid);
			for($i=0; $i < count($itemIds); $i++){
				$itemObj = new Reservation_Model_ReservationMenuItems();
				$itemObj->setbmi_booking_menu_orderid($orderid);
				$itemObj->setbmi_itemid($itemIds[$i]);
				$itemObj->setbmi_item_price($itemPrices[$i]);
				$itemObj->setbmi_count($itemCounts[$i]);
				
				$status = $itemsDataMapper->saveItemsByOrderId($itemObj);
			}
			$db->commit();
			return true;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getSelectedMenuByBookingId($bookingid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('bmo_id','bmo_price'))
				   ->where('bmo_bookingid = ?',$bookingid);
			$row = $table->fetchRow($select);
			$selectedItems = array();
			if($row){
				$itemsDataMapper = new Reservation_Model_ReservationMenuItemsDataMapper();
				$menuItems = $itemsDataMapper->getItemDetailsByOrderid($row->bmo_id);
				$selectedItems['totalPrice'] = $row->bmo_price;
				$selectedItems['itemsArr']   = $menuItems;
			}
			return $selectedItems;		
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveReservationMenuOrder($booking_id_arr)
	{
		try
		{
			$table  = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('bmo_id','bmo_bookingid','bmo_comments','bmo_price','bmo_createdby','bmo_createddatetime'))
				   ->where('bmo_bookingid IN(?)',$booking_id_arr);
				   
			$rowset = $table->fetchAll($select);
			$result = array();
			$menuarray = array();
			$menuidarray = array();
			
			if(count($rowset) > 0)
			{
				$result["status"] = true;
				foreach($rowset as $row)
				{
					$menuarray[] = array('bmo_id'=>$row->bmo_id,'bmo_bookingid'=>$row->bmo_bookingid,'bmo_comments'=>$row->bmo_comments,'bmo_price'=>$row->bmo_price,'bmo_createdby'=>$row->bmo_createdby,'bmo_createddatetime'=>$row->bmo_createddatetime);
					$menuidarray[] = $row->bmo_id;
				}
				$result["menuorder"] = $menuarray;
				$result["menuids"] = $menuidarray;
			}else{
				$result["status"] = false;
			}
			
			return $result;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
}