<?php
/**
*	Name			: ReservationOptionsDataMapper.php
*	Author			: Sairam
*	Creation Date	: 02/04/2012
*	Path 			: application/modules/Reservation/models/ReservationOptionsDataMapper.php
*	Description		: This is the Model class for the booking Reservation Options Data Mapper table.
*					   	
*/
class Reservation_Model_ReservationOptionsDataMapper
{
	/**
	 * Instance variable of Reservation_options a table
	 * @var object
	 */
	protected $_dbTable;

	/**
     * @param instance of DbTable Reservation_options $dbTable
     * @return self
     */
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	/**
     * @return instance of DbTable Reservation_options
     */
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Reservation_Model_DbTable_ReservationOptions');
		}
		return $this->_dbTable;
	}
	
	public function AddBookingOptions(Reservation_Model_ReservationOptions $BookingOptions)
	{
		try{
			$status = false;
			$checkstatus = "";
			$db = Zend_Db_Table::getDefaultAdapter();
			$table = $this->getDbTable();
			$data = array(
							'boptresid'				=>	$BookingOptions->getResid(),
						  	'boptdescription'		=>	$BookingOptions->getDescription(),
						  	'boptcreated_by'		=>	$BookingOptions->getCreatedbyId(),
							'boptcreated_datetime'	=>	$BookingOptions->getCreatedDateTime(),
							'boptstatus'			=>	$BookingOptions->getStatus(),
							'boptcode'				=>	strtoupper($BookingOptions->getCode()),
							'bopttype'				=>	$BookingOptions->getType()
			);
			
			$checkstatus = $this->CheckBookingOption($BookingOptions);
			$codeStatus = $this->verifyCode($BookingOptions);
			if($checkstatus && $codeStatus){
				$row_insert = $table->insert($data);
				if($row_insert){
					$status = true;
				}
			}
			$returnArr = array();
			$returnArr['status'] = $status;
			$returnArr['codestatus'] = $codeStatus;
			$returnArr['descstatus'] = $checkstatus;			 					

			return $returnArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditBookingOptions(Reservation_Model_ReservationOptions $BookingOptions)
	{
		try{
			$status = false;
			$checkstatus = "";
			$db = Zend_Db_Table::getDefaultAdapter();
			$table = $this->getDbTable();
			$set = array(
							'boptdescription'		=>	$BookingOptions->getDescription(),
						  	'boptupdated_by'		=>	$BookingOptions->getUpdatedbyId(),
							'boptupdated_datetime'	=>	$BookingOptions->getUpdatedDateTime(),
							'boptcode'				=>	strtoupper($BookingOptions->getCode())
			);
			
			$descstatus = $this->CheckBookingOption($BookingOptions);
			$editcodesta= $this->verifyCode($BookingOptions);
			if($descstatus && $editcodesta){
				$where = $db->quoteInto('boptid = ?',$BookingOptions->getId());
				$result = $this->getDbTable()->update($set,$where);
				if($result){
					$status = true;
				}
			}
			$returnArr = array();
			$returnArr['status'] = $status;
			$returnArr['codestatus'] = $editcodesta;
			$returnArr['descstatus'] = $descstatus;			 					

			return $returnArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	public function GetBookingOptionsListByRestid($restid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from(array('bop'=>'mt.booking_options'),array('boptid','boptresid','boptdescription','boptcreated_datetime','boptstatus','boptcode','bopttype'))
					->where('bop.boptresid = ?',$restid)
					->order(array('boptcode ASC'));
			$records = $table->fetchAll($select);

			foreach($records as $value)
			{
				$resultSet[] = array('boptid' => $value->boptid,'boptresid' => $value->boptresid,'boptdescription' => $value->boptdescription,'boptcreated_datetime' => $value->boptcreated_datetime,'boptstatus' => $value->boptstatus,'boptcode'=>$value->boptcode,'bopttype'=>$value->bopttype);
			}
			
			return $resultSet;	  
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getBookingOptionsByresId(Reservation_Model_ReservationOptions $bokoptions)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from(array('mt.booking_options'),array('boptid','boptdescription'))
			   ->where('boptresid = ?',$bokoptions->getResid())
			   ->where('bopttype = ?','PRIMARY')
			   ->where('boptstatus = ?',true);
			$result = $this->getDbTable()->fetchAll($select);
			$resultArr = array();
			if($result){
                            
                                if($bokoptions->getCompanyid()==25){
                                    $resultArr[] =  array('key'=>'','value'=>'Any Special Occasion?');
                                }else{
                                    $resultArr[] =  array('key'=>'','value'=>'Select Option');
                                }				
				foreach($result as $value){
					$resultArr[] = array('key'=>$value->boptid,'value'=>$value->boptdescription);
				}
			}
			return $resultArr;
		}catch(Exception $ex){
		throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getSecBookingOptionsByresId(Reservation_Model_ReservationOptions $bokoptions)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from(array('mt.booking_options'),array('boptid','boptdescription'))
			   ->where('boptresid = ?',$bokoptions->getResid())
			   ->where('bopttype = ?','SECONDARY')
			   ->where('boptstatus = ?',true);
			$result = $this->getDbTable()->fetchAll($select);
			$resultArr = array();
			if($result){
				$resultArr[] =  array('key'=>'','value'=>'Select Option');
				foreach($result as $value){
					$resultArr[] = array('key'=>$value->boptid,'value'=>$value->boptdescription);
				}
			}
			return $resultArr;
		}catch(Exception $ex){
		$db->rollBack();
		throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateBookingOptionStatus(Reservation_Model_ReservationOptions $bokoptions)
	{
		try{
			$table  = $this->getDbTable();
			
			$set = array('boptstatus' => $bokoptions->getStatus());			
			$where = array('boptid = ?'=>$bokoptions->getId());			
			$rows_affected = $table->update($set,$where);
			
			return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function CheckBookingOption(Reservation_Model_ReservationOptions $bokoptions)
	{
		try{
			$select = $this->getDbTable()->select();		
			$select->from('mt.booking_options',array('COUNT(boptid) as count'))
			       ->where('boptdescription ILIKE ?',$bokoptions->getDescription())
			       ->where('boptresid = ?', $bokoptions->getResid());
			if($bokoptions->getId() != 0){
				$select->where('boptid <> ?',$bokoptions->getId());
			}    
	       		       
			$rowset = $this->getDbTable()->fetchAll($select);
			$count = 0;		
			foreach($rowset as $row){
				$count = $row->count;
			}
			if($count == 0){
				return true;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function verifyCode(Reservation_Model_ReservationOptions $bokoptions)
	{
		$select = $this->getDbTable()->select();
		$select->from('mt.booking_options',array('COUNT(boptid) as count'))
      		   ->where('boptcode ILIKE ?',$bokoptions->getCode())
		       ->where('boptresid = ?', $bokoptions->getResid());
		
		if($bokoptions->getId() != 0){
				$select->where('boptid <> ?',$bokoptions->getId());
		}
			
		$rowset = $this->getDbTable()->fetchAll($select);
		$count = 0;		
		foreach($rowset as $row){
			$count = $row->count;
		}
		if($count == 0){
			return true;
		}else{
			return false;
		}
	}
	
	public function GetBookingOptionsByRestaurantId($restaurantid)
	{
		try{
			$finalArr = array();
			$resultSet = array();
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from(array('bop'=>'mt.booking_options'),array('boptid','boptresid','boptdescription','boptcreated_by','boptcreated_datetime','boptupdated_by','boptupdated_datetime','boptstatus','boptcode','bopttype'))
					->where('bop.boptresid = ?',$restaurantid)
					->order(array('boptcode ASC'));
			$records = $table->fetchAll($select);
			foreach($records as $row)
			{
				foreach($row as $key=>$value)
				{
					if($key == 'boptcreated_by' || $key == 'boptupdated_by'){
						$resultSet[$key] = null;
					}else{
						$resultSet[$key] = $value;
					}
				}
				$finalArr[] = $resultSet;
			}
			
			return $finalArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}