<?php
/**
*	Name			: ReservationWaitingQuoteMapDataMapper.php
*	Author			: snehal
*	Creation Date	: 8/6/2011
*	Path 			: application/modules/Reservation/models/ReservationWaitingQuoteMapDataMapper.php
*	Description		: This is the datamapper class for blocking a table.
*					   	
*/
class Reservation_Model_ReservationWaitingQuoteMapDataMapper
{
	/**
	 * Instance variable of blocking a table
	 * @var object
	 */
	protected $_dbTable;

	/**
     * @param instance of DbTable restaurant_table_status $dbTable
     * @return self
     */
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	/**
     * @return instance of DbTable restaurant_table_status
     */
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Reservation_Model_DbTable_ReservationWaitingQuoteMap');
		}
		return $this->_dbTable;
	}

	/**
	 * @param instance of blocktable
	 * function to blocking a table 
	 */
	public function InsertQuotedTimes(Reservation_Model_ReservationWaitingQuoteMap $QuoteMap)
	{
		try{
			$data = array('bwqm_fk_booking_id'		=>	$QuoteMap->getBookId(),
						  'bwqm_fk_quote'			=>	$QuoteMap->getQuoteId(),
						  'bwqm_quote_madeon'		=>	date('Y-m-d h:i:s'));
			
			$result = $this->getDbTable()->insert($data);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function InsertQuotedTimesFromNativeApp($bookid, $quotedtime, $updateddatetime)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('COUNT(id) as COUNT'))
				   ->where('bwqm_fk_booking_id = ?',$bookid)
				   ->where('bwqm_fk_quote = ?',$quotedtime)
				   ->where('bwqm_quote_madeon = ?',$updateddatetime);
		
			$rowSet = $this->getDbTable()->fetchAll($select);
			$count = "";
			foreach($rowSet as $row){
				$count = $row->COUNT;
			}	   
			if($count == 0){
				$data = array('bwqm_fk_booking_id'		=>	$bookid,
							  'bwqm_fk_quote'			=>	$quotedtime,
							  'bwqm_quote_madeon'		=>	$updateddatetime
						);
				
				$this->getDbTable()->insert($data);
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetWaitingQuote($bookingId)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('map'=>'mt.booking_waiting_quote_map'),array('bwqm_fk_quote','bwqm_quote_madeon'))
				   ->join(array('qut'=>'mt.quoted_time_bd'),'qut.id = map.bwqm_fk_quote',array('description'))
				   ->where('map.bwqm_fk_booking_id = ?',$bookingId)
				   ->order('map.id');
				   
			$rowSet = $this->getDbTable()->fetchAll($select);
			$result = array();
			foreach($rowSet as $row){
				$result[$row->description] = $row->bwqm_quote_madeon;
			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetWaitingQuoteByBookingIds($bookingIds)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('id','bwqm_fk_booking_id','bwqm_fk_quote','bwqm_quote_madeon'))
				   ->where('bwqm_fk_booking_id IN(?)',$bookingIds);
				   
			$rowSet = $this->getDbTable()->fetchAll($select);
			$resultArr = array();
			foreach($rowSet as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					$subArr[$key1]= $value1;
				}
				$resultArr[] = $subArr;
			}
			return $resultArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
}