<?php
/**
*	Name			: ReservationsCountDataMapper.php
*	Author			: snehal
*	Creation Date	: 4/29/2011
*	Path 			: application/modules/Reservation/models/ReservationsCountDataMapper.php
*	Description		: This is the datamapper class for reservations count table.
*					   	
*/
class Reservation_Model_ReservationsCountDataMapper
{
	/**
	 * Instance variable of reservation count table
	 * @var object
	 */
	protected $_dbTable;

	/**
     * @param instance of DbTable reservation count $dbTable
     * @return self
     */
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	/**
     * @return instance of DbTable reservation count
     */
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Reservation_Model_DbTable_ReservationsCount');
		}
		return $this->_dbTable;
	}

	/**
	 * @param restaurantid and reserved partysize 
	 * function to save the count of reservations 
	 */
	public function saveReservationsCount($resid,$partySize)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rrcreservation_count as count'))
				   ->where('rrcfk_restaurant = ?',$resid);
			$result = $table->fetchRow($select);
			if($result->count){
				$total = $result->count+$partySize;
				$set = array('rrcreservation_count'=>$total);
				$where = $db->quoteInto('rrcfk_restaurant = ?',$resid);
				$row_affected = $table->update($set,$where);
			}else{
				$data = array('rrcfk_restaurant'=>$resid,
							  'rrcreservation_count'=>$partySize,
							  'rrcstatus'=>true);
				$resultSet = $table->insert($data);
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * function to retreive all reservations count taken by the DineDesk 
	 */
	public function retrieveBookingscount()
	{
		try{
			$cache = new Uss_Helper_CacheManager();
			$count = "";
			if(!$count = $cache->Fetch('reservationcount')){
				$table = $this->getDbTable();
				$select = $table->select();
				$select->from($table,array('SUM(rrcreservation_count) as TotalSize'));
					   
				$RowSet = $table->fetchAll($select);
	
				foreach($RowSet as $record){
					$count=$record->TotalSize;
				}
				$cache->SaveData($count,'reservationcount',600);
			}else{
				$count = $cache->Fetch('reservationcount');
			}
			return $count;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
}
