<?php
/**
*	Name			: BlockTableDataMapper.php
*	Author			: snehal
*	Creation Date	: 1/13/2011
*	Path 			: application/modules/Reservation/models/BlockTableDataMapper.php
*	Description		: This is the datamapper class for blocking a table.
*					   	
*/
class Reservation_Model_RestaurantQuoteSettingsDataMapper
{
	/**
	 * Instance variable of blocking a table
	 * @var object
	 */
	protected $_dbTable;

	/**
     * @param instance of DbTable restaurant_table_status $dbTable
     * @return self
     */
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	/**
     * @return instance of DbTable restaurant_table_status
     */
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Reservation_Model_DbTable_RestaurantQuoteSettings');
		}
		return $this->_dbTable;
	}
	
	public function AddRestaurantQuote(Reservation_Model_RestaurantQuoteSettings $quote)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('rqs_id','rqs_wait_quote_type'))
					->where('rqs_fk_restaurant = ?',$quote->getRestId())
					->where('rqs_status = ?','T');
			$rowSet = $this->getDbTable()->fetchRow($select);
			$resultant = array();
			if($rowSet->rqs_id){
				if($rowSet->rqs_wait_quote_type == 'Variable'){
					$set = array('rqs_wait_quote_type'	=> $quote->getQuoteType(),'rqs_wait_time'=>$quote->getQuoteTime());
					$where = array('rqs_id = ?'=>$rowSet->rqs_id);
					$rowUpdate = $this->getDbTable()->update($set,$where);
					$mapper = new Reservation_Model_RestaurantQuoteTimeSettingsDataMapper();
					$set = array('rwqs_status'	=> 'F');
					$where = array('rwqs_fk_quote_settings = ?'=>$rowSet->rqs_id);
					$rowUpdate = $mapper->getDbTable()->update($set,$where);
					
					$resultant['status'] = true;
					$resultant['result'] = $rowUpdate;
				}else{
					$resultant['status'] = false;
					$resultant['msg'] = 'The Quote Time Settings of type '.$rowSet->rqs_wait_quote_type.' already exists';
				}
			}else{
				$data = array(
								'rqs_fk_restaurant'		=>	$quote->getRestId(),
								'rqs_wait_quote_type'	=>	$quote->getQuoteType(),
								'rqs_status'			=>	$quote->getStatus(),
								'rqs_wait_time'			=>	$quote->getQuoteTime()
				);
				$result = $this->getDbTable()->insert($data);
				$resultant['status'] = true;
				$resultant['result'] = $result;
			}			
			return $resultant;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
public function UpdateRestaurantQuote(Reservation_Model_RestaurantQuoteSettings $quote)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$mapper = new Reservation_Model_RestaurantQuoteTimeSettingsDataMapper();
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('rqs_id','rqs_wait_quote_type'))
					->where('rqs_fk_restaurant = ?',$quote->getRestId())
//					->where('rqs_id = ?',$quote->getId())
					->where('rqs_status = ?','T');
			$rowSet = $this->getDbTable()->fetchRow($select);
			$resultant = array();
			if($rowSet->rqs_id){
				$db->beginTransaction();
				if($rowSet->rqs_wait_quote_type != $quote->getQuoteType() && $quote->getQuoteType() == 'Fixed'){
					$set = array('rwqs_status'=>'F');
					$where = array('rwqs_fk_quote_settings = ?',$rowSet->rqs_id);
					$updateRow = $mapper->getDbTable()->update($set,$where);
				}
				$set = array(
								'rqs_fk_restaurant'		=>	$quote->getRestId(),
								'rqs_wait_quote_type'	=>	$quote->getQuoteType(),
								'rqs_wait_time'			=>	$quote->getQuoteTime()
				);
				$where = array('rqs_fk_restaurant = ?'=>$quote->getRestId(),'rqs_status'=>'T');
				$rowUpdate = $this->getDbTable()->update($set,$where);
				$db->commit();
			}
			$resultant['status'] = true;
			$resultant['result'] = $rowUpdate;
			return $resultant;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage());
		}
	}
	
	public function GetQuoteTimings($restid,$reqType = '')
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rqs_id','rqs_wait_quote_type','rqs_wait_time'))
				   ->where('rqs_status = ?',true)
				   ->where('rqs_fk_restaurant = ?',$restid);
				   
			$row = $table->fetchRow($select);				   
			$result = array();
			if($row){
				$result['status'] = true;
				if($row->rqs_wait_quote_type == "Fixed"){
					$result['quote_type']   = "Fixed";
					$result['waiting_time'] = $row->rqs_wait_time;
				}else if($row->rqs_wait_quote_type == "Variable"){
					$result['quote_type']   = "Variable";					
					$quoteTimeSettingsDataMapper = new Reservation_Model_RestaurantQuoteTimeSettingsDataMapper();
					if($reqType == 'ajax'){
						$timeSettingResult = $quoteTimeSettingsDataMapper->GetQuoteTimeSettingsAjax($restid);
						$result['settings'] = $timeSettingResult;	
					}else{
						$timeSettingResult = $quoteTimeSettingsDataMapper->GetQuoteTimeSettings($restid);
						$result['settings'] = $timeSettingResult;	
					}				
				}	
			}else{
				$result['status'] = false;
			}
			
			return $result;
				   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function CheckQuoteTimeSettings($resid,$pax)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rqs_id','rqs_wait_quote_type','rqs_wait_time'))
				   ->where('rqs_status = ?',true)
				   ->where('rqs_fk_restaurant = ?',$resid);
				   
			$row = $table->fetchRow($select);				   
			$result = array();
			if($row){
				if($row->rqs_wait_quote_type == "Fixed"){
					$result['status'] = true;
					$result['quote_type']   = "Fixed";
					$result['waiting_time'] = $row->rqs_wait_time;
				}else if($row->rqs_wait_quote_type == "Variable"){
					$result['quote_type']   = "Variable";					
					$quoteTimeSettingsDataMapper = new Reservation_Model_RestaurantQuoteTimeSettingsDataMapper();
					$timeSettingResult = $quoteTimeSettingsDataMapper->CheckQuoteTimeSettings($resid,$pax);
					if(count($timeSettingResult)){
						foreach($timeSettingResult as $row){
							$result['status'] = true;
							$result['waiting_time'] = $row->rwqs_quoted_time;
						}
					}else{
						$result['status'] = false;
					}										
				}	
			}else{
				$result['status'] = false;
			}
			
			return $result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function RetrieveQuoteSettingByRestId($restid)
	{
		try
		{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rqs_id','rqs_fk_restaurant','rqs_wait_quote_type','rqs_status','rqs_wait_time'))				   
				   ->where('rqs_fk_restaurant = ?',$restid);				   
			$row = $table->fetchRow($select);
			
			$restquotesettings = array();
			
			if($row)
			{
				$restquotesettings[] = array('rqs_id'			   => $row->rqs_id,
											 'rqs_fk_restaurant'   => $row->rqs_fk_restaurant,
											 'rqs_wait_quote_type' => $row->rqs_wait_quote_type,
											 'rqs_status' 		   => $row->rqs_status,
											 'rqs_wait_time' 	   => $row->rqs_wait_time);
				
			}
			
			return $restquotesettings;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function AddRestaurantQuoteFromIpad($quoteDetails)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			
			$resultArray = array();	
			
			foreach($quoteDetails as $row)
			{
				if($row->rqs_id == 0){
					$data = array();				
					$data = array('rqs_fk_restaurant'    => $row->rqs_fk_restaurant,
								  'rqs_status' 	         => true,
								  'rqs_wait_quote_type'  => $row->rqs_wait_quote_type,
								  'rqs_wait_time'        => $row->rqs_wait_time);
					
					$rqsid = $this->getDbTable()->insert($data);
					
					$quoteMapTables = $row->quote_wait;
					if(count($quoteMapTables) > 0)
					{					
						$mapper = new Reservation_Model_RestaurantQuoteTimeSettingsDataMapper();
						$quoteMapTable = $mapper->getDbTable();
						
						foreach($quoteMapTables as $quote)
						{	
							$quoteTableData = array(
									'rwqs_fk_restaurant'		=>	$quote->rwqs_fk_restaurant,
									'rwqs_quoted_time'			=>	$quote->rwqs_quoted_time,
									'rwqs_startpax'				=>	$quote->rwqs_startpax,
									'rwqs_endpax'				=>	$quote->rwqs_endpax,
									'rwqs_status'				=>	true,
									'rwqs_fk_quote_settings'	=>	$rqsid
							);
							if($quote->rwqs_created_date != null && $quote->rwqs_created_date != ""){
								$quoteTableData['rwqs_created_date'] =  $quote->rwqs_created_date;
							}
							
							if($quote->rwqs_created_time != null && $quote->rwqs_created_time != ""){
								$quoteTableData['rwqs_created_time'] 	=  $quote->rwqs_created_time;
							}
							
							if($quote->rwqs_updated_date != null && $quote->rwqs_updated_date != ""){
								$quoteTableData['rwqs_updated_date'] 	  	=  $quote->rwqs_updated_date;
							}
							
							if($quote->rwqs_updated_time != null && $quote->rwqs_updated_time != ""){
								$quoteTableData['rwqs_updated_time'] 	   	=  $quote->rwqs_updated_time;
							}
							
							$rwqs_id = $quoteMapTable->insert($quoteTableData); 
						}					
					}				
					$resultArray[] = array('quote_locid'=>$row->rqs_locid,'quote_webid'=>$rqsid,'rwqs_id'=>$rwqs_id);
				}else if($row->rqs_sync_status == 'S'){
					$set = array('rqs_fk_restaurant'    => $row->rqs_fk_restaurant,
								 'rqs_status' 	        => true,
								 'rqs_wait_quote_type'  => $row->rqs_wait_quote_type,
								 'rqs_wait_time'        => $row->rqs_wait_time);
					$where = array('rqs_id = ?'=>$row->rqs_id,'rqs_status'=>'T');
					$rowUpdate = $this->getDbTable()->update($set,$where);
					
					$quoteMapTables = $row->quote_wait;
					if(count($quoteMapTables) > 0)
					{					
						$mapper = new Reservation_Model_RestaurantQuoteTimeSettingsDataMapper();
						$quoteMapTable = $mapper->getDbTable();
						
						foreach($quoteMapTables as $quote)
						{	
							$quoteTableData = array(
									'rwqs_fk_restaurant'		=>	$quote->rwqs_fk_restaurant,
									'rwqs_quoted_time'			=>	$quote->rwqs_quoted_time,
									'rwqs_startpax'				=>	$quote->rwqs_startpax,
									'rwqs_endpax'				=>	$quote->rwqs_endpax,
									'rwqs_status'				=>	true,
									'rwqs_fk_quote_settings'	=>	$row->rqs_id,
							);
							
							if($quote->rwqs_created_date != null && $quote->rwqs_created_date != ""){
								$quoteTableData['rwqs_created_date'] =  $quote->rwqs_created_date;
							}
							
							if($quote->rwqs_created_time != null && $quote->rwqs_created_time != ""){
								$quoteTableData['rwqs_created_time'] 	=  $quote->rwqs_created_time;
							}
							
							if($quote->rwqs_updated_date != null && $quote->rwqs_updated_date != ""){
								$quoteTableData['rwqs_updated_date'] 	  	=  $quote->rwqs_updated_date;
							}
							
							if($quote->rwqs_updated_time != null && $quote->rwqs_updated_time != ""){
								$quoteTableData['rwqs_updated_time'] 	   	=  $quote->rwqs_updated_time;
							}
							
							$rwqs_id = $quoteMapTable->insert($quoteTableData); 
						}					
					}				
					$resultArray[] = array('quote_locid'=>$row->rqs_locid,'quote_webid'=>$row->rqs_id,'rwqs_id'=>$rwqs_id);
				}else if($row->rqs_sync_status == 'U'){
					$set = array('rqs_fk_restaurant'    => $row->rqs_fk_restaurant,
								 'rqs_status' 	        => true,
								 'rqs_wait_quote_type'  => $row->rqs_wait_quote_type,
								 'rqs_wait_time'        => $row->rqs_wait_time);
					$where = array('rqs_id = ?'=>$row->rqs_id,'rqs_status'=>'T');
					$rowUpdate = $this->getDbTable()->update($set,$where);
					
					
					if($row->quote_wait && $row->rqs_wait_quote_type != 'Fixed'){
						$quoteMapTables = $row->quote_wait;
					$rwqsIdArr = array();
					foreach($quoteMapTables as $quorow)
					{
						$rwqsIdArr[] = $quorow->rwqs_id;
					}
					
					$mapper = new Reservation_Model_RestaurantQuoteTimeSettingsDataMapper();
					$quoteMapTable = $mapper->getDbTable();
					$quoteselect = $quoteMapTable->select();
					$quoteselect->from($quoteMapTable,array('rwqs_id','rwqs_updated_time'))
				       ->where('rwqs_id IN (?)',$rwqsIdArr);
					$quoterowSet = $quoteMapTable->fetchAll($quoteselect);

					$webQuotesArr = array();
					foreach($quoterowSet as $quoteRow){
						$webQuotesArr[$quoteRow->rwqs_id] = $quoteRow->rwqs_updated_time;
					}
					
					if(count($quoteMapTables) > 0)
					{					
						foreach($quoteMapTables as $quote)
						{	
							if(array_key_exists($quote->rwqs_id,$webQuotesArr))
							{
								$webupadateddate = strtotime($webQuotesArr[$quote->rwqs_id]);
							}else{
								$webupadateddate = 0;
							}
							if($quote->rwqs_updated_time != "" && $quote->rwqs_updated_time != "null")
						    {			    	
							    $nativeupadateddate = strtotime($quote->rwqs_updated_time);
								
								if($nativeupadateddate > $webupadateddate)
								{
									$quoteTableData = array(
									'rwqs_fk_restaurant'		=>	$quote->rwqs_fk_restaurant,
									'rwqs_quoted_time'			=>	$quote->rwqs_quoted_time,
									'rwqs_startpax'				=>	$quote->rwqs_startpax,
									'rwqs_endpax'				=>	$quote->rwqs_endpax,
									'rwqs_status'				=>	$quote->rwqs_status,
									'rwqs_fk_quote_settings'	=>	$row->rqs_id
									);
									
									if($quote->rwqs_updated_date != null && $quote->rwqs_updated_date != ""){
										$quoteTableData['rwqs_updated_date'] 	  	=  $quote->rwqs_updated_date;
									}
									
									if($quote->rwqs_updated_time != null && $quote->rwqs_updated_time != ""){
										$quoteTableData['rwqs_updated_time'] 	   	=  $quote->rwqs_updated_time;
									}
							
									$quotewhere = array('rwqs_id = ?'=>$quote->rwqs_id,'rwqs_status'=>'T');
									$quoterowUpdate = $quoteMapTable->update($quoteTableData,$quotewhere);
								}
							}
						}					
					}				
					$resultArray[] = array('quote_locid'=>$row->rqs_locid,'quote_webid'=>$row->rqs_id,'rwqs_id'=>$rwqs_id);
					}
				}
			}
			$db->commit();
			return $resultArray;
		}catch(Exception $ex){
			$db->rollBack();
			Uss_Logger_FileLogger::info("In Exception ".$ex->getMessage());
			throw new Exception($ex->getMessage());
		}
	}
}
