<?php
/**
*	Name			: BlockTableDataMapper.php
*	Author			: snehal
*	Creation Date	: 1/13/2011
*	Path 			: application/modules/Reservation/models/BlockTableDataMapper.php
*	Description		: This is the datamapper class for blocking a table.
*					   	
*/
class Reservation_Model_RestaurantQuoteTimeSettingsDataMapper
{
	/**
	 * Instance variable of blocking a table
	 * @var object
	 */
	protected $_dbTable;

	/**
     * @param instance of DbTable restaurant_table_status $dbTable
     * @return self
     */
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	/**
     * @return instance of DbTable restaurant_table_status
     */
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Reservation_Model_DbTable_RestaurantQuoteTimeSettings');
		}
		return $this->_dbTable;
	}
	
	public function AddRestaurantQuoteAndTime(Reservation_Model_RestaurantQuoteTimeSettings $quote)
	{
		try{
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($quote->getRestId());
			date_default_timezone_set($timezone);
			
			$db = Zend_Db_Table::getDefaultAdapter();
			$quoteTypeMapper = new Reservation_Model_RestaurantQuoteSettingsDataMapper();
			$select = $quoteTypeMapper->getDbTable()->select();
			$select->from($quoteTypeMapper->getDbTable(),array('rqs_id','rqs_wait_quote_type'))
					->where('rqs_fk_restaurant = ?',$quote->getRestId())
					->where('rqs_status = ?','T');
			$rowSet = $quoteTypeMapper->getDbTable()->fetchRow($select);
			$resultant = array();
			$db->beginTransaction();
			if($rowSet->rqs_id){
				$Timeselect = $this->getDbTable()->select();
				$startpax = $quote->getStartPax();
				$endpax = $quote->getEndPax();
				$Timeselect->from($this->getDbTable(),array('rwqs_id','rwqs_quoted_time'))
						->where('rwqs_fk_restaurant = ?',$quote->getRestId())
						->where("rwqs_startpax <= $startpax OR rwqs_startpax <= $endpax")
						->where("rwqs_endpax >= $startpax OR rwqs_endpax >= $endpax")
						->where('rwqs_status = ?','T')
						->where('rwqs_fk_quote_settings = ?',$rowSet->rqs_id);
				$TimerowSet = $this->getDbTable()->fetchRow($Timeselect);
				if($TimerowSet && $TimerowSet->rwqs_id){
					$resultant['status'] = false;
					$resultant['msg'] = 'The Quote Time Settings for this range already exists';
				}else{
					if($rowSet->rqs_wait_quote_type == 'Fixed'){
						$set = array('rqs_wait_quote_type'	=>	'Variable');
						$where = array('rqs_id = ?'=>$rowSet->rqs_id);
						$rowUpdate = $quoteTypeMapper->getDbTable()->update($set,$where);
					}
					$data = array(
								'rwqs_fk_restaurant'		=>	$quote->getRestId(),
								'rwqs_quoted_time'			=>	$quote->getQuoteTime(),
								'rwqs_startpax'				=>	$quote->getStartPax(),
								'rwqs_endpax'				=>	$quote->getEndPax(),
								'rwqs_status'				=>	$quote->getStatus(),
								'rwqs_fk_quote_settings'	=>	$rowSet->rqs_id,
								'rwqs_created_date'			=>  date('Y-m-d'),
								'rwqs_created_time'			=>  date('H:i:s')
					);
					$result = $this->getDbTable()->insert($data);
					$resultant['status'] = true;
					$resultant['result'] = $result;
				}
			}else{
				$data = array(
								'rqs_fk_restaurant'		=>	$quote->getRestId(),
								'rqs_wait_quote_type'	=>	$quote->getQuoteType(),
								'rqs_status'			=>	$quote->getStatus(),
								'rqs_wait_time'			=>	$quote->getQuoteTime()
				);	
				$result = $quoteTypeMapper->getDbTable()->insert($data);
				if($result){
					$data = array(
								'rwqs_fk_restaurant'		=>	$quote->getRestId(),
								'rwqs_quoted_time'			=>	$quote->getQuoteTime(),
								'rwqs_startpax'				=>	$quote->getStartPax(),
								'rwqs_endpax'				=>	$quote->getEndPax(),
								'rwqs_status'				=>	$quote->getStatus(),
								'rwqs_fk_quote_settings'	=>	$result
					);
					$resultant = $this->getDbTable()->insert($data);
				}
				$resultant['status'] = true;
				$resultant['result'] = $result;
			}			
			$db->commit();
			return $resultant;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage());
		}
	}
	
	public function UpdateRestaurantQuoteAndTime(Reservation_Model_RestaurantQuoteTimeSettings $quote)
	{
		try{
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($quote->getRestId());
			date_default_timezone_set($timezone);
			
			$db = Zend_Db_Table::getDefaultAdapter();
			$quoteTypeMapper = new Reservation_Model_RestaurantQuoteSettingsDataMapper();
			$select = $quoteTypeMapper->getDbTable()->select();
			$select->from($quoteTypeMapper->getDbTable(),array('rqs_id','rqs_wait_quote_type'))
					->where('rqs_fk_restaurant = ?',$quote->getRestId())
					->where('rqs_status = ?','T');
			$rowSet = $quoteTypeMapper->getDbTable()->fetchRow($select);
			$resultant = array();
			$db->beginTransaction();
			if($rowSet->rqs_id){
				$Timeselect = $this->getDbTable()->select();
				$startpax = $quote->getStartPax();
				$endpax = $quote->getEndPax();
				$Timeselect->from($this->getDbTable(),array('rwqs_id','rwqs_quoted_time'))
						->where('rwqs_fk_quote_settings = ?',$rowSet->rqs_id)
						->where("(rwqs_startpax >= $startpax AND rwqs_startpax <= $endpax) OR (rwqs_endpax >= $startpax AND rwqs_endpax <= $endpax)")
//						->orwhere("rwqs_endpax >= $startpax AND rwqs_endpax <= $endpax")
						->where('rwqs_status = ?','T')
						->where('rwqs_id != ?',$quote->getId());
				$TimerowSet = $this->getDbTable()->fetchRow($Timeselect);
				if($TimerowSet && $TimerowSet->rwqs_id){
					$resultant['status'] = false;
					$resultant['msg'] = 'The Quote Time Settings for this range already exists';
				}else{
					if($rowSet->rqs_wait_quote_type == 'Variable'){
						$set = array(
									'rwqs_quoted_time'			=>	$quote->getQuoteTime(),
									'rwqs_startpax'				=>	$quote->getStartPax(),
									'rwqs_endpax'				=>	$quote->getEndPax(),
									'rwqs_updated_date'			=>  date('Y-m-d'),
									'rwqs_updated_time'			=>  date('H:i:s')
						);
						$where = array('rwqs_id = ?'=>$quote->getId());
						$result = $this->getDbTable()->update($set,$where);
						$resultant['status'] = true;
						$resultant['result'] = $result;
					}else if($rowSet->rqs_wait_quote_type == 'Fixed'){
						$set = array(
										'rqs_wait_quote_type'	=>	'Variable'
						);
						$where = array('rqs_fk_restaurant = ?'=>$quote->getRestId(),'rqs_id = ?'=>$rowSet->rqs_id);
						$rowUpdate = $quoteTypeMapper->getDbTable()->update($set,$where);
						$set = array(
									'rwqs_quoted_time'			=>	$quote->getQuoteTime(),
									'rwqs_startpax'				=>	$quote->getStartPax(),
									'rwqs_endpax'				=>	$quote->getEndPax(),
									'rwqs_fk_quote_settings'	=>	$rowSet->rqs_id,
									'rwqs_updated_date'			=>  date('Y-m-d'),
									'rwqs_updated_time'			=>  date('H:i:s')
						);
						$where = array('rwqs_id = ?'=>$quote->getId());
						$result = $this->getDbTable()->update($set,$where);
						$resultant['status'] = true;
						$resultant['result'] = $result;
					}
				}
			}
			
			$db->commit();
			return $resultant;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage());
		}
	}
	public function GetQuoteTimeSettings($restid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from($table,array('rwqs_id','rwqs_startpax','rwqs_endpax','rwqs_quoted_time'))
				   ->join(array('times'=>'mt.quoted_time_bd'),'rwqs_quoted_time = code',array('code as timecode','description as timedesc'))			
				   ->where('rwqs_fk_restaurant = ?',$restid)
				   ->where('rwqs_status = ?',true)
				   ->order(array('rwqs_id'));
			$rowset = $table->fetchAll($select);	   
			return $rowset;
				   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function GetQuoteTimeSettingsAjax($restid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from($table,array('rwqs_id','rwqs_startpax','rwqs_endpax','rwqs_quoted_time'))
				   ->join(array('times'=>'mt.quoted_time_bd'),'rwqs_quoted_time = code',array('code as timecode','description as timedesc'))			
				   ->where('rwqs_fk_restaurant = ?',$restid)
				   ->where('rwqs_status = ?',true)
				   ->order(array('rwqs_id'));
			$rowset = $table->fetchAll($select);
			$result = array();
			foreach($rowset as $row){
				if($row->rwqs_quoted_time >= 5 && $row->rwqs_quoted_time <= 55){
					$meridian = 'Minutes';
				}else{
					$meridian = 'Hours';
				}
				$result[] = array(
								'id'		=>	$row->rwqs_id,
								'startpax'	=>	$row->rwqs_startpax,
								'endpax'	=>	$row->rwqs_endpax,
								'quote'		=>	$row->rwqs_quoted_time,
								'meridian'	=>	$meridian
							);
			}	   
			return $result;
				   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function CheckQuoteTimeSettings($restid,$pax)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rwqs_id','rwqs_startpax','rwqs_endpax','rwqs_quoted_time'))
					->where("rwqs_startpax <= $pax AND rwqs_endpax >= $pax")
				   ->where('rwqs_fk_restaurant = ?',$restid)
				   ->where('rwqs_status = ?',true);
			$rowset = $table->fetchAll($select);	   
			return $rowset;
				   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
public function RetrieveRestQuoteTimeSettings($restid)
	{
		try
		{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rwqs_id','rwqs_fk_restaurant','rwqs_startpax','rwqs_endpax','rwqs_status','rwqs_fk_quote_settings','rwqs_quoted_time','rwqs_created_by','rwqs_created_date','rwqs_created_time','rwqs_updated_by','rwqs_updated_date','rwqs_updated_time'))
				   ->where('rwqs_fk_restaurant = ?',$restid);
				   
		    $rowSet = $table->fetchAll($select);		    
		   
		    $restquotetimes = array();
		  
		    foreach($rowSet as $row)
		    {
	    		$restquotetimes[] = array('rwqs_id' 			   => $row->rwqs_id,
			    						  'rwqs_fk_restaurant' 	   => $row->rwqs_fk_restaurant,
				    					  'rwqs_startpax' 	 	   => $row->rwqs_startpax,
				    					  'rwqs_endpax' 		   => $row->rwqs_endpax,
				    					  'rwqs_status' 		   => $row->rwqs_status,
				    					  'rwqs_fk_quote_settings' => $row->rwqs_fk_quote_settings,
				    					  'rwqs_quoted_time' 	   => $row->rwqs_quoted_time,
				    					  'rwqs_created_by' 	   => $row->rwqs_created_by,
				    					  'rwqs_created_date' 	   => $row->rwqs_created_date,
				    					  'rwqs_created_time' 	   => $row->rwqs_created_time,
				    					  'rwqs_updated_by' 	   => $row->rwqs_updated_by,
				    					  'rwqs_updated_date' 	   => $row->rwqs_updated_date,
				    					  'rwqs_updated_time' 	   => $row->rwqs_updated_time);
		    }
			   		    
		    return $restquotetimes;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function RetrieveQuoteTimesbd()
	{
		try
		{
			$table = new Zend_Db_Table('mt.quoted_time_bd');
			$select = $table->select();
			$select->from(array('mt.quoted_time_bd'),array('id','code','description','status'))
			->where('status = ?',true);
			$rowSet = $table->fetchAll($select);
			$restquotetimes = array();
			foreach($rowSet as $row)
			{
				$restquotetimes[] = array('id' 			=> $row->id,
						'code' 	   	=> $row->code,
						'description' => $row->description,
						'status'	    => $row->status);
			}
			return $restquotetimes;
				
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function RetrieveChangedRestQuoteTimeSettings($restid)
	{
		try
		{
			$restaurantService = new Application_Service_Firm();
			$timeZone = $restaurantService->GetRestaurantTimeZone($restid);			
			date_default_timezone_set($timeZone);
			
			$date = date('Y-m-d');
			
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rwqs_id','rwqs_fk_restaurant','rwqs_startpax','rwqs_endpax','rwqs_status','rwqs_fk_quote_settings','rwqs_quoted_time','rwqs_created_by','rwqs_created_date','rwqs_created_time','rwqs_updated_by','rwqs_updated_date','rwqs_updated_time'))
				   ->where('rwqs_fk_restaurant = ?',$restid)
				   ->where("rwqs_created_date::text LIKE (?) OR rwqs_updated_date::text LIKE (?)",'%'.$date.'%');
				   
		    $rowSet = $table->fetchAll($select);		    
		   
		    $restquotetimes = array();
		  
		    foreach($rowSet as $row)
		    {
	    		$restquotetimes[] = array('rwqs_id' 			   => $row->rwqs_id,
			    						  'rwqs_fk_restaurant' 	   => $row->rwqs_fk_restaurant,
				    					  'rwqs_startpax' 	 	   => $row->rwqs_startpax,
				    					  'rwqs_endpax' 		   => $row->rwqs_endpax,
				    					  'rwqs_status' 		   => $row->rwqs_status,
				    					  'rwqs_fk_quote_settings' => $row->rwqs_fk_quote_settings,
				    					  'rwqs_quoted_time' 	   => $row->rwqs_quoted_time,
				    					  'rwqs_created_by' 	   => $row->rwqs_created_by,
				    					  'rwqs_created_date' 	   => $row->rwqs_created_date,
				    					  'rwqs_created_time' 	   => $row->rwqs_created_time,
				    					  'rwqs_updated_by' 	   => $row->rwqs_updated_by,
				    					  'rwqs_updated_date' 	   => $row->rwqs_updated_date,
				    					  'rwqs_updated_time' 	   => $row->rwqs_updated_time);
		    }
			   		    
		    return $restquotetimes;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
}
