<?php

class Server_Model_ServerDataMapper
{
	protected $_dbTable;
	
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}
	
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Server_Model_DbTable_Servers');
		}
		return $this->_dbTable;
	}
	
	public function updateorInsertServerDetails(Server_Model_Server $server)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			if($server->getserid() != null)
			{
				$db->beginTransaction();
				$set = array('serv_name' 			=> $server->getser_name(),
							 'serv_colorcode'	    => $server->getser_colorcode(),
							 'serv_updatedby'	    => $server->getserupdatedby(),
							 'serv_updateddate'		=> $server->getserupdateddate(),
        // Pratik changes - 22-09-2020 //////
                'serv_newupdateddate'		=> $server->getsernewupdateddate(),
        ////////////////////////////////////
							 'serv_updateddatetime' => $server->getserupdatedtime(),
							 'serv_sync_status'		=> 'C');			
				$where = $db->quoteInto('serv_id = ?',$server->getserid());	
				$ser_id = $this->getDbTable()->update($set,$where);	
				
				if($server->getTableid() != null){
					$sertabMapper = new Server_Model_ServerTableMapDataMapper();
					$set = array('stm_status' 		=> "false");
					$where = $db->quoteInto('stm_fk_serv = ?',$server->getserid());
					$ser_id = $sertabMapper->getDbTable()->update($set,$where);	

					$serTabObj = new Server_Model_ServerTableMap();
					$serTabObj->setStm_fk_ser($server->getserid())
							  ->setStm_staus(true)
							  ->setstm_tableid($server->getTableid());
					$serverIds = $sertabMapper->savetabledetails($serTabObj);
				}else{
					$sertabMapper = new Server_Model_ServerTableMapDataMapper();
					$set = array('stm_status' 		=> "false");
					$where = $db->quoteInto('stm_fk_serv = ?',$server->getserid());
					$ser_id = $sertabMapper->getDbTable()->update($set,$where);	
				}
				$db->commit();
			}else{
				$db->beginTransaction();
				$data = array('serv_name' 			=> $server->getser_name(),
							  'serv_colorcode'  	=> $server->getser_colorcode(),
							  'serv_createdby'  	=> $server->getsercreatedby(),
							  'serv_createddatetime'=> $server->getsercreateddateandtime(),
							  'serv_resid'   		=> $server->getser_resid(),
							  'serv_status'			=> 1);				
				$ser_id = $this->getDbTable()->insert($data);

				if($ser_id){	
					$sertabMapper = new Server_Model_ServerTableMapDataMapper();						
					$serTabObj = new Server_Model_ServerTableMap();
					$serTabObj->setStm_fk_ser($ser_id)
							  ->setStm_staus(true)
							  ->setstm_tableid($server->getTableid());
					$serverIds = $sertabMapper->savetabledetails($serTabObj);
				}	
				
				$db->commit();	
			}		
			return true; 	
		}catch (Exception $ex){	
			$db->rollBack();
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getallTables($restaurantid,$diningid)
	{
		try{
			$restaurantmapper = new FirmManagement_Model_FirmTableDataMapper();
			$table = $restaurantmapper->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsttable_pax','rsttable_number','rstid','rstdiningid'))
				   ->where('rstfk_restaurant = ?',$restaurantid)
				   ->where('rstdiningid = ?',$diningid)
				   ->where('rsttable_status = ?','TRUE');
			$tables = $table->fetchAll($select);
			$data = array();
			foreach($tables as $tab){
					$data[] = array('Table no'=> $tab->rsttable_number,
								  'Table Id'  => $tab->rstid."_".$tab->rstdiningid,
    					  	  	  'Pax' 	  => $tab->rsttable_pax		    					  
    					  	      );		
				}
			return $data;	
		}catch (Exception $ex){	
			throw new Exception($ex->getMessage());
		}
	}
	
	public function retrieveServersByRestId($restid,$date)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
					  		
			$select->from(array('ser'=>'mt.servers'),array('serv_id','serv_colorcode','serv_name','serv_status','serv_firstname','serv_lastname'))
				   ->join(array('sbd'=>'mt.server_status_bd'),'sbd.id = ser.serv_status',array('code','description'))	
			       ->where('ser.serv_resid = ?',$restid)
			       ->where('ser.serv_status != ?',3)	
			       ->distinct()		       
			       ->order(array('ser.serv_id'));			       
			$rowset = $table->fetchAll($select);
						
			$serverArr = array();
			
			$prev_ser_id  = "";
			$status  = "";
			$statuscode  = "";
			$colocode  = "";
			$name     = "";
      $serv_firstname = "";
      $serv_lastname = "";
			$seatedinv	  = array();
			
			if(count($rowset) > 0)
			{
				/* Get Seated Inventory */
			
				$bookService = new Application_Service_Reservation();				
				$seatedinv = $bookService->GetSeatedInventory($restid,$date);
				
				foreach($rowset as $row)
				{
					$count = 0;
					$secseatcount   = 0;
					$servidarr      = array();	
								
					$server_id 	    = $row->serv_id;	
					$colocode    	  = $row->serv_colorcode;
         if(trim($row->serv_name) != ''){
          $name        	  = $row->serv_name;
        }else{
				  $name        	  = trim($row->serv_firstname." ".$row->serv_lastname);
        }
					
					$status         = $row->serv_status;
					$statuscode     = $row->code;
          $serv_firstname = trim($row->serv_firstname);
          $serv_lastname  = trim($row->serv_lastname);
          
						if($row->serv_id)
						{
							$servidarr[] = $row->serv_id;
							$count = $this->getServerTableSum($servidarr);
							$servseatcount =  $this->getSeatedServTableSum($servidarr,$seatedinv);	
						}

						$serverArr[] = array('ServerId'  => $server_id,
										    'Colorcode'  => $colocode,
										    'Servername' => $name,
											  'totalcount' => $count,	
											  'status' 	 => $status,	
											  'statuscode' => $statuscode,	
											  'count'		 =>	$servseatcount,
                        'serv_firstname' => $serv_firstname,
                        'serv_lastname' => $serv_lastname
    			 );
				}
											
			}			
			return $serverArr;		
		}
		catch (Exception $ex)
		{	
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getSeatedServTableSum($serverid,$seatedinv)
	{
		try
		{
			$restTableMapper = new FirmManagement_Model_FirmTableDataMapper();
			
			$restTable = $restTableMapper->getDbTable();
			$restTableSelect = $restTable->select();
			
			$restTableSelect->from(array('rst'=>'mt.restaurant_tables'),array('rstid'))
			                ->join(array('stm'=>'mt.server_table_map'),'stm.stm_tableid = rst.rstid',array(''))
			                ->where('stm.stm_fk_serv IN(?)',$serverid)
			                ->where('stm.stm_status = ?', true);
			                            
			$secTabSum = 0;                
			$rowset = $restTable->fetchAll($restTableSelect);
			
			if(count($rowset) > 0)
			{
				foreach($rowset as $row)
				{
					if(array_key_exists($row->rstid,$seatedinv))
					{
						$secTabSum = $secTabSum + $seatedinv[$row->rstid];
					}
				}
			}
			
			return $secTabSum;
			
		}catch (Exception $ex){	
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getServerTableSum($serverid)
	{
		try
		{
			$restTableMapper = new FirmManagement_Model_FirmTableDataMapper();
			
			$restTable = $restTableMapper->getDbTable();
			$restTableSelect = $restTable->select();
			
			$restTableSelect->from(array('rst'=>'mt.restaurant_tables'),array('sum(rsttable_pax) as secount'))
			                ->join(array('stm'=>'mt.server_table_map'),'stm.stm_tableid = rst.rstid',array(''))
			                ->where('stm.stm_fk_serv IN(?)',$serverid)
			                ->where('stm.stm_status = ?', true);
			                
						                
			$secTabSum = 0;                
			$rowset = $restTable->fetchAll($restTableSelect);

			if(count($rowset) > 0)
			{
				foreach($rowset as $row)
				{
					$secTabSum = $row->secount;	
				}	
			}
			
			return $secTabSum;			                
		}
		catch (Exception $ex)
		{	
			throw new Exception($ex->getMessage());
		}
	}
	
	public function clearalltablesofservers($resid)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			$db = Zend_Db_Table::getDefaultAdapter();		  		
			$select->from(array('ser'=>'mt.servers'),array('serv_id'))
			       ->where('ser.serv_resid = ?',$resid)
//			       ->where('ser.serv_status = ?',1)	
			       ->distinct();		       
			$serverids = $table->fetchAll($select);
			
			if(count($serverids) > 0){				
				foreach($serverids as $server){
					$serverId = $server->serv_id;
					$sertabMapper = new Server_Model_ServerTableMapDataMapper();
					$set = array('stm_status' 		=> "false");
					$where = $db->quoteInto('stm_fk_serv = ?',$serverId);
					$ser_id = $sertabMapper->getDbTable()->update($set,$where);	
				}			
			}
			
			return true;
		}catch (Exception $ex){	
			throw new Exception($ex->getMessage());
		}
	}
	
	public function ActivateorDeactServer($servid,$status,$restaurantid)
	{
		try{
			$restaurantService = new Application_Service_Firm();
			$timeZone = $restaurantService->GetRestaurantTimeZone($restaurantid);			
			date_default_timezone_set($timeZone);
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			$table  = $this->getDbTable();
      //Pratik code changes - 22-09-2020 - start /////
			$set = array('serv_status'  		=> $status,
						 'serv_sync_status'		=> 'C',
						 //'serv_updateddate'		=> date('Y-m-d'),
             'serv_newupdateddate' => date('Y-m-d'),
             'serv_updateddate' => date("H:i:s",time()),
						 'serv_updateddatetime' => date("H:i:s",time()),
						 'serv_updatedby'		=> $userdata['User_Id']
						);			
			$where = array('serv_id = ?' => $servid); 
      ///////////////// End //////////////////////
			$result = $table->update($set,$where);
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getServerByBookingid($bookingid)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);		
			$select->from(array('sec'=>'mt.servers'),array('serv_id','serv_name','serv_colorcode'))
				   ->join(array('bok'=>'mt.booking'),'bok.bok_serverid = sec.serv_id',array(''))
			       ->where('bok.bokid = ?',$bookingid)
				   ->where('sec.serv_status = ?',1);
				   
			$rowset = $table->fetchRow($select);	
			$result = array();
			if($rowset)
			{
				$result['serverid'] = $rowset->serv_id;
				$result['servername'] = $rowset->serv_name;
				$result['servercolor'] = $rowset->serv_colorcode;
			}
			return $result;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getServersByRestaurantid($restid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
					  		
			$select->from(array('mt.servers'),array('serv_id','serv_colorcode','serv_name'))
				   ->where('serv_resid = ?',$restid)
			       ->where('serv_status = ?',1);			       
			$rowset = $table->fetchAll($select);
			$serverArr = array();
			foreach($rowset as $row)
			{
				$serverArr[] = array('serverid' => $row->serv_id,
									 'servername' => $row->serv_name,
									 'servercolor' => $row->serv_colorcode);
			}
			return $serverArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retrieveServersByRestIdForSync($restid)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
					  		
			$select->from($table,array('serv_id','serv_staffid','serv_colorcode','serv_name','serv_status','serv_createdby','serv_createddatetime','serv_resid','serv_updatedby','serv_updateddate','serv_updateddatetime'))				   	
			       ->where('serv_resid = ?',$restid)
			       ->distinct()				       		       
			       ->order('serv_id');			       
			$rowset = $table->fetchAll($select);						
			
			$result = array();
			$serverList = array();
			if(count($rowset) > 0)
			{	$result['status'] = true;
			
				foreach($rowset as $row)
				{
					$serverArr = array();
					$serverArr['serv_id']		  		= $row->serv_id;
					$serverArr['serv_staffid'] 			= $row->serv_staffid;
					$serverArr['serv_colorcode'] 		= $row->serv_colorcode;
					$serverArr['serv_name'] 			= $row->serv_name;
					$serverArr['serv_status'] 			= $row->serv_status;
					$serverArr['serv_createdby'] 		= $row->serv_createdby;
					$serverArr['serv_createddatetime'] 	= $row->serv_createddatetime;
					$serverArr['serv_resid'] 			= $row->serv_resid;
					$serverArr['serv_updatedby'] 		= $row->serv_updatedby;
					$serverArr['serv_updateddate'] 		= $row->serv_updateddate;
					$serverArr['serv_updateddatetime']	= $row->serv_updateddatetime;
					
					/* Retrieve Server Inventory */
					$serverTableMapDataMapper = new Server_Model_ServerTableMapDataMapper();
					$serTabTable = $serverTableMapDataMapper->getDbTable();
					$serTabSelect = $serTabTable->select();
					$serTabSelect->from($serTabTable,array('stm_id','stm_fk_serv','stm_status','stm_diningid','stm_tableid','stm_tableno'))
								 ->where('stm_fk_serv = ?',$row->serv_id);
					$tabRowSet = $serTabTable->fetchAll($serTabSelect);

					$tablesArr = array();
					
					if(count($tabRowSet))
					{						
						foreach($tabRowSet as $tabRow)
						{
							$serverTabArr = array();
							$serverTabArr['stm_id'] = $tabRow->stm_id;
							$serverTabArr['stm_fk_serv'] = $tabRow->stm_fk_serv;
							$serverTabArr['stm_status'] = $tabRow->stm_status;
							$serverTabArr['stm_diningid'] = $tabRow->stm_diningid;
							$serverTabArr['stm_tableid'] = $tabRow->stm_tableid;
							$serverTabArr['stm_tableno'] = $tabRow->stm_tableno;
							
							$tablesArr[] = $serverTabArr;
						}
					}
					
					$serverArr['servertables'] = $tablesArr;	

					$serverList[] = $serverArr;
				}

				$result['server'] = $serverList;
			}else{
				$result['status'] = false;
				$result['server'] = $serverList;
			}			
			return $result;		
		}
		catch (Exception $ex)
		{	
			throw new Exception($ex->getMessage());
		}
	}

	public function saveNativeServers($serverDetails)
	{
		try
		{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			
			$resultArray = array();	
			
			foreach($serverDetails as $row)
			{				
				$data = array();				
				$data = array('serv_colorcode'       => $row->serv_colorcode,
							  'serv_name' 	         => trim($row->serv_firstname),
							  'serv_status'          => $row->serv_status,
							  'serv_resid'           => $row->serv_resid,
							  //'serv_createdby'       => $row->ser_createdby,
							  'serv_createddatetime' => $row->serv_createddate);
				
				$serverid = $this->getDbTable()->insert($data);
								
				/*Insert Server Map Tables */
				$serverMapTables = json_decode($row->server_tables);
				if(count($serverMapTables) > 0)
				{					
					$serverTableMapDataMapper = new Server_Model_ServerTableMapDataMapper();
					$servMapTable = $serverTableMapDataMapper->getDbTable();
					
					foreach($serverMapTables as $serverTables)
					{
						$servTableData = array('stm_fk_serv'  => $serverid,
											   'stm_status'   => $serverTables->stm_status,
											   'stm_diningid' => $serverTables->stm_diningid,
											   'stm_tableid'  => $serverTables->stm_tableid,
											   'stm_tableno'  => $serverTables->stm_tableno);
						
						$servMapeId = $servMapTable->insert($servTableData); 
					}					
				}				
				$resultArray[] = array('ser_id'=>$row->ser_id,'ser_webid'=>$serverid);
			}
			
			$db->commit();
			
			return $resultArray;
		}
		catch (Exception $ex)
		{	
			$db->rollBack();			
			throw new Exception($ex->getMessage());
		}
	}
	
	public function saveNativeChangeServers($serverDetails)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();			
		/* Collect All Server Id's from native and get updated time */
		$serverIdArr = array();
		$restid = "";
		
		foreach($serverDetails as $servrow)
		{
			$serverIdArr[] = $servrow->ser_webid;
			$restid = $servrow->ser_resid;
		}
		if(count($serverIdArr) > 0){
			try
			{
				$db->beginTransaction();
			
				if($restid != ""){
					
					$timezone = "";
					$mapper = new FirmManagement_Model_FirmDataMapper();
					$timezone = $mapper->GetRestaurantTimeZone($restid);
					date_default_timezone_set($timezone);
				}
				
				$table = $this->getDbTable();
				$select = $table->select();
				
				$select->from($table,array('serv_id','serv_updateddatetime'))
				       ->where('serv_id IN (?)',$serverIdArr);
				       
				$webServerArr = array();
		
				$serverRowSet = $table->fetchAll($select);
				
				foreach($serverRowSet as $servRow){
					$webServerArr[$servRow->serv_id] = $servRow->serv_updateddatetime;
				}
							
				foreach($serverDetails as $row)
				{
					if(array_key_exists($row->ser_webid,$webServerArr))
					{
						$webupadateddate = strtotime($webServerArr[$row->ser_webid]);
					}else{
						$webupadateddate = 0;
					}				
				    
				    if($row->ser_updatedtime != "" && $row->ser_updatedtime != "null")
				    {			    	
					    $nativeupadateddate = strtotime($row->ser_updatedtime);
						
						if($nativeupadateddate > $webupadateddate)
						{
							$set = array('serv_colorcode'        => $row->serv_colorcode,
										  'serv_name' 	         => $row->ser_firstname,
										  'serv_status'          => $row->ser_status,
										  'serv_resid'           => $row->ser_resid
										  );
										  
										  if($row->ser_updatedby != "" && $row->ser_updatedby != null)
										  {
										  	$set['serv_updatedby']  = $row->ser_updatedby;
										  }
										  
										  if($row->ser_updateddate != "" && $row->ser_updateddate != null)
										  {
										  	$set['serv_updateddate']  = $row->servupdateddate;
										  }
										  
										  if($row->ser_updateddatetime != "" && $row->ser_updateddatetime != null)
										  {
										  	$set['serv_updateddatetime']  = $row->ser_updateddatetime;
										  }									 
							
							$where = array('serv_id = ?'=>$row->ser_webid);
							
							$rows_affected = $this->getDbTable()->update($set,$where);
							
							if($rows_affected)
							{
								/* Inactivate Previously Assigned Tables */
								
								$serverTableMapDataMapper = new Server_Model_ServerTableMapDataMapper();
								$servMapTable = $serverTableMapDataMapper->getDbTable();							
								$tableSet = array('stm_status' => "False");
								$tableWhere = array('stm_fk_serv = ?' => $row->ser_webid);
								
								$tblrows_affected = $servMapTable->update($tableSet,$tableWhere);
								
								/*Insert Server Map Tables */
								$serverMapTables = json_decode($row->server_tables);
								
								if(count($serverMapTables) > 0)
								{	
									foreach($serverMapTables as $serverTables)
									{
										$servTableData = array('stm_fk_serv'  => $row->ser_webid,
															   'stm_status'   => $serverTables->stm_status,
															   'stm_diningid' => $serverTables->stm_diningid,
															   'stm_tableid'  => $serverTables->stm_tableid,
															   'stm_tableno'  => $serverTables->stm_tableno);
										
										$servMapeId = $servMapTable->insert($servTableData); 
									}												
								}
							}					
						}
				    }				
				}						
				$db->commit();
				$status = true;
				return $status;
			}
			catch (Exception $ex)
			{	
				$db->rollBack();
				Uss_Logger_FileLogger::info("In Exception ".$ex->getMessage());
				throw new Exception($ex->getMessage());
			}
		}else{
			return $status;
		}
	}
	
	public function retrieveServersByRestIdForIpadSync($restid)
	{
		try
		{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
				
			$select->from($table,array('serv_id','serv_staffid','serv_colorcode','serv_name','serv_status','serv_createdby','serv_createddatetime','serv_resid','serv_updatedby','serv_updateddate','serv_updateddatetime','serv_firstname','serv_lastname'))
			->where('serv_resid = ?',$restid)
			->distinct()
			->order('serv_id');
			$rowset = $table->fetchAll($select);
				
			$result = array();
			$serverList = array();
			if(count($rowset) > 0)
			{	$result['status'] = true;
				
			foreach($rowset as $row)
			{
				$serverArr = array();
				$serverArr['serv_id']		  		= $row->serv_id;
				$serverArr['serv_staffid'] 			= $row->serv_staffid;
				$serverArr['serv_colorcode'] 		= $row->serv_colorcode;
        if(trim($row->serv_name) != ''){
          $serverArr['serv_name'] = $row->serv_name;
        }else{
				  $serverArr['serv_name'] 			= trim($row->serv_firstname.' '.$row->serv_lastname);
        }
				$serverArr['serv_status'] 			= $row->serv_status;
				$serverArr['serv_createdby'] 		= $row->serv_createdby;
				$serverArr['serv_createddatetime'] 	= $row->serv_createddatetime;
				$serverArr['serv_resid'] 			= $row->serv_resid;
				$serverArr['serv_updatedby'] 		= $row->serv_updatedby;
				$serverArr['serv_updateddate'] 		= $row->serv_updateddate;
				$serverArr['serv_updateddatetime']	= $row->serv_updateddatetime;
				$serverArr['serv_firstname'] 			= trim($row->serv_firstname);
        $serverArr['serv_lastname'] 			= trim($row->serv_lastname);
        
				/* Retrieve Server Inventory */
				$serverTableMapDataMapper = new Server_Model_ServerTableMapDataMapper();
				$serTabTable = $serverTableMapDataMapper->getDbTable();
				$serTabSelect = $serTabTable->select();
				$serTabSelect->from($serTabTable,array('stm_id','stm_fk_serv','stm_status','stm_diningid','stm_tableid','stm_tableno'))
				->where('stm_fk_serv = ?',$row->serv_id)
				->where('stm_status = ?',true);
				$tabRowSet = $serTabTable->fetchAll($serTabSelect);
	
				$tablesArr = array();
					
				if(count($tabRowSet))
				{
					foreach($tabRowSet as $tabRow)
					{
						$serverTabArr = array();
						$serverTabArr['stm_id'] = $tabRow->stm_id;
						$serverTabArr['stm_fk_serv'] = $tabRow->stm_fk_serv;
						$serverTabArr['stm_status'] = $tabRow->stm_status;
						$serverTabArr['stm_diningid'] = $tabRow->stm_diningid;
						$serverTabArr['stm_tableid'] = $tabRow->stm_tableid;
						$serverTabArr['stm_tableno'] = $tabRow->stm_tableno;
							
						$tablesArr[] = $serverTabArr;
					}
				}
					
				$serverArr['servertables'] = $tablesArr;
	
				$serverList[] = $serverArr;
			}
	
			$result['server'] = $serverList;
			}else{
				$result['status'] = false;
				$result['server'] = $serverList;
			}
			return $result;
		}
		catch (Exception $ex)
		{
			throw new Exception($ex->getMessage());
		}
	}
	
	public function saveIosChangeServers($serverDetails)
	{
		$status = false;
		$db = Zend_Db_Table::getDefaultAdapter();			
		/* Collect All Server Id's from native and get updated time */
		$serverIdArr = array();
		$restid = "";
		
		foreach($serverDetails as $servrow)
		{
			$serverIdArr[] = $servrow->ser_webid;
			$restid = $servrow->ser_resid;
		}
		if(count($serverIdArr) > 0){
			try
			{
				$db->beginTransaction();
			
				if($restid != ""){
					
					$timezone = "";
					$mapper = new FirmManagement_Model_FirmDataMapper();
					$timezone = $mapper->GetRestaurantTimeZone($restid);
					date_default_timezone_set($timezone);
				}
				
				$table = $this->getDbTable();
				$select = $table->select();
				
				$select->from($table,array('serv_id','serv_updateddatetime','serv_updateddate'))
				       ->where('serv_id IN (?)',$serverIdArr);
				       
				$webServerArr = array();
				$webDateArr = array();
				$serverRowSet = $table->fetchAll($select);
				
				foreach($serverRowSet as $servRow){
					$webServerArr[$servRow->serv_id] = $servRow->serv_updateddatetime;
					$webDateArr[$servRow->serv_id] = $servRow->serv_updateddate;
				}
							
				foreach($serverDetails as $row)
				{
					if(array_key_exists($row->ser_webid,$webServerArr))
					{
						$webupadatedtime = strtotime($webServerArr[$row->ser_webid]);
					}else{
						$webupadatedtime = 0;
					}				
				    
					if(array_key_exists($row->ser_webid,$webDateArr))
					{
						$webupadateddate = strtotime($webDateArr[$row->ser_webid]);
					}else{
						$webupadateddate = 0;
					}
					$date = strtotime(date('Y-m-d'));
										
					if($webupadateddate == $date){
						if($row->ser_updatedtime != "" && $row->ser_updatedtime != "null")
					    {			    	
						    $nativeupadateddate = strtotime($row->ser_updatedtime);
							
							if($nativeupadateddate > $webupadatedtime)
							{
								$set = array('serv_colorcode'        => $row->serv_colorcode,
											  'serv_name' 	         => $row->ser_firstname,
											  'serv_status'          => $row->ser_status,
											  'serv_resid'           => $row->ser_resid
											  );
											  
											  if($row->ser_updatedby != "" && $row->ser_updatedby != null)
											  {
											  	$set['serv_updatedby']  = $row->ser_updatedby;
											  }
											  
											  if($row->ser_updateddate != "" && $row->ser_updateddate != null)
											  {
											  	$set['serv_updateddate']  = $row->servupdateddate;
											  }
											  
											  if($row->ser_updateddatetime != "" && $row->ser_updateddatetime != null)
											  {
											  	$set['serv_updateddatetime']  = $row->ser_updateddatetime;
											  }									 
								
								$where = array('serv_id = ?'=>$row->ser_webid);
								
								$rows_affected = $this->getDbTable()->update($set,$where);
								
								if($rows_affected)
								{
									/* Inactivate Previously Assigned Tables */
									
									$serverTableMapDataMapper = new Server_Model_ServerTableMapDataMapper();
									$servMapTable = $serverTableMapDataMapper->getDbTable();							
									$tableSet = array('stm_status' => "False");
									$tableWhere = array('stm_fk_serv = ?' => $row->ser_webid);
									
									$tblrows_affected = $servMapTable->update($tableSet,$tableWhere);
									
									/*Insert Server Map Tables */
									$serverMapTables = $row->server_tables;
									
									if(count($serverMapTables) > 0)
									{	
										foreach($serverMapTables as $servermapTables)
										{
											$serverMapTable = $serverTableMapDataMapper->getDbTable();							
											$tablemapSet = array('stm_status' => "False");
											$tablemapWhere = array('stm_tableid = ?' => $servermapTables->stm_tableid);
											
											$tblrows_affected = $serverMapTable->update($tablemapSet,$tablemapWhere);
										}
									
										foreach($serverMapTables as $serverTables)
										{
											$servTableData = array('stm_fk_serv'  => $row->ser_webid,
																   'stm_status'   => $serverTables->stm_status,
																   'stm_diningid' => $serverTables->stm_diningid,
																   'stm_tableid'  => $serverTables->stm_tableid,
																   'stm_tableno'  => $serverTables->stm_tableno);
											
											$servMapeId = $servMapTable->insert($servTableData); 
										}												
									}
								}					
							}
				    	}
					}else{
						$set = array('serv_colorcode'        => $row->serv_colorcode,
									  'serv_name' 	         => $row->ser_firstname,
									  'serv_status'          => $row->ser_status,
									  'serv_resid'           => $row->ser_resid
									  );
									  
						if($row->ser_updatedby != "" && $row->ser_updatedby != null)
						{
						 	$set['serv_updatedby']  = $row->ser_updatedby;
						}
						  
						if($row->ser_updateddate != "" && $row->ser_updateddate != null)
						{
						  	$set['serv_updateddate']  = $row->servupdateddate;
						}
						  
						if($row->ser_updateddatetime != "" && $row->ser_updateddatetime != null)
						{
						  	$set['serv_updateddatetime']  = $row->ser_updateddatetime;
						}									 
						
						$where = array('serv_id = ?'=>$row->ser_webid);
						
						$rows_affected = $this->getDbTable()->update($set,$where);
						
						if($rows_affected)
						{
							/* Inactivate Previously Assigned Tables */
							
							$serverTableMapDataMapper = new Server_Model_ServerTableMapDataMapper();
							$servMapTable = $serverTableMapDataMapper->getDbTable();							
							$tableSet = array('stm_status' => "False");
							$tableWhere = array('stm_fk_serv = ?' => $row->ser_webid);
							
							$tblrows_affected = $servMapTable->update($tableSet,$tableWhere);
							
							/*Insert Server Map Tables */
							$serverMapTables = $row->server_tables;
							
							if(count($serverMapTables) > 0)
							{	
								foreach($serverMapTables as $servermapTables)
								{
									$serverMapTable = $serverTableMapDataMapper->getDbTable();							
									$tablemapSet = array('stm_status' => "False");
									$tablemapWhere = array('stm_tableid = ?' => $servermapTables->stm_tableid);
									
									$tblrows_affected = $serverMapTable->update($tablemapSet,$tablemapWhere);
								}
										
								foreach($serverMapTables as $serverTables)
								{
									$servTableData = array('stm_fk_serv'  => $row->ser_webid,
														   'stm_status'   => $serverTables->stm_status,
														   'stm_diningid' => $serverTables->stm_diningid,
														   'stm_tableid'  => $serverTables->stm_tableid,
														   'stm_tableno'  => $serverTables->stm_tableno);
									
									$servMapeId = $servMapTable->insert($servTableData); 
								}												
							}
						}
				    }				
				}						
				$db->commit();
				$status = true;
				return $status;
			}
			catch (Exception $ex)
			{	
				$db->rollBack();
				Uss_Logger_FileLogger::info("In Exception ".$ex->getMessage());
				throw new Exception($ex->getMessage());
			}
		}else{
			return $status;
		}
	}
	
	public function retrieveChangedServersByRestIdForIpadSync($restid)
	{
		try
		{
			$restaurantService = new Application_Service_Firm();
			$timeZone = $restaurantService->GetRestaurantTimeZone($restid);			
			date_default_timezone_set($timeZone);
			
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$date = date('Y-m-d');
			$select->from($table,array('serv_id','serv_staffid','serv_colorcode','serv_name','serv_status','serv_createdby','serv_createddatetime','serv_resid','serv_updatedby','serv_updateddate','serv_updateddatetime'))
			->where('serv_resid = ?',$restid)
			->where("serv_updateddate::text LIKE (?) OR serv_createddatetime::text LIKE (?)",'%'.$date.'%')
			->distinct()
			->order('serv_id');
			$rowset = $table->fetchAll($select);
				
			$result = array();
			$serverList = array();
			if(count($rowset) > 0)
			{	
				$result['status'] = true;
				
				foreach($rowset as $row)
				{
					$serverArr = array();
					$serverArr['serv_id']		  		= $row->serv_id;
					$serverArr['serv_staffid'] 			= $row->serv_staffid;
					$serverArr['serv_colorcode'] 		= $row->serv_colorcode;
					$serverArr['serv_name'] 			= $row->serv_name;
					$serverArr['serv_status'] 			= $row->serv_status;
					$serverArr['serv_createdby'] 		= $row->serv_createdby;
					$serverArr['serv_createddatetime'] 	= $row->serv_createddatetime;
					$serverArr['serv_resid'] 			= $row->serv_resid;
					$serverArr['serv_updatedby'] 		= $row->serv_updatedby;
					$serverArr['serv_updateddate'] 		= $row->serv_updateddate;
					$serverArr['serv_updateddatetime']	= $row->serv_updateddatetime;
						
					/* Retrieve Server Inventory */
					$serverTableMapDataMapper = new Server_Model_ServerTableMapDataMapper();
					$serTabTable = $serverTableMapDataMapper->getDbTable();
					$serTabSelect = $serTabTable->select();
					$serTabSelect->from($serTabTable,array('stm_id','stm_fk_serv','stm_status','stm_diningid','stm_tableid','stm_tableno'))
					->where('stm_fk_serv = ?',$row->serv_id)
					->where('stm_status = ?',true);
					$tabRowSet = $serTabTable->fetchAll($serTabSelect);
		
					$tablesArr = array();
						
					if(count($tabRowSet))
					{
						foreach($tabRowSet as $tabRow)
						{
							$serverTabArr = array();
							$serverTabArr['stm_id'] = $tabRow->stm_id;
							$serverTabArr['stm_fk_serv'] = $tabRow->stm_fk_serv;
							$serverTabArr['stm_status'] = $tabRow->stm_status;
							$serverTabArr['stm_diningid'] = $tabRow->stm_diningid;
							$serverTabArr['stm_tableid'] = $tabRow->stm_tableid;
							$serverTabArr['stm_tableno'] = $tabRow->stm_tableno;
								
							$tablesArr[] = $serverTabArr;
						}
					}
						
					$serverArr['servertables'] = $tablesArr;
		
					$serverList[] = $serverArr;
				}
		
				$result['server'] = $serverList;
			}else{
				$result['status'] = false;
				$result['server'] = $serverList;
			}
			return $result;
		}
		catch (Exception $ex)
		{
			throw new Exception($ex->getMessage());
		}
	}
	
	public function saveIosNativeServers($serverDetails)
	{
		try
		{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			
			$resultArray = array();	
			
			foreach($serverDetails as $row)
			{				
				$data = array();				
				$data = array('serv_colorcode'       => $row->serv_colorcode,
							  'serv_name' 	         => $row->ser_firstname,
							  'serv_status'          => $row->ser_status,
							  'serv_resid'           => $row->ser_resid,
							  //'serv_createdby'       => $row->ser_createdby,
							  'serv_createddatetime' => $row->ser_createddate);
				
				$serverid = $this->getDbTable()->insert($data);
								
				/*Insert Server Map Tables */
				$serverMapTables = $row->server_tables;
				if(count($serverMapTables) > 0)
				{					
					$serverTableMapDataMapper = new Server_Model_ServerTableMapDataMapper();
					$servMapTable = $serverTableMapDataMapper->getDbTable();
					
					foreach($serverMapTables as $servermapTables)
					{
						$tablemapSet = array('stm_status' => "False");
						$tablemapWhere = array('stm_tableid = ?' => $servermapTables->stm_tableid);
						
						$tblrows_affected = $servMapTable->update($tablemapSet,$tablemapWhere);
					}
										
					foreach($serverMapTables as $serverTables)
					{
						$servTableData = array('stm_fk_serv'  => $serverid,
											   'stm_status'   => $serverTables->stm_status,
											   'stm_diningid' => $serverTables->stm_diningid,
											   'stm_tableid'  => $serverTables->stm_tableid,
											   'stm_tableno'  => $serverTables->stm_tableno);
						
						$servMapeId = $servMapTable->insert($servTableData); 
					}					
				}				
				$resultArray[] = array('ser_id'=>$row->ser_id,'ser_webid'=>$serverid);
			}
			
			$db->commit();
			
			return $resultArray;
		}
		catch (Exception $ex)
		{	
			$db->rollBack();	
			Uss_Logger_FileLogger::info($ex->getMessage());		
			throw new Exception($ex->getMessage());
		}
	}
}