<?php
class SocialMedia_Model_SocialMediaDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('SocialMedia_Model_DbTable_SocialMedia');
		}
		return $this->_dbTable;
	}
	
	public function AddFacebookPageId($restid,$appid){
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$status = false; 
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsmid'))
				   ->where('rsm_restid = ?',$restid);
			$result = $table->fetchRow($select);
			if($result->rsmid){
				$set = array('rsm_pageid'=>	$appid);
				$where = $db->quoteInto('rsm_restid = ?',$restid);
				
				$id = $this->getDbTable()->update($set,$where);
				Uss_Logger_FileLogger::info($id.'s');
			}else{
				$data = array(
					'rsm_restid'	=>	$restid,
					'rsm_pageid'	=>	$appid,
					'rsm_status'	=>	true
				);
				
				$id = $this->getDbTable()->insert($data);
				Uss_Logger_FileLogger::info($id);
			}
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditFacebookPageId($restid, $appid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false; 
			
			$set = array('rsm_pageid'=>	$appid);
			$where = $db->quoteInto('rsm_restid = ?',$restid);
			
			$id = $this->getDbTable()->update($set,$where);
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFacebookPageIdByRestId($restid)
	{
		try{
			$pageid = "";
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('rsm_pageid','rsmid'))
				   ->where('rsm_restid = ?',$restid);
			
			$resultset = $table->fetchAll($select);
			foreach ($resultset as $fbpageid){
				$pageid = $fbpageid->rsm_pageid;
			}
			return $pageid;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantInfoByFBPageid($pageid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('rsm'=>'mt.restaurant_socialmedia'),array('rsm_restid'))
				   ->join(array('rst'=>'mt.restaurant'),'rst.resid = rsm.rsm_restid',array('resrestaurant_name','resphone','resaddress'))
				   ->where('rsm.rsm_pageid = ?',$pageid);
			
			$resultset = $table->fetchRow($select);
			$resulArr = array();
			if($resultset){
				$resulArr['restaurantid'] = $resultset->rsm_restid;
				$resulArr['restaurantname'] = $resultset->resrestaurant_name;
				$resulArr['restaurantphone'] = $resultset->resphone;
				$resulArr['restaurantaddress'] = $resultset->resaddress; 
			}
			return $resulArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AddFacebookDealPageId($restid,$appid){
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$status = false; 
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsmid'))
				   ->where('rsm_restid = ?',$restid);
			$result = $table->fetchRow($select);
			if($result->rsmid){
				$set = array('rsm_deal_pageid'=>	$appid);
				$where = $db->quoteInto('rsm_restid = ?',$restid);
				
				$id = $this->getDbTable()->update($set,$where);
			}else{
				$data = array(
					'rsm_restid'	=>	$restid,
					'rsm_deal_pageid'	=>	$appid,
					'rsm_status'	=>	true
				);
				$id = $this->getDbTable()->insert($data);
			}
			
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditFacebookDealPageId($restid, $appid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false; 
			
			$set = array('rsm_deal_pageid'=>	$appid);
			$where = $db->quoteInto('rsm_restid = ?',$restid);
			
			$id = $this->getDbTable()->update($set,$where);
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFacebookDealPageIdByRestId($restid)
	{
		try{
			$pageid = "";
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('rsm_deal_pageid','rsmid'))
				   ->where('rsm_restid = ?',$restid);
			
			$resultset = $table->fetchAll($select);
			foreach ($resultset as $fbpageid){
				$pageid = $fbpageid->rsm_deal_pageid;
			}
			return $pageid;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantInfoByFBDealPageid($pageid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('rsm'=>'mt.restaurant_socialmedia'),array('rsm_restid'))
				   ->join(array('rst'=>'mt.restaurant'),'rst.resid = rsm.rsm_restid',array('resrestaurant_name','resphone','resaddress'))
				   ->where('rsm.rsm_deal_pageid = ?',$pageid);
			
			$resultset = $table->fetchRow($select);
			$resulArr = array();
			if($resultset){
				$resulArr['restaurantid'] = $resultset->rsm_restid;
				$resulArr['restaurantname'] = $resultset->resrestaurant_name;
				$resulArr['restaurantphone'] = $resultset->resphone;
				$resulArr['restaurantaddress'] = $resultset->resaddress; 
			}
			return $resulArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AddFacebookMenuPageId($restid,$appid){
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$status = false; 
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsmid'))
				   ->where('rsm_restid = ?',$restid);
			$result = $table->fetchRow($select);
			if($result->rsmid){
				$set = array('rsm_menu_pageid'=>	$appid);
				$where = $db->quoteInto('rsm_restid = ?',$restid);
				
				$id = $this->getDbTable()->update($set,$where);
			}else{
				$data = array(
					'rsm_restid'	=>	$restid,
					'rsm_menu_pageid'	=>	$appid,
					'rsm_status'	=>	true
				);
				$id = $this->getDbTable()->insert($data);
			}
			
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditFacebookMenuPageId($restid, $appid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false; 
			
			$set = array('rsm_menu_pageid'=>	$appid);
			$where = $db->quoteInto('rsm_restid = ?',$restid);
			
			$id = $this->getDbTable()->update($set,$where);
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFacebookMenuPageIdByRestId($restid)
	{
		try{
			$pageid = "";
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('rsm_menu_pageid','rsmid'))
				   ->where('rsm_restid = ?',$restid);
			
			$resultset = $table->fetchAll($select);
			foreach ($resultset as $fbpageid){
				$pageid = $fbpageid->rsm_menu_pageid;
			}
			return $pageid;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantInfoByFBMenuPageid($pageid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('rsm'=>'mt.restaurant_socialmedia'),array('rsm_restid'))
				   ->join(array('rst'=>'mt.restaurant'),'rst.resid = rsm.rsm_restid',array('resrestaurant_name','resphone','resaddress'))
				   ->where('rsm.rsm_menu_pageid = ?',$pageid);
			
			$resultset = $table->fetchRow($select);
			$resulArr = array();
			if($resultset){
				$resulArr['restaurantid'] = $resultset->rsm_restid;
				$resulArr['restaurantname'] = $resultset->resrestaurant_name;
				$resulArr['restaurantphone'] = $resultset->resphone;
				$resulArr['restaurantaddress'] = $resultset->resaddress; 
			}
			return $resulArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AddFacebookInquiryPageId($restid,$appid){
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$status = false; 
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsmid'))
				   ->where('rsm_restid = ?',$restid);
			$result = $table->fetchRow($select);
			if($result->rsmid){
				$set = array('rsm_inquiry_pageid'=>	$appid);
				$where = $db->quoteInto('rsm_restid = ?',$restid);
				
				$id = $this->getDbTable()->update($set,$where);
			}else{
				$data = array(
					'rsm_restid'	=>	$restid,
					'rsm_inquiry_pageid'	=>	$appid,
					'rsm_status'	=>	true
				);
				$id = $this->getDbTable()->insert($data);
			}
			
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditFacebookInquiryPageId($restid, $appid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false; 
			
			$set = array('rsm_inquiry_pageid'=>	$appid);
			$where = $db->quoteInto('rsm_restid = ?',$restid);
			
			$id = $this->getDbTable()->update($set,$where);
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFacebookInquiryPageIdByRestId($restid)
	{
		try{
			$pageid = "";
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('rsm_inquiry_pageid','rsmid'))
				   ->where('rsm_restid = ?',$restid);
			
			$resultset = $table->fetchAll($select);
			foreach ($resultset as $fbpageid){
				$pageid = $fbpageid->rsm_inquiry_pageid;
			}
			return $pageid;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantInfoByFBInquiryPageid($pageid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('rsm'=>'mt.restaurant_socialmedia'),array('rsm_restid'))
				   ->join(array('rst'=>'mt.restaurant'),'rst.resid = rsm.rsm_restid',array('resrestaurant_name','resphone','resaddress'))
				   ->where('rsm.rsm_inquiry_pageid = ?',$pageid);
			
			$resultset = $table->fetchRow($select);
			$resulArr = array();
			if($resultset){
				$resulArr['restaurantid'] = $resultset->rsm_restid;
				$resulArr['restaurantname'] = $resultset->resrestaurant_name;
				$resulArr['restaurantphone'] = $resultset->resphone;
				$resulArr['restaurantaddress'] = $resultset->resaddress; 
			}
			return $resulArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function AddFacebookBookingPageId($restid,$appid){
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$status = false; 
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('rsmid'))
				   ->where('rsm_restid = ?',$restid);
			$result = $table->fetchRow($select);
			if($result->rsmid){
				$set = array('rsm_booking_pageid'=>	$appid);
				$where = $db->quoteInto('rsm_restid = ?',$restid);
				
				$id = $this->getDbTable()->update($set,$where);
			}else{
				$data = array(
					'rsm_restid'	=>	$restid,
					'rsm_booking_pageid'	=>	$appid,
					'rsm_status'	=>	true
				);
				$id = $this->getDbTable()->insert($data);
			}
			
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function EditFacebookBookingPageId($restid, $appid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false; 
			
			$set = array('rsm_booking_pageid'=>	$appid);
			$where = $db->quoteInto('rsm_restid = ?',$restid);
			
			$id = $this->getDbTable()->update($set,$where);
			if($id){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFacebookBookingPageIdByRestId($restid)
	{
		try{
			$pageid = "";
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('rsm_booking_pageid','rsmid'))
				   ->where('rsm_restid = ?',$restid);
			
			$resultset = $table->fetchAll($select);
			foreach ($resultset as $fbpageid){
				$pageid = $fbpageid->rsm_booking_pageid;
			}
			return $pageid;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestaurantInfoByFBBookingPageid($pageid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('rsm'=>'mt.restaurant_socialmedia'),array('rsm_restid'))
				   ->join(array('rst'=>'mt.restaurant'),'rst.resid = rsm.rsm_restid',array('resrestaurant_name','resphone','resaddress'))
				   ->where('rsm.rsm_booking_pageid = ?',$pageid);
			
			$resultset = $table->fetchRow($select);
			$resulArr = array();
			if($resultset){
				$resulArr['restaurantid'] = $resultset->rsm_restid;
				$resulArr['restaurantname'] = $resultset->resrestaurant_name;
				$resulArr['restaurantphone'] = $resultset->resphone;
				$resulArr['restaurantaddress'] = $resultset->resaddress; 
			}
			return $resulArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
}