<?php
class SocialMedia_Model_SocialPostsMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}


	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('SocialMedia_Model_DbTable_SocialPosts');
		}
		return $this->_dbTable;
	}
	
	public function SavePosts(SocialMedia_Model_SocialPosts $restFBSpl)
	{
		try{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			$data = array(
					'rsp_image'					=>	$restFBSpl->getrsp_image(),
					'rsp_fk_business'			=>	$restFBSpl->getrsp_fk_business(),
					'rsp_description'			=>	$restFBSpl->getrsp_description(),
					'rsp_post_created_at'		=>	$restFBSpl->getrsp_post_created_at(),
					'rsp_post_created_by'		=>	$restFBSpl->getrsp_post_created_by(),
					'rsp_status'				=>	'T',
					'rsp_type'					=>	$restFBSpl->getrsp_type()
			);
			
			$spl_id = $this->getDbTable()->insert($data);
			$status = true;
			return $spl_id;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFbPosts(SocialMedia_Model_SocialPosts $restFBSpl,$perPage=null,$offSet=null)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array(
													'rsp_id',
													'rsp_image',
													'rsp_fk_business',
													'rsp_description',
													'rsp_post_created_at',
													'rsp_post_created_by',
													'rsp_status',
													'rsp_type'))
					->where('rsp_fk_business = ?',$restFBSpl->getrsp_fk_business())
					->where('rsp_type = ?','post')
					->where('rsp_status = ?',true)
					->order('rsp_id DESC');
			if($restFBSpl->getId()){
				$select->where('rsp_id = ?',$restFBSpl->getId());
			}
			if(($perPage!=null)&&($offSet!=null))
			{
				$select->limit($perPage,$offSet);
			}
			$result = $this->getDbTable()->fetchAll($select);
			return $result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetFbPostsByNetwork(SocialMedia_Model_SocialPosts $restFBSpl,$perPage=null,$offSet=null)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$twiSelect = $this->getDbTable()->select();
			$twiSelect->setIntegrityCheck(false);
			$twiSelect->from(array('mt.business_twi_posts'),array('rtwp_id','rtwp_post_twi_id','rtwp_post_id','rtwp_fk_business','rtwp_post_date','rtwp_post_time','rtwp_created_fb_by','rtwp_status','rtwp_created_fb_for','rtwp_sent_status'))
					  ->join(array('twiprof'=>'mt.business_twi_profile'),'btwp_id = rtwp_created_fb_by',array('btwp_id','btwp_fk_profile','btwp_user_id','btwp_user_access_token','btwp_user_access_token_secret','btwp_user_name','btwp_status'))
					  ->where('rtwp_fk_business = ?',$restFBSpl->getrsp_fk_business())
					  ->where('rtwp_sent_status = ?',100)
					  ->where('btwp_status = ?',true);
					  
			$fbSelect = $this->getDbTable()->select();
			$fbSelect->setIntegrityCheck(false);
			$fbSelect->from(array('mt.business_fb_posts'),array('rfbp_id','rfbp_post_fb_id','rfbp_post_id','rfbp_fk_business','rfbp_post_date','rfbp_post_time','rfbp_created_fb_by','rfbp_status','rfbp_created_fb_for','rfbp_sent_status'))
					  ->join(array('fbprofpage'=>'mt.business_fb_profile_pages'),'bfbpp_id = rfbp_created_fb_for',array('bfbpp_id','bfbpp_profile_id','bfbpp_page_id','bfbpp_page_name','bfbpp_page_category','bfbpp_page_access','bfbpp_page_roles','bfbpp_page_status'))
					  ->join(array('fbprof'=>'mt.business_fb_profile'),'bfbp_id = rfbp_created_fb_by',array('bfbp_id','bfbp_fk_profile','bfbp_user_id','bfbp_user_access_token','bfbp_user_name','bfbp_user_page','bfbp_status','bfbp_created','bfbp_updated'))
					  ->where('rfbp_fk_business = ?',$restFBSpl->getrsp_fk_business())
					  ->where('rfbp_sent_status = ?',100)
					  ->where('bfbp_status = ?',true);
					  
			$inSelect = $this->getDbTable()->select();
			$inSelect->setIntegrityCheck(false);
			$inSelect->from(array('mt.business_link_posts'),array('rinp_id','rinp_post_in_id','rinp_post_id','rinp_fk_business','rinp_post_date','rinp_post_time','rinp_created_by','rinp_status','rinp_created_for','rinp_sent_status'))
					  ->joinLeft(array('inprofpage'=>'mt.business_link_profile_pages'),'binpp_id = rinp_created_for',array('binpp_id','binpp_profile_id','binpp_page_id','binpp_page_name','binpp_page_category','binpp_page_access','binpp_page_roles','binpp_page_status'))
					  ->joinLeft(array('inprof'=>'mt.business_link_profile'),'binp_id = rinp_created_by',array('binp_id','binp_fk_profile','binp_user_id','binp_user_access_token','binp_user_access_token_secret','binp_user_name','binp_user_page','binp_status','binp_created','binp_updated'))
					  ->where('rinp_fk_business = ?',$restFBSpl->getrsp_fk_business())
					  ->where('rinp_sent_status = ?',100)
					  ->where('binp_status = ?',true);
			$select->from($this->getDbTable(),array('rsp_id','rsp_image','rsp_type','rsp_fk_business','rsp_description','rsp_post_created_at','rsp_post_created_by','rsp_status'))
					->joinLeft($fbSelect,'rfbp_post_id = rsp_id',array('rfbp_post_fb_id','rfbp_post_id','rfbp_fk_business','rfbp_post_date','rfbp_post_time','rfbp_created_fb_by','rfbp_status','rfbp_created_fb_for','bfbpp_id','bfbpp_profile_id','bfbpp_page_id','bfbpp_page_name','bfbpp_page_category','bfbpp_page_access','bfbpp_page_roles','bfbpp_page_status','bfbp_id','bfbp_fk_profile','bfbp_user_id','bfbp_user_access_token','bfbp_user_name','bfbp_user_page','bfbp_status','bfbp_created','bfbp_updated'))
					->joinLeft($twiSelect,'rtwp_post_id = rsp_id',array('rtwp_id','rtwp_post_twi_id','rtwp_post_id','rtwp_fk_business','rtwp_post_date','rtwp_post_time','rtwp_created_fb_by','rtwp_status','rtwp_created_fb_for','btwp_id','btwp_fk_profile','btwp_user_id','btwp_user_access_token','btwp_user_access_token_secret','btwp_user_name','btwp_status'))
					->joinLeft($inSelect,'rinp_post_id = rsp_id',array('rinp_id','rinp_post_in_id','rinp_post_id','rinp_fk_business','rinp_post_date','rinp_post_time','rinp_created_by','rinp_status','rinp_created_for','binp_id','binp_fk_profile','binp_user_id','binp_user_access_token','binp_user_access_token_secret','binp_user_name','binp_status'))
					->where('rsp_fk_business = ?',$restFBSpl->getrsp_fk_business())
					->where('rsp_status = ?',true)
					->where('rsp_type = ?','post')
					->order('rsp_id DESC');
			if($restFBSpl->getId()){
				$select->where('rsp_id = ?',$restFBSpl->getId());
			}
			if(($perPage!=null)&&($offSet!=null))
			{
				$select->limit($perPage,$offSet);
			}
			$result = $this->getDbTable()->fetchAll($select);
			return $result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetSchPosts(SocialMedia_Model_SocialPosts $restFBSpl)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array(
													'rsp_id',
													'rsp_image',
													'rsp_fk_business',
													'rsp_description',
													'rsp_post_created_at',
													'rsp_post_created_by',
													'rsp_status',
													'rsp_type'))
					->where('rsp_fk_business = ?',$restFBSpl->getrsp_fk_business())
					->where('rsp_type = ?','sch')
					->where('rsp_status = ?',true)
					->order('rsp_id DESC');
			if($restFBSpl->getId()){
				$select->where('rsp_id = ?',$restFBSpl->getId());
			}
			$result = $this->getDbTable()->fetchAll($select);
			return $result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetSchPostsByNetwork(SocialMedia_Model_SocialPosts $restFBSpl)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$twiSelect = $this->getDbTable()->select();
			$twiSelect->setIntegrityCheck(false);
			$twiSelect->from(array('mt.business_twi_posts'),array('rtwp_id','rtwp_post_twi_id','rtwp_post_id','rtwp_fk_business','rtwp_post_date','rtwp_post_time','rtwp_created_fb_by','rtwp_status','rtwp_created_fb_for','rtwp_sent_status'))
					  ->join(array('twiprof'=>'mt.business_twi_profile'),'btwp_id = rtwp_created_fb_by',array('btwp_id','btwp_fk_profile','btwp_user_id','btwp_user_access_token','btwp_user_access_token_secret','btwp_user_name','btwp_status'))
					  ->where('rtwp_fk_business = ?',$restFBSpl->getrsp_fk_business())
					  ->where('rtwp_sent_status = ?',101)
					  ->where('btwp_status = ?',true);
					  
			$fbSelect = $this->getDbTable()->select();
			$fbSelect->setIntegrityCheck(false);
			$fbSelect->from(array('mt.business_fb_posts'),array('rfbp_id','rfbp_post_fb_id','rfbp_post_id','rfbp_fk_business','rfbp_post_date','rfbp_post_time','rfbp_created_fb_by','rfbp_status','rfbp_created_fb_for','rfbp_sent_status'))
					  ->join(array('fbprofpage'=>'mt.business_fb_profile_pages'),'bfbpp_id = rfbp_created_fb_for',array('bfbpp_id','bfbpp_profile_id','bfbpp_page_id','bfbpp_page_name','bfbpp_page_category','bfbpp_page_access','bfbpp_page_roles','bfbpp_page_status'))
					  ->join(array('fbprof'=>'mt.business_fb_profile'),'bfbp_id = rfbp_created_fb_by',array('bfbp_id','bfbp_fk_profile','bfbp_user_id','bfbp_user_access_token','bfbp_user_name','bfbp_user_page','bfbp_status','bfbp_created','bfbp_updated'))
					  ->where('rfbp_fk_business = ?',$restFBSpl->getrsp_fk_business())
					  ->where('rfbp_sent_status = ?',101)
					  ->where('bfbp_status = ?',true);
					  
			$select->from($this->getDbTable(),array('rsp_id','rsp_image','rsp_type','rsp_fk_business','rsp_description','rsp_post_created_at','rsp_post_created_by','rsp_status'))
					->joinLeft($fbSelect,'rfbp_post_id = rsp_id',array('rfbp_post_fb_id','rfbp_post_id','rfbp_fk_business','rfbp_post_date','rfbp_post_time','rfbp_created_fb_by','rfbp_status','rfbp_created_fb_for','bfbpp_id','bfbpp_profile_id','bfbpp_page_id','bfbpp_page_name','bfbpp_page_category','bfbpp_page_access','bfbpp_page_roles','bfbpp_page_status','bfbp_id','bfbp_fk_profile','bfbp_user_id','bfbp_user_access_token','bfbp_user_name','bfbp_user_page','bfbp_status','bfbp_created','bfbp_updated'))
					->joinLeft($twiSelect,'rtwp_post_id = rsp_id',array('rtwp_id','rtwp_post_twi_id','rtwp_post_id','rtwp_fk_business','rtwp_post_date','rtwp_post_time','rtwp_created_fb_by','rtwp_status','rtwp_created_fb_for','btwp_id','btwp_fk_profile','btwp_user_id','btwp_user_access_token','btwp_user_access_token_secret','btwp_user_name','btwp_status'))
					->where('rsp_fk_business = ?',$restFBSpl->getrsp_fk_business())
					->where('rsp_status = ?',true)
					->where('rsp_type = ?','sch')
					->order('rsp_id DESC');
			if($restFBSpl->getId()){
				$select->where('rsp_id = ?',$restFBSpl->getId());
			}
			$result = $this->getDbTable()->fetchAll($select);
			return $result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}