<?php
class User_Model_AdminPatronDataMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('User_Model_DbTable_AdminUser');
		}
		return $this->_dbTable;
	}
	
	public function AddAdminUser(User_Model_AdminPatron $adminuser)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$userMapper = new User_Model_ClientDataMapper();
		try{
			$db->beginTransaction();
				
			$userId = $userMapper->save($adminuser);
				
			$adminuser->setUserid($userId);
			
			$table = $this->getDbTable();
			$data = array(
					'adufk_user'		=>	$adminuser->getUserId(),
					'adufirst_name'		=>	$adminuser->getadu_firstname(),
					'adulast_name'		=>	$adminuser->getadu_lastname(),
					'adufk_comapnyid'	=>	$adminuser->getadu_company_id(),
					'adu_status'		=>	$adminuser->getadu_status(),
					'aducreateddatetime'=>	date('Y-m-d H:i:s')
			);
			$status = $table->insert($data);
			$db->commit();
			if($status){
				return true;
			}else{
				return false;
			}
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function update(User_Model_AdminPatron $adminuser)
	{
		
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();		
			$userMapper = new User_Model_ClientDataMapper();
			try{
				$db->beginTransaction();
				
				$userMapper->upadteAdminUserRole($adminuser->getUserId(), $adminuser->getRole());
				
				$set = array(
						'adufk_user'		=>	$adminuser->getUserId(),
						'adufirst_name'		=>	$adminuser->getadu_firstname(),
						'adulast_name'		=>	$adminuser->getadu_lastname(),
						'adufk_comapnyid'	=>	$adminuser->getadu_company_id()
					);
				$where = array('adufk_user = ?' => $adminuser->getUserId());	
				$rows_affected = $this->getDbTable()->update($set,$where);
				$db->commit();
				$status = true;
				return $status;
			}catch(Exception $ex){
				$db->rollBack();
				throw new Exception($ex->getMessage()) ;	
			}
	}
	
	public function ManageAdminUsers($data)
	{
		try{
			$userType = $data['Usertype'];
			$companyid = $data['companyid'];
			
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('adu'=>'mt.admin_user'),array('aduid','adufirst_name','adulast_name','adu_status','adufk_user'))
				   ->join(array('usr'=>'mt.user'),'usr.usrid = adu.adufk_user',array('usremail','usruser_status_id'))
				   ->join(array('usrsts'=>'mt.userstatus_bd'),'usrsts.id = usr.usruser_status_id',array('code as statuscode','description as statusdesc'))
				   ->join(array('com'=>'mt.company'),'com.com_id = adu.adufk_comapnyid',array('com_companyname as company'))
				   ->order('adu.aduid');
			if($userType == "ADU" && $companyid != 1){
				$select->where('adu.adufk_comapnyid = ? ', $companyid);
			}
			
			$result = $table->fetchAll($select);
			return $result;			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getAdminUserDetailsById($userid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('adu'=>'mt.admin_user'),array('aduid','adufk_user','adufirst_name','adulast_name','adu_status','adufk_comapnyid'))
					->join(array('usr'=>'mt.user'),'usr.usrid = adu.adufk_user',array('usremail','usrrole_id'))
				   ->where('adu.adufk_user = ?',$userid);
			
			$result = $table->fetchRow($select);
			
			$roleObj = new Application_Model_Role();
			$roleObj->setCompanyId($result['adufk_comapnyid']);
			$roleObj->setStatus('TRUE');
			
			$mapper = new Application_Model_RoleDataMapper();
			$roleList = $mapper->getRolesByCompany($roleObj);
				    	
			$adminuser = new User_Model_AdminPatron();
			$adminuser->setEmail($result->usremail)
					  ->setRole($result->usrrole_id)
					  ->setadu_firstname($result->adufirst_name)
					  ->setadu_lastname($result->adulast_name)
					  ->setadu_company_id($result->adufk_comapnyid)
					  ->setId($result->aduid)
					  ->setUserId($result->adufk_user)
					  ->setRolebd($roleList);
					  	
			return $adminuser;			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
}