<?php

class User_Model_ClientDataMapper
{
	protected $_dbTable;
	
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}	
	
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('User_Model_DbTable_Client');
		}
		return $this->_dbTable;
	}
		
	public function save(User_Model_Client $user)
	{
		try{				
			$length = 8;
			$characters = '0123456789abcdefghijklmnopqrstuvwxyz';
			$randomdata = "";
			$offset = strlen($characters) - 1;
			for ($p = 0; $p < $length; $p++) {
				$randomdata .= $characters[mt_rand(0, $offset)];
			}
			$passSha = sha1($user->getPassword().$randomdata);
			$update = date('Y-m-d H:i:s');
			$user= array(
			'usremail'           => $user->getEmail(),
			'usrpassword'        => $passSha,
			'usrusertype_id'	 => $user->getUsertypeid(),
			'usrrole_id'		 => $user->getRole(),
			'usrregistered_date' => $user->getRegistereddate(),
			'usruser_status_id'	 => $user->getUserStatusid(),
			'usrpassphrase' 	 => $randomdata,
			'usrcreateddatetime' => $update,
			'usripaddress'		 =>	$_SERVER["REMOTE_ADDR"]
			);	
				
			$user_id = $this->getDbTable()->insert($user);		
			return $user_id;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}		
	}		
	
	public function getLoginProfile($data)
	{	
		try{
		/* Get Usertype from Usertype BaseData */
			$user_id       = $data->usrid;
			$usertype_Id   = $data->usrusertype_id;
			$email         = $data->usremail;
			$signupdate    = null;
			$lastlogindate = null;
			/* Updating Users Last Login Date */
			if($user_id){
				$this->UpdateUserLoggedInDate($user_id);
			}
					
			if($data->usrregistered_date){
				$signupdate  = $data->usrregistered_date;	
			}
			
			if($data->usrlast_login_date){
				$lastlogindate = $data->usrlast_login_date;
			}
			
			$userType = $this->getUsertype($usertype_Id);
			switch($userType->code){
				case 'CUS':
						$cusMapper = new User_Model_GuestDataMapper();
						$table  = $cusMapper->getDbTable();
						$select = $table->select();
						$select->from($table,array('cussalution','cusfirst_name','cuslast_name','custimezone','cusphone','cusmobile','cuscity_id','cusstate_id','cusregion_id'))
							   ->where('cusfk_user = ?',$user_id);
					    $row = $table->fetchRow($select);
						$result = array('Email'      	=> $email,
										'Salution'   	=> $row->cussalution,
										'Firstname'  	=> $row->cusfirst_name,
										'LastName'   	=> $row->cuslast_name,
										'User_Id'    	=> $user_id,
										'Usertype'   	=> $userType->code,
										'Timezone'   	=> $row->custimezone,
										'State_Id'		=> $row->cusstate_id,
										'City_Id'    	=> $row->cuscity_id,
										'Region_Id'		=> $row->cusregion_id,
										'Phone'      	=> $row->cusphone,
										'cusmobile'  	=> $row->cusmobile,
										'companyid'		=> '',
										'SignUpdate'    => $signupdate,
									    'LastLoginDate' => $lastlogindate);
								    
						return $result;
						
					break;
					
				case 'RSO':
	
						$rsoMapper = new User_Model_ManagerDataMapper();
						$table 	   = $rsoMapper->getDbTable();
						$select    = $table->select();
						$select->from($table,array('rsofk_salution','rsofirst_name','rsolast_name','rsophone','rsostateid','rsocityid','rsoregionid','rso_companyid','presid','defaultview'))
							   ->where('rsofk_user = ?',$user_id) ;   
						$row       = $table->fetchRow($select);
						
						if ($row->presid == null){
							$rsoMapper = new FirmManagement_Model_FirmDataMapper();
							$table 	   = $rsoMapper->getDbTable();
							$select    = $table->select();
							$select->from(array('rest'=>'mt.restaurant'),array('resid','resrestaurant_name','restcapacity','resreservation_system','resstatus','resschestatus','resfloorplanstatus','resphonenotify','resnotification','respaymentstatus','resphonenotify'))
							->where('resfk_user = ?',$user_id) ;
							$newrow = $table->fetchRow($select);
							$presid = $newrow->resid;
							$mapper = new User_Model_ManagerDataMapper;
							$status = $mapper->addPresid($presid,$user_id);
						} else {
							$presid = $row->presid;
                                                        $rsoMapper = new FirmManagement_Model_FirmDataMapper();
							$table 	   = $rsoMapper->getDbTable();
							$select    = $table->select();
							$select->from(array('rest'=>'mt.restaurant'),array('resid','resrestaurant_name','restcapacity','resreservation_system','resstatus','resschestatus','resfloorplanstatus','resphonenotify','resnotification','respaymentstatus','resphonenotify'))
							->where('resid = ?',$presid) ;
							$newrow = $table->fetchRow($select);
						}
						$restNameByOwnObj = new FirmManagement_Model_FirmNamesByOwnerId();
						$restNameByOwnObj->setRestOwnerId($user_id);
						$restMapper = new FirmManagement_Model_FirmDataMapper();
						$restList   = $restMapper->getRestaurantNamesByOwnerId($restNameByOwnObj);
						
						/* Reterieve Restaurant Owner Permission's */
						
						$permTypMapp = new Application_Model_PermissionsTypeDataMapper();
						$Permissions = $permTypMapp->getRestUserMenuBD();
						
						$result = array('Email'      	=> $email,
										'User_Id'   	=> $user_id,
										'Usertype'  	=> $userType->code,
										'Salution'  	=> $row->rsofk_salution,
										'Firstname' 	=> $row->rsofirst_name,
										'LastName'  	=> $row->rsolast_name,
										'State_Id'		=> $row->rsostateid,
										'City_Id'    	=> $row->rsocityid,
										'Region_Id'		=> $row->rsoregionid,									
										'SignUpdate'    => $signupdate,
									    'LastLoginDate' => $lastlogindate,
										'Phone'      	=> $row->rsophone,
										'Permissions'   => $Permissions,
										'companyid'		=> $row->rso_companyid,
										'RestId' 		=> $presid,
										'DefaultView'	=> $row->defaultview,
										'restList'		=> $restList,
                                                                                'schStatus'     =>  $newrow->resschestatus,
                                                                                'flrStatus'     =>  $newrow->resfloorplanstatus);														
											
						 return $result;						
					
					break;	
					
				case 'RSU' :
						 $rsuMapper = new User_Model_PatronDataMapper();
						 $table     = $rsuMapper->getDbTable();
						 $select    = $table->select();
						 $select->setIntegrityCheck(false);
						 
						 $select->from(array('rsu'=>'mt.restaurant_user'),array('rsusalution','rsufirst_name','rsulast_name','rsufk_restaurant','rsuphone','rsup_resid','rsudefaultview'))
						 		->join(array('rest'=>'mt.restaurant'),'rest.resid = rsu.rsufk_restaurant',array('resid','resfk_user','res_companyid'))
						 		->join(array('usr'=>'mt.user'),'usr.usrid = rsu.rsufk_user',array('usrrole_id'))
						 		->where('rsu.rsufk_user = ?', $user_id);
	
						 $row = $table->fetchRow($select); 		
						 $role_id = 0;
						 $role_id = $row->usrrole_id;
						 
						 /* Reterieve Perimission's by role id */				 
						if ($row->rsup_resid == null){				
							$presid = $row->resid;
							$db = Zend_Db_Table::getDefaultAdapter();				
							$set = array('rsup_resid'  => $presid
							);
							$where = $db->quoteInto('rsufk_restaurant = ?',$presid);
							$rows_affected = $rsuMapper->getDbTable()->update($set,$where);
						} else {
							$presid = $row->rsup_resid;
						}
						
						 $rolesPermMapper = new Application_Model_RolePermissionMapDataMapper();
						 $permRowSet = $rolesPermMapper->getPermissionByRole($role_id);						 					
						 
						$restNameByOwnObj = new FirmManagement_Model_FirmNamesByOwnerId();
						$restNameByOwnObj->setRestId($presid);
						$restMapper = new FirmManagement_Model_FirmDataMapper();
						$restList   = $restMapper->getRestaurantNamesByOwnerId($restNameByOwnObj);
						 
						 $result = array('User_Id'  	=> $user_id,
										'Usertype'  	=> $userType->code,		
						 				'Salution'  	=> $row->rsusalution,							
										'Firstname' 	=> $row->rsufirst_name,
										'LastName'  	=> $row->rsulast_name,
										'RestId'    	=> $row->resid,
						 				'RestOwnId' 	=> $row->resfk_user,
										'SignUpdate'    => $signupdate,
									    'LastLoginDate' => $lastlogindate,
						 				'Permissions'   => $permRowSet,
						 				'Email'      	=> $email,
						 				'Phone'      	=> $row->rsuphone,
						 				'companyid'		=> $row->res_companyid,
						 				'DefaultView' 	=> $row->rsudefaultview,
										'restList'		=> $restList);
						 
						 return $result;
						 
					break;
					
				case 'SRU' :
						 $rsuMapper = new User_Model_PatronDataMapper();
						 $table     = $rsuMapper->getDbTable();
						 $select    = $table->select();
						 $select->setIntegrityCheck(false);
						 
						 $select->from(array('rsu'=>'mt.restaurant_user'),array('rsusalution','rsufirst_name','rsulast_name','rsufk_restaurant','rsuphone','rsup_resid','rsudefaultview'))
						 		->join(array('usr'=>'mt.user'),'usr.usrid = rsu.rsufk_user',array('usrrole_id'))
						 		->join(array('sru'=>'mt.restaurant_super_user'),'rsu_rsu_fk_user = rsufk_user',array('array_agg(rsu_rsu_restaurant) as resIdArr','array_agg(resrestaurant_name) as resNameArr'))
						 		->join(array('rest'=>'mt.restaurant'),'rest.resid = sru.rsu_rsu_restaurant',array('resfk_user','res_companyid'))
						 		->where('rsu.rsufk_user = ?', $user_id)
								->where('sru.rsu_rsu_status = ?',true )
						 		->group(array('usrrole_id','rsufirst_name','rsulast_name','rsufk_restaurant','rsuphone','rsup_resid','rsudefaultview','resfk_user','res_companyid','rsusalution'));
	
						 $row = $table->fetchRow($select); 		
						 $role_id = 0;
						 $role_id = $row->usrrole_id;
						 
								 
						if ($row->rsup_resid == null){				
							$presid = $row->rsufk_restaurant;
							$db = Zend_Db_Table::getDefaultAdapter();				
							$set = array('rsup_resid'  => $presid
							);
							$where = $db->quoteInto('rsufk_restaurant = ?',$presid);
							$rows_affected = $rsuMapper->getDbTable()->update($set,$where);
						} else {
							$presid = $row->rsup_resid;
						}
						 /* Reterieve Perimission's by role id */		
						 $rolesPermMapper = new Application_Model_RolePermissionMapDataMapper();
						 $permRowSet = $rolesPermMapper->getPermissionByRole($role_id);						 					
						 
						$restNameByOwnObj = new FirmManagement_Model_FirmNamesByOwnerId();
						$restNameByOwnObj->setRestId($presid);
						$restMapper = new FirmManagement_Model_FirmDataMapper();
//						$restList   = $restMapper->getRestaurantNamesByOwnerId($restNameByOwnObj);
						$resIdArr = explode(',',substr($row->resIdArr,1,-1));
						$resNameArr = explode(',',substr($row->resNameArr,1,-1));
						$restNames = array();
						$restNames[] = array('key'=>'','value'=>'Select Restaurant');
						for($i = 0; $i<count($resNameArr);$i++){
							if(strstr($resNameArr[$i],'"')){
								$val = substr($resNameArr[$i],1,-1);
							}else{
								$val = $resNameArr[$i];
							}
							$restNames[] = array('key'=>$resIdArr[$i],'value'=>$val);
						}
						 $result = array('User_Id'  	=> $user_id,
										'Usertype'  	=> $userType->code,	
						 				'Salution'  	=> $row->rsusalution,								
										'Firstname' 	=> $row->rsufirst_name,
										'LastName'  	=> $row->rsulast_name,
										'RestId'    	=> $row->rsufk_restaurant,
						 				'RestOwnId' 	=> $row->resfk_user,
										'SignUpdate'    => $signupdate,
									    'LastLoginDate' => $lastlogindate,
						 				'Permissions'   => $permRowSet,
						 				'Email'      	=> $email,
						 				'Phone'      	=> $row->rsuphone,
						 				'RestId' 		=> $presid,
						 				'companyid'		=> $row->res_companyid,
						 				'DefaultView' 	=> $row->rsudefaultview,
										'restList'		=> $restNames);
						 
						 return $result;
						 
					break;	
					
				case 'ADM' :
					
						$adminPermMapper = new Application_Model_AdminPermissionsTypeDataMapper();
						$permRowSet = $adminPermMapper->getAdminMenuBD();
						$result = array('User_Id'  		=> $user_id,
										'Usertype' 		=> $userType->code,
										'Permissions'   => $permRowSet,
										'companyid'		=> 1,
										'restownerId'	=> "",
										'RestId'  => ""
									);
						return $result; 
						
					break;	
				
				case 'ADU' :
						$aduMapper = new User_Model_AdminPatronDataMapper();
						$table     = $aduMapper->getDbTable();
						$select    = $table->select();
						$select->setIntegrityCheck(false);
						 
						$select->from(array('adu'=>'mt.admin_user'),array('adufirst_name','adulast_name','adufk_comapnyid','aduphone'))
						 	   ->join(array('com'=>'mt.company'),'com.com_id = adu.adufk_comapnyid',array('com_companyname'))
						 	   ->join(array('usr'=>'mt.user'),'usr.usrid = adu.adufk_user',array('usrrole_id'))
						 	   ->where('adu.adufk_user = ?', $user_id);
	
						 $row = $table->fetchRow($select); 		
						 $role_id = "";
						 $role_id = $row->usrrole_id;
						 $companyid = $row->adufk_comapnyid;
						 
						 /* Reterieve Perimission's by role id */				 
						 if($role_id == 1){
						 	$adminPermMapper = new Application_Model_AdminPermissionsTypeDataMapper();
						 	$permRowSet = $adminPermMapper->getAdminMenuBD();
						 }else{
						 	$rolesPermMapper = new Application_Model_AdminRolePermissionMapDataMapper();
						 	$permRowSet = $rolesPermMapper->getAdminUserPermissionByRole($role_id);
						 }						 					
						 
						$result = array('User_Id'  		=> $user_id,
										'Usertype' 		=> $userType->code,
										'Firstname'		=> $row->adufirst_name,
										'LastName'  	=> $row->adulast_name,
										'Permissions'   => $permRowSet,
										'companyid'		=> $companyid,
										'restownerId'	=> ""			
									);
						return $result; 
						
					break;	
			} 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
		
	}	
	
	public function getUsertype($usertype_id)
	{
		$usertype = array();
		$usertypeMapper = new Application_Model_UsertypeDataMapper();
		$usertype = $usertypeMapper->getUsertypeBD();
		
		foreach($usertype as $type){
			if($usertype_id == $type->id){
				return $type;
			}
		}
		
	}	  	

	public function update(User_Model_Client $user)
	{
		$update = date('Y-m-d H:i:s');
		$set = array(
			'usremail'=>$user->getEmail(),
			'usrrole_id'		=>  $user->getRestUserRoleId(),
			'usruser_status_id'	=>	$user->getUserStatusid(),
			'usrrole_id'		=>	$user->getRestUserRoleId(),
			'usrupdateddatetime'=>  $update,
			'usrusertype_id'	=>	$user->getUsertypeid(),
		
		
		);
		if($user->getPassword()){
			$length = 8;
			$characters = '0123456789abcdefghijklmnopqrstuvwxyz';
			$randomdata = "";
			for ($p = 0; $p < $length; $p++) {
				$randomdata .= $characters[mt_rand(0, strlen($characters))];
			}
			$passSha = sha1($user->getPassword().$randomdata);			
			
			$set['usrpassword']	= $passSha;
			$set['usrpassphrase'] = $randomdata;
		}	
		$where = array('usrid = ?'=> $user->getId());
		$rows_affected = $this->getDbTable()->update($set,$where);
		return $rows_affected;
	}
	
	public function updatePassword(User_Model_Client $user, $userid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			if($user->getPassPhrase()){
				$result = $db->fetchOne(
	    		"SELECT usrid FROM mt.user WHERE usrpassphrase = :title",
	    			array('title' => $user->getPassPhrase())
				);
				if($result){
					$length = 8;
					$characters = '0123456789abcdefghijklmnopqrstuvwxyz';
					$randomdata = "";
					for ($p = 0; $p < $length; $p++) {
						$randomdata .= $characters[mt_rand(0, strlen($characters))];
					}
					$passSha = sha1($user->getPassword().$randomdata);
					$update = date('Y-m-d H:i:s');
					$usertabledata = array('usrpassword'        => $passSha,'usrpassphrase' => $randomdata,'usrupdateddatetime'=>$update);
					$valid = $this->getDbTable()->update($usertabledata, array('usrid = ?' => $result));
					
					$ValidPwd = true;
//					if($valid){
//						$set = array('usrpassphrase' =>	'');
//						$where = array('usrid = ?'=> $result);
//						$rows_affected = $this->getDbTable()->update($set,$where);
//					}
					
				}else{
					$ValidPwd = false;
				}
				return $ValidPwd;
			}else{
				$result = $db->fetchRow(
	    		"SELECT usrpassword,usrpassphrase FROM mt.user WHERE usrid = :title",
	    			array('title' => $userid->getUserId())
				);
				$usr_password=sha1($user->getOldpassword().$result['usrpassphrase']);
				
				$ValidPwd = true;
				if($result['usrpassword'] == $usr_password){
					$length = 8;
					$characters = '0123456789abcdefghijklmnopqrstuvwxyz';
					$randomdata = "";
					for ($p = 0; $p < $length; $p++) {
						$randomdata .= $characters[mt_rand(0, strlen($characters))];
					}
					$passSha = sha1($user->getPassword().$randomdata);
					$update = date('Y-m-d H:i:s');
					$usertabledata = array('usrpassword'        => $passSha,'usrpassphrase' => $randomdata,'usrupdateddatetime'=>$update);
					$this->getDbTable()->update($usertabledata, array('usrid = ?' => $userid->getUserId()));
					$ValidPwd = true;
				}
				else{
				 $ValidPwd = false;	     
				}
				return $ValidPwd;
			}			
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getEmailStatus(User_Model_Signin $email)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$result = $db->fetchOne("select count(usremail) from mt.user where usremail= :title",
							array('title' => $email->getEmailAddress()));
			if($result == 1)
			{
				$status = true; 
			}else{
				$status = false;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateUserLoggedInDate($userid)
	{
		$date  = date('Y-m-d H:i:s');
		$set   = array('usrlast_login_date'=>$date);
		$where = array('usrid = ?'=>$userid);		
		$rows_affected = $this->getDbTable()->update($set,$where);
		
		if($rows_affected){
			return true;
		}else{
			return false;
		}
	}
	
	public function getUsertypeidByemail($email)
	{
		try{
			$table = $this->getDbTable();
			$select    = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('usr'=> 'mt.user'),array('usrusertype_id','usrid'))
				   ->join(array('utb'=>'mt.usertype_bd'),'utb.id = usr.usrusertype_id',array('code'))
				   ->where('usremail = ?',$email);
				   
			$userresult = $table->fetchRow($select);
			
			if($userresult != NULL){
				switch($userresult->code){
					case 'CUS':
							$cusMapper = new User_Model_GuestDataMapper();
							$table  = $cusMapper->getDbTable();
							$select = $table->select();
							$select->from($table,array('cusfirst_name','cuslast_name'))
								   ->where('cusfk_user = ?',$userresult->usrid);
						    $row = $table->fetchRow($select);
							$result = array('Email'      	=> $email,
											'Firstname'  	=> $row->cusfirst_name,
											'LastName'   	=> $row->cuslast_name,
											'User_Id'  		=> $userresult->usrid,
											);
							return $result;
						break;
						
					case 'RSO':
		
							$rsoMapper = new User_Model_ManagerDataMapper();
							$table 	   = $rsoMapper->getDbTable();
							$select    = $table->select();
							$select->from($table,array('rsofirst_name','rsolast_name'))
								   ->where('rsofk_user = ?',$userresult->usrid) ;   
							$row       = $table->fetchRow($select);				
							
							$result = array('Email'      	=> $email,
											'Firstname' 	=> $row->rsofirst_name,
											'LastName'  	=> $row->rsolast_name,
											'User_Id'  		=> $userresult->usrid,									
										   );	
							 return $result;
						break;	
						
					case 'RSU' :
							 $rsuMapper = new User_Model_PatronDataMapper();
							 $table     = $rsuMapper->getDbTable();
							 $select    = $table->select();
							 $select->setIntegrityCheck(false);
							 
							 $select->from(array('rsu'=>'mt.restaurant_user'),array('rsufirst_name','rsulast_name','rsufk_restaurant'))
							 		->join(array('rest'=>'mt.restaurant'),'rest.resid = rsu.rsufk_restaurant',array('resid','resfk_user'))
							 		->where('rsu.rsufk_user = ?', $userresult->usrid);
		
							 $row = $table->fetchRow($select); 		
		
							 $result = array('Firstname' => $row->rsufirst_name,
											 'LastName'  => $row->rsulast_name,
							 				 'User_Id'   => $userresult->usrid,
											);
							 return $result;
						break;
					case 'SRU' :
							 $rsuMapper = new User_Model_PatronDataMapper();
							 $table     = $rsuMapper->getDbTable();
							 $select    = $table->select();
							 $select->setIntegrityCheck(false);
							 
							 $select->from(array('rsu'=>'mt.restaurant_user'),array('rsufirst_name','rsulast_name','rsufk_restaurant'))
							 		->join(array('rest'=>'mt.restaurant'),'rest.resid = rsu.rsufk_restaurant',array('resid','resfk_user'))
							 		->where('rsu.rsufk_user = ?', $userresult->usrid);
		
							 $row = $table->fetchRow($select); 		
		
							 $result = array('Firstname' => $row->rsufirst_name,
											 'LastName'  => $row->rsulast_name,
							 				 'User_Id'   => $userresult->usrid,
											);
							 return $result;
						break;	
				}
			
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getUsertypeidByUserId($userId)
	{
		try{
			$table = $this->getDbTable();
			$select    = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('usr'=> 'mt.user'),array('usrusertype_id','usrid'))
			->join(array('utb'=>'mt.usertype_bd'),'utb.id = usr.usrusertype_id',array('code'))
			->where('usrid = ?',$userId);
				
			$userresult = $table->fetchRow($select);
				
			if($userresult != NULL){
				switch($userresult->code){
					case 'CUS':
						$cusMapper = new User_Model_GuestDataMapper();
						$table  = $cusMapper->getDbTable();
						$select = $table->select();
						$select->from($table,array('cusfirst_name','cuslast_name'))
						->where('cusfk_user = ?',$userresult->usrid);
						$row = $table->fetchRow($select);
						$result = array(
								'Firstname'  	=> $row->cusfirst_name,
								'LastName'   	=> $row->cuslast_name,
								'User_Id'  		=> $userresult->usrid,
								'Type'			=> $userresult->code
						);
						return $result;
						break;
	
					case 'RSO':
	
						$rsoMapper = new User_Model_ManagerDataMapper();
						$table 	   = $rsoMapper->getDbTable();
						$select    = $table->select();
						$select->from($table,array('rsofirst_name','rsolast_name'))
						->where('rsofk_user = ?',$userresult->usrid) ;
						$row       = $table->fetchRow($select);
							
						$result = array(
								'Firstname' 	=> $row->rsofirst_name,
								'LastName'  	=> $row->rsolast_name,
								'User_Id'  		=> $userresult->usrid,
								'Type'			=> $userresult->code
						);
						return $result;
						break;
	
					case 'RSU' :
						$rsuMapper = new User_Model_PatronDataMapper();
						$table     = $rsuMapper->getDbTable();
						$select    = $table->select();
						$select->setIntegrityCheck(false);
	
						$select->from(array('rsu'=>'mt.restaurant_user'),array('rsufirst_name','rsulast_name','rsufk_restaurant'))
						->join(array('rest'=>'mt.restaurant'),'rest.resid = rsu.rsufk_restaurant',array('resid','resfk_user'))
						->where('rsu.rsufk_user = ?', $userresult->usrid);
	
						$row = $table->fetchRow($select);
	
						$result = array('Firstname' => $row->rsufirst_name,
								'LastName'  => $row->rsulast_name,
								'User_Id'   => $userresult->usrid,
								'Type'			=> $userresult->code
						);
						return $result;
						break;
					case 'SRU' :
						$rsuMapper = new User_Model_PatronDataMapper();
						$table     = $rsuMapper->getDbTable();
						$select    = $table->select();
						$select->setIntegrityCheck(false);
	
						$select->from(array('rsu'=>'mt.restaurant_user'),array('rsufirst_name','rsulast_name','rsufk_restaurant'))
						->join(array('rest'=>'mt.restaurant'),'rest.resid = rsu.rsufk_restaurant',array('resid','resfk_user'))
						->where('rsu.rsufk_user = ?', $userresult->usrid);
	
						$row = $table->fetchRow($select);
	
						$result = array('Firstname' => $row->rsufirst_name,
								'LastName'  => $row->rsulast_name,
								'User_Id'   => $userresult->usrid,
								'Type'			=> $userresult->code
						);
						return $result;
						break;
				}
					
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateForgotPwd($userid,$password)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table = $this->getDbTable();
			$set   = array('usrpassphrase'=>$password);
			$where = $db->quoteInto('usrid = ?',$userid);
			
			$this->getDbTable()->update($set,$where);
			return true;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function emailValidCheck($email)
	{
		try{
			$usrstatus = 1;
			$db = Zend_Db_Table::getDefaultAdapter();
			$result = $db->fetchOne("select count(usremail) from mt.user where usremail = '".$email."'and usruser_status_id = ".$usrstatus);
	
			if((int)$result)
			{
				$status = true; 
			}else{
				$status = false;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkEmailOnReservation($email)
	{
		try{
			$usrstatus = 1;
			$db = Zend_Db_Table::getDefaultAdapter();
			$result = $db->fetchRow("select usrid,usruser_status_id from mt.user where usremail = '".$email."'");
	
			if((int)$result)
			{
//				if($result['usruser_status_id'] == 2){
//					$set = array(
//						'usruser_status_id'	=>	1						
//					);
//					$where = array('usrid = ?'=> $result['usrid']);
//					$rows_affected = $this->getDbTable()->update($set,$where);
//				}
				return array('status'=>false,'userId'=>$result['usrid']);
			}else{
				return array('status'=>true);
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetStateAndCityById($user_id)
	{
		try{
			$cusMapper = new User_Model_GuestDataMapper();
						$table  = $cusMapper->getDbTable();
						$select = $table->select();
						$select->from($table,array('cuscity_id','cusstate_id'))
							   ->where('cusfk_user = ?',$user_id);
					    $row = $table->fetchRow($select);
						$result = array('state'		=> $row->cusstate_id,
										'city'    	=> $row->cuscity_id
										);
								    
						return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getUserStatusByEmail($email)
	{
		try{
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->from($table,array('usruser_status_id'))
				   ->where('usremail = ?',$email);
		    $row = $table->fetchRow($select);
		   
		    if($row){
		    	$result = array('userstatusid' => $row->usruser_status_id);
		    }else{
		    	$result = array('userstatusid' => "");
		    }
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function manageRestaurantOwners(User_Model_RestOwnSearch $obj,$offset)
	{
		try{
			$limit = 20;
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$stateTableMapper = new Application_Model_StateDataMapper();
			$stateTable       = $stateTableMapper->getDbTable();
			$stateTableSelect = $stateTable->select(); 
			$stateTableSelect->from($stateTable,array('id','code','description'))
							->where('status = ?',true);

			$cityTableMapper = new Application_Model_CityDataMapper();
			$cityTable       = $cityTableMapper->getDbTable();
			$cityTableSelect = $cityTable->select(); 
			$cityTableSelect->from($cityTable,array('id','code','description'))
							->where('status = ?',true);	

			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
							
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail','usrregistered_date','usruser_status_id','usrusertype_id','usripaddress'))
				  ->joinLeft(array('res'=>'mt.restaurant'),'usr.usrid = res.resfk_user',array(''))
				  ->distinct()
				   ->join(array('own'=>'mt.restaurant_owner'),'own.rsofk_user = usr.usrid',array('rsofirst_name','rsolast_name','rsorestaurant_name','rsophone','rsostateid','rsocityid','rsodescription','rsoregionid','rsocantfind','rsoyourstate','rsoyourregion','rsoyourcity','rso_companyid'))
				   ->join(array('usrsts'=>'mt.userstatus_bd'),'usrsts.id = usr.usruser_status_id',array('code as statuscode','description as statusdesc'))
				   //->joinLeft(array('state'=>$stateTableSelect),'state.id = own.rsostateid',array('description as state'))
				   //->joinLeft(array('cty'=>$cityTableSelect),'cty.id = own.rsocityid',array('description as city'))
				   ->where('usr.usrusertype_id = ?',3);
				   
			if($obj->getCompany()){
				$select->where('own.rso_companyid = ?',$obj->getCompany());
			}else if($userdata['Usertype'] == "ADU" && $userdata['companyid'] != 1){
				$select->where('own.rso_companyid = ?',$userdata['companyid']);
			}				
			if($obj->getResName()){
				$select->where('res.resrestaurant_name Ilike ?','%'.trim($obj->getResName()).'%');
			}				   
			if($obj->getEmail()){
				$select->where('usr.usremail Ilike ?','%'.trim($obj->getEmail()).'%');
			}
			if($obj->getId()){
				$select->where('usr.usrid = ?',$obj->getId());
			}
			if($obj->getStatusId()){
				$select->where('usr.usruser_status_id = ?',$obj->getStatusId());
			}
			if($obj->getFirstname()){
				$select->where('own.rsofirst_name Ilike ?','%'.trim($obj->getFirstname()).'%');
			}
			if($obj->getLastname()){
				$select->where('own.rsolast_name Ilike ?','%'.trim($obj->getLastname()).'%');
			}
			if($obj->getStateid()){
				$select->where('own.rsostateid = ?',$obj->getStateid());
			}
			if($obj->getRegionid()){
				$select->where('own.rsoregionid = ?',$obj->getRegionid());
			}
			if($obj->getCityid()){
				$select->where('own.rsocityid = ?',$obj->getCityid());
			}
			
			$select->order('usr.usrregistered_date DESC');
		    //$result = $table->fetchAll($select);
		    $rowset = new Zend_Paginator(
					  new Zend_Paginator_Adapter_DbTableSelect($select)
					);
					
			$rowset->setItemCountPerPage($limit);
		    $rowset->setCurrentPageNumber($offset);
		    return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function viewAllUsers(User_Model_RestOwnSearch $obj,$offset)
	{
		try{
			$limit = 20;
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$stateTableMapper = new Application_Model_StateDataMapper();
			$stateTable       = $stateTableMapper->getDbTable();
			$stateTableSelect = $stateTable->select(); 
			$stateTableSelect->from($stateTable,array('id','code','description'))
							->where('status = ?',true);

			$cityTableMapper = new Application_Model_CityDataMapper();
			$cityTable       = $cityTableMapper->getDbTable();
			$cityTableSelect = $cityTable->select(); 
			$cityTableSelect->from($cityTable,array('id','code','description'))
							->where('status = ?',true);				
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
							
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail','usrregistered_date','usruser_status_id','usrusertype_id'))
				   ->joinLeft(array('own'=>'mt.restaurant_owner'),'own.rsofk_user = usr.usrid',array('rsofirst_name','rsolast_name','rsorestaurant_name','rsophone','rsostateid','rsocityid','rsodescription','rsoregionid'))
				   ->joinLeft(array('rusr'=>'mt.restaurant_user'),'rusr.rsufk_user= usr.usrid',array('rsufirst_name','rsulast_name'))
				   ->joinLeft(array('rest'=>'mt.restaurant'),'rest.resfk_user=own.rsofk_user OR rest.resfk_user=rusr.rsufk_restaurant',array('resrestaurant_name'))
				   ->join(array('usrsts'=>'mt.userstatus_bd'),'usrsts.id = usr.usruser_status_id',array('code as statuscode','description as statusdesc'))
				   ->join(array('usrsbd'=>'mt.usertype_bd'),'usrsbd.id = usr.usrusertype_id',array('description as usertype'))
				   //->joinLeft(array('state'=>$stateTableSelect),'state.id = own.rsostateid',array('description as state'))
				   //->joinLeft(array('cty'=>$cityTableSelect),'cty.id = own.rsocityid',array('description as city'))
				   ->where("usr.usrusertype_id=4 OR usr.usrusertype_id=3 OR usr.usrusertype_id=6");
			if($userdata['Usertype'] == "ADU" && $userdata['companyid'] != 1){
				$select->where('rest.res_companyid = ?', $userdata['companyid']);
			}
			if($obj->getEmail()){
				$select->where('usr.usremail Ilike ?','%'.trim($obj->getEmail()).'%');
			}
			if($obj->getId()){
				$select->where('usr.usrid = ?',$obj->getId());
			}
			if($obj->getStatusId()){
				$select->where('usr.usruser_status_id = ?',$obj->getStatusId());
			}
			if($obj->getFirstname()){
				$select->where('own.rsofirst_name Ilike ?','%'.trim($obj->getFirstname()).'%');
				$select->orWhere('rusr.rsufirst_name Ilike ?','%'.trim($obj->getFirstname()).'%');
			}
			if($obj->getLastname()){
				$select->where('own.rsolast_name Ilike ?','%'.trim($obj->getLastname()).'%');
			    $select->orWhere('rusr.rsulast_name Ilike ?','%'.trim($obj->getLastname()).'%');
			}
			if($obj->getStateid()){
				$select->where('own.rsostateid = ?',$obj->getStateid());
			}
			if($obj->getRegionid()){
				$select->where('own.rsoregionid = ?',$obj->getRegionid());
			}
			if($obj->getCityid()){
				$select->where('own.rsocityid = ?',$obj->getCityid());
			}
			$select->order('usr.usrregistered_date DESC');
		    $result = $table->fetchAll($select);
		    $rowset = new Zend_Paginator(
					  new Zend_Paginator_Adapter_DbTableSelect($select)
					);
					
			$rowset->setItemCountPerPage($limit);
		    $rowset->setCurrentPageNumber($offset);
		    return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateRestaurantOwnerStatus($userid, $code)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false;
			$UserStatus = $this->getUserStatusIdByCode($code);
			$set = array('usruser_status_id' => $UserStatus->id);
			$where = $db->quoteInto('usrid = ?',$userid);

			$rows_affected = $this->getDbTable()->update($set,$where);

			if($rows_affected > 0){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getUserStatusIdByCode($code)
	{
		try{
			$Mapper = new Application_Model_UserStatusDataMapper();
			$List = $Mapper->fetchAll();

			foreach($List as $status){
				if($code == $status->code){
					return $status;
				}
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}		
	} 
	
	public function EditRestaurantOwnerDetails(User_Model_Client $obj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false;
			$update = date('Y-m-d H:i:s');
			if($obj->getEmail()){
				$set = array('usremail' 	=> $obj->getEmail());
			}
			if($obj->getPassword()){
				$length = 8;
				$characters = '0123456789abcdefghijklmnopqrstuvwxyz';
				$randomdata = "";
				for ($p = 0; $p < $length; $p++) {
					$randomdata .= $characters[mt_rand(0, strlen($characters))];
				}
				$passSha = sha1($obj->getPassword().$randomdata);
				$set = array('usrpassword' 	=> $passSha,'usrpassphrase' => $randomdata);
			}

			$set['usrupdateddatetime'] = $update;
			$where = $db->quoteInto('usrid = ?',$obj->getId());

			$rows_affected = $this->getDbTable()->update($set,$where);

			if($rows_affected > 0){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	
	public function getNameandEmailByUserId($userid)
	{
		try{
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail'))
				   ->join(array('own'=>'mt.restaurant_owner'),'own.rsofk_user = usr.usrid',array('rsofirst_name','rsolast_name'))
				   ->where('usr.usrid = ?',$userid);
			$result = $table->fetchRow($select);
		    return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function getEmailByUserId($userid)
	{
		try{
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail'))
					->where('usr.usrid = ?',$userid);
			$result = array($table->fetchRow($select));
			
			
			$user = new User_Model_Client($result);
			$user->setEmail($result);
					
		    return $user;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	/**
	 * display the entire customer list.
	 */
	public function manageCustomers(User_Model_Guest $obj,$offset)
	{
		try{
			$limit = 20;
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);			
							
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail','usrregistered_date','usruser_status_id','usrusertype_id'))
				   ->join(array('cus'=>'mt.customer'),'cus.cusfk_user = usr.usrid',array('cusfirst_name','cuslast_name','cusstate_id','cuscity_id','cusmobile'))
				   ->join(array('usrsts'=>'mt.userstatus_bd'),'usrsts.id = usr.usruser_status_id',array('code as statuscode','description as statusdesc'))
				   ->joinLeft(array('state'=>'mt.state_bd'),'state.id = cus.cusstate_id',array('description as state'))
				   ->joinLeft(array('cty'=>'mt.city_bd'),'cty.id = cus.cuscity_id',array('description as city'))
				   ->where('usr.usrusertype_id = ?',2);
			if($obj->getEmail()){
				$select->where('usr.usremail Ilike ?','%'.trim($obj->getEmail()).'%');
			}
			if($obj->getId()){
				$select->where('usr.usrid = ?',$obj->getId());
			}
			if($obj->getStatusId()){
				$select->where('usr.usruser_status_id = ?',$obj->getStatusId());
			}
			if($obj->getFirstname()){
				$select->where('cus.cusfirst_name Ilike ?','%'.trim($obj->getFirstname()).'%');
			}
			if($obj->getLastname()){
				$select->where('cus.cuslast_name Ilike ?','%'.trim($obj->getLastname()).'%');
			}
			if($obj->getStateid()){
				$select->where('cus.cusstate_id = ?',$obj->getStateid());
			}
			if($obj->getCityid()){
				$select->where('cus.cuscity_id = ?',$obj->getCityid());
			}
			$select->order('usr.usrregistered_date DESC');
		    //$result = $table->fetchAll($select);
		    $rowset = new Zend_Paginator(
					  new Zend_Paginator_Adapter_DbTableSelect($select)
					);
					
			$rowset->setItemCountPerPage($limit);
		    $rowset->setCurrentPageNumber($offset);
		    return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * Update the customer status
	 */
	public function UpdateCustomerStatus($userid, $code)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false;
			$UserStatus = $this->getUserStatusIdByCode($code);
			$set = array('usruser_status_id' => $UserStatus->id);
			$where = $db->quoteInto('usrid = ?',$userid);

			$rows_affected = $this->getDbTable()->update($set,$where);

			if($rows_affected > 0){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * Update the customer email and password by admin
	 */
	public function EditCusEmailAndPassword(User_Model_Client $obj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$status = false;
			$update = date('Y-m-d H:i:s');
			if($obj->getEmail()){
				$set = array('usremail' 	=> $obj->getEmail());
			}
			if($obj->getPassword()){
				$length = 8;
				$characters = '0123456789abcdefghijklmnopqrstuvwxyz';
				$randomdata = "";
				for ($p = 0; $p < $length; $p++) {
					$randomdata .= $characters[mt_rand(0, strlen($characters))];
				}
				$passSha = sha1($obj->getPassword().$randomdata);
				
				$set = array('usrpassword' 	=> $passSha,'usrpassphrase' => $randomdata);
			}
			$set['usrupdateddatetime'] = $update;
						
			$where = $db->quoteInto('usrid = ?',$obj->getId());

			$rows_affected = $this->getDbTable()->update($set,$where);

			if($rows_affected > 0){
				$status = true;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getCustomerNameandEmailByUserId($userid)
	{
		try{
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail'))
				   ->joinLeft(array('cus'=>'mt.customer'),'cus.cusfk_user = usr.usrid',array('cusfirst_name','cuslast_name'))
				   ->join(array('typ'=>'mt.usertype_bd'),'usr.usrusertype_id = typ.id',array('code','description'))
				   ->where('usr.usrid = ?',$userid);
			$result = $table->fetchRow($select);
		    return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getRestOwnDetails($userid)
	{
		try{
			
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail'))
				   ->join(array('rso'=>'mt.restaurant_owner'),'rso.rsofk_user = usr.usrid',array('rsoid','rsofk_salution','rsofirst_name','rsolast_name'))
				   ->where('usr.usrid = ?',$userid);
				   
			$row = $table->fetchRow($select);
			
			$data = array('Email'      	=> $row->usremail,
						  'User_Id'   	=> $row->usrid,							
						  'Salution'  	=> $row->rsofk_salution,
						  'Firstname' 	=> $row->rsofirst_name,
						  'LastName'  	=> $row->rsolast_name);
			
			return $data;
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getUserPassPhrase($user)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail','usrpassphrase'))
				   ->where('usremail = ?',$user);
				   
			$row = $table->fetchRow($select);
			return $row;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * GET USER EMAIL AND PASSWORD WITH USERID
	 */
	public function getUserCredentailsByUserId($userid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('usr'=>'mt.user'),array('usremail','usrpassword'))
				   ->where('usrid = ?',$userid);
				   
			$row = $table->fetchRow($select);
			return $row;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateAllPhrase()
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$result = $db->fetchAll(
	    		"SELECT usrid,usrpassword,usrpassphrase FROM mt.user "
				);
			foreach($result as $row){
				$id = $row['usrid'];
				if(strlen($row['usrpassword']) < 30){
					$length = 8;
					$characters = '0123456789abcdefghijklmnopqrstuvwxyz';
					$randomdata = "";
					for ($p = 0; $p < $length; $p++) {
						$randomdata .= $characters[mt_rand(0, strlen($characters))];
					}
					$update = date('Y-m-d H:i:s');
					$passSha = sha1($row['usrpassword'].$randomdata);
					$usertabledata = array('usrpassword'        => $passSha,'usrpassphrase' => $randomdata,'usrupdateddatetime'=>$update);
					$this->getDbTable()->update($usertabledata, array('usrid = ?' => $id));
				}
			}
			$map = new FirmManagement_Model_OverBookedPasswordDataMapper();
			$s = $map->updateAll();
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function upadteAdminUserRole($userid, $roleid)
	{
		try{
			$table = $this->getDbTable();
			
			$set = array(
				'usrrole_id'		=>	$roleid
			);
				
			$where = array('usrid = ?'=> $userid);
			$rows_affected = $this->getDbTable()->update($set,$where);
			return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	public function manageRestaurantUsers(User_Model_RestOwnSearch $obj,$offset)
	{
		try{
			$limit = 20;
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$stateTableMapper = new Application_Model_StateDataMapper();
			$stateTable       = $stateTableMapper->getDbTable();
			$stateTableSelect = $stateTable->select(); 
			$stateTableSelect->from($stateTable,array('id','code','description'))
							->where('status = ?',true);

			$cityTableMapper = new Application_Model_CityDataMapper();
			$cityTable       = $cityTableMapper->getDbTable();
			$cityTableSelect = $cityTable->select(); 
			$cityTableSelect->from($cityTable,array('id','code','description'))
							->where('status = ?',true);		
							
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail','usrregistered_date','usruser_status_id','usrusertype_id'))
				   //->joinLeft(array('own'=>'mt.restaurant_owner'),'own.rsofk_user = usr.usrid',array('rsofirst_name','rsolast_name','rsorestaurant_name','rsophone','rsostateid','rsocityid','rsodescription','rsoregionid'))
				   ->join(array('rusr'=>'mt.restaurant_user'),'rusr.rsufk_user= usr.usrid',array('rsufirst_name','rsulast_name'))
				   
				   ->join(array('rest'=>'mt.restaurant'),'rest.resid=rusr.rsufk_restaurant',array('resrestaurant_name','res_companyid'))
				   ->join(array('usrsts'=>'mt.userstatus_bd'),'usrsts.id = usr.usruser_status_id',array('code as statuscode','description as statusdesc'))
				   ->join(array('usrsbd'=>'mt.usertype_bd'),'usrsbd.id = usr.usrusertype_id',array('description as usertype'))
				   //->joinLeft(array('state'=>$stateTableSelect),'state.id = own.rsostateid',array('description as state'))
				   //->joinLeft(array('cty'=>$cityTableSelect),'cty.id = own.rsocityid',array('description as city'))
				   ->where("usr.usrusertype_id=4 OR usr.usrusertype_id=6");	

			if($userdata['Usertype'] == "ADU" && $userdata['companyid'] != 1){
				$select->where('rest.res_companyid = ?', $userdata['companyid']);
			}
			
			if($obj->getResName()){
				$select->where('rest.resrestaurant_name Ilike ?','%'.trim($obj->getResName()).'%');
			}				   
			if($obj->getEmail()){
				$select->where('usr.usremail Ilike ?','%'.trim($obj->getEmail()).'%');
			}
			if($obj->getId()){
				$select->where('usr.usrid = ?',$obj->getId());
			}
			if($obj->getStatusId()){
				$select->where('usr.usruser_status_id = ?',$obj->getStatusId());
			}
			if($obj->getFirstname()){
				$select->where('rusr.rsufirst_name Ilike ?','%'.trim($obj->getFirstname()).'%');
			}
			if($obj->getLastname()){
				$select->where('rusr.rsulast_name Ilike ?','%'.trim($obj->getLastname()).'%');
			}
			if($obj->getStateid()){
				$select->where('rest.resstate_id = ?',$obj->getStateid());
			}
			if($obj->getRegionid()){
				$select->where('rest.resregion_id = ?',$obj->getRegionid());
			}
			if($obj->getCityid()){
				$select->where('rest.rescity_id = ?',$obj->getCityid());
			}
			$select->order('usr.usrregistered_date DESC');
		    //$result = $table->fetchAll($select);
		    $rowset = new Zend_Paginator(
					  new Zend_Paginator_Adapter_DbTableSelect($select)
					);
					
			$rowset->setItemCountPerPage($limit);
		    $rowset->setCurrentPageNumber($offset);
		  
		    return $rowset;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function manageLoginProfileWidget($userDet)
	{	
		$db = Zend_Db_Table::getDefaultAdapter();
			
		try{
			$db->beginTransaction();
			$table  =$this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('usr'=>'mt.user'),array('usrid','usremail','usrregistered_date','usruser_status_id','usrusertype_id','usrlast_login_date'))
					->where('usremail = ?',$userDet->email);
			$usrRes = $table->fetchRow($select);
			if(!$usrRes){
				$email = $userDet->email;
				$length = 8;
				$characters = '0123456789abcdefghijklmnopqrstuvwxyz';
				$password = "";
				for ($p = 0; $p < $length; $p++) {
					$password .= $characters[mt_rand(0, strlen($characters))];
				}
				$randomdata = "";
				for ($p = 0; $p < $length; $p++) {
					$randomdata .= $characters[mt_rand(0, strlen($characters))];
				}
				$passSha = sha1($password.$randomdata);
				$update = date('Y-m-d H:i:s');
				$user= array(
						'usremail'           => $userDet->email,
						'usrpassword'        => $passSha,
						'usrusertype_id'	 => 2,
						'usrrole_id'		 => 4,
						'usrregistered_date' => date('Y-m-d'),
						'usruser_status_id'	 => 1,
						'usrpassphrase' 	 => $randomdata,
						'usrcreateddatetime' => $update
				);	
					
				$user_id = $this->getDbTable()->insert($user);
				
				$cusMapper = new User_Model_GuestDataMapper();
				$customerTable = $cusMapper->getDbTable();
				
				$data = array(
		  		'cusfk_user' 		=> $user_id,
		  		'cusfirst_name' 	=> $userDet->first_name,
		  		'cuslast_name'  	=> $userDet->last_name,		
		 		 );
		 		 
		 		$customer_id = $customerTable->insert($data);	
		 				
				$db->commit();
				
				$mailmapper = new Application_Service_Communication();
				$mailObj = new Communication_Model_Mail();
				$mailObj->setMsgCode('Customer_Confirmation');
				$name = $userDet->name;
				$data = array('UserName' => $name,
							  'pass' => $password,
							  'SenTo'    => $email);
				$mailObj->setData($data);
				$mailStatus = $mailmapper->SendMail($mailObj);
				
				$usertype_Id   = 2;
								
			}else{
				$user_id       = $usrRes->usrid;
				$usertype_Id   = $usrRes->usrusertype_id;
				$email         = $usrRes->usremail;
			}
			/* Get Usertype from Usertype BaseData */
			
			$signupdate    = null;
			$lastlogindate = null;
			/* Updating Users Last Login Date */
			if($user_id){
				$this->UpdateUserLoggedInDate($user_id);
			}
					
			if($usrRes->usrregistered_date){
				$signupdate  = $usrRes->usrregistered_date;	
			}else{
				$signupdate  = date('Y-m-d');
			}
			
			if($usrRes->usrlast_login_date){
				$lastlogindate = $usrRes->usrlast_login_date;
			}else{
				$lastlogindate = '';
			}
			
			$userType = $this->getUsertype($usertype_Id);
			switch($userType->code){
				case 'CUS':
						$cusMapper = new User_Model_GuestDataMapper();
						$table  = $cusMapper->getDbTable();
						$select = $table->select();
						$select->from($table,array('cussalution','cusfirst_name','cuslast_name','custimezone','cusphone','cusmobile','cuscity_id','cusstate_id','cusregion_id'))
							   ->where('cusfk_user = ?',$user_id);
					    $row = $table->fetchRow($select);
						$result = array('Email'      	=> $email,
										'Salution'   	=> $row->cussalution,
										'Firstname'  	=> $row->cusfirst_name,
										'LastName'   	=> $row->cuslast_name,
										'User_Id'    	=> $user_id,
										'Usertype'   	=> $userType->code,
										'Timezone'   	=> $row->custimezone,
										'State_Id'		=> $row->cusstate_id,
										'City_Id'    	=> $row->cuscity_id,
										'Region_Id'		=> $row->cusregion_id,
										'Phone'      	=> $row->cusphone,
										'cusmobile'  	=> $row->cusmobile,
										'SignUpdate'    => $signupdate,
										'companyid'		=> '',
									    'LastLoginDate' => $lastlogindate);
								    
						return $result;
						
					break;
					
				case 'RSO':
	
						$rsoMapper = new User_Model_ManagerDataMapper();
						$table 	   = $rsoMapper->getDbTable();
						$select    = $table->select();
						$select->from($table,array('rsofk_salution','rsofirst_name','rsolast_name','rsophone','rsostateid','rsocityid','rsoregionid','rso_companyid'))
							   ->where('rsofk_user = ?',$user_id) ;   
						$row       = $table->fetchRow($select);

						
						/* Reterieve Restaurant Owner Permission's */
						
						$permTypMapp = new Application_Model_PermissionsTypeDataMapper();
						$Permissions = $permTypMapp->getRestUserMenuBD();
						
						$result = array('Email'      	=> $email,
										'User_Id'   	=> $user_id,
										'Usertype'  	=> $userType->code,
										'Salution'  	=> $row->rsofk_salution,
										'Firstname' 	=> $row->rsofirst_name,
										'LastName'  	=> $row->rsolast_name,
										'State_Id'		=> $row->rsostateid,
										'City_Id'    	=> $row->rsocityid,
										'Region_Id'		=> $row->rsoregionid,									
										'SignUpdate'    => $signupdate,
									    'LastLoginDate' => $lastlogindate,
										'Phone'      	=> $row->rsophone,
										'Permissions'   => $Permissions,
										'companyid'		=> $row->rso_companyid);														
											
						 return $result;						
					
					break;	
					
				case 'RSU' :
						 $rsuMapper = new User_Model_PatronDataMapper();
						 $table     = $rsuMapper->getDbTable();
						 $select    = $table->select();
						 $select->setIntegrityCheck(false);
						 
						 $select->from(array('rsu'=>'mt.restaurant_user'),array('rsusalution','rsufirst_name','rsulast_name','rsufk_restaurant','rsuphone'))
						 		->join(array('rest'=>'mt.restaurant'),'rest.resid = rsu.rsufk_restaurant',array('resid','resfk_user','res_companyid'))
						 		->join(array('usr'=>'mt.user'),'usr.usrid = rsu.rsufk_user',array('usrrole_id'))
						 		->where('rsu.rsufk_user = ?', $user_id);
	
						 $row = $table->fetchRow($select); 		
						 $role_id = 0;
						 $role_id = $row->usrrole_id;
						 
						 /* Reterieve Perimission's by role id */				 
						 
						 $rolesPermMapper = new Application_Model_RolePermissionMapDataMapper();
						 $permRowSet = $rolesPermMapper->getPermissionByRole($role_id);						 					
						 
						 
						 
						 $result = array('User_Id'  	=> $user_id,
										'Usertype'  	=> $userType->code,									
										'Firstname' 	=> $row->rsufirst_name,
										'LastName'  	=> $row->rsulast_name,
						 				'Salution'  	=> $row->rsusalution,
										'RestId'    	=> $row->resid,
						 				'RestOwnId' 	=> $row->resfk_user,
										'SignUpdate'    => $signupdate,
									    'LastLoginDate' => $lastlogindate,
						 				'Permissions'   => $permRowSet,
						 				'Email'      	=> $email,
						 				'Phone'      	=> $row->rsuphone,
						 				'companyid'		=> $row->res_companyid);
						 
						 return $result;
						 
					break;

				case 'SRU' :
						 $rsuMapper = new User_Model_PatronDataMapper();
						 $table     = $rsuMapper->getDbTable();
						 $select    = $table->select();
						 $select->setIntegrityCheck(false);
						 
						 $select->from(array('rsu'=>'mt.restaurant_user'),array('rsusalution','rsufirst_name','rsulast_name','rsufk_restaurant','rsuphone','rsup_resid','rsudefaultview'))
						 		->join(array('usr'=>'mt.user'),'usr.usrid = rsu.rsufk_user',array('usrrole_id'))
						 		->join(array('sru'=>'mt.restaurant_super_user'),'rsu_rsu_fk_user = rsufk_user',array('array_agg(rsu_rsu_restaurant) as resIdArr','array_agg(resrestaurant_name) as resNameArr'))
						 		->join(array('rest'=>'mt.restaurant'),'rest.resid = sru.rsu_rsu_restaurant',array('resfk_user','res_companyid'))
						 		->where('rsu.rsufk_user = ?', $user_id)
								->where('sru.rsu_rsu_status = ?', true)
						 		->group(array('usrrole_id','rsufirst_name','rsulast_name','rsufk_restaurant','rsuphone','rsup_resid','rsudefaultview','resfk_user','res_companyid'));
	
						 $row = $table->fetchRow($select); 		
						 $role_id = 0;
						 $role_id = $row->usrrole_id;
						 
						 /* Reterieve Perimission's by role id */				 
						 
						 $rolesPermMapper = new Application_Model_RolePermissionMapDataMapper();
						 $permRowSet = $rolesPermMapper->getPermissionByRole($role_id);						 					
						 
						$restNameByOwnObj = new FirmManagement_Model_FirmNamesByOwnerId();
						$restNameByOwnObj->setRestId($presid);
						$restMapper = new FirmManagement_Model_FirmDataMapper();
//						$restList   = $restMapper->getRestaurantNamesByOwnerId($restNameByOwnObj);
						$resIdArr = explode(',',substr($row->resIdArr,1,-1));
						$resNameArr = explode(',',substr($row->resNameArr,1,-1));
						$restNames = array();
						$restNames[] = array('key'=>'','value'=>'Select Restaurant');
						for($i = 0; $i<count($resNameArr);$i++){
							$restNames[] = array('key'=>$resIdArr[$i],'value'=>$resNameArr[$i]);
						}
						 $result = array('User_Id'  	=> $user_id,
										'Usertype'  	=> $userType->code,	
										'Salution'  	=> $row->rsusalution,								
										'Firstname' 	=> $row->rsufirst_name,
										'LastName'  	=> $row->rsulast_name,
										'RestId'    	=> $row->resid,
						 				'RestOwnId' 	=> $row->resfk_user,
										'SignUpdate'    => $signupdate,
									    'LastLoginDate' => $lastlogindate,
						 				'Permissions'   => $permRowSet,
						 				'Email'      	=> $email,
						 				'Phone'      	=> $row->rsuphone,
						 				'companyid'		=> $row->res_companyid,
						 				'DefaultView' 	=> $row->rsudefaultview,
										'restList'		=> $restNames);
						 
						 return $result;
						 
					break;
					
				case 'ADM' :
					
						$adminPermMapper = new Application_Model_AdminPermissionsTypeDataMapper();
						$permRowSet = $adminPermMapper->getAdminMenuBD();
						$result = array('User_Id'  		=> $user_id,
										'Usertype' 		=> $userType->code,
										'Permissions'   => $permRowSet,
										'companyid'		=> 1,
										'restownerId'	=> ""
									);
						return $result; 
						
					break;	
				
				case 'ADU' :
						$aduMapper = new User_Model_AdminPatronDataMapper();
						$table     = $aduMapper->getDbTable();
						$select    = $table->select();
						$select->setIntegrityCheck(false);
						 
						$select->from(array('adu'=>'mt.admin_user'),array('adufirst_name','adulast_name','adufk_comapnyid','aduphone'))
						 	   ->join(array('com'=>'mt.company'),'com.com_id = adu.adufk_comapnyid',array('com_companyname'))
						 	   ->join(array('usr'=>'mt.user'),'usr.usrid = adu.adufk_user',array('usrrole_id'))
						 	   ->where('adu.adufk_user = ?', $user_id);
	
						 $row = $table->fetchRow($select); 		
						 $role_id = "";
						 $role_id = $row->usrrole_id;
						 $companyid = $row->adufk_comapnyid;
						 
						 /* Reterieve Perimission's by role id */				 
						 if($role_id == 1){
						 	$adminPermMapper = new Application_Model_AdminPermissionsTypeDataMapper();
						 	$permRowSet = $adminPermMapper->getAdminMenuBD();
						 }else{
						 	$rolesPermMapper = new Application_Model_AdminRolePermissionMapDataMapper();
						 	$permRowSet = $rolesPermMapper->getAdminUserPermissionByRole($role_id);
						 }						 					
						 
						$result = array('User_Id'  		=> $user_id,
										'Usertype' 		=> $userType->code,
										'Firstname'		=> $row->adufirst_name,
										'LastName'  	=> $row->adulast_name,
										'Permissions'   => $permRowSet,
										'companyid'		=> $companyid,
										'restownerId'	=> ""			
									);
						return $result; 
						
					break;	
			}
			$db->commit();
				
		}catch(Exception $ex){
				
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
		
	}	
	
	public function getUsersByResId($resid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
						
			$select->from(array('resusr' => 'mt.restaurant_user'), array('rsufk_restaurant','rsuid','rsufirst_name','rsulast_name'));
			$select->joinLeft(array('susr' => 'mt.restaurant_super_user'),'susr.rsu_rsu_fk_user = resusr.rsufk_user ',array(''));
			$select->join(array('usr' => 'mt.user'), 'resusr.rsufk_user = usr.usrid', array('usrid','usremail','usrregistered_date','usrusertype_id'));
			$select->join(array('rol'=>'mt.role_bd'),'usr.usrrole_id = rol.id',array('id as roleid','code as rolename','description as roledesc'));
			$select->join(array('usrtyp'=>'mt.userstatus_bd'),'usrtyp.id = usr.usruser_status_id',array('code','description'));
			$select->joinLeft(array('usrinit'=>'mt.restaurant_user_initials'),'usrinit.rsui_fk_user = usr.usrid',array('rsui_initial'));			
			
			
//			$select->where('usr.usrrole_id = ?',$roleid);
			$select->where("resusr.rsufk_restaurant = $resid or susr.rsu_rsu_restaurant = $resid");
			$select->order('usr.usrid');
			$select->group(array('usrinit.rsui_initial','usrtyp.description','roleid','rsuid','usrtyp.code','rsufirst_name','rsulast_name' ,'usrid','usremail','usrregistered_date','usrusertype_id'));
			$Result = $this->getDbTable()->fetchAll($select);
			
			return $Result;
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getCountrycodebyUserid($userid,$usertype,$resid)
	{	
		try{
			$table = $this->getDbTable();
			$query= $table->select();
			$query->setIntegrityCheck(false);
			
			$query->from(array('usr' => 'mt.user'),array('usrid'));
			$query->joinLeft(array('rso' => 'mt.restaurant_owner'),'rso.rsofk_user = usr.usrid',array('rsocountrycode'));
			$query->joinLeft(array('rsu' => 'mt.restaurant_user'),'rsu.rsufk_user = usr.usrid',array('rsucountrycode'));
			$query->joinLeft(array('cus' => 'mt.customer'),'usr.usrid = cus.cusfk_user',array('cuscountrycode'));
			$query->joinLeft(array('adu' => 'mt.admin_user'),'usr.usrid = adu.adufk_user',array('adufk_comapnyid'));
			
			if($usertype == 'RSU' || $usertype == 'SRU'){
				$query->joinLeft(array('rest'=>'mt.restaurant'),'rest.resid = rsu.rsufk_restaurant',array('res_countrycode'));
				$query->where("usrid = $userid  and rest.resid =  $resid");	 
			}  
			if($usertype == 'CUS'){
				$query->joinLeft(array('rest'=>'mt.restaurant'),'rso.rsofk_user= rest.resfk_user OR rsu.rsufk_restaurant=rest.resid',array('res_countrycode'));							
				$query->where("usrid =?", $userid);
			//	$query->orwhere("rest.resid= ?", $resid);
			}
			if($usertype == 'RSO'){
				$query->joinLeft(array('rest'=>'mt.restaurant'),'rest.resfk_user = rso.rsofk_user',array('res_countrycode'));
				$query->where('usrid = ?',$userid);	 
			}   	  
			
			if($usertype == 'ADM' || $usertype == 'ADU'){
				$query->joinleft(array('rest'=>'mt.restaurant'),'rest.res_companyid = adu.adufk_comapnyid',array('res_countrycode'));
				$query->where('usrid = ?',$userid);
				$query->orwhere('resid = ?',$resid);	 
			}
			
			$row = $table->fetchRow($query); 
			
			if($row->cuscountrycode){
				return $row->cuscountrycode;
			}else if($row->rsucountrycode){
				return $row->rsucountrycode;
			}else if($row->rsocountrycode != null){
				return $row->rsocountrycode;
			}else if($row->res_countrycode  != null){
				return $row->res_countrycode;
			}else{
				$restMapper = new FirmManagement_Model_FirmDataMapper();
				$restList   = $restMapper->getCountrycodebyId($resid);
				if($restList){
					return $restList;
				}else{
					return '+91';
				}
				
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function RetrieveRestOwnerdetails($userid)
	{
		try
		{
			
			$table = $this->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('usrid','usremail','usrpassword','usrusertype_id','usrrole_id','usrregistered_date','usrlastlogged_in_ip','usrlast_login_date','usruser_status_id','usrcreatedby','usrcreateddatetime','usrupdatedby','usrupdateddatetime','usrpassphrase'))
				  ->where('usrid = ?',$userid) ;
				     
			$row = $table->fetchRow($select);
			$result = array();
			foreach ($row as $key=>$value){
				$result[$key] = $value;
			}
			
			$result['usrcreatedby'] = null;
			$result['usrupdatedby'] = null;
			if($result['usrlast_login_date'] == null){
				$result['usrlast_login_date'] = $ownusertabledata->usrregistered_date;
			}
			
			return $result;
			
		}catch(Exception $ex)
		{
			throw new Exception($ex->getMessage()) ;
		}
	}
}
