
<?php
/**
*	Name			: ReservationController.php
*	Author			: Zubair Ahmed
*	Creation Date	: 09/30/2013
*	Path 			: application/modules/Reservation/controllers/ReservationController.php
*	Description		: This is controller class for the reservation module.
*					   	
*/
class Reservation_ReservationController extends Zend_Controller_Action
{
	protected $_reservationService = null;
	protected $_restService = null;
	
	/**
     * Initialize the booking service instance 
     * and restaurant service instance.
     */
	public function init()
	{
		if(!$this->_reservationService){
			$this->_reservationService	= new Application_Service_Reservation();
		}
		if(!$this->_restService){
			$this->_restService	= new Application_Service_Firm();
		}
	}

	public function indexAction()
	{
		// action body
	}

	/**
	 * display the customer booking history
	 */
	public function customerhistoryAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->_helper->layout()->setLayout('customerlayout');
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$page = $this->_request->getParam('page');
				if (empty($page)){
					$page = 1;
				}
				$request = $this->getRequest();
				if(isset($request->actstat)){
					$this->view->actstat = $request->actstat;
				}
				$form = $this->_reservationService->getCustBookHistForm();
				$formdata = array();
				if($this->getRequest()->isPost()){
					$formdata = $this->getRequest()->getPost();


					if($formdata['bookid'])
					{
						$this->view->bokid = $formdata['bookid'];
					}
					if($formdata['restname'])
					{
						$this->view->restname = $formdata['restname'];
					}
					if($formdata['startdate'])
					{
						$this->view->startdate = $formdata['startdate'];
					}
					if($formdata['enddate'])
					{
						$this->view->enddate = $formdata['enddate'];
					}
					
					if($formdata['patronName'])
					{
						$this->view->patronName = $formdata['patronName'];
					}
					
					if($formdata['booksorton'])
					{
						$this->view->booksorton = $formdata['booksorton'];
					}
				}
				$bookResults = $this->_reservationService->GetCustBookingHistory($formdata,$data['User_Id'],$data['Phone'],$data['Email'],$page);
				$this->view->bookHistRes = $bookResults;
				$this->view->form = $form;

			}
			else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * display the restaurants avaliable slots for the search on date and time
	 */
	public function searchforrestaurantslistAction()
	{
		try{
			$bokService = new Application_Service_Reservation();
			$stateBd    = $bokService->GetStateBaseData();
			//$cityBd		= $bokService->GetCityBaseData();
			//$neighborBd = $bokService->GetNeighborhodBaseData();
			$restTypeBd = $bokService->GetRestaurantTypesBaseData();
			$price = $bokService->GetRestaurantPriceBaseData();

			$request = $this->getRequest();
			//$this->_helper->layout()->setLayout('searchlayout');
			$page = $this->_request->getParam('page');
			if (empty($page)){
				$page = 1;
			}
			$result = $this->_reservationService->SearchListView($request,$page);
			$this->view->searchList = $result['searchList'];

			
			$regionsArray = array();			
			if($request->state)
			{
				$regionMapper = new Application_Model_RegionDataMapper();
				$regionObject = new Application_Model_Region();
				$regionObject->setStateId($request->state);
				$regionResult = $regionMapper->getRegionByStateId($regionObject);				
				$regionsArray = $regionResult->getRegionList();				
			}
			
			$cityArr = array();
			if($request->region)
			{
				$cityMapper = new Application_Model_CityDataMapper();
				$cityObj = new Application_Model_City();
				$cityObj->setRegionId($request->region);
				$cityBd		= $this->_restService->getCitysByRegionId($cityObj);
				
				$cityArr=$cityBd->getCityList();
			
			}
			$neighborArr = array();		
			if($request->city)
			{
				$bokService = new Application_Service_Reservation();
				$nghMapper = new Application_Model_NeighborhoodDataMapper();
				$nghObj = new Application_Model_Neighborhood();
				$nghObj->setCityId($request->city);
				$neighborBd = $this->_restService->getNghIdCidyId($nghObj);
				$cityBd		= $bokService->GetCityBaseData();
				$cityArr = $cityBd;
				$neighborArr = $neighborBd->getNeighborhoodList();
			
			}
			
			$this->view->state    = $request->state;
			$this->view->region   = $request->region;
			$this->view->city     = $request->city;
			$this->view->neighbor = $request->neighbor;
			$this->view->cuisine  = $request->cuisine;
			$this->view->time = $result['time'];
			$this->view->date = $result['date'];
			$this->view->pax = $result['pax'];
			$this->view->resid = $result['resid'];
			if($request->price){
				$this->view->price = $result['price'];
			}
						
			$this->view->resName = $request->resname;
			$this->view->filresId = $request->filresid;

			$this->view->stateBd    = $stateBd;
            $this->view->regionBd   = $regionsArray;
			$this->view->cityBd     = $cityArr;
			$this->view->neighborBd = $neighborArr;
			$this->view->restTypeBd = $restTypeBd;
			$this->view->priceBd = $price;
			$bokService = null;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * display all the restaurants (information only) for the search with out date and time
	 */
	public function searchforrestaurantsAction()
	{
	try{
			$bokService = new Application_Service_Reservation();
			$stateBd  = $bokService->GetStateBaseData();
						
			
			/*$regionBd		= $bokService->GetRegionBaseData();
			$cityBd		= $bokService->GetCityBaseData();
			$neighborBd = $bokService->GetNeighborhodBaseData();*/
			$restTypeBd = $bokService->GetRestaurantTypesBaseData();
			$price      = $bokService->GetRestaurantPriceBaseData();

			$request = $this->getRequest();

			$result = $this->_reservationService->SearchRestaurants($request);
			$this->view->searchList = $result['searchList'];
			if(isset($result['offset'])){
				$this->view->offset		   = $result['offset'];
			}
			$regionsArray = array();
			
			if($request->state)
			{
				$regionMapper = new Application_Model_RegionDataMapper();
				$regionObject = new Application_Model_Region();
				$regionObject->setStateId($request->state);
				$regionResult = $regionMapper->getRegionByStateId($regionObject);				
				$regionsArray = $regionResult->getRegionList();				
			}
			$cityArr = array();
			if($request->region)
			{
				$bokService = new Application_Service_Reservation();
				$cityMapper = new Application_Model_CityDataMapper();
				$cityObj = new Application_Model_City();
				$cityObj->setRegionId($request->region);
				$cityBd		= $bokService->GetCityBaseData($cityObj);
				
				$cityArr = $cityBd;
			
			}
			$neighborArr = array();		
			if($request->city)
			{
				$bokService = new Application_Service_Reservation();
				$nghMapper = new Application_Model_NeighborhoodDataMapper();
				$nghObj = new Application_Model_Neighborhood();
				$nghObj->setCityId($request->city);
				$neighborBd = $this->_restService->getNghIdCidyId($nghObj);
				$cityBd		= $bokService->GetCityBaseData();
				$cityArr = $cityBd;
				$neighborArr = $neighborBd->getNeighborhoodList();
			}
			$this->view->prev = $result['prev'];
			$this->view->next = $result['next'];

			$this->view->pax = $request->pax;
			$this->view->state    = $request->state;
			$this->view->region = $request->region;
			$this->view->city = $request->city;
			$this->view->neighbor = $request->neighbor;
			$this->view->cuisine = $request->cuisine;
			$this->view->price = $request->price;
			$this->view->resName = $request->resname;
			$this->view->filresId = $request->filresid;
			if(isset($result['time'])){
			$this->view->time = $result['time'];
			}
			if(isset($result['date'])){
			$this->view->date = $result['date'];
			}

			$this->view->stateBd    = $stateBd;
            $this->view->regionBd   = $regionsArray;
			$this->view->cityBd     = $cityArr;
			$this->view->neighborBd = $neighborArr;
			$this->view->restTypeBd = $restTypeBd;
			$this->view->priceBd    = $price;
			
			$bokService = null;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * display the restaurant specials (informational and purchasable) for the serach
	 */
	public function searchrestaurantdealAction()
	{
		try{
			
			$cityBd	    = $this->_reservationService->GetCityBaseData();
			$neighborBd = $this->_reservationService->GetNeighborhodBaseData();
			$restTypeBd = $this->_reservationService->GetRestaurantTypesBaseData();
			$price      = $this->_reservationService->GetRestaurantPriceBaseData();

			$request = $this->getRequest();

			$result = $this->_reservationService->SearchRestaurantsSpecialslistview($request);
			$this->view->searchList = $result['searchList'];
			

			$this->view->pax = $request->pax;
			$this->view->city = $request->city;
			$this->view->neighbor = $request->neighbor;
			$this->view->cuisine = $request->cuisine;
			$this->view->time       = $request->time;
			$this->view->date       = $request->date;
			$this->view->pax        = $request->pax;
			$this->view->resid      = $request->resid;
			if($request->price){
				$this->view->price  = $request->price;
			}
			$this->view->resName    = $request->resname;
			$this->view->filresId   = $request->filresid;
			
			$this->view->city       = $request->city;
			$this->view->neighbor   = $request->neighbor;
			$this->view->cuisine    = $request->cuisine;
			$this->view->cityBd     = $cityBd;
			$this->view->neighborBd = $neighborBd;
			$this->view->restTypeBd = $restTypeBd;
			$this->view->priceBd    = $price;
		
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * display all the restaurants(google mapview) for the search on with out date and time  
	 */
	public function searchrestaurantslocationAction()
	{
			try{
			$bokService = new Application_Service_Reservation();
			$stateBd    = $bokService->GetStateBaseData();
			//$regionBd	= $bokService->GetRegionBaseData();
			//$cityBd		= $bokService->GetCityBaseData();
			//$neighborBd = $bokService->GetNeighborhodBaseData();
			$restTypeBd = $bokService->GetRestaurantTypesBaseData();
			$price      = $bokService->GetRestaurantPriceBaseData();

			$request = $this->getRequest();

			$result = $this->_reservationService->SearchRestaurants($request);
			$this->view->searchList = $result['searchList'];
			$this->view->prev		   = $result['prev'];
			$this->view->next		   = $result['next'];
			if(isset($result['offset'])){
				$this->view->offset		   = $result['offset'];
			}
			$regionsArray = array();
			if($request->state)
			{
				$regionMapper = new Application_Model_RegionDataMapper();
				$regionObject = new Application_Model_Region();
				$regionObject->setStateId($request->state);
				$regionResult = $regionMapper->getRegionByStateId($regionObject);				
				$regionsArray = $regionResult->getRegionList();				
			}
			$cityArr = array();
		    if($request->region)
			{
				$cityMapper = new Application_Model_CityDataMapper();
				$cityObj = new Application_Model_City();
				$cityObj->setRegionId($request->region);
				$cityBd		= $this->_restService->getCitysByRegionId($cityObj);
				
				$cityArr=$cityBd->getCityList();
			}
			$neighborArr = array();		
			if($request->city)
			{
				$bokService = new Application_Service_Reservation();
				$nghMapper = new Application_Model_NeighborhoodDataMapper();
				$nghObj = new Application_Model_Neighborhood();
				$nghObj->setCityId($request->city);
				$neighborBd = $this->_restService->getNghIdCidyId($nghObj);
				$cityBd		= $bokService->GetCityBaseData();
				$cityArr = $cityBd;
				$neighborArr = $neighborBd->getNeighborhoodList();
			}
			
			$this->view->pax 	  = $request->pax;
			$this->view->state    = $request->state;
			$this->view->region   = $request->region;
			$this->view->city 	  = $request->city;
			$this->view->neighbor = $request->neighbor;
			$this->view->cuisine  = $request->cuisine;
			$this->view->price    = $request->price;
			$this->view->resName  = $request->resname;
			$this->view->filresId = $request->filresid;

			$this->view->stateBd    = $stateBd;
			$this->view->regionBd   = $regionsArray;
			$this->view->cityBd     = $cityArr;
			$this->view->neighborBd = $neighborArr;
			$this->view->restTypeBd = $restTypeBd;
			$this->view->priceBd    = $price;
			
			$bokService = null;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * display Restaurant Details and Booking Summary
	 */
	public function reservationsummaryAction()
	{
		try{
			$request = $this->getRequest();
			$restDetails = $this->_reservationService->GetRestaurantDetails($request);
			$this->view->restdetails = $restDetails;

			$dateSplit = explode("-",$request->resdate);
			$s = mktime(0,0,0,(int)$dateSplit[0],(int)$dateSplit[1],(int)$dateSplit[2]);
			$this->view->date = date("D d M Y",$s);
			$this->view->resdate = $request->resdate;
			$this->view->time = $request->restime;
			$this->view->name = $request->resname;
			$this->view->add = $request->resaddress;
			$this->view->inventoryid = $request->inventoryid;
			$this->view->pax = $request->respax;
			$this->view->restaurantid = $request->restaurantid;
			$this->view->bookingstatus = $request->bookingstatus;
			$this->view->tablesize = $request->tablesize;
			$this->view->nooftables = $request->nooftables;
			$this->view->specialid  = $request->specialid;
			$this->view->booktype   = $request->booktype;
			$this->view->specialamt = $request->specialamt;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * display the booking details including the userDetails entered
	 */
	public function reservationdetailsAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$loginReq = 'Yes';
			$data = array();
			$stateId = "";
			$cityId = "";
			$regionId = "";
			$request = $this->getRequest();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$this->view->userdata = $data;
				if(isset($data['Firstname'])){
					$formData['firstName'] = $data['Firstname'];
				}else{
					$formData['firstName'] = "";
				}
				if(isset($data['LastName'])){
					$formData['lastName'] = $data['LastName'];
				}else{
					$formData['lastName'] = "";
				}
				if(isset($data['Phone'])){
					$formData['number'] = $data['Phone'];
				}else{
					$formData['number'] = "";
				}
				if(isset($data['Email'])){
					$formData['email'] = $data['Email'];
				}else{
					$formData['email'] = "";
				}
				if(isset($data['User_Id'])){
					$formData['userid'] = $data['User_Id'];
				}else{
					$formData['userid'] = "";
				}
				
				if(isset($request->booktype)){
					if($request->booktype == 'SPL'){
						$loginReq = "No";
					}
				}
				if($data['Usertype'] == 'CUS'){
					if(isset($data['State_Id'])){
						$stateId = $data['State_Id'];
					}if(isset($data['City_Id'])){
						$cityId = $data['City_Id'];
					}
					if(isset($data['Region_Id'])){
						$regionId = $data['Region_Id'];
					}
				}			
			}
			$paymentStatus = $request->paymentStatus;
			if($this->getRequest()->isPost()){
				if($bookedData = $this->_reservationService->BookingDetails($this->getRequest()->getPost(),$stateId,$cityId,$regionId)){
					if($bookedData){
						if(!$bookedData['result']){
							$form = $this->_reservationService->getBookingDetailsForm();
			
							$dateSplit = explode("-",$request->resdate);
							$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
							$weekdate = date("Y-m-d", $s);
							
							$formData  = array('resId'=>(int)$request->restaurantid,
				                           'resName'=>$request->resname,
				                           'resAddress'=>$request->resaddress,
				                           'resDate'=>$request->resdate,
				                           'resTime'=>$request->restime,
				                           'pax'=>$request->respax,
										   'inventoryid'=>$request->inventoryid
				
							);
							$this->view->resdate = date('D d M Y',$s);
							$this->view->resname = $request->resname;
							$this->view->resaddress = $request->resaddress;
							$this->view->restime = $request->restime;
							$this->view->respax = $request->respax;
							$this->view->bookingstatus = $request->bookingstatus;
							$this->view->restaurantid = $request->restaurantid;
							$this->view->tablesize = $request->tablesize;
							$this->view->nooftables = $request->nooftables;
				
							$auth = Zend_Auth::getInstance();
							$data = array();
							if($auth->hasIdentity()){
								$storage = new Zend_Auth_Storage_Session();
								$data = $storage->read();
								$this->view->userdata = $data;
								$formData['firstName'] = $data['Firstname'];
								$formData['lastName'] = $data['LastName'];
								$formData['number'] = $data['Phone'];
								$formData['email'] = $data['Email'];
								$formData['userid'] = $data['User_Id'];
								//$formData['notificationType'] = ;
							}
				
				
				
							$form->populate($formData);
							//$form->setDefaults(array('notificationType'	=>	'email'));
				
							$this->view->form = $form;
						}else{
							$bookedData = $bookedData['result'];
							$resid = $request->restaurantid;
							$this->_helper->redirector('reservationconfirmation','Reservation','Reservation',array('bokid'=>$bookedData));
						}
					}
				}
			}else{
				$form = $this->_reservationService->getBookingDetailsForm();
				$request = $this->getRequest();
				
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				
				$formData  = array('resId'=>(int)$request->restaurantid,
	                           'resName'=>$request->resname,
	                           'resAddress'=>$request->resaddress,
	                           'resDate'=>$request->resdate,
	                           'resTime'=>$request->restime,
	                           'pax'=>$request->respax
	
				);
	
				
				$this->view->resdate = date('D d M Y',$s);
				$this->view->resname = $request->resname;
				$this->view->resaddress = $request->resaddress;
				$this->view->resphone = $request->resphone;
				$this->view->restime = $request->restime;
				$this->view->inventoryid = $request->inventoryid;
				$this->view->respax = $request->respax;
				$this->view->bookingstatus = $request->bookingstatus;
	
				$this->view->tablesize = $request->tablesize;
				$this->view->nooftables = $request->nooftables;
				$this->view->specialid  = $request->specialid;
				$this->view->booktype   = $request->booktype;
				$this->view->specialamt = $request->specialamt;
				
				$form->populate($formData);
				$this->view->form = $form;
			}
			//$form->setDefaults(array('notificationType'	=>	'email'));
			$this->view->loginreq = $loginReq;
			$this->view->form = $form;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * 
	 * display the conformation message of the reservation
	 */
	public function reservationconfirmationAction()
	{
		try{
			$request = $this->getRequest();
			$bokid   = $request->bokid;
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$bStat = false;
			if($request->bokstat)
			{
				$bStat = $request->bokstat;
			}
			$this->view->bokStat = $bStat;
			$this->view->bookedData = $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * display the restaurant details
	 */
	public function restaurantinfoAction()
	{
		try{		
			$this->_helper->layout()->setLayout('ddweblayout');
			$request = $this->getRequest();
			//$this->_helper->viewRenderer->setNoRender();
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			if($request->restaurantid){
				$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
			}else{
				$resStat = false;
			}
			
			$this->view->secureLoginStatus = $resStat;
			$restDetails = $this->_reservationService->GetRestaurantDetails($request);
			$x = $restDetails->getRestLongitude();
			$this->view->longi = $x;
			$this->view->restdetails = $restDetails;
			$this->view->category = $request->category;

			if($request->resdate){
				$this->view->resdate = $request->resdate;
			}
			if($request->restime){
				$this->view->time = $request->restime;
			}
			if($request->resname){
				$this->view->name = $request->resname;
			}
			if($request->resaddress){
				$this->view->add = $request->resaddress;
			}
			if($request->respax){
				$this->view->pax = $request->respax;
			}
			if($request->restaurantid){
				$this->view->resid = $request->restaurantid;
			}
			if($request->state){
				$this->view->state = $request->state;
			}
			if($request->region){
				$this->view->region = $request->region;
			}
			if($request->city){
				$this->view->city = $request->city;
			}
			if($request->neighbor){
				$this->view->neighbor = $request->neighbor;
			}
			if($request->cuisine){
				$this->view->cuisine = $request->cuisine;
			}
			if($request->price){
				$this->view->price = $request->price;
			}
			if($request->redaction){
				$this->view->redaction = $request->redaction;
			}
			if($request->time){
				$this->view->searchtime = $request->time;
			}
			if($request->type)
			{
				$this->view->type = $request->type;
			}
			if($request->searchfilresname)
			{
				$this->view->searchfilresname = $request->searchfilresname;
			}
			if($request->filresid)
			{
				$this->view->filresid = $request->filresid;
			}
			if($request->from)
			{
				$this->view->from = $request->from;
			}
			if($request->offset)
			{
				$this->view->offset = $request->offset;
			}
			if($request->prev)
			{
				$this->view->prev = $request->prev;
			}
			if($request->next)
			{
				$this->view->next = $request->next;
			}
			if($request->bokstat)
			{
				$this->view->bokStat = $request->bokstat;
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}
	
	/**
	 * display restaurant special details 
	 */
	public function dealdetailsofrestaurantAction()
	{
		try{
			$request = $this->getRequest();
			$restDetails = $this->_reservationService->GetRestaurantDetails($request);
			$this->view->restdetails = $restDetails;
			$this->view->category = $request->category;

			if($request->resdate){
				$this->view->resdate = $request->resdate;
			}
			if($request->restime){
				$this->view->time = $request->restime;
			}
			if($request->resname){
				$this->view->name = $request->resname;
			}
			if($request->resaddress){
				$this->view->add = $request->resaddress;
			}
			if($request->respax){
				$this->view->pax = $request->respax;
			}
			if($request->restaurantid){
				$this->view->resid = $request->restaurantid;
			}
			if($request->city){
				$this->view->city = $request->city;
			}
			if($request->neighbor){
				$this->view->neighbor = $request->neighbor;
			}
			if($request->cuisine){
				$this->view->cuisine = $request->cuisine;
			}
			if($request->price){
				$this->view->price = $request->price;
			}
			if($request->redaction){
				$this->view->redaction = $request->redaction;
			}
			if($request->time){
				$this->view->searchtime = $request->time;
			}
			if($request->type)
			{
				$this->view->type = $request->type;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}
	
	/** 
	 * display all the reservations of the restaurant for that day and dining areas
	 */
	public function floorplanAction()
	{
		try{
			$this->view->todaydate = date("m-d-Y");
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				//$this->_helper->layout()->setLayout('desklayout');
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$this->view->userId = $data['User_Id'];
				$this->view->companyid = $data['companyid'];
				$this->view->userStatus = $data['Usertype'];
				$this->view->userPermissions = $data['Permissions'];
				if(array_key_exists('LastLoginDate', $data))
				{
					$this->view->lastLogin = $data['LastLoginDate'];
				}
				else
				{
					$this->view->lastLogin = '';
				}
				if($data['Usertype'] == "RSO" || $data['Usertype'] == "ADM" || $data['Usertype'] == "ADU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "RSU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "SRU"){
					$restNameList = $data['restList'];
				}
				
				if(isset($request->restaurantid)){
					$restId = $request->restaurantid;
				}else{
					$restId = $data['RestId'];
					$request->setParam('restaurantid',$restId);
					$x = $request->restaurantid;
				}
				
				$menu = $this->_reservationService->getReservationMenu($restId);
				$this->view->menu = $menu;
				$NameList = array();
				//echo '<pre>'; print_r($data); exit;
				foreach($restNameList as $resNameVal){
					$NameList[$resNameVal['key']] = $resNameVal['value'];
				}
				$timeSettingsResult = $this->_reservationService->reteriveWaitingreservationQuoteTimes($request);
				$this->view->timeSettingsResult = $timeSettingsResult;
				$form = $this->_reservationService->getQuoteTimeSettingsForm();
				$this->view->quoteform = $form;
				$userService = new Application_Service_Client();
				$restUsers = $userService->getRestaurantOwnersAndUsersByRestId($restId);
				if($request){
					if(array_key_exists($restId,$NameList)){
						$form = $this->_reservationService->getMakeReservationForm();
						$mealsData = $this->_reservationService->getMealsByResid($restId,'settings');
						$form->resTime->addMultiOptions($mealsData['times']);
						$waitingForm = $this->_reservationService->getWaitingReservForm();
						$walkinForm = $this->_reservationService->getWalkInReservForm();
						$bokform = $this->_reservationService->getBlockReservForm();
						$result = $this->_reservationService->ReservationDesk($request,$data);
						$TableLayoutStr 		   = $result['Layout'];
						$this->view->finalStr 	   = $TableLayoutStr['finalStr'];
						$this->view->floorSepStr   = $result['FloorSep'];
						$this->view->etnStr 	   = $TableLayoutStr['etnStr'];
						$this->view->diningares	   = $result['diningareas'];
						$this->view->diningid	   = $result['diningid'];
						$this->view->InQueueList   = $result['InQueue'];
						$this->view->TableStatus   = $result['TableStatus'];
						$this->view->AttendingList = $result['Attending'];
						$this->view->WaitingList   = $result['WaitingList'];
//						$this->view->OverBooking   = $result['OverBooking'];
						$this->view->FreezeStatus  = $result['FreezeStatus'];
						$this->view->RestLogo      = $result['RestLogo'];
						$this->view->FreezedDates = $result['FreezedDates'];
						$this->view->NoShowCount = $result['No-Show'];
						$this->view->Completed = $result['Completed'];
						$this->view->CompletedList = $result['CompletedList'];
						$this->view->mealType 		= $result['mealType'];
						$this->view->reservCount 	= $result['reservCount'];
						$this->view->serverList = $result['ServerList'];
            //echo '<pre>'; print_r($result['ServerList']); exit;
						if(isset($result['mealCount'])){
							$this->view->mealCount = $result['mealCount'];
						}
//						$this->view->quotedList = $result['quotedList'];
						if(array_key_exists('Alert',$result)){
							$this->view->Alertmessage = $result['Alert'];
						}
						else
						{
							$this->view->Alertmessage = '';
						}
//						$this->view->AlertStstus   = $result['AlertStstus'];
						if(array_key_exists('Alertusertype', $result))
						{
							$this->view->usertype 	   = $result['Alertusertype'];
						}
						else
						{
							$this->view->usertype 	   = '';
						}
//						$this->view->paymentstatus = $result['paymentstatus'];
						if(isset($result['chartImg'])){
							$this->view->chartImg = $result['chartImg'];
						}else{
							$this->view->chartImg = "";
						}
						$this->view->selectedTab = $request->selTab;
						if(isset($request->bokstat)){
							$this->view->bokStat = $request->bokstat;
						}else{
							$this->view->bokStat = '';
						}
						if(isset($request->act)){
							$this->view->act = $request->act;
						}
						$form->reservationInitials->addMultiOptions($restUsers);
						if($data['Usertype'] == 'ADM' || $data['Usertype'] == 'ADU'){
							$form->setDefaults(array('reservationInitials'=> $data['restownerId']));
						}else{
							$form->setDefaults(array('reservationInitials'=> $data['User_Id']));
						}						
						$restDetails = $this->_reservationService->GetRestaurantDetails($request);
						$this->view->restdetails = $restDetails;
						if($restDetails->getresbookingoption_setting()){
							$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
							if(count($bookingoptions) > 1){
								$form->bokoptions->addMultiOptions($bookingoptions);
								$this->view->bokoptionsts   = true;
							}else{
								$this->view->bokoptionsts   = false;
							}							
						}else{
							$this->view->bokoptionsts   = false;
						}
						
						$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
				    	$CountryCode = $CountryCodeMapper->fetchAll();
           $countrycodenew = $CountryCodeMapper->getCountryCode();
				    	$CodeList = array();
				    	$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
               /*
				    	foreach($CountryCode as $listcode){
				    		$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
				    	}*/
             foreach($countrycodenew as $listcode){
               $CodeList[] = array('key'=>$listcode['key'],'value'=>$listcode['value']);
		    	   }	
					    //echo '<pre>'; print_r($CodeList); exit;
				    	$this->view->codelist = $CodeList;
						
						$restDataMapper = new FirmManagement_Model_FirmDataMapper();
						$countrycode = $restDataMapper->getCountrycodebyId($restId);
						if($countrycode){
							$formValues = array('countryCode' => $countrycode);
							$this->view->countrycode = $countrycode;
							$form->populate($formValues);
							$waitingForm->populate($formValues);	
							$walkinForm->populate($formValues);	
							$bokform->populate($formValues);				
						}
				    	
						$this->view->MakeResForm   = $form;
						$this->view->MakeWaitingResForm = $waitingForm;
						$this->view->MakewalkinForm = $walkinForm;
						$this->view->blockform = $bokform;
						$addcontactform = $this->_reservationService->getAddCustomerContactForm();
						$this->view->addcontact = $addcontactform;
						$this->view->restaurantid  = $request->restaurantid;
						
						if($request->date){
							$tSel = explode('-',$request->date);
							if($tSel[0] > 12){
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
							}else {
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
							}
						}else{
							$this->view->date = date("m-d-Y");
							$this->view->formDateVal = date("d M Y");
						}
						if(isset($request->makereservationstatus)){
							$this->view->makereservationstatus = $request->makereservationstatus;
						}
						$this->view->secureLoginStatus = 'true';
						$this->view->diningPeriods = $result['meal_periods'];
					}else{
						$restDetails = $this->_reservationService->GetRestaurantDetails($request);
						$this->view->restdetails = $restDetails;
						$this->view->restaurantid  = $request->restaurantid;
						
						if($request->date){
							$tSel = explode('-',$request->date);
							if($tSel[0] > 12){
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
							}else {
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
							}
						}else{
							$this->view->date = date("m-d-Y");
							$this->view->formDateVal = date("d M Y");
						}
						$this->view->secureLoginStatus = 'false';
					}
					$mealPeriod = $request->meal;
					if(isset($mealPeriod))
					{
						$this->view->mealPeriod = $mealPeriod;
					}
					else
					{
						$this->view->mealPeriod = '';
					}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * 	auto refresh to retreive the reservations of the restaurant using ajax call
	 */
	public function ajaxfloorplanAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$results = $this->_reservationService->Ajax_ReservationDesk($request);
			echo $results;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	/**
	 * 		auto refresh to retreive the blocked reservations of the restaurant using ajax call
	 */	
	public function inlinereservationspostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();

			$results = $this->_reservationService->Ajax_InQueueList($request);
			echo $results;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/** 
	 * display the reservations of the restaurant based on date and slots  
	 */
	public function reservationlistAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$this->view->userStatus = $data['Usertype'];
				$this->view->userPermissions = $data['Permissions'];
				
				if($data['Usertype'] == "RSO"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "RSU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "SRU"){
					$restNameList = $data['restList'];
				}
				$restId = $request->restaurantid;
				$NameList = array();
				
				foreach($restNameList as $resNameVal){
					$NameList[$resNameVal['key']] = $resNameVal['value'];
				}
				
				if(isset($request->bokstat)){
					$this->view->bokStat = $request->bokstat;
				}else{
					$this->view->bokStat = '';
				}
				if($request){
					if(array_key_exists($restId,$NameList)){
						$form = $this->_reservationService->getMakeReservationForm();
						$result = $this->_reservationService->ReservationList($request);
						if(isset($result['slots'])){
							$this->view->bookingList = $result['slots'];
						}
						$this->view->diningareas = $result['diningareas'];
	//					$this->view->chartImg = $result['chartImg'];
						$TableLayoutStr 		   = $result['layout'];
						$this->view->finalStr 	   = $TableLayoutStr['finalStr'];
						$this->view->etnStr 	   = $TableLayoutStr['etnStr'];
						$this->view->TableStatus   = $result['TableStatus'];
						$this->view->prev		   = $result['prev'];
						$this->view->next		   = $result['next'];
						$this->view->FreezedDates = $result['FreezedDates'];
	
						if(isset($result['offset'])){
							$this->view->offset		   = $result['offset'];
						}
						if(isset($result['nextvalue'])){
							$this->view->nextval     = $result['nextvalue'];
						}
						$this->view->FreezeStatus  = $result['FreezeStatus'];
						if($result['date']){
							$this->view->date = $result['date'];
						}else{
							$this->view->date = date("m-d-Y");
						}
	
						if($result['RestLogo']){
							$this->view->RestLogo  = $result['RestLogo'];
						}
						if($result['RestName']){
							$this->view->RestName = $result['RestName'];
						}
	
						$this->view->restaurantid  = $request->restaurantid;
						$this->view->MakeResForm   = $form;
						$bokform = $this->_reservationService->getBlockReservForm();
						$this->view->blockform = $bokform;
						$addcontactform = $this->_reservationService->getAddCustomerContactForm();
						$this->view->addcontact = $addcontactform;
						$restDetails = $this->_reservationService->GetRestaurantDetails($request);
						$this->view->restdetails = $restDetails;
	
						if(isset($request->makereservationstatus)){
							$this->view->makereservationstatus = $request->makereservationstatus;
						}
						if(isset($request->addcontactstatus)){
							$this->view->addcontactstatus = $request->addcontactstatus;
						}
						$this->view->secureLoginStatus = 'true';
					}else{
						$this->view->secureLoginStatus = 'false';
					}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/** 
	 * display the reservations report for all the reservations with diffrent search criteria taken by restaurant
	 */
	public function reservationhistoryAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$this->view->userStatus = $data['Usertype'];
				$this->view->userPermissions = $data['Permissions'];
				
				if($data['Usertype'] == "RSO" || $data['Usertype'] == 'ADM' || $data['Usertype'] == 'ADU'){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "RSU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "SRU"){
					$restNameList = $data['restList'];
				}
				$request = $this->getRequest();
				$restId = $request->restaurantid;
				$NameList = array();
				
				foreach($restNameList as $resNameVal){
					$NameList[$resNameVal['key']] = $resNameVal['value'];
				}
				
				if(array_key_exists($restId,$NameList)){
					$page = $this->_request->getParam('page');
					if (empty($page)){
						$page = 1;
					}
					if($this->getRequest()->isPost()){
						$this->view->viewtab = 'tab';
					}
					if(isset($data['DefaultView']))
					{
						$this->view->defaultview = $data['DefaultView'];
					} 
					$result = $this->_reservationService->ReservationReport($request,$page);
					$bokstatus = $this->_reservationService->getBookingStatusBd();
	
					if($request->reserveid){
						$this->view->reservid = $request->reserveid;
					}
					if($request->bokstartdate){
						$formatSd = date('m-d-Y',strtotime($request->bokstartdate));
						$this->view->bokstartdate = $request->bokstartdate;
						$this->view->formatSd = $formatSd;
					}
					if($request->bokenddate){
						$formatEd = date('m-d-Y',strtotime($request->bokenddate));
						$this->view->bokenddate = $request->bokenddate;
						$this->view->formatEd = $formatEd;
					}
					if($request->bokstarttime){
						$this->view->bokstarttime = $request->bokstarttime;
					}
					if($request->bokendtime){
						$this->view->bokendtime = $request->bokendtime;
					}
					if($request->bookstatus){
						$bookingstatus = $request->bookstatus;
						$bokstsarr = array();
						foreach($bookingstatus as $types){
							$bokstsarr[] = $types;
						}
						$this->view->status = $bokstsarr;
					}
					if($request->bokdatetype){
						$this->view->datetype = $request->bokdatetype;
					}
					if($request->restaurantid){
						$this->view->restaurantid = $request->restaurantid;
					}
					if($request->date){
						$this->view->date = $request->date;
					}else{
						$this->view->date = date("m-d-Y");
					}
					
					if($request->origin){
						$origin = $request->origin;
						$originsarr = array();
						foreach($origin as $types){
							$originsarr[] = $types;
						}
						$this->view->origin = $originsarr;
					}
					
					if($request->reportsorton){
						$this->view->reportsorton = $request->reportsorton;	
					}
					
					if($request->reportsortorder){
						$this->view->reportsortorder = $request->reportsortorder;
					}
					
					$form = $this->_reservationService->getMakeReservationForm();
					$this->view->MakeResForm   = $form;
					$this->view->rowSet 	   = $result['RowSet'];
					$this->view->counts        = $result['Count'];
					if($result['RestLogo']){
						$this->view->RestLogo  = $result['RestLogo'];
					}
					if($result['RestName']){
						$this->view->RestName = $result['RestName'];
					}
					$this->view->bokStatus = $bokstatus;
					$addcontactform = $this->_reservationService->getAddCustomerContactForm();
					$this->view->addcontact = $addcontactform;
					$restDetails = $this->_reservationService->GetRestaurantDetails($request);
					$this->view->restdetails = $restDetails;
					if($restDetails->getresbookingoption_setting()){
						$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
						if(count($bookingoptions) > 1){
							$form->bokoptions->addMultiOptions($bookingoptions);
							$this->view->bokoptionsts   = true;
						}else{
							$this->view->bokoptionsts   = false;
						}							
					}else{
						$this->view->bokoptionsts   = false;
					}
					if(isset($request->makereservationstatus)){
						$this->view->makereservationstatus = $request->makereservationstatus;
					}
					if(isset($request->addcontactstatus)){
						$this->view->addcontactstatus = $request->addcontactstatus;
					}
					$this->view->secureLoginStatus = 'true';
				}else{
					$this->view->secureLoginStatus = 'false';
				}
				
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * 	retreive the restaurantnames by id
	 */	
	public function retreivefirmnamesbyidpostAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();

				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				
				$resultObj = $this->_restService->GetRestNameById($data);

				$jsonObj = json_encode($resultObj);
				echo $jsonObj;
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action for allocating the table for the reservation
	 */
	public function assigntableAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				
				$request = $this->getRequest();
				$result = $this->_reservationService->AllocateSeat($request, $data);
				if($result['status']){
					echo "t";


				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function assigntablepartlyAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				
				$request = $this->getRequest();
				$result = $this->_reservationService->PartiallyAllocateSeat($request, $data);
				if($result['status']){
					echo "t";
//					if(isset($request->selTab)){
//						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> date("m-d-Y"),'selTab'=>$request->selTab));
//					}else{
//						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> date("m-d-Y")));
//					}

				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action for allocating the table for the reservation from listview
	 */	
	public function assignlisttableAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->AllocateSeat($request);
				if($result['status']){
					if(isset($request->selTab)){
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> $request->date,'selTab'=>$request->selTab));
					}else{
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> $request->date));
					}


				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * action for pre-allocating the table for the reservation
	 */	
	public function assigntablebeforeguestAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				
				$request = $this->getRequest();
				$result = $this->_reservationService->PreAllocateSeat($request, $data);
				if($result['status']){
					echo "t";


				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * action for pre-allocating the table for the reservation from listview
	 */	
	public function assigntablebeforeguestlistAction()
	{
		try{


			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->PreAllocateSeat($request);
				if($result['status']){
					if(isset($request->selTab)){
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> $request->date,'selTab'=>$request->selTab));
					}else{
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> $request->date));
					}


				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * action for moving the reservation to a different table
	 */	
	public function changetableAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->MoveParty($request);
				if($result['status']){
					echo "t";

				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * action for moving the reservation to a different table in listview
	 */
	public function changetablelistAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->MoveParty($request);
				if($result['status']){
					if(isset($request->selTab)){
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> $request->date,'selTab'=>$request->selTab));
					}else{
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> $request->date));
					}

				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action for making the reservation by the restaurant from listview
	 */	
	public function takeareservationAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$stateId = "";
				$cityId = "";
				$regionId = "";
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$resid = $request->restaurantid;
				$values = $this->getRequest()->getPost();

				if(isset($data['State_Id'])){
					$stateId = $data['State_Id'];
				}
				if(isset($data['City_Id'])){
					$cityId = $data['City_Id'];
				}
				if(isset($data['Region_Id'])){
					$regionId = $data['Region_Id'];
				}
				
				$result = $this->_reservationService->MakeReservation($this->getRequest()->getPost(),$data['User_Id'],$stateId,$cityId,$regionId);

				if(!$result['result']){
					$result = 0;
				}
				if($request->date){
					$date = $request->date;
				}else{
					$date = date("m-d-Y");
				}
				if(isset($request->selTab)){
					return $this->_helper->redirector($request->returnAction,'Reservation','Reservation',
					array('restaurantid' => $request->restaurantid,
												  		'makereservationstatus' => $result['result'],
														'addcontactstatus'=>$request->addcontactstatus,
														'date'=> $date,
														'selTab'=>$request->selTab
					));
				}else{
					return $this->_helper->redirector($request->returnAction,'Reservation','Reservation',
					array('restaurantid' => $request->restaurantid,
												  		'makereservationstatus' => $result['result'],
														'addcontactstatus'=>$request->addcontactstatus,
														'date'=> $date));
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}

	/**	
	 * 	action for making the reservation by the restaurant using ajax call
	 */	
	public function takeareservationbypostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			$stateId = "";
			$cityId = "";
			$regionId = "";
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$resid = $request->restaurantid;
				if(isset($data['State_Id'])){
					$stateId = $data['State_Id'];
				}
				if(isset($data['City_Id'])){
					$cityId = $data['City_Id'];
				}
				if(isset($data['Region_Id'])){
					$regionId = $data['Region_Id'];
				}
				$blockStatus = $request->blockedStatus;
				//echo '<pre>'; print_r($this->getRequest()->getPost()); exit;
				$result = $this->_reservationService->MakeReservation($this->getRequest()->getPost(),$data['User_Id'],$stateId,$cityId,$regionId,'widget');

				if($request->date){
					$date = $request->date;
				}else{
					$date = date("m-d-Y");
				}
				if(!$result['result']){
					echo json_encode($result);
				}else{
					if(($blockStatus == 1) && ($request->notificationType == 'email' || $request->notificationType == 'both')){
						echo json_encode($result);
					}else{
						echo json_encode(array('restid'=>$resid,'date'=>$date,'booking'=>$result['booking'],'result'=>$result['result']));
					}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}

	/**	
	 * 	action for blocking a reservation  
	 */	
	public function blockareservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$resid = $request->restaurantid;
				$bokid = $request->bokid;
				$result = $this->_reservationService->MakeBlockReservation($request,$bokid,$resid);

				if($request->date){
					$date = $request->date;
				}else{
					$date = date("m-d-Y");
				}
				if(!$result){
					$result = 0;
				}else{
					echo "t";
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}

	/**	
	 * 	action for blocking the reservations from listview
	 */	
	public function blockareservationlistAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$resid = $request->restaurantid;
				$bokid = $request->bokid;
				$result = $this->_reservationService->MakeBlockReservation($request,$bokid,$resid);

				if($request->blkdate){
					$date = $request->blkdate;
				}else{
					$date = date("m-d-Y");
				}
				if(!$result){
					$result = 0;
				}
				if(isset($request->selTab)){
					return $this->_helper->redirector($request->blkreturnAction,'Reservation','Reservation',
					array('restaurantid' => $request->restaurantid,
								  'date'=> $date,
								  'selTab'=>$request->selTab));
				}else{
					return $this->_helper->redirector($request->blkreturnAction,'Reservation','Reservation',
					array('restaurantid' => $request->restaurantid,

														'date'=> $date));
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}
	
	/**	
	 * 	action for changing the table table status
	 */	
	public function updatereservationstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
// 			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				
				$request = $this->getRequest();
				$result = $this->_reservationService->ChangeTableStatus($request, $data);
				if($result['status']){
					if(isset($request->bokaction)){
						if($request->bokaction == 'SHOW'){
							echo $result['count'];
						}else{
							echo "t";
						}
					}else{
							echo "t";
						}
				}else{
					echo 'f';
				}
// 			}else{
// 				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
// 			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action for changing the table table status from listview
	 */	
	public function updatereservationstatuslistAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				
				$request = $this->getRequest();
				$result = $this->_reservationService->ChangeTableStatus($request, $data);
				if($result['status']){
					if(isset($request->selTab)){
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> $request->date,'selTab'=>$request->selTab));
					}else{
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$result['restaurant_id'],'date'=> $request->date));
					}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	


	
	/**	
	 * 	display the restaurants avaliable slots and the mapview of the restaurant for the search on date and time
	 */
	public function searchlocationAction()
	{
		try{
			$bokService = new Application_Service_Reservation();
			$stateBd    = $bokService->GetStateBaseData();
			//$regionBd		= $bokService->GetRegionBaseData();
			$restTypeBd = $bokService->GetRestaurantTypesBaseData();
			$price = $bokService->GetRestaurantPriceBaseData();

			$request = $this->getRequest();
			//$this->_helper->layout()->setLayout('searchlayout');
			$page = $this->_request->getParam('page');
			if (empty($page)){
				$page = 1;
			}
			$result = $this->_reservationService->SearchMapView($request,$page);
			$this->view->searchList = $result['searchList'];
			$regionsArray = array();
			if($request->state)
			{
				$regionMapper = new Application_Model_RegionDataMapper();
				$regionObject = new Application_Model_Region();
				$regionObject->setStateId($request->state);
				$regionResult = $regionMapper->getRegionByStateId($regionObject);				
				$regionsArray = $regionResult->getRegionList();				
			}
			$cityArr = array();
			if($request->region)
			{
				$cityMapper = new Application_Model_CityDataMapper();
				$cityObj = new Application_Model_City();
				$cityObj->setRegionId($request->region);
				$cityBd		= $this->_restService->getCitysByRegionId($cityObj);
				$cityArr=$cityBd->getCityList();
			
			}
			$neighborArr = array();		
			if($request->city)
			{
				$nghMapper = new Application_Model_NeighborhoodDataMapper();
				$nghObj = new Application_Model_Neighborhood();
				$nghObj->setCityId($request->city);
				$neighborBd = $this->_restService->getNghIdCidyId($nghObj);
				$neighborArr=$neighborBd->getNeighborhoodList();
			}
			$this->view->state  = $request->state;
			$this->view->region = $request->region;
			$this->view->city = $request->city;
			$this->view->neighbor = $request->neighbor;
			$this->view->cuisine = $request->cuisine;
			$this->view->time = $result['time'];
			$this->view->date = $result['date'];
			$this->view->pax = $result['pax'];
			$this->view->resid = $result['resid'];
			if($request->price){
				$this->view->price = $result['price'];
			}
			$this->view->resName = $request->resname;
			$this->view->filresId = $request->filresid;
			
			$this->view->stateBd    = $stateBd;
			$this->view->regionBd   = $regionsArray;
			$this->view->cityBd     = $cityArr;
			$this->view->neighborBd = $neighborArr;
			$this->view->restTypeBd = $restTypeBd;
			$this->view->priceBd = $price;
			$bokService = null;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to add a note to the reservation 
	 */	
	public function reservationinfoAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->AddReservationNote($request);
				if($request->date){
					$date = $request->date;
				}else{
					$date = date("m-d-Y");
				}
				if($result){

					echo json_encode(array('res'=>$result,'status'=>'t'));
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to add a note to the reservation from listview
	 */	
	public function reservationinfolistAction()
	{
		try{


			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->AddReservationNote($request);
				if($request->date){
					$date = $request->date;
				}else{
					$date = date("m-d-Y");
				}
				if($result){
					if(isset($request->selTab)){
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$request->restaurantid,'date'=> $date,'selTab'=>$request->selTab));
					}else{
						return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$request->restaurantid,'date'=> $date));
					}
				}else{
					return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$request->restaurantid,'date'=> $date));



				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to freeze the restaurant slots 
	 */
	public function blockscheduleAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$freezedDates = $this->_reservationService->FreezeReservation($request,$data['User_Id']);
				if($request->date){
					$date = $request->date;
					echo json_encode($date);
				}else{
					echo json_encode('f');
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function blockscheduledescriptionAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->manageFreezeDescription($request);
			if($result){
				echo json_encode($result);			
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to freeze the restaurant slots from list view
	 */	
	public function blockschedulelistAction()
	{
		try{


			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$status = $this->_reservationService->FreezeReservation($request,$data['User_Id']);
				if($request->date){
					$date = $request->date;
				}else{
					$date = date("m-d-Y");
				}
				if($status){
					return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$request->restaurantid,'date'=>$date));


				}

			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to unfreeze the restaurant slots 
	 */	
	public function unblockscheduleAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				if($request->date){
					$date = $request->date;
				}else{
					$date = date("m-d-Y");
				}

				$freezedDates = $this->_reservationService->UnFreezeReservation($request,$data['User_Id']);
				if($freezedDates){

					//return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$request->restaurantid,'date'=>$date));
					echo json_encode($freezedDates);
				}

			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to unfreeze the restaurant slots from listview
	 */	
	public function unblockschedulelistAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				if($request->date){
					$date = $request->date;
				}else{
					$date = date("m-d-Y");
				}

				$status = $this->_reservationService->UnFreezeReservation($request,$data['User_Id']);
				if($status){
					return $this->_helper->redirector($request->get_action,'Reservation','Reservation',array('restaurantid'=>$request->restaurantid,'date'=>$date));


				}

			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to retreive the restaurant details by owner id 
	 */	
	public function retreiverestaurantdetailsbyidpostAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();

				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				
				$resultObj = $this->_restService->GetRestDataById($data);

				$jsonObj = json_encode($resultObj);
				echo $jsonObj;
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to block the table using ajax action
	 */	
	public function holdpartypostAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$data = array();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$request = $this->getRequest();
				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				$result = $this->_reservationService->BlockTable($request,$data);

				if($result){
					echo $result;
				}else{
					echo 'f';
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function unholdpartypostAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$data = array();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$request = $this->getRequest();
				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				$result = $this->_reservationService->UnBlockTable($request,$data);

				if($result){
					echo $result;
				}else{
					echo 'f';
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to make multiple reservations block from reservation list
	 */	
	public function holdpartiesAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			$data = array();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$request = $this->getRequest();


				$result = $this->_reservationService->BlockTable($request,$data);

				if($result){
					echo "t";
				}else{
					echo "f";
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to retreive the times for blocking the slot using ajax call
	 */
	public function retreiveslotstoholdpaxpostAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				$results = $this->_reservationService->getRestTimingsByPax($request,"BKD");
				$res = json_encode($results);
				echo $res;
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * action to retrieve the times for unblocking the slot using ajax call
	 */
	public function retreiveslotstounholdpaxpostAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				$results = $this->_reservationService->getRestTimingsByPax($request,"UNBKD");
				$res = json_encode($results);
				echo $res;
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to retreive the restaurant slots using ajax call
	 */	
	public function retreivefirmslotsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
      //echo '<pre>'; print_r($request); exit;
			$results = $this->_reservationService->getRestaurantTimings($request);
			$searchListArr = array();
			if(isset($results)){
				$index = 0;
				if($request->fromaction == 'reservation'){
					foreach($results as $listval){
						$searchListArr[$index] = $listval;
						$index++;
					}
				}else{
					foreach($results as $listval){
						if($listval['status'] == 'WAL'){
							continue;
						}else{
							$searchListArr[$index] = $listval;
							$index++;
						}
					}
				}
			}			
			echo json_encode($searchListArr);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	} 

	/**	
	 * 	action to retreive the schedule timings using ajax call
	 */
	public function retreivescheduledslotsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$results = $this->_reservationService->getSchdTimings($request);
			echo json_encode($results);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to cancel the schedule 
	 */
	public function cancelreservationstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->ChangeTableStatusToCan($request);
			$returnAction = $request->returnAction;
			if($request->date){
				$date = $request->date;
			}else{
				$date = date("m-d-Y");
			}
			//return $this->_helper->redirector($returnAction,'Reservation','Reservation',array('restaurantid'=>$request->restaurantid,'bookingid'=>$request->bookingid,'date'=>$date,'selTab'=>$request->selTab));
			$s = json_encode($result);
			echo $s;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	

	
	/**
	 * 	action to display the widget of the restaurant
	 */
	public function reservationwidgetAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$restService = new Application_Service_Firm();

			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->userlogstat = 'true';
			}else{
				$this->view->userlogstat = 'false';
			}
			//$form = new Application_Form_Search();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}			
			if(isset($request->bokSrcComp)){
				$this->view->bokSrcComp = $request->bokSrcComp;
			}else{
				$this->view->bokSrcComp = 'INAT';
			}			
			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($resid);
			date_default_timezone_set($timezone);
			
			$specialserv = new Application_Service_Deals();
			/*code to retrive the tagline*/
			$splTag = '';
			$tagline = $specialserv->GetSpecialTagLineByResId($resid);
			if($tagline){
				$splTag=$tagline->spl_tag_tagline;
			}
			$this->view->tagLine=$splTag;
			//-------------------------------//
			
			/*special status by date*/
//			$splStat = $specialserv->getRestaurantSpecialByDate($request);
			$restDataMapper = new FirmManagement_Model_FirmDataMapper();
			$splstatus = $restDataMapper->GetSpecialSetting($resid);
			$splcheck = $splstatus->resspecialsetting;
			$this->view->splStat = 1;
			$this->view->splcheck = $splcheck;
			
			$widsettings = $this->_restService->getRestaurantCustomizeWidgetByResid($resid);
			if($widsettings){
				$this->view->widsettings = $widsettings;
			}
			
			if($this->getRequest()->isPost()){
				$postBool = true;
				
					
				$maxPartyRes = "";
				$maxParty = "";
				$maxPartyAllowed = "Yes";
				$minParty = "";
				// BEGIN Getting Max and Min Party Sizes Day Wise//	
				$dateSplit = explode("-",$request->date);
				$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));	 
				
				$object = new FirmManagement_Model_FirmDayPartySettings();
				$object->setrdpsfk_restaurants($resid);	
				$mapper = new FirmManagement_Model_FirmDayPartySettingsMapper();
				$resultArray = $mapper->GetDayPartySize($object);
				$maxallowedsize = $resultArray['ressize'];
				$tempdata = $resultArray['times'];
				foreach($tempdata as $item)
				{
					$x=strtoupper($item['day']);
					$y=strtoupper($weekday);
					$z = strcmp ($x,$y);
					if(!$z){
						if($item['daystatus'])
						{
							$maxParty = $item['maxsize'];
							$minParty = $item['minsize'];
							
						}else{
							
							$maxParty = $maxallowedsize;
							$minParty = 1;
							
						}
						break;
					}else{
							
							$maxParty = $maxallowedsize;
							$minParty = 1;
							
						}
				}
				
				if(!$resultArray){
						$maxParty = $maxallowedsize;
						$minParty = 1;
				}
				if(($request->pax > $maxParty || $request->pax < $minParty)){
					$maxPartyAllowed = "No";	
				}
				// END Getting Max and Min Party Sizes Day Wise//	
				$searchList = $this->_reservationService->GetRestTimingsFromWidget($request, $resid);
				$index = 0;  
				if($searchList){
					foreach($searchList as $listval){
						if($listval['status'] == 'WAL'){
							continue;
						}else{
							$searchListArr[$index] = $listval;
							$index++;
						}
					}
				}else{
					$frezresult = $this->_reservationService->getFreezeTypeByDate($request);
					if($frezresult){

						$this->view->freezedesc = $frezresult['desc'];
					}else{
						$serv = new Application_Service_Firm();
						$msg = $serv->getRestaurantTimeSearchMessage($request->restid);
						$this->view->freezedesc = $msg->resbooking_search_msg;
					}
				}
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				
				
				$this->view->searchlist = $searchListArr;
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->mealtype = $request->mealtype;
				$this->view->forDate = $weekdate;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
								
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->resPhone	= $resDetails->getRestphone();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
				$this->view->maxPartyStatus = $maxPartyAllowed;
				$this->view->maxParty = $maxParty;
				$this->view->minParty = $minParty;
				$this->view->resCompanyid = $resDetails->getcompanyid();
				
				
			}else{
				$this->view->restid = $resid;
				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resCompanyid = $resDetails->getcompanyid();
				$this->view->resDetails = $resDetails;
				$this->view->mealTypes = $this->_reservationService->getRestaurantMealTypes($request);
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$owner = new FirmManagement_Model_OwnerByRestaurantId();
				$owner->setRestaurantId($resid);
				$resownername = $mapper->getOwnerByRestId($owner);
				$restList = '';
				if($resownername){
					$restNameByOwnObj = new FirmManagement_Model_FirmNamesByOwnerId();
					$restNameByOwnObj->setRestOwnerId($resownername->getRestUser());
					$restList   = $mapper->getRestaurantDataByOwnerId($restNameByOwnObj);
					$this->view->restList = $restList;
				}
				$this->view->postBool = $postBool;
				$this->view->resCompanyid = $resDetails->getcompanyid();
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function reservationwidgetrestlocationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$searchListArr = array();
			$searchList = $this->_reservationService->GetRestTimingsOnLocFromWidget($request);
			$index = 0;
			if($searchList){
				foreach($searchList as $key=>$listval){
					if($listval['sch']){
						$searchArr = array();
						foreach ($listval['sch'] as $searchData){
							if($searchData['status'] == 'WAL'){
								continue;
							}else{
								$searchArr[$index] = $searchData;
								$index++;
							}
						}
						$searchListArr[$key]['sch'] = $searchArr;
						$searchListArr[$key]['details'] = $listval['details'];
					}
				}
			}
			echo json_encode($searchListArr);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivetimesAction()
	{
		try{
			
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			if($request){
				$resid = $request->restaurantid;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype($request->splFrom);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,1);
				$index = 0; 
				$searchListArr = Array();
				if($searchList[0]){
					$List = $searchList[0][$request->splid];
					if($List->getTimesArray()){
						foreach($List->getTimesArray() as $listval){
							if($listval['status'] == 'WAL'){
								continue;
							}else{
								$searchListArr[$index] = $listval;
								$index++;
							} 
						}					
						echo json_encode($searchListArr);
					}else{
						echo json_encode('f');
					}
				}else{					
					echo json_encode('f');
				} 
				
			}else{
				echo json_encode('f');
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialreservationwidgetretreivetimesAction()
	{
		try{
			
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			if($request){
				$resid = $request->restaurantid;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype($request->splFrom);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,1);
				$index = 0; 
				$searchListArr = Array();
				if($searchList[0]){
					$List = $searchList[0][$request->splid];
					if($List->getTimesArray()){
						foreach($List->getTimesArray() as $listval){
							if($listval['status'] == 'WAL'){
								continue;
							}else{
								$searchListArr[$index] = $listval;
								$index++;
							} 
						}					
						echo json_encode($searchListArr);
					}else{
						echo json_encode('f');
					}
				}else{					
					echo json_encode('f');
				} 
				
			}else{
				echo json_encode('f');
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function dealwidgetreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			$check = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			
			$restService = new Application_Service_Firm();

			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			
			if($this->getRequest()->isPost()){
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$limit = '';
				$offset = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;	
					}else{
						$limit = 2;	
					}
					
					$check = $searchList[1];	
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}else{
					$frezresult = $this->_reservationService->getFreezeTypeByDate($request);
					if($frezresult['type'] == 'All'){
						$frzdescMap = $this->_reservationService->getFreezeDesc($request);
						if($frzdescMap && $frzdescMap->rfdm_desc){
							$this->view->freezedesc = $frzdescMap->rfdm_desc;
						}else{
							$serv = new Application_Service_Firm();
							$msg = $serv->getRestaurantTimeSearchMessage($request->restid);
							$this->view->freezedesc = $msg->resbooking_search_msg;
						}
					}else{
						$serv = new Application_Service_Firm();
						$msg = $serv->getRestaurantTimeSearchMessage($request->restid);
						$this->view->freezedesc = $msg->resbooking_search_msg;
					}
				}
				
				$splService = new Application_Service_Deals();				
				$splService->IncrementSpecialSearchCount($resid);
				
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				$this->view->check = $searchList[1];
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->splFrom = $request->splFrom;
				$this->view->page = $page;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialdealwidgetreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			$check = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			
			$restService = new Application_Service_Firm();

			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			
			if($this->getRequest()->isPost()){
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$limit = '';
				$offset = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;	
					}else{
						$limit = 2;	
					}
					
					$check = $searchList[1];	
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}else{
					$frezresult = $this->_reservationService->getFreezeTypeByDate($request);
					if($frezresult['type'] == 'All'){
						$frzdescMap = $this->_reservationService->getFreezeDesc($request);
						if($frzdescMap && $frzdescMap->rfdm_desc){
							$this->view->freezedesc = $frzdescMap->rfdm_desc;
						}else{
							$serv = new Application_Service_Firm();
							$msg = $serv->getRestaurantTimeSearchMessage($request->restid);
							$this->view->freezedesc = $msg->resbooking_search_msg;
						}
					}else{
						$serv = new Application_Service_Firm();
						$msg = $serv->getRestaurantTimeSearchMessage($request->restid);
						$this->view->freezedesc = $msg->resbooking_search_msg;
					}
				}
				
				$splService = new Application_Service_Deals();				
				$splService->IncrementSpecialSearchCount($resid);
				
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				$this->view->check = $searchList[1];
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->splFrom = $request->splFrom;
				$this->view->page = $page;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetlistallAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$resid = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			$restService = new Application_Service_Firm();
			$searchList = array();
			
			$resttimings = new Reservation_Model_GetRestaurantTimings();
				
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->pagein){
					$page = $request->pagein;
				}else{
					$page = 2;
				}
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimingsAjax($resttimings,$page);
				if($searchList[0]){
					echo json_encode(array('result'=>$searchList[0],'page'=>$page+1));
				}else{
					echo json_encode(array('result'=>''));
				}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialdealwidgetlistallAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$resid = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			$restService = new Application_Service_Firm();
			$searchList = array();
			
			$resttimings = new Reservation_Model_GetRestaurantTimings();
				
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->pagein){
					$page = $request->pagein;
				}else{
					$page = 2;
				}
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimingsAjax($resttimings,$page);
				if($searchList[0]){
					echo json_encode(array('result'=>$searchList[0],'page'=>$page+1));
				}else{
					echo json_encode(array('result'=>''));
				}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetviewallAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			$restService = new Application_Service_Firm();

			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			if($this->getRequest()->isPost()){
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$limit = '';
				$offset = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 2;
					}else{
						$limit = 4;
					}
					
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->splFrom = $request->splFrom;
				$this->view->page = $page;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
                                $this->view->resCompanyid = $resDetails->getcompanyid();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}else{
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				
				$resttimings->setDate(date('m-d-Y'));
				$resttimings->setRestId($resid);
				$resttimings->setTime(date('h:i A'));
				$resttimings->setpartysize(2);
				$resttimings->setschtype('viewall');
				if(date('m-d-Y')){
					$dateSplit = explode("-",date('m-d-Y'));
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$limit = '';
				$offset = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 2;
					}else{
						$limit = 10;
					}
					
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",date('m-d-Y'));
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				$this->view->restid = $resid;
				$pax = 2;
				$date = date('m-d-Y');
				$this->view->pax = 2;
				$this->view->date = date('m-d-Y');
				$this->view->time = date('h:i A');
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->splFrom = 'viewall';
				$this->view->page = $page;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
                                $this->view->resCompanyid = $resDetails->getcompanyid();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialdealwidgetviewallAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			$restService = new Application_Service_Firm();

			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			if($this->getRequest()->isPost()){
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$limit = '';
				$offset = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 2;
					}else{
						$limit = 4;
					}
					
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->splFrom = $request->splFrom;
				$this->view->page = $page;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
                                $this->view->resCompanyid = $resDetails->getcompanyid();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}else{
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				
				$resttimings->setDate(date('m-d-Y'));
				$resttimings->setRestId($resid);
				$resttimings->setTime(date('h:i A'));
				$resttimings->setpartysize(2);
				$resttimings->setschtype('viewall');
				if(date('m-d-Y')){
					$dateSplit = explode("-",date('m-d-Y'));
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$limit = '';
				$offset = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 2;
					}else{
						$limit = 10;
					}
					
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",date('m-d-Y'));
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				$this->view->restid = $resid;
				$pax = 2;
				$date = date('m-d-Y');
				$this->view->pax = 2;
				$this->view->date = date('m-d-Y');
				$this->view->time = date('h:i A');
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->splFrom = 'viewall';
				$this->view->page = $page;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
                                $this->view->resCompanyid = $resDetails->getcompanyid();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetreservationdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			$check = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->userlogstat = 'true';
			}else{
				$this->view->userlogstat = 'false';
			}
			$restService = new Application_Service_Firm();

			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			if($this->getRequest()->isPost()){
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype($request->splFrom);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$specialMapper = new Application_Service_Deals();
				$specialCount = new Deals_Model_RestaurantSpecialCounter();
				$specialCount->setSpecialId($request->splid)
							 ->setRestaurantid($resid);
				$specialCounter = $specialMapper->SpecialCountIncrementer($specialCount);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$offset = '';
				$limit = '';
				$statLtd = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;
					}else{
						$limit = 2;	
					}
				
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$statLtd = 'true';
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				if($statLtd){
					$this->view->check = $check;
				}else{
					$this->view->check = 'false';
				}
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
//				$this->view->paymentStatus = $payStat;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->page = $page;
				$this->view->splFrom = $request->splFrom;
				$this->view->splid = $request->splid;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}else{
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$todDate = date('m-d-Y');
				$todTime = date('h:i A');
				$resttimings->setDate($todDate);
				$resttimings->setRestId($resid);
				$resttimings->setTime(date('h:i A'));
				$resttimings->setpartysize(2);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype('viewall');
				$resttimings->setschtype('viewall');
				if($todDate){
					$dateSplit = explode("-",$todDate);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$specialMapper = new Application_Service_Deals();
				$specialCount = new Deals_Model_RestaurantSpecialCounter();
				$specialCount->setSpecialId($request->splid)
							 ->setRestaurantid($resid);
				$specialCounter = $specialMapper->SpecialCountIncrementer($specialCount);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$offset = '';
				$limit = '';
				$statLtd = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;
					}else{
						$limit = 2;	
					}
				
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$statLtd = 'true';
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",$todDate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				if($statLtd){
					$this->view->check = $check;
				}else{
					$this->view->check = 'false';
				}
				$this->view->restid = $resid;
				$pax = 2;
				$date = $todDate;
				$this->view->pax = 2;
				$this->view->date = $todDate;
				$this->view->time = $todTime;
//				$this->view->paymentStatus = $payStat;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->page = $page;
				$this->view->splFrom = 'viewall';
				$this->view->splid = $request->splid;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialdealwidgetreservationdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			$check = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->userlogstat = 'true';
			}else{
				$this->view->userlogstat = 'false';
			}
			$restService = new Application_Service_Firm();

			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			if($this->getRequest()->isPost()){
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype($request->splFrom);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$specialMapper = new Application_Service_Deals();
				$specialCount = new Deals_Model_RestaurantSpecialCounter();
				$specialCount->setSpecialId($request->splid)
							 ->setRestaurantid($resid);
				$specialCounter = $specialMapper->SpecialCountIncrementer($specialCount);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$offset = '';
				$limit = '';
				$statLtd = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;
					}else{
						$limit = 2;	
					}
				
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$statLtd = 'true';
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				if($statLtd){
					$this->view->check = $check;
				}else{
					$this->view->check = 'false';
				}
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->page = $page;
				$this->view->splFrom = $request->splFrom;
				$this->view->splid = $request->splid;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}else{
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$todDate = date('m-d-Y');
				$todTime = date('h:i A');
				$resttimings->setDate($todDate);
				$resttimings->setRestId($resid);
				$resttimings->setTime(date('h:i A'));
				$resttimings->setpartysize(2);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype('viewall');
				$resttimings->setschtype('viewall');
				if($todDate){
					$dateSplit = explode("-",$todDate);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$specialMapper = new Application_Service_Deals();
				$specialCount = new Deals_Model_RestaurantSpecialCounter();
				$specialCount->setSpecialId($request->splid)
							 ->setRestaurantid($resid);
				$specialCounter = $specialMapper->SpecialCountIncrementer($specialCount);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$offset = '';
				$limit = '';
				$statLtd = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;
					}else{
						$limit = 2;	
					}
				
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$statLtd = 'true';
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",$todDate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				

				$this->view->searchlist = $searchList[0];
				if($statLtd){
					$this->view->check = $check;
				}else{
					$this->view->check = 'false';
				}
				$this->view->restid = $resid;
				$pax = 2;
				$date = $todDate;
				$this->view->pax = 2;
				$this->view->date = $todDate;
				$this->view->time = $todTime;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->page = $page;
				$this->view->splFrom = 'viewall';
				$this->view->splid = $request->splid;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetreservationauthenticationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$respl = $request->ressplName;
			$stateId = "";
			$cityId = "";
			$regionId = "";
			
			$restService = new Application_Service_Firm();
			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			$restid = $request->restaurantid;
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$result = $mapper->GetSpecialRequestSetting($restid);
			$this->view->splreq = $result->resspecial_request;
			
			$otpmapper = new FirmManagement_Model_FirmDataMapper();
			$otpResult = $otpmapper->GetOtpSettingStatus($restid);
			if($otpResult->resotp_setting){
				$this->view->otpresult = 'true';
			}else{
				$this->view->otpresult = 'false';
			}
			if($this->getRequest()->isPost() && $request->splFrom != 'widgetsplbooking'){
				if($result = $this->_reservationService->BookingDetails($this->getRequest()->getPost(),$stateId,$cityId,$regionId,'widget')){
					if($result){
						if(!$result['result']){
							$form = $this->_reservationService->getBookingDetailsForm();
							$payStat = 'false';
							if($request->specialid){	
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
								
								$splService = new Application_Service_Deals();	
								$splResult = $splService->GetWidgetSpecialDetailsById($request->restaurantid,$request->specialid,false);
								if($splResult->getCatTypeCode() == 'SP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';
								}else if($splResult->getCatTypeCode() == 'CP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';

								}
							}
							
							$request = $this->getRequest();
							$formData  = array('resId'=>(int)$request->restaurantid,
				                           'resName'=>$request->resname,
				                           'resAddress'=>$request->resaddress,
				                           'resDate'=>$request->resdate,
				                           'resTime'=>$request->restime,
				                           'pax'=>$request->respax,
										   'inventoryid'=>$request->inventoryid,
										   'paymentStatus'=>$payStat
				
							);
				
					
							$this->view->resdate = date('D d M Y',$s);
							$this->view->date = $weekdate;
							$this->view->resname = $request->resname;
							$this->view->resaddress = $request->resaddress;
							$this->view->restime = $request->restime;
							$this->view->respax = $request->respax;
							$this->view->bookingstatus = $request->bookingstatus;
							$this->view->restaurantid = $request->restaurantid;
							$this->view->tablesize = $request->tablesize;
							$this->view->nooftables = $request->nooftables;
							$this->view->specialid  = $request->specialid;
							$this->view->booktype   = $request->booktype;
							$this->view->specialamt = $request->specialamt;
							$this->view->ressplName = $request->ressplName;
							$this->view->splResult = $splResult;
							$auth = Zend_Auth::getInstance();
							$data = array();
							if($auth->hasIdentity()){
								$storage = new Zend_Auth_Storage_Session();
								$data = $storage->read();
								$this->view->userdata = $data;
								$formData['firstName'] = $data['Firstname'];
								$formData['lastName'] = $data['LastName'];
								$formData['number'] = $data['Phone'];
								$formData['email'] = $data['Email'];
								$formData['userid'] = $data['User_Id'];
							}

							$form->populate($formData);
							$this->view->form = $form;
						}else{
							$paymentStatus = $request->paymentStatus;
							if($request->specialid){	
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
								$splService = new Application_Service_Deals();	
								$splResult = $splService->GetWidgetSpecialDetailsById($request->restaurantid,$request->specialid,false);
								if($splResult->getCatTypeCode() == 'SP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';
								}else if($splResult->getCatTypeCode() == 'CP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';
								}
							}
							$bookedData = $result['result'];
								$resid = $request->restaurantid;
								$respl = $request->ressplName;
								$this->_helper->redirector('dealwidgetconfirmation','Reservation','Reservation',array('bokid'=>$bookedData,'resid'=>$resid,'ressplName'=>$request->ressplName,'bokstat'=>true));
							
						}
					}
				}
			}else{
				$form = $this->_reservationService->getBookingDetailsForm();
			
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				$payStat = 'false';
				if($request->specialid){	
					$splService = new Application_Service_Deals();	
					$splResult = $splService->GetWidgetSpecialDetailsById($request->restaurantid ,$request->specialid,false);
					if($splResult->getCatTypeCode() == 'SP'){
						$payStat = 'true';
						$this->view->splTransactType = 'SPLPAID';
					}else if($splResult->getCatTypeCode() == 'CP'){
						$payStat = 'true';
						$this->view->splTransactType = 'SPLPAID';
					}
				}
		
				$request = $this->getRequest();
				$formData  = array('resId'=>(int)$request->restaurantid,
	                           'resName'=>$request->resname,
	                           'resAddress'=>$request->resaddress,
	                           'resDate'=>$request->resdate,
	                           'resTime'=>$request->restime,
	                           'pax'=>$request->respax,
							   'inventoryid'=>$request->inventoryid,
							   'paymentStatus'=>'false'
	
				);
	
				$this->view->splResult = $splResult;
				$this->view->resdate = date('D d M Y',$s);
				$this->view->resname = $request->resname;
				$this->view->resaddress = $request->resaddress;
				$this->view->restime = $request->restime;
				$this->view->date = $weekdate;
				$this->view->respax = $request->respax;
				$this->view->bookingstatus = $request->bookingstatus;
				$this->view->restaurantid = $request->restaurantid;
				$this->view->tablesize = $request->tablesize;
				$this->view->nooftables = $request->nooftables;
				$this->view->specialid  = $request->specialid;
				$this->view->booktype   = $request->booktype;
				$this->view->specialamt = $request->specialamt;
				$this->view->ressplName = $request->ressplName;
				
				$auth = Zend_Auth::getInstance();
				$data = array();
				if($auth->hasIdentity()){
					$storage = new Zend_Auth_Storage_Session();
					$data = $storage->read();
					$this->view->userdata = $data;
					$formData['firstName'] = $data['Firstname'];
					$formData['lastName'] = $data['LastName'];
					$formData['number'] = $data['Phone'];
					$formData['email'] = $data['Email'];
					$formData['userid'] = $data['User_Id'];
				}	
				$form->populate($formData);
				$resservice = new Application_Service_Firm();
				$optionsetting = $resservice->getBookingOptionsSetting($request->restaurantid);
				if($optionsetting->resbookingoption_setting){
					$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
					if(count($bookingoptions) > 1){
						$form->bokoptions->addMultiOptions($bookingoptions);
						$this->view->bokoptionsts   = true;
					}else{
						$this->view->bokoptionsts   = false;
					}							
				}else{
					$this->view->bokoptionsts   = false;
				}
				$this->view->form = $form;
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialdealwidgetreservationauthenticationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$respl = $request->ressplName;
			$stateId = "";
			$cityId = "";
			$regionId = "";
			
			$restService = new Application_Service_Firm();
			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			$restid = $request->restaurantid;
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$result = $mapper->GetSpecialRequestSetting($restid);
			$this->view->splreq = $result->resspecial_request;
			
			$otpmapper = new FirmManagement_Model_FirmDataMapper();
			$otpResult = $otpmapper->GetOtpSettingStatus($restid);
			if($otpResult->resotp_setting){
				$this->view->otpresult = 'true';
			}else{
				$this->view->otpresult = 'false';
			}
			if($this->getRequest()->isPost() && $request->splFrom != 'widgetsplbooking'){
				if($result = $this->_reservationService->BookingDetails($this->getRequest()->getPost(),$stateId,$cityId,$regionId,'widget')){
					if($result){
						if(!$result['result']){
							$form = $this->_reservationService->getBookingDetailsForm();
							$payStat = 'false';
							if($request->specialid){	
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
								
								$splService = new Application_Service_Deals();	
								$splResult = $splService->GetWidgetSpecialDetailsById($request->restaurantid,$request->specialid,false);
								if($splResult->getCatTypeCode() == 'SP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';
								}else if($splResult->getCatTypeCode() == 'CP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';

								}
							}
							
							$request = $this->getRequest();
							$formData  = array('resId'=>(int)$request->restaurantid,
				                           'resName'=>$request->resname,
				                           'resAddress'=>$request->resaddress,
				                           'resDate'=>$request->resdate,
				                           'resTime'=>$request->restime,
				                           'pax'=>$request->respax,
										   'inventoryid'=>$request->inventoryid,
										   'paymentStatus'=>$payStat
				
							);
				
					
							$this->view->resdate = date('D d M Y',$s);
							$this->view->date = $weekdate;
							$this->view->resname = $request->resname;
							$this->view->resaddress = $request->resaddress;
							$this->view->restime = $request->restime;
							$this->view->respax = $request->respax;
							$this->view->bookingstatus = $request->bookingstatus;
							$this->view->restaurantid = $request->restaurantid;
							$this->view->tablesize = $request->tablesize;
							$this->view->nooftables = $request->nooftables;
							$this->view->specialid  = $request->specialid;
							$this->view->booktype   = $request->booktype;
							$this->view->specialamt = $request->specialamt;
							$this->view->ressplName = $request->ressplName;
							$this->view->splResult = $splResult;
							$auth = Zend_Auth::getInstance();
							$data = array();
							if($auth->hasIdentity()){
								$storage = new Zend_Auth_Storage_Session();
								$data = $storage->read();
								$this->view->userdata = $data;
								$formData['firstName'] = $data['Firstname'];
								$formData['lastName'] = $data['LastName'];
								$formData['number'] = $data['Phone'];
								$formData['email'] = $data['Email'];
								$formData['userid'] = $data['User_Id'];
							}

							$form->populate($formData);
							$this->view->form = $form;
						}else{
							$paymentStatus = $request->paymentStatus;
							if($request->specialid){	
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
								$splService = new Application_Service_Deals();	
								$splResult = $splService->GetWidgetSpecialDetailsById($request->restaurantid,$request->specialid,false);
								if($splResult->getCatTypeCode() == 'SP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';
								}else if($splResult->getCatTypeCode() == 'CP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';
								}
							}
							$bookedData = $result['result'];
								$resid = $request->restaurantid;
								$respl = $request->ressplName;
								$this->_helper->redirector('socialdealwidgetconfirmation','Reservation','Reservation',array('bokid'=>$bookedData,'resid'=>$resid,'ressplName'=>$request->ressplName,'bokstat'=>true));
							
						}
					}
				}
			}else{
				$form = $this->_reservationService->getBookingDetailsForm();
			
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				$payStat = 'false';
				if($request->specialid){	
					$splService = new Application_Service_Deals();	
					$splResult = $splService->GetWidgetSpecialDetailsById($request->restaurantid ,$request->specialid,false);
					if($splResult->getCatTypeCode() == 'SP'){
						$payStat = 'true';
						$this->view->splTransactType = 'SPLPAID';
					}else if($splResult->getCatTypeCode() == 'CP'){
						$payStat = 'true';
						$this->view->splTransactType = 'SPLPAID';
					}
				}
		
				$request = $this->getRequest();
				$formData  = array('resId'=>(int)$request->restaurantid,
	                           'resName'=>$request->resname,
	                           'resAddress'=>$request->resaddress,
	                           'resDate'=>$request->resdate,
	                           'resTime'=>$request->restime,
	                           'pax'=>$request->respax,
							   'inventoryid'=>$request->inventoryid,
							   'paymentStatus'=>'false'
	
				);
	
				$this->view->splResult = $splResult;
				$this->view->resdate = date('D d M Y',$s);
				$this->view->resname = $request->resname;
				$this->view->resaddress = $request->resaddress;
				$this->view->restime = $request->restime;
				$this->view->date = $weekdate;
				$this->view->respax = $request->respax;
				$this->view->bookingstatus = $request->bookingstatus;
				$this->view->restaurantid = $request->restaurantid;
				$this->view->tablesize = $request->tablesize;
				$this->view->nooftables = $request->nooftables;
				$this->view->specialid  = $request->specialid;
				$this->view->booktype   = $request->booktype;
				$this->view->specialamt = $request->specialamt;
				$this->view->ressplName = $request->ressplName;
				
				$auth = Zend_Auth::getInstance();
				$data = array();
				if($auth->hasIdentity()){
					$storage = new Zend_Auth_Storage_Session();
					$data = $storage->read();
					$this->view->userdata = $data;
					$formData['firstName'] = $data['Firstname'];
					$formData['lastName'] = $data['LastName'];
					$formData['number'] = $data['Phone'];
					$formData['email'] = $data['Email'];
					$formData['userid'] = $data['User_Id'];
				}	
				$form->populate($formData);
				$resservice = new Application_Service_Firm();
				$optionsetting = $resservice->getBookingOptionsSetting($request->restaurantid);
				if($optionsetting->resbookingoption_setting){
					$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
					if(count($bookingoptions) > 1){
						$form->bokoptions->addMultiOptions($bookingoptions);
						$this->view->bokoptionsts   = true;
					}else{
						$this->view->bokoptionsts   = false;
					}							
				}else{
					$this->view->bokoptionsts   = false;
				}
				$this->view->form = $form;
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetconfirmationAction()
	{
		try{
			$this->_helper->layout->disableLayout();

			$request = $this->getRequest();
			if(isset($request->bokstat)){
				$this->view->bokStat = $request->bokstat;
			}else{
				$this->view->bokStat = '';
			}
			$restId = $request->resid;
			$bokid   = $request->bokid;
			$notStatus = $this->_reservationService->CheckReservationNotificationStatusByBokPhraseId($bokid);
			$this->view->notStatus = $notStatus;
			$this->view->phraseId = $bokid;
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$this->view->bookedData = $result;
			$this->view->restaurantid = $restId;
			$this->view->ressplName = $request->ressplName;
			$restService = new Application_Service_Firm();
			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}
	
	public function socialdealwidgetconfirmationAction()
	{
		try{
			$this->_helper->layout->disableLayout();

			$request = $this->getRequest();
			if(isset($request->bokstat)){
				$this->view->bokStat = $request->bokstat;
			}else{
				$this->view->bokStat = '';
			}
			$restId = $request->resid;
			$bokid   = $request->bokid;
			$notStatus = $this->_reservationService->CheckReservationNotificationStatusByBokPhraseId($bokid);
			$this->view->notStatus = $notStatus;
			$this->view->phraseId = $bokid;
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$this->view->bookedData = $result;
			$this->view->restaurantid = $restId;
			$this->view->ressplName = $request->ressplName;
			$restService = new Application_Service_Firm();
			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}
	
	/**	
	 * 	action to display the booking deatils of the reservation to be taken from widget
	 */	
	public function reservationwidgetreservationdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$stateId = "";
			$cityId = "";
			$regionId = "";
			
			/* Get Widget Theme Start */
			$restService = new Application_Service_Firm();
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			if(isset($request->bokSrcComp)){
				$this->view->bokSrcComp = $request->bokSrcComp;
			}else{
				$this->view->bokSrcComp = 'INAT';
			}
			/* Get Widget Theme End */
			
			$restid = $request->restaurantid;
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$result = $mapper->GetSpecialRequestSetting($restid);
			$this->view->splreq = $result->resspecial_request;
			$widsettings = $this->_restService->getRestaurantCustomizeWidgetByResid($restid);
			if($widsettings){
				$this->view->widsettings = $widsettings;
			}
			$otpmapper = new FirmManagement_Model_FirmDataMapper();
			$otpResult = $otpmapper->GetOtpSettingStatus($restid);
			if($otpResult->resotp_setting){
				$this->view->otpresult = 'true';
			}else{
				$this->view->otpresult = 'false';
			}
			
			$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
	    	$CountryCode = $CountryCodeMapper->fetchAll();
	    	$CodeList = array();
	    	$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
	    	foreach($CountryCode as $listcode){
	    		$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
	    	}
		    	
	    	$this->view->codelist = $CodeList;
			
			if($this->getRequest()->isPost()){
				if($result = $this->_reservationService->BookingDetails($this->getRequest()->getPost(),$stateId,$cityId,$regionId,'widget')){
					if($result){
						if(!$result['result']){
							$form = $this->_reservationService->getBookingDetailsForm();
							$payStat = 'false';
							if(!$request->specialid){
								$payService = new Application_Service_Renumeration();
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
									
								$payStat = 'false';
								$payType = '';
								if($payResult){
									$payType = $payResult['rpsnoshow_type'];
									$this->view->payType = $payType; 
									$this->view->payAmt = $payResult['payamount'];
									if($request->respax >= $payResult['paypax']){		
										$payStat = 'true';
									}
								}
							}
							
							$request = $this->getRequest();
							$formData  = array('resId'=>(int)$request->restaurantid,
				                           'resName'=>$request->resname,
				                           'resAddress'=>$request->resaddress,
				                           'resDate'=>$request->resdate,
				                           'resTime'=>$request->restime,
				                           'pax'=>$request->respax,
										   'inventoryid'=>$request->inventoryid,
										   'resCompanyid'=>$request->rescompanyid,
										   'paymentStatus'=>$payStat
				
							);
				
					
							$dateSplit = explode("-",$request->resdate);
							$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								
							$this->view->resdate = date('l, F j Y',$s);
							$this->view->resname = $request->resname;
							$this->view->resaddress = $request->resaddress;

							$restid = new FirmManagement_Model_FirmById();
							$restid->setRestaurantId($request->restaurantid);
							$resDetails = $mapper->getRestaurantById($restid);
				$this->view->resCompanyid = $resDetails->getcompanyid();

							$this->view->restime = $request->restime;
							$this->view->respax = $request->respax;
							$this->view->bookingstatus = $request->bookingstatus;
							$this->view->restaurantid = $request->restaurantid;
							$this->view->tablesize = $request->tablesize;
							$this->view->nooftables = $request->nooftables;
							$this->view->specialid  = $request->specialid;
							$this->view->booktype   = $request->booktype;
							$this->view->specialamt = $request->specialamt;
							$this->view->mealtype = $request->mealtype;
							
							$auth = Zend_Auth::getInstance();
							$data = array();
							if($auth->hasIdentity()){
								$storage = new Zend_Auth_Storage_Session();
								$data = $storage->read();
								$this->view->userdata = $data;
								$formData['firstName'] = $data['Firstname'];
								$formData['lastName'] = $data['LastName'];
								$formData['number'] = $data['Phone'];
								$formData['email'] = $data['Email'];
								$formData['userid'] = $data['User_Id'];
								//$formData['notificationType'] = ;
															
								$codemapper = new User_Model_ClientDataMapper();
								$usercountrycode = $codemapper->getCountrycodebyUserid($data['User_Id'],$data['Usertype'],$request->restaurantid);
								if($usercountrycode){
										$formData['countryCode'] =  $usercountrycode;
									}											
								}else{						
									$codemapper = new FirmManagement_Model_FirmDataMapper();
									$countrycode = $codemapper->getCountrycodebyId($request->restaurantid);
									if($countrycode){
										$formData['countryCode'] =  $countrycode;
										$this->view->countrycode = $countrycode;
									}
								}	


							
							
							$form->populate($formData);
							//$form->setDefaults(array('notificationType'	=>	'email'));
				
							$this->view->form = $form;
						}else{
							$paymentStatus = $request->paymentStatus;
							if($paymentStatus == 'true'){
								$this->view->cusprofId = $result['profileId'];
								$this->view->paymentprofId = $result['payment'];
								$this->view->bookingid = $result['result'];
								$this->view->userid = $result['userId'];
								$this->view->resid = $request->restaurantid;
							}else{
								$bookedData = $result['result'];
								$resid = $request->restaurantid;
								$this->_helper->redirector('reservationwidgetconfirmation','Reservation','Reservation',array('bokid'=>$bookedData,'resid'=>$resid,'bokstat'=>true,'bokSrcComp'=>$this->view->bokSrcComp,'rescompanyid'=>$this->view->resCompanyid));
							}
						}
					}
				}
			}else{
				$form = $this->_reservationService->getBookingDetailsForm();
			
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				$payStat = 'false';
				if(!$request->specialid){			
					$payService = new Application_Service_Renumeration();
					$payResult = '';	
					$payStat = 'false';
					$payType = '';
					if($payResult){
						$payType = $payResult['rpsnoshow_type'];
						$this->view->payType = $payType; 
						$this->view->payAmt = $payResult['payamount'];
						if($request->respax >= $payResult['paypax']){		
							$payStat = 'true';
						}
					}
				}
				
				$request = $this->getRequest();
				$formData  = array('resId'=>(int)$request->restaurantid,
	                           'resName'=>$request->resname,
	                           'resAddress'=>$request->resaddress,
	                           'resDate'=>$request->resdate,
	                           'resTime'=>$request->restime,
	                           'pax'=>$request->respax,
							   'inventoryid'=>$request->inventoryid,
							   'resCompanyid'=>$request->rescompanyid,	
							   'paymentStatus'=>$payStat
	
				);
	
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$this->view->resdate = date('D d M Y',$s);
				$this->view->resname = $request->resname;
				$this->view->resaddress = $request->resaddress;
				
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($request->restaurantid);
				$resDetails = $mapper->getRestaurantById($restid);
				$this->view->resCompanyid = $resDetails->getcompanyid();


				$this->view->restime = $request->restime;
				$this->view->respax = $request->respax;
				$this->view->bookingstatus = $request->bookingstatus;
				$this->view->restaurantid = $request->restaurantid;
				$this->view->tablesize = $request->tablesize;
				$this->view->nooftables = $request->nooftables;
				$this->view->specialid  = $request->specialid;
				$this->view->booktype   = $request->booktype;
				$this->view->specialamt = $request->specialamt;
				$this->view->mealtype = $request->mealtype; 
				
				$auth = Zend_Auth::getInstance();
				$data = array();
				if($auth->hasIdentity()){
					$storage = new Zend_Auth_Storage_Session();
					$data = $storage->read();
					if($data['User_Id']){
						$this->view->userdata = $data;
						$formData['firstName'] = $data['Firstname'];
						$formData['lastName'] = $data['LastName'];
						$formData['number'] = $data['Phone'];
						$formData['email'] = $data['Email'];
						$formData['userid'] = $data['User_Id'];
						//$formData['notificationType'] = ;
						$codemapper = new User_Model_ClientDataMapper();
						$usercountrycode = $codemapper->getCountrycodebyUserid($data['User_Id'],$data['Usertype'],$request->restaurantid);		
						if($usercountrycode){
							$formData['countryCode'] =  $usercountrycode;
						}
					}else{
						$codemapper = new FirmManagement_Model_FirmDataMapper();
						$countrycode = $codemapper->getCountrycodebyId($request->restaurantid);
						if($countrycode){
							$formData['countryCode'] =  $countrycode;
						}	
					}
				}else{
					$codemapper = new FirmManagement_Model_FirmDataMapper();
					$countrycode = $codemapper->getCountrycodebyId($request->restaurantid);
					if($countrycode){
						$formData['countryCode'] =  $countrycode;
					}	
				}

	
	
	
				$form->populate($formData);
				$resservice = new Application_Service_Firm();
				$bokoptionstatus = $resservice->getBookingOptionsSetting($request->restaurantid);
				if($bokoptionstatus->resbookingoption_setting){
					$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
					$secbookingoptions = $this->_reservationService->getSecBookingOptionsByresId($request);
					if(count($bookingoptions) > 1){
						$form->bokoptions->addMultiOptions($bookingoptions);
						$this->view->bokoptionsts   = true;
					}else{
						$this->view->bokoptionsts   = false;
					}
					if(count($secbookingoptions) > 1){
						$form->boksecoptions->addMultiOptions($secbookingoptions);
						$this->view->secbokoptionsts   = true;
					}else{
						$this->view->secbokoptionsts   = false;
					}							
				}else{
					$this->view->bokoptionsts   = false;
					$this->view->boksecoptionsts   = false;
				}
	
				$this->view->form = $form;
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to display the reservation confirmation of the reservation taken from the widget
	 */
	public function reservationwidgetconfirmationAction()
	{
		try{
			$this->_helper->layout->disableLayout();

			$request = $this->getRequest();
			if(isset($request->bokstat)){
				$this->view->bokStat = $request->bokstat;
			}else{
				$this->view->bokStat = '';
			}
			if(isset($request->bokSrcComp)){
				$this->view->bokSrcComp = $request->bokSrcComp;
			}else{
				$this->view->bokSrcComp = 'INAT';
			}
			/* Get Widget Theme Start */
			$restService = new Application_Service_Firm();
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			
			$restId = $request->resid;
			$widsettings = $this->_restService->getRestaurantCustomizeWidgetByResid($restId);
			if($widsettings){
				$this->view->widsettings = $widsettings;
			}
			$bokid   = $request->bokid;
			$notStatus = $this->_reservationService->CheckReservationNotificationStatusByBokPhraseId($bokid);
			$this->view->notStatus = $notStatus;
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$this->view->phraseId = $bokid;
			$this->view->bookedData = $result;
			
			$autoconfStatus = $this->_reservationService->GetAutoConfirmStatusByResid($restId);
			$this->view->autoconfirm = $autoconfStatus;
			$restid = new FirmManagement_Model_FirmById();
			$restid->setRestaurantId($restId);
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$resDetails = $mapper->getRestaurantById($restid);
			$this->view->resCompanyid = $resDetails->getcompanyid();
			$this->view->restaurantid = $restId;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}
        
        public function getreservenotifionfirstloadAction()
        {
            try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
                        $request = $this->getRequest();
                        $lastbokid='';
                        $results ='';
                        if($request->lastbokid){
                            $lastbokid = $request->lastbokid;
                        }
                        
                        $storage = new Zend_Auth_Storage_Session();
                        $data = $storage->read();
                        $restid = $data['RestId'];
                        if($restid){
                            $results = $this->_reservationService->getReservationNotifiByRestId($restid, $lastbokid);
                        }                                                
                        echo json_encode($results);
                        
                        
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
            
        }


	/**	
	 * 	action to retreive the booking details using ajax call
	 */	
	public function retreivereservationdetailspostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$results = $this->_reservationService->getBookingObjByBookingId($request);
			echo json_encode($results);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	/**
	 *  action to retreive the customer booking details using ajax call
	 */
	public function retreivecustomerreservationdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$results = $this->_reservationService->getBookingDetailsByBookingId($request);
			echo json_encode($results);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivecustomerdealreservationdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$results = $this->_reservationService->getBookingSplDetailsByBookingId($request);
			echo json_encode($results);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to retreive the blocked reservation details using ajax call
	 */
	public function retreiveholdreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$results = $this->_reservationService->GetBlockBookingDetails($request->bokid);
			echo json_encode($results);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action to check the overbook password using ajax call
	 */
	public function verifyauthAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				$result = $this->_reservationService->CheckPassword($request,$data);
				if($result){
					if($request->page){
						$defaultView  = $data['DefaultView']; 
						if($defaultView){
							echo $defaultView;
						}else{
							echo 'calendar';
						}
					}else{
						echo "t";
					}
				}else{
					echo "f";
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to save reserved customer datails as a contact of the restaurant using ajax call
	 */
	public function addcustomerdetailspostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$results = $this->_restService->AddCustomerContact($this->getRequest()->getPost());
			echo json_encode($results);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to check the email existence
	 */
	public function verifyemailcontactAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				$request = $this->getRequest();
				$result = $this->_restService->CusContactEmailCheck($request);
				if($result){
					echo "t";
				}else{
					echo "f";
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to retreive the customer names for autocomplete in makereservation popup using ajax call
	 */
	public function retreivecustomerAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$text = trim($request->firstname);
			$lastname = $request->lastname;
			$restid = $request->restaurantid;
			$result = $this->_restService->getCustomerNames($text,$restid,$lastname);
			$list = array();
			$cusListArr = null;
			if($result){

				foreach($result as $key=>$value){
					$list[] = array('rgu' => array("key"=>$key,"value"=>$value));
				}
			}
			if(count($list) > 0){
				$cusListArr = array('cuslist'=>$list);
				$cusJson = json_encode($cusListArr);
				echo $cusJson;
			}else{
				//$test = "f";
				$cusJson = json_encode("f");
				echo $cusJson;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function searchforcustomerbynameAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$text = trim($request->inputtext);
			$restid = $request->restaurantid;
			$result = $this->_restService->searchCusContactByName($text,$restid);
			$list = array();
			$cusListArr = null;
			if($result){
				foreach($result as $key=>$value){
					$list[] = array('rgu' => array("key"=>$key,"value"=>$value));
				}
			}
			if(count($list) > 0){
				$cusListArr = array('cuslist'=>$list);
				$cusJson = json_encode($cusListArr);
				echo $cusJson;
			}else{
				//$test = "f";
				$cusJson = json_encode("f");
				echo $cusJson;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to retreive the customer details by id 
	 */	
	public function retreivecustomerdetailsbyidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			if($request->customerid){
				$result = $this->_restService->GetCustomerDetailsArr($request);
				echo json_encode($result);

			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to update the restaurants email using ajax call
	 */	
	public function editrestemailpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			
			$result = $this->_restService->UpdateRestEmailById($request);
			if($result){
				echo "t";
			}else{
				echo "f";
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function editrestaurantprimaryemailpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_restService->UpdateRestPrimaryEmail($request);
			if($result){
				echo "t";
			}else{
				echo "f";
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function retreiverestaurantemailidpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->GetRestaurantEmailById($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode("f");
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreiveemailsofrestaurantpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->GetRestaurantEmails($request);
			if(!empty($result)){
				echo json_encode($result);
			}else{
				echo json_encode("f");
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	
	public function addrestemailpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();	
			$result = $this->_restService->AddRestEmailById($request);
			if($result){
				echo $result;
			}else{
				echo "f";
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to download the report as a pdf file 
	 */	
	public function getreportAction()
	{
		$this->_helper->layout->disableLayout();
		$this->_helper->viewRenderer->setNoRender();
		$request = $this->getRequest();
     
		if($request){
			$result = $this->_reservationService->getAllReservationReport($request);
			$file = 'reports/'.$request->report.'.pdf';
			//echo '<pre>'; print_r($request->report); exit;
			$size = filesize($file);		
			if (file_exists($file))
			{ 
				header("Content-type: application/force-download");
				header("Content-Transfer-Encoding: Binary");
				header('Content-Length: '.$size);
				header("Content-disposition: attachment; filename=".basename($file));
				readfile($file);
	
			}
			
		}
	}
	

	
	/*
	 * action to cancel the reservation by the customer using the link
	 */
	public function reservationcancelAction()
	{
		$msg = "";
		try{
			$request = $this->getRequest();
			$result = $this->_reservationService->CancelReservationCon($request);
			if($result['result']){
				$this->view->bookedData = $result['result'];
				$this->view->status = $result['status'];
			}else{
				$msg = true;
				$this->view->msg = $msg;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function changereservationpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->updateBookingDetailsByBookid($request);
			if($result){
				echo 't';
			}else{
				echo 'f';
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function changereservationAction()
	{
		try{
			$stateId = "";
			$cityId = "";
			$regionId = "";
			$request = $this->getRequest();
//			$paymentStatus = $request->paymentStatus;			
			if($bookedData = $this->_reservationService->UpdateBookingDetails($request,$stateId,$cityId,$regionId,$request->bokid)){
				if($bookedData){
					$bookedData = $bookedData['result'];
					$resid = $request->restaurantid;
					$this->_helper->redirector('reservationconfirmation','Reservation','Reservation',array('bokid'=>$bookedData));
				}
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to retrieve reservations count using ajax call 
	 */	
	public function retreivereservationscountpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getReservationsCount($request);
			$value = number_format($result*40);
			echo number_format($result).'-'.$value;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * 	action to cancel the pre-allocation of table
	 */
	public function unasigntablebeforeguestAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->CancelPreAllocation($request);
			if($result){
				echo 't';
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * 	action to cancel the pre-allocation of table from listview
	 */
	public function unasigntablebeforeguestlistAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->CancelPreAllocation($request);
				if($result){
					return $this->_helper->redirector('reservationlist','Reservation','Reservation',array('restaurantid'=>$request->restaurantid,'date'=> $request->date));
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * 	action to retreive all the freezeddates
	 */
	public function retreiveblockeddateAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$freezedDates = $this->_reservationService->GetFreezedDatesByMonth($request);
			echo json_encode($freezedDates);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * 	action to retreive the restaurantlayout by dining id
	 */
	public function retreivefloorbydiningAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$resultStr = $this->_reservationService->GetLayoutByDiningId($request);
			echo json_encode($resultStr);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to retreive all the noshow reservations of that day
	 */	
	public function retreiveunasignedreservationsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$resultStr = $this->_reservationService->GetNoShowReservations($request);
			echo json_encode($resultStr);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	/* Waiting Block start*/
	
	/**	
	 * 	action for making waiting reservation
	 */
	public function waitreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			$stateId = "";
			$cityId = "";
			$regionId = "";
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$resid = $request->restaurantid;
				if(isset($data['State_Id'])){
					$stateId = $data['State_Id'];
				}
				if(isset($data['City_Id'])){
					$cityId = $data['City_Id'];
				}
				if(isset($data['Region_Id'])){
					$regionId = $data['Region_Id'];
				}
				
				$result = $this->_reservationService->MakeWaitingReservation($this->getRequest()->getPost(),$data['User_Id'],$stateId,$cityId,$regionId);

				if($request->date){
					$date = $request->date;
				}else{
					$date = date("m-d-Y");
				}
				
				if(!$result){
					$result = 0;
				}else{
					echo json_encode(array('restid'=>$resid,'bookid'=>$result['bookid'],'result'=>$result['result'],'date'=>$request->date));
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action for change waiting time
	 */
	public function reschedulewaitingreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->ChangeWaitingTime($request);
				if($result)
				{
					echo json_encode("t");
				}else{
					echo json_encode("f");
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**	
	 * 	action for get waiting times using ajax call
	 */
	public function retreivetimesforwaitingAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->GetWaitingTimes($request);
				echo json_encode($result);
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action for sending waiting custom message 
	 */
	public function postwaitingmessageAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
// 			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->SendWaitingCustomMessage($this->getRequest()->getPost());
				echo $result;
// 			}else{
// 				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
// 			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action for customer status change
	 */
	public function reservationdetailsbyrandAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$request = $this->getRequest();
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($request->bokid);
			$this->view->bookedData = $result;
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updatereservationstatusbycustomerAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$request = $this->getRequest();
			$result = $this->_reservationService->ChangeCustomerReservationStatus($request);
			$this->view->bookedData = $result;
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/* Waiting Block end*/
	
	public function retreivefirmsettingsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$payService = new Application_Service_Renumeration();
				
				$result = $payService->GetRestaurantPaymentSettingsByResId($request->resid,$request->resdate);
				echo json_encode($result);
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function organizeunasignedreservationsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$bookId = $request->bookingid;
				$bookingDetails = $this->_reservationService->GetBookingDetails($bookId);
				$bookDet = $this->_reservationService->getBookingDetailsByBookingId($request);
				$userId = $bookingDetails->getbokuserid();
				$customerDetails = new User_Model_Guest();
				$customerDetails->setUserid($userId);
				
				
				if($bookingDetails->getbokbooking_type_code() == 'PAID'){
					$userMapper = new User_Model_ClientDataMapper();
					$userDet = $userMapper->getCustomerNameandEmailByUserId($userId);
					$customerDetails->setEmail($userDet->usremail);
					$payService = new Application_Service_Renumeration();
					echo json_encode(array('status'=>'true','book'=>$bookDet));	
				}else{
					echo json_encode(array('status'=>'false'));
				}
				
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreiveinhousereservationsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$result = $this->_reservationService->MakeWalkinReservation($request,$data['User_Id'],'web');
				if($result){
					echo json_encode($result);
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivereservationstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->getBokStatus($request);
			echo json_encode($status);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivecurrentreservationstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->getBokPrasentStatus($request);
			echo json_encode($status);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivecustomerdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getRestCustomerDetails($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function customerhistorypostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getCusBokHistory($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivecusthistoryAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getBokHistoryofCus($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivecustomerhistoryAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$page = $this->_request->getParam('page');
				if (empty($page)){
					$page = 1;
				}
			$result = $this->_reservationService->getBokHistoryofCuspage($request,$page);
			if($result){
				echo json_encode($result);
			}else{
				echo 'f';
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivemealtypecountAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getCountByMealType($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode(array('stat'=>'t'));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function managemealtypepostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->manageResMealType($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode(array('stat'=>'t'));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function addmealtypesAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->addRestaurantMealType($request);
			if($result){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updatemealtypepostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->editResMealType($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode(array('stat'=>'t'));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updatemealstatpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->UpdateMealStattus($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode(array('stat'=>'t'));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivemealdatabyidpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getMealDetailsByMealId($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode(array('stat'=>'t'));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivemealtypespostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getRestaurantMealTypes($request,'settings');
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode(array('stat'=>'f'));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function managenotificationstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->updateNotificationStatus($request);
			if($result){
				echo 't';

			}else{
				echo 'f';
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function addreservationtooutlookAction()
	{
		try{
			
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$bokid = $request->bokid;			
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			
			$dateSplit = explode("-",$result->getbokbooking_date());		
			$desc = "";
			$desc .= 'Hi,\n\n';
			$desc .= 'Your complimentary reservation has been brought to you by DineDesk. \n\n';
			$desc .= 'Reservation Id: '.$result->getbokid().'\n\n';
			$desc .= 'LOCATION \n\n';
			$desc .= $result->getresrestaurant_name().'\n';
			$desc .= $result->getresaddress().',\n';
			$desc .= $result->getResNeighborhood().',\n';
			$desc .= $result->getResCity().'-'.$result->getResZipcode().'. \n\n';
			$desc .= 'Phone: '.$result->getResPhone().'\n';
			$desc .= 'E-mail: '.$result->getResEmail().'\n\n';
			$desc .= 'RESERVATION SCHEDULE \n\n';
			$desc .= 'Date: '.date('D d M Y',mktime(0,0,0,$dateSplit[1],$dateSplit[2],$dateSplit[0])).'\n';
			$desc .= 'Time: '.date("h:i A",strtotime($result->getbokbooking_timings())).'\n';
			$desc .= 'Party size: '.$result->getbokparty_size().'\n\n';
			$desc .= 'We look forward to serving you again. Bon Appetit! \n';
			$desc .= 'Thanks, \n';
			$desc .= 'DineDesk \n';
			$desc .= 'www.dinedesk.com\n';
			
			header("Content-Type: text/Calendar");
			header("Content-Disposition: inline; filename=calendar.ics");
			echo "BEGIN:VCALENDAR\n";
			echo "VERSION:2.0\n";
			echo "PRODID:-//Foobar Corporation//NONSGML Foobar//EN\n";
			echo "METHOD:REQUEST\n"; // requied by Outlook
			echo "BEGIN:VEVENT\n";
			echo "ORGANIZER;CN=".$result->getresrestaurant_name().":MAILTO:".$result->getResEmail()."\n";
			echo "UID:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."-".rand()."-example.com\n"; // required by Outlok
			echo "DTSTAMP:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."\n"; // required by Outlook
			echo "DTSTART:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."\n";
			echo "LOCATION: ".$result->getresaddress()."\n";
			echo "SUMMARY:Table Reservation at ".$result->getresrestaurant_name()."\n";
			echo "DESCRIPTION: ".$desc."\n";
			echo "END:VEVENT\n";
			echo "END:VCALENDAR\n";
			
		}catch (Exception $ex){
			Uss_Logger_FileLogger::info($ex->getMessage());
			return true;
			//throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function bookingdetailsaddtoicalAction()
	{
		try{
			
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
//			session_start();
//			if(!$_SESSION['bokid']){
//				$_SESSION['bokid'] = $request->bokid;			
//			}
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($request->bokid);
			
			$dateSplit = explode("-",$result->getbokbooking_date());	

			$desc = "";
			$desc .= 'Hi,\n\n';
			$desc .= 'Your reservation is confirmed through DineDesk. \n\n';
			$desc .= 'Reservation Id: '.$result->getbokid().'\n\n';
			$desc .= 'LOCATION \n\n';
			$desc .= $result->getresrestaurant_name().'\n';
			$desc .= $result->getresaddress().',\n';
			$desc .= $result->getResNeighborhood().',\n';
			$desc .= $result->getResCity().'-'.$result->getResZipcode().'. \n\n';
			$desc .= 'Phone: '.$result->getResPhone().'\n';
			$desc .= 'E-mail: '.$result->getResEmail().'\n\n';
			$desc .= 'RESERVATION SCHEDULE \n\n';
			$desc .= 'Date: '.date('D d M Y',mktime(0,0,0,$dateSplit[1],$dateSplit[2],$dateSplit[0])).'\n';
			$desc .= 'Time: '.date("h:i A",strtotime($result->getbokbooking_timings())).'\n';
			$desc .= 'Party size: '.$result->getbokparty_size().'\n\n';
			$desc .= 'We look forward to serving you again. Bon Appetit! \n';
			$desc .= 'Thanks, \n';
			$desc .= 'DineDesk \n';
			$desc .= 'www.dinedesk.com\n';

			header('Content-type: text/calendar; charset=utf-8');
			header("Content-Disposition: inline; filename=calendar.ics");
			$ical = "BEGIN:VCALENDAR\n"
					."VERSION:2.0\n"
					."METHOD:REQUEST\n"
					."PRODID:-//Foobar Corporation//NONSGML Foobar//EN\n"
					."BEGIN:VEVENT\n"
					."ORGANIZER;CN=".$result->getresrestaurant_name().":MAILTO:".$result->getResEmail()."\n"
					."DTSTART:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."Z\n"
					."LOCATION:".$result->getresaddress()."\n"
					."TRANSP: OPAQUE\n"
					."SEQUENCE:0\n"
					."UID:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."-".rand()."\n"
					."DTSTAMP:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."\n"
					."SUMMARY:Table Reservation at ".$result->getresrestaurant_name()."\n"
					."DESCRIPTION:".$desc."\n"
					."PRIORITY:1\n"
					."CLASS:PUBLIC\n"
					."BEGIN:VALARM\n"
					."TRIGGER:-PT10080M\n"
					."ACTION:DISPLAY\n"
					."DESCRIPTION:Reminder\n"
					."END:VALARM\n"
					."END:VEVENT\n"
					."END:VCALENDAR";
			echo $ical;
			
		}catch (Exception $ex){
			Uss_Logger_FileLogger::info($ex->getMessage());
			return true;
		}
	}
	
	public function socialreservationaddtoicalAction()
	{
		try{
			
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
//			session_start();
			if(!$_SESSION['bokid']){
				$_SESSION['bokid'] = $request->bokid;			
			}
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($_SESSION['bokid']);
			
			$dateSplit = explode("-",$result->getbokbooking_date());	

			$desc = "";
			$desc .= 'Hi,\n\n';
			$desc .= 'Your reservation is confirmed through DineDesk. \n\n';
			$desc .= 'Reservation Id: '.$result->getbokid().'\n\n';
			$desc .= 'LOCATION \n\n';
			$desc .= $result->getresrestaurant_name().'\n';
			$desc .= $result->getresaddress().',\n';
			$desc .= $result->getResNeighborhood().',\n';
			$desc .= $result->getResCity().'-'.$result->getResZipcode().'. \n\n';
			$desc .= 'Phone: '.$result->getResPhone().'\n';
			$desc .= 'E-mail: '.$result->getResEmail().'\n\n';
			$desc .= 'RESERVATION SCHEDULE \n\n';
			$desc .= 'Date: '.date('D d M Y',mktime(0,0,0,$dateSplit[1],$dateSplit[2],$dateSplit[0])).'\n';
			$desc .= 'Time: '.date("h:i A",strtotime($result->getbokbooking_timings())).'\n';
			$desc .= 'Party size: '.$result->getbokparty_size().'\n\n';
			$desc .= 'We look forward to serving you again. Bon Appetit! \n';
			$desc .= 'Thanks, \n';
			$desc .= 'DineDesk \n';
			$desc .= 'www.dinedesk.com\n';

			header('Content-type: text/calendar; charset=utf-8');
			header("Content-Disposition: inline; filename=calendar.ics");
			$ical = "BEGIN:VCALENDAR\n"
					."VERSION:2.0\n"
					."METHOD:REQUEST\n"
					."PRODID:-//Foobar Corporation//NONSGML Foobar//EN\n"
					."BEGIN:VEVENT\n"
					."ORGANIZER;CN=".$result->getresrestaurant_name().":MAILTO:".$result->getResEmail()."\n"
					."DTSTART:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."Z\n"
					."LOCATION:".$result->getresaddress()."\n"
					."TRANSP: OPAQUE\n"
					."SEQUENCE:0\n"
					."UID:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."-".rand()."\n"
					."DTSTAMP:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."\n"
					."SUMMARY:Table Reservation at ".$result->getresrestaurant_name()."\n"
					."DESCRIPTION:".$desc."\n"
					."PRIORITY:1\n"
					."CLASS:PUBLIC\n"
					."BEGIN:VALARM\n"
					."TRIGGER:-PT10080M\n"
					."ACTION:DISPLAY\n"
					."DESCRIPTION:Reminder\n"
					."END:VALARM\n"
					."END:VEVENT\n"
					."END:VCALENDAR";
			echo $ical;
			
		}catch (Exception $ex){
			Uss_Logger_FileLogger::info($ex->getMessage());
			return true;
		}
	}
	
	public function socialreservationaddtooutlookAction()
	{
		try{
			
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$bokid = $request->bokid;			
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			
			$dateSplit = explode("-",$result->getbokbooking_date());		
			$desc = "";
			$desc .= 'Hi,\n\n';
			$desc .= 'Your complimentary reservation has been brought to you by DineDesk. \n\n';
			$desc .= 'Reservation Id: '.$result->getbokid().'\n\n';
			$desc .= 'LOCATION \n\n';
			$desc .= $result->getresrestaurant_name().'\n';
			$desc .= $result->getresaddress().',\n';
			$desc .= $result->getResNeighborhood().',\n';
			$desc .= $result->getResCity().'-'.$result->getResZipcode().'. \n\n';
			$desc .= 'Phone: '.$result->getResPhone().'\n';
			$desc .= 'E-mail: '.$result->getResEmail().'\n\n';
			$desc .= 'RESERVATION SCHEDULE \n\n';
			$desc .= 'Date: '.date('D d M Y',mktime(0,0,0,$dateSplit[1],$dateSplit[2],$dateSplit[0])).'\n';
			$desc .= 'Time: '.date("h:i A",strtotime($result->getbokbooking_timings())).'\n';
			$desc .= 'Party size: '.$result->getbokparty_size().'\n\n';
			$desc .= 'We look forward to serving you again. Bon Appetit! \n';
			$desc .= 'Thanks, \n';
			$desc .= 'DineDesk \n';
			$desc .= 'www.dinedesk.com\n';
			
			header("Content-Type: text/Calendar");
			header("Content-Disposition: inline; filename=calendar.ics");
			echo "BEGIN:VCALENDAR\n";
			echo "VERSION:2.0\n";
			echo "PRODID:-//Foobar Corporation//NONSGML Foobar//EN\n";
			echo "METHOD:REQUEST\n"; // requied by Outlook
			echo "BEGIN:VEVENT\n";
			echo "ORGANIZER;CN=".$result->getresrestaurant_name().":MAILTO:".$result->getResEmail()."\n";
			echo "UID:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."-".rand()."-example.com\n"; // required by Outlok
			echo "DTSTAMP:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."\n"; // required by Outlook
			echo "DTSTART:".date('Ymd',strtotime($result->getbokbooking_date())).'T'.date('His',strtotime($result->getbokbooking_timings()))."\n";
			echo "LOCATION: ".$result->getresaddress()."\n";
			echo "SUMMARY:Table Reservation at ".$result->getresrestaurant_name()."\n";
			echo "DESCRIPTION: ".$desc."\n";
			echo "END:VEVENT\n";
			echo "END:VCALENDAR\n";
			
		}catch (Exception $ex){
			Uss_Logger_FileLogger::info($ex->getMessage());
			return true;
			//throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function addreservationtogoogleAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$bokid = $request->bokid;			
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$resId = $result->getbokfk_restaurant();
			
			$my_calendar = 'http://www.google.com/calendar/feeds/default/private/full';
		 	if (!isset($_SESSION['cal_token'])) {
				if (isset($_GET['token'])) {
			        $session_token = Zend_Gdata_AuthSub::getAuthSubSessionToken($_GET['token']);
					$_SESSION['cal_token'] = $session_token;
			     } else {
			     	$temp =$_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'];
			        $googleUri = Zend_Gdata_AuthSub::getAuthSubTokenUri(
			             'http://'. $_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'],
			             $my_calendar, 0, 1);
			        header('Location: '.$googleUri);
			        exit();
			     }
		 	}
		 
		$client = Zend_Gdata_AuthSub::getHttpClient($_SESSION['cal_token']);
		$dateSplit = explode("-",$result->getbokbooking_date());
		$desc = "";
		$desc .= 'Hi,<br />';
		$desc .= 'Your complimentary reservation has been brought to you by DineDesk. <br /><br />';
		$desc .= 'Reservation Id: '.$result->getbokid().'<br /><br />';
		$desc .= 'LOCATION <br /><br />';
		$desc .= $result->getresrestaurant_name().'<br />';
		$desc .= $result->getresaddress().',<br />';
		$desc .= $result->getResNeighborhood().',<br />';
		$desc .= $result->getResCity().'-'.$result->getResZipcode().'.<br /><br />';
		$desc .= 'Phone: '.$result->getResPhone().'<br />';
		$desc .= 'E-mail: '.$result->getResEmail().'<br /><br />';
		$desc .= 'RESERVATION SCHEDULE <br /><br />';
		$desc .= 'Date: '.date('D d M Y',mktime(0,0,0,$dateSplit[1],$dateSplit[2],$dateSplit[0])).'<br />';
		$desc .= 'Time: '.date("h:i A",strtotime($result->getbokbooking_timings())).'<br />';
		$desc .= 'Party size: '.$result->getbokparty_size().'<br /><br />';
		$desc .= 'We look forward to serving you again. Bon Appetit! <br />';
		$desc .= 'Thanks, <br />';
		$desc .= 'DineDesk <br />';
		$desc .= 'www.dinedesk.com ';
		
		
		$where  = $result->getresaddress().','.$result->getResNeighborhood().','.$result->getResCity().'-'.$result->getResZipcode().'.';
		$startDate = $result->getbokbooking_date();
		$sTime = $result->getbokbooking_timings();
		$startTime = explode(" ",$sTime);
		$starttimeHM = explode(":",$startTime[0]);
		if($startTime[1] ==  "PM"){
			if((int)$starttimeHM[0] != 12){
				(int)$starttimeHM[0] += 12;
			}
		}
		if($startTime[1] ==  "AM" && (int)$starttimeHM[0] == 12){
			(int)$starttimeHM[0] = 0;
		}
		$bokstarttime= $starttimeHM[0].':'.$starttimeHM[1];
		$endDate = $result->getbokbooking_date();
		$eTime = $result->getbokbooking_timings();
		$endTime = explode(" ",$eTime);
		$endtimeHM = explode(":",$endTime[0]);
		if($endTime[1] ==  "PM"){
			if((int)$endtimeHM[0] != 12){
				(int)$endtimeHM[0] += 12;
			}
		}
		if($endTime[1] ==  "AM" && (int)$endtimeHM[0] == 12){
			(int)$endtimeHM[0] = 0;
		}
		$endtimeHM[0] = $endtimeHM[0]+1;
		$bokendtime= $endtimeHM[0].':'.$endtimeHM[1];
			
		$resServ = new Application_Service_Firm();
		$timeZonecode = $resServ->GetRestaurantTimeZone($resId);		
		$dateTimeZone  = new DateTimeZone($timeZonecode);
    	$dateTime = new DateTime("now", $dateTimeZone);
		$tzOffset = $dateTimeZone->getOffset($dateTime);
		$tzOffset = substr($tzOffset, 0, 3);
		
		$gdataCal = new Zend_Gdata_Calendar($client);
		$newEvent = $gdataCal->newEventEntry();

		$newEvent->title = $gdataCal->newTitle('Reservation at '.$result->getresrestaurant_name());
		$newEvent->where = array($gdataCal->newWhere($where));
		$newEvent->content = $gdataCal->newContent($desc);
		$when = $gdataCal->newWhen();
		$when->startTime = "{$startDate}T{$bokstarttime}:00.000";
		$when->endTime = "{$endDate}T{$bokendtime}:00.000";
		$newEvent->when = array($when);
		
		$createdEvent = $gdataCal->insertEvent($newEvent);
		$linkArr = $createdEvent->link;
		
		header('Location: '.$linkArr[0]->href);
		exit();
		}catch (Exception $ex){
			Uss_Logger_FileLogger::info($ex->getMessage());
			return true;
			//throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialreservationaddtogoogleAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$bokid = $request->bokid;			
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$resId = $result->getbokfk_restaurant();
			
			$my_calendar = 'http://www.google.com/calendar/feeds/default/private/full';
		 	if (!isset($_SESSION['cal_token'])) {
				if (isset($_GET['token'])) {
			        $session_token = Zend_Gdata_AuthSub::getAuthSubSessionToken($_GET['token']);
					$_SESSION['cal_token'] = $session_token;
			     } else {
			     	$temp =$_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'];
			        $googleUri = Zend_Gdata_AuthSub::getAuthSubTokenUri(
			             'http://'. $_SERVER['SERVER_NAME'] . $_SERVER['REQUEST_URI'],
			             $my_calendar, 0, 1);
			        header('Location: '.$googleUri);
			        exit();
			     }
		 	}
		 
		$client = Zend_Gdata_AuthSub::getHttpClient($_SESSION['cal_token']);
		$dateSplit = explode("-",$result->getbokbooking_date());
		$desc = "";
		$desc .= 'Hi,<br />';
		$desc .= 'Your complimentary reservation has been brought to you by DineDesk. <br /><br />';
		$desc .= 'Reservation Id: '.$result->getbokid().'<br /><br />';
		$desc .= 'LOCATION <br /><br />';
		$desc .= $result->getresrestaurant_name().'<br />';
		$desc .= $result->getresaddress().',<br />';
		$desc .= $result->getResNeighborhood().',<br />';
		$desc .= $result->getResCity().'-'.$result->getResZipcode().'.<br /><br />';
		$desc .= 'Phone: '.$result->getResPhone().'<br />';
		$desc .= 'E-mail: '.$result->getResEmail().'<br /><br />';
		$desc .= 'RESERVATION SCHEDULE <br /><br />';
		$desc .= 'Date: '.date('D d M Y',mktime(0,0,0,$dateSplit[1],$dateSplit[2],$dateSplit[0])).'<br />';
		$desc .= 'Time: '.date("h:i A",strtotime($result->getbokbooking_timings())).'<br />';
		$desc .= 'Party size: '.$result->getbokparty_size().'<br /><br />';
		$desc .= 'We look forward to serving you again. Bon Appetit! <br />';
		$desc .= 'Thanks, <br />';
		$desc .= 'DineDesk <br />';
		$desc .= 'www.dinedesk.com ';
		
		
		$where  = $result->getresaddress().','.$result->getResNeighborhood().','.$result->getResCity().'-'.$result->getResZipcode().'.';
		$startDate = $result->getbokbooking_date();
		$sTime = $result->getbokbooking_timings();
		$startTime = explode(" ",$sTime);
		$starttimeHM = explode(":",$startTime[0]);
		if($startTime[1] ==  "PM"){
			if((int)$starttimeHM[0] != 12){
				(int)$starttimeHM[0] += 12;
			}
		}
		if($startTime[1] ==  "AM" && (int)$starttimeHM[0] == 12){
			(int)$starttimeHM[0] = 0;
		}
		$bokstarttime= $starttimeHM[0].':'.$starttimeHM[1];
		$endDate = $result->getbokbooking_date();
		$eTime = $result->getbokbooking_timings();
		$endTime = explode(" ",$eTime);
		$endtimeHM = explode(":",$endTime[0]);
		if($endTime[1] ==  "PM"){
			if((int)$endtimeHM[0] != 12){
				(int)$endtimeHM[0] += 12;
			}
		}
		if($endTime[1] ==  "AM" && (int)$endtimeHM[0] == 12){
			(int)$endtimeHM[0] = 0;
		}
		$endtimeHM[0] = $endtimeHM[0]+1;
		$bokendtime= $endtimeHM[0].':'.$endtimeHM[1];
			
		$resServ = new Application_Service_Firm();
		$timeZonecode = $resServ->GetRestaurantTimeZone($resId);		
		$dateTimeZone  = new DateTimeZone($timeZonecode);
    	$dateTime = new DateTime("now", $dateTimeZone);
		$tzOffset = $dateTimeZone->getOffset($dateTime);
		$tzOffset = substr($tzOffset, 0, 3);
		
		$gdataCal = new Zend_Gdata_Calendar($client);
		$newEvent = $gdataCal->newEventEntry();

		$newEvent->title = $gdataCal->newTitle('Reservation at '.$result->getresrestaurant_name());
		$newEvent->where = array($gdataCal->newWhere($where));
		$newEvent->content = $gdataCal->newContent($desc);
		$when = $gdataCal->newWhen();
		$when->startTime = "{$startDate}T{$bokstarttime}:00.000";
		$when->endTime = "{$endDate}T{$bokendtime}:00.000";
		$newEvent->when = array($when);
		
		$createdEvent = $gdataCal->insertEvent($newEvent);
		$linkArr = $createdEvent->link;
		
		header('Location: '.$linkArr[0]->href);
		exit();
		}catch (Exception $ex){
			Uss_Logger_FileLogger::info($ex->getMessage());
			return true;
			//throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivemaximumallowedsizeAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			if($request){
				$resid = $request->restaurantid;
				$restService = new Application_Service_Firm();										 
				$maxPartyRes = $restService->MaxPartyAllowedByRest($resid);							
				if($maxPartyRes){
					echo json_encode($maxPartyRes->resmaxpax);						
				}else{
					echo json_encode('f');
				}
			}else{
				echo json_encode('f');	
			}				
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreiveblockscheduledescriptionAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			if($request){
				//$result = $this->_reservationService->getFreezeTypeByDate($request);
				$frzdescMap = $this->_reservationService->getFreezeDesc($request);
				if($frzdescMap && $frzdescMap->rfdm_desc){
					$result['desc'] = $frzdescMap->rfdm_desc;
					echo json_encode($result);
				}else{
					echo json_encode('f');
				}
			}else{
				echo json_encode('f');	
			}				
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function addwaitingkioskAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$request = $this->getRequest();
				$this->_helper->layout->disableLayout();
				if($request->restaurantid){
					$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
				}else{
					$resStat = false;
				}
        
				$this->view->secureLoginStatus = $resStat;
				if($resStat){
		//		$this->_helper->viewRenderer->setNoRender();
					$waitingForm = $this->_reservationService->getWaitingKioskReservForm();
					
					$this->view->restaurantid = $request->restaurantid;
					$timeSettingsResult = $this->_reservationService->reteriveWaitingreservationQuoteTimes($request);
					$this->view->timeSettingsResult = $timeSettingsResult;
					$resServ = new Application_Service_Firm();
					$timeZonecode = $resServ->GetRestaurantTimeZone($request->restaurantid);
					date_default_timezone_set($timeZonecode);
					$date = date('m-d-Y');
					$this->view->date = $date;
					if($request->successMsg){
						$this->view->successMsg = "Your reservation is successfully added to the waiting list";
					}
					$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
					$CountryCode = $CountryCodeMapper->fetchAll();
					$CodeList = array();
					$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
					foreach($CountryCode as $listcode){
						//$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
            $CodeList[] = array('key'=>$listcode->getDescription(),'value'=>$listcode->getCode());
					}
					
					$this->view->codelist = $CodeList;
					$restDataMapper = new FirmManagement_Model_FirmDataMapper();
					$countrycode = $restDataMapper->getCountrycodebyId($request->restaurantid);
					if($countrycode){
						$this->view->countrycode = $countrycode;
					}
					
					$reservCount = $this->_reservationService->getcurrentwaitlistcount($request->restaurantid,$date);
					$this->view->reservCount = $reservCount;
					
					if($this->getRequest()->isPost()){
						$stateId = '';
						$cityId = '';
						$regionId = '';
						
						$storage = new Zend_Auth_Storage_Session();
						$data = $storage->read();
						$resid = $request->restaurantid;
						if(isset($data['State_Id'])){
							$stateId = $data['State_Id'];
						}
						if(isset($data['City_Id'])){
							$cityId = $data['City_Id'];
						}
						if(isset($data['Region_Id'])){
							$regionId = $data['Region_Id'];
						}
						
						$result = $this->_reservationService->CustomerKioskReservation($this->getRequest()->getPost(),$data['User_Id'],$stateId,$cityId,$regionId);
            //echo '<pre>'; print_r($result); exit;
						if($result['status']){
							if($result['result']){
								return $this->_helper->redirector('addwaitingkiosk','Reservation','Reservation',array('restaurantid'=>$request->restaurantid,'date'=> $date,'successMsg'=>'Your reservation is successfully added to the waiting list'));
							}
						}else{
							$this->view->MakeWaitingResForm = $result['Form'];
						}
						$kioskSetting = $this->_reservationService->CheckKioskSettingsOnLoad($request->restaurantid,$request->waitpax);
						if($kioskSetting['status']){
							$this->view->waittime = $kioskSetting['waiting_time'];
						}else{
							$this->view->waittime = 'f';
						}
					}else{
             //echo '<pre>'; print_r($request); exit;
						$this->view->MakeWaitingResForm = $waitingForm;
						$kioskSetting = $this->_reservationService->CheckKioskSettingsOnLoad($request->restaurantid,1);
						if($kioskSetting['status']){
							$this->view->waittime = $kioskSetting['waiting_time'];
						}else{
							$this->view->waittime = 'f';
						}
					}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function waitingsettingsAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$storage = new Zend_Auth_Storage_Session();
			$request = $this->getRequest();
			$data = $storage->read();
			
			if($request->restaurantid){
				$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
			}else{
				$resStat = false;
			}
			
			$this->view->secureLoginStatus = $resStat;
			$this->_helper->layout->disableLayout();
			if($resStat){
				
				$form = $this->_reservationService->getQuoteTimeSettingsForm();
				
				$this->view->restaurantid = $request->restaurantid;
				$this->view->date = $request->date;
				$this->view->reqaction = $request->reqaction;
				if($this->getRequest()->isPost()){
					$operation = $request->frmStat;
					$result = $this->_reservationService->ManageWaitQuoteSettings($this->getRequest()->getPost(),$request);
					switch($operation){
						case	'Add':
							$resultantArr = array();
							if($result['status']){
								if($result['msgstatus']){
									$resultantArr['msgstatus'] = $result['msgstatus'];
									$resultantArr['status'] = $result['result'];
									$resultantArr['form'] = $result['Form'];
									$resultantArr['operation'] = $operation;
								}else{
									$resultantArr['status'] = $result['result'];
									$resultantArr['form'] = $form;
								}								
							}else{
								$resultantArr['form'] = $result['Form'];
							}
							break;
						case	'Edit':
							if($result['status']){
								if($result['msgstatus']){
									$resultantArr['msgstatus'] = $result['msgstatus'];
									$resultantArr['status'] = $result['result'];
									$resultantArr['form'] = $result['Form'];
									$resultantArr['operation'] = $operation;
								}else{
									$resultantArr['status'] = $result['result'];
									$resultantArr['form'] = $form;
								}	
							}else{
								$resultantArr['form'] = $result['Form'];
							}
							break;
					}
					echo json_encode($resultantArr);
				}
			}
			
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getkiosktimingsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$quoteSettings = $this->_reservationService->reteriveWaitingreservationQuoteTimes($request,'ajax');
			$result['quoteSettings'] = $quoteSettings;
			echo json_encode($result);
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function checkkiosksettingsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->CheckKioskSettings($request);
			if($result['status']){
				echo $result['waiting_time'];
			}else{
				echo 'f';
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivewaitingtimesAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			if($request->restaurantid){
				$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
			}else{
				$resStat = false;
			}
			$this->view->secureLoginStatus = $resStat;
			
			if($request && $resStat){
				
				$timeSettingsResult = $this->_reservationService->reteriveWaitingreservationQuoteTimes($request);
				$restInfo           = $this->_reservationService->GetRestInfo($request);
				$this->view->timeSettingsResult = $timeSettingsResult;
				$this->view->restInfo			= $restInfo;
				$this->view->restaurantid 		= $request->restaurantid;
				
				$resServ = new Application_Service_Firm();
				$timeZonecode = $resServ->GetRestaurantTimeZone($request->restaurantid);
				date_default_timezone_set($timeZonecode);
				$date = date('m-d-Y');
				$this->view->date = $date;
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
		
	}
	
	public function updatereservationconfirmstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->changeBokConfirmStatus($request);
			if(isset($request->src) && $request->src == 'mail'){
				echo '<script type="text/javascript"> window.top.close(); </script>';
			}else{
				if($status){
					echo json_encode('t');
				}else{
					echo json_encode('f');
				}
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function approvedreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->ManageCheckedInResv($request);
			if($status){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function guestarrivedreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->ManageAllArrivedResv($request);
			if($status){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function guestarrivingreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->ManagePartialArrivedResv($request);
			if($status){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function delayedbyguestreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->ManageRunningLateResv($request);
			if($status){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	public function emptyreservationstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->ClearReservationStatus($request);
			if($status){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	public function currentguestlistAction(){
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$pdf = $this->_reservationService->zendpdf($request);
			$file = 'managerest/'.$request->restaurantid.'/chits/'.$request->restaurantid.'.pdf';
			
			$size = filesize($file);		
			if (file_exists($file))
			{
				header("Content-type: application/force-download");
				header("Content-Transfer-Encoding: Binary");
				header('Content-Length: '.$size);
				header("Content-disposition: attachment; filename=".basename($file));
				readfile($file);
	
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function undohandledreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->cancelCompletion($request);
			if($status){
				$return = 't';
			}else{
				$return = 'f';
			}
			echo $return;
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function undohandledreservationcalendarAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->cancelCompletionBookView($request);
			if($status){
				$return = 't';
			}else{
				$return = 'f';
			}
			echo $return;
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**	
	 * 	action to retreive all the completed reservations of that day
	 */	
	public function retreivehandledreservationsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$resultStr = $this->_reservationService->GetCompletedReservations($request);
			echo json_encode($resultStr);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function calendarAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->todaydate = date("m-d-Y");
				$request = $this->getRequest();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$this->view->companyid = $data['companyid'];
				$this->view->userStatus = $data['Usertype'];
				$this->view->userId = $data['User_Id'];
				$this->view->userPermissions = $data['Permissions'];
				
				if($data['Usertype'] == "RSO" || $data['Usertype'] == "ADM" || $data['Usertype'] == "ADU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "RSU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "SRU"){
					$restNameList = $data['restList'];
				}
				if(isset($request->restaurantid)){
					$restId = $request->restaurantid;
				}else{
					$restId = $data['RestId'];
					$request->setParam('restaurantid',$restId);
					$x = $request->restaurantid;
				}
				$menu = $this->_reservationService->getReservationMenu($restId);
				$this->view->menu = $menu;
				$NameList = array();
				
				foreach($restNameList as $resNameVal){
					$NameList[$resNameVal['key']] = $resNameVal['value'];
				}
				
				if(isset($request->bokstat)){
					$this->view->bokStat = $request->bokstat;
				}else{
					$this->view->bokStat = '';
				}
				$mealsettings = $this->_reservationService->ChekRestMealSettings($request);
				$this->view->mealsettings = $mealsettings;
				$userService = new Application_Service_Client();
				$restUsers = $userService->getRestaurantOwnersAndUsersByRestId($restId);
				//echo $mealsettings; exit;
				$timeSettingsResult = $this->_reservationService->reteriveWaitingreservationQuoteTimes($request);
				$this->view->timeSettingsResult = $timeSettingsResult;
				$form = $this->_reservationService->getQuoteTimeSettingsForm();
				$this->view->quoteform = $form;
				
				
				if($request){
					if(array_key_exists($restId,$NameList)){
						$form = $this->_reservationService->getMakeReservationForm();
						$mealsData = $this->_reservationService->getMealsByResid($restId,'settings');
						$form->resTime->addMultiOptions($mealsData['times']);
						$waitingForm = $this->_reservationService->getWaitingReservForm();
						$walkinForm = $this->_reservationService->getWalkInReservForm();
						$bokform = $this->_reservationService->getBlockReservForm();
            
						$result = $this->_reservationService->getBookingsforDayView($request,$data);
            
						$TableLayoutStr 		   = $result['Layout'];
						$this->view->finalStr 	   = $TableLayoutStr['finalStr'];
						$this->view->floorSepStr   = $result['FloorSep'];
						$this->view->etnStr 	   = $TableLayoutStr['etnStr'];
						$this->view->diningareas   = $result['diningareas'];
						$this->view->diningid	   = $result['diningid'];
						$this->view->TableStatus   = $result['TableStatus'];
						//echo '<pre>'; print_r($result); exit;
						$this->view->FreezeStatus  = $result['FreezeStatus'];
						$this->view->RestLogo      = $result['RestLogo'];
						$this->view->mealType 		= $result['mealType'];
						$this->view->reservCount 	= $result['reservCount'];
						if(isset($result['mealCount'])){
							$this->view->mealCount = $result['mealCount'];
						}
						$this->view->mealDetails = $result['mealDetails'];
						$this->view->bookingList = $result['DayView'];
						if(array_key_exists('DayViewWal',$result))
						{
							$this->view->bookingListWal = $result['DayViewWal'];
						}
						else
						{
							$this->view->bookingListWal = '';
						}
//						$this->view->bookingListCount = $result['DayViewCount'];
//						$this->view->bookingListWalCount = $result['DayViewWalCount'];
						
						$this->view->Seated = $result['Seated'];
						$this->view->SeatedCount = $result['SeatedCount'];
						
						$this->view->Completed = $result['Completed'];
						$this->view->CompletedCount = $result['CompletedCount'];						

						$form->reservationInitials->addMultiOptions($restUsers);
						$form->setDefaults(array('reservationInitials'=> $data['User_Id']));
						$resservice = new Application_Service_Firm();
						$bokoptionstatus = $resservice->getBookingOptionsSetting($request->restaurantid);
						if($bokoptionstatus->resbookingoption_setting){
							$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
							if(count($bookingoptions) > 1){
								$form->bokoptions->addMultiOptions($bookingoptions);
								$this->view->bokoptionsts   = true;
							}else{
								$this->view->bokoptionsts   = false;
							}							
						}else{
							$this->view->bokoptionsts   = false;
						}
						
						$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
				    	$CountryCode = $CountryCodeMapper->fetchAll();
				    	$CodeList = array();
				    	$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
				    	foreach($CountryCode as $listcode){
				    		$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
				    	}
					    	
				    	$this->view->codelist = $CodeList;
						
						$restDataMapper = new FirmManagement_Model_FirmDataMapper();
						$countrycode = $restDataMapper->getCountrycodebyId($restId);
						if($countrycode){
							$formValues = array('countryCode' => $countrycode);
							$this->view->countrycode = $countrycode;
							$form->populate($formValues);
							$waitingForm->populate($formValues);	
							$walkinForm->populate($formValues);	
							$bokform->populate($formValues);											
						}
						
						$this->view->MakeResForm   = $form;
						$this->view->MakeWaitingResForm = $waitingForm;
						$this->view->MakewalkinForm = $walkinForm;
						$this->view->blockform = $bokform;
						$this->view->restaurantid  = $request->restaurantid;
						if($request->date){
							$tSel = explode('-',$request->date);
							if($tSel[0] > 12){
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
							}else {
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
							}
						}else{
							$this->view->date = date("m-d-Y");
							$this->view->formDateVal = date("d M Y");
						}
						$request->setParam('date',$this->view->date);
						$this->view->availability = $this->_reservationService->GetAvailabilityOfRestaurant($request);
						$this->view->secureLoginStatus = 'true';
						$this->view->diningPeriods = $result['meal_periods'];
					}else{
						$this->view->secureLoginStatus = 'false';
					}
					if(isset($request->act)){
						$this->view->act = $request->act;
					}
					$mealPeriod = $request->meal;
					if(isset($mealPeriod))
					{
						$this->view->mealPeriod = $mealPeriod;
					}
					else
					{
						$this->view->mealPeriod = '';
					}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function ajaxcalendarAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$results = $this->_reservationService->Ajax_BookingsDayView($request);
      //echo '<pre>'; print_r($results); exit;
			echo $results;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	

	public function calendarviewmonthAction()
	{
		try{			
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->todaydate = date("m-d-Y");
				$request = $this->getRequest();				
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				if($request->restaurantid){
					$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
				}else{
					$resStat = false;
				}
				$this->view->secureLoginStatus = $resStat;
				if($resStat){
					$mealsettings = $this->_reservationService->ChekRestMealSettings($request);

					$form = $this->_reservationService->getMakeReservationForm();	
					$waitingForm = $this->_reservationService->getWaitingReservForm();
					$walkinForm = $this->_reservationService->getWalkInReservForm();
					$bokform = $this->_reservationService->getBlockReservForm();	
					$result = $this->_reservationService->RetrieveBookingsWeekView($request);
					$userService = new Application_Service_Client();
					$restUsers = $userService->getRestaurantOwnersAndUsersByRestId($request->restaurantid);
					$this->view->datesarray = $result['dateArr'];
					$this->view->partysizecount = $result['partysizecountArr'];
					$this->view->bookingcount = $result['bookingcount'];
					$this->view->displaydate = $result['displaydate'];
					$this->view->date = $result['today'];
					$this->view->formDateVal = $result['todaydate'];
					$form->reservationInitials->addMultiOptions($restUsers);
					$form->setDefaults(array('reservationInitials'=> $data['User_Id']));
					$this->view->restaurantid = $request->restaurantid;
					$this->view->defaultview = $data['DefaultView'];	
					
					$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
			    	$CountryCode = $CountryCodeMapper->fetchAll();
			    	$CodeList = array();
			    	$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
			    	foreach($CountryCode as $listcode){
			    		$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
			    	}
				    	
			    	$this->view->codelist = $CodeList;
					
					$restDataMapper = new FirmManagement_Model_FirmDataMapper();
					$countrycode = $restDataMapper->getCountrycodebyId($request->restaurantid);
					if($countrycode){
						$formValues = array('countryCode' => $countrycode);
						$this->view->countrycode = $countrycode;
						$form->populate($formValues);
						$waitingForm->populate($formValues);	
						$walkinForm->populate($formValues);	
//						$bokform->populate($formValues);											
					}
					$this->view->MakeResForm   = $form;
						$this->view->MakeWaitingResForm = $waitingForm;
						$this->view->MakewalkinForm = $walkinForm;
						$this->view->blockform = $bokform;
					if(isset($request->bokstat)){
						$this->view->bokStat = $request->bokstat;
					}else{
						$this->view->bokStat = '';
					}
					$result = $this->_reservationService->RetrieveBookingsMonthView($request);
					$this->view->mealsettings = $mealsettings;
					$this->view->datesarray = $result;
					$this->view->restaurantid = $request->restaurantid;
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function calendarviewmonthpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->RetrieveBookingsMonthView($request);
			echo json_encode($result);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function calendarviewweekAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->todaydate = date("m-d-Y");
				$request = $this->getRequest();	
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();	
				if($request->restaurantid){
					$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
				}else{
					$resStat = false;
				}
				$this->view->secureLoginStatus = $resStat;
				if($resStat){
					$form = $this->_reservationService->getMakeReservationForm();	
					$waitingForm = $this->_reservationService->getWaitingReservForm();
					$walkinForm = $this->_reservationService->getWalkInReservForm();
					$bokform = $this->_reservationService->getBlockReservForm();	
					$mealsettings = $this->_reservationService->ChekRestMealSettings($request);
					$result = $this->_reservationService->RetrieveBookingsWeekView($request);
					$userService = new Application_Service_Client();
					$restUsers = $userService->getRestaurantOwnersAndUsersByRestId($request->restaurantid);
					$this->view->mealsettings = $mealsettings;
					$this->view->datesarray = $result['dateArr'];
					$this->view->partysizecount = $result['partysizecountArr'];
					$this->view->bookingcount = $result['bookingcount'];
					$this->view->displaydate = $result['displaydate'];
					$this->view->date = $result['today'];
					$this->view->formDateVal = $result['todaydate'];
					$form->reservationInitials->addMultiOptions($restUsers);
					$form->setDefaults(array('reservationInitials'=> $data['User_Id']));
					$this->view->restaurantid = $request->restaurantid;
					$this->view->defaultview = $data['DefaultView'];				
					
					$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
			    	$CountryCode = $CountryCodeMapper->fetchAll();
			    	$CodeList = array();
			    	$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
			    	foreach($CountryCode as $listcode){
			    		$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
			    	}
				    	
			    	$this->view->codelist = $CodeList;
					
					$restDataMapper = new FirmManagement_Model_FirmDataMapper();
					$countrycode = $restDataMapper->getCountrycodebyId($request->restaurantid);
					if($countrycode){
						$formValues = array('countryCode' => $countrycode);
						$this->view->countrycode = $countrycode;
						$form->populate($formValues);
						$waitingForm->populate($formValues);	
						$walkinForm->populate($formValues);	
//						$bokform->populate($formValues);											
					}
					$this->view->MakeResForm   = $form;
					$this->view->MakeWaitingResForm = $waitingForm;
					$this->view->MakewalkinForm = $walkinForm;
					$this->view->blockform = $bokform;
					
					if(isset($request->bokstat)){
						$this->view->bokStat = $request->bokstat;
					}else{
						$this->view->bokStat = '';
					}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function calendarviewweekpostAction(){
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->RetrieveBookingsWeekView($request);
			echo json_encode($result);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function managecustommenuAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();	
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				if($request->restid){
					$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restid);
				}else{
					$resStat = false;
				}
				$this->view->secureLoginStatus = $resStat;
				if($resStat){
					$this->_helper->layout()->setLayout('restaurantuserlayout');
					if($this->getRequest()->isPost()){
						$result = $this->_reservationService->ManageCustomMenu($this->getRequest()->getPost());
						if($result){
							$this->view->status = $result['status'];
						}else{
							$this->view->status = 'err';
						}
					}
					$this->view->returnAction = $request->returnAction;
					$this->view->restid = $request->restid;
					$menu = $this->_reservationService->getReservationMenu($request->restid,'edit');
					$this->view->menu = $menu;
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function managecustommenupostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->ManageCustomMenu($this->getRequest()->getPost());
				if($result){
					echo json_encode($result);
				}
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function updatereservationmenustatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$result = $this->_reservationService->ChangeReservationMenuStatus($request);
				if($result['status']){
					echo json_encode($result['status']);
			//		return $this->_helper->redirector('managecustommenu','Reservation','Reservation',array('restid'=>$request->restid,'returnAction'=> $request->returnAction));
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function addreservationoptionsAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest(); 
				
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				if($request->restaurantid){
					$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
				}else{
					$resStat = false;
				}
				$this->view->secureLoginStatus = $resStat;
				$this->view->returnAction = $request->returnAction;
				if($resStat){
					$this->_helper->layout()->setLayout('restaurantuserlayout');
					if($this->getRequest()->isPost()){
					$operation = $request->operation;
						switch($operation){
							case 'ADD'	:
								if($request->addtype == "PRIMARY"){
									$result = $this->_reservationService->addBookingOptions($this->getRequest()->getPost(),$data,$request);
								}else{
									$result = $this->_reservationService->addSecondaryBookingOptions($this->getRequest()->getPost(),$data,$request);
								}
								if($result['status']){
									return $this->_helper->_redirector('workareamanagement','Firm','FirmManagement',array('restaurantid' => $request->restaurantid));
									break;
								}else{
									return $this->_helper->_redirector('workareamanagement','Firm','FirmManagement',array('restaurantid' => $request->restaurantid,'addstatus'=>'a','codestatus'=>$result['codestatus'],'descstatus'=>$result['descstatus'],'description'=>$request->description,'addcode'=>$request->addcode,'addtype'=>$request->addtype));
									break;
								}
							case 'EDIT' :
								$editDetails = $this->_reservationService->EditBookingOptions($this->getRequest()->getPost(),$data,$request);
								if($editDetails['status']){
									break;
								}else{
									return $this->_helper->_redirector('workareamanagement','Firm','FirmManagement',array('restaurantid' => $request->restaurantid,'addstatus'=>'e','codestatus'=>$editDetails['codestatus'],'descstatus'=>$editDetails['descstatus'],'description'=>$request->description,'addcode'=>$request->addcode,'bokoptionid'=>$request->bokoptionid));
									break;
								}
						}
					}
					
					$restService = new Application_Service_Firm();
					$optionsetting = $restService->getBookingOptionsSetting($request->restaurantid);
					$this->view->optionsetting = $optionsetting->resbookingoption_setting;
					$this->view->restaurantid = $request->restaurantid;
					
					$optionList = $this->_reservationService->getBookingOptionsListByRestid($request->restaurantid);
					$this->view->optionList = $optionList;
				} 
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
		throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function managereservationoptionstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->UpdateBookingOptionStatus($request);
			if($result){
				echo $result;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetindexAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			
			$restIdObj = new Deals_Model_SpecialsByRestId();
			$restIdObj->setRestaurantId($request->restid);			
			
			$mapper = new Deals_Model_RestaurantSpecialDataMapper();
			$result = $mapper->RetrieveAllActiveSpecialsByRestId($restIdObj,$request);
			$this->view->spllist = $result['list'];
			if(isset($result['offset'])){
				$this->view->offset		   = $result['offset'];
			}
			$this->view->prev = $result['prev'];
			$this->view->next = $result['next'];
			$this->view->restid = $request->restid;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			
			$restid = $request->where;
			$splid = $request->splid;
			$splIdObj = new Deals_Model_RestaurantSpecialById();
			$splIdObj->setSpecialId($splid)
					 ->setRestId($restid);
			$mapper = new Deals_Model_RestaurantSpecialDataMapper();
			$result = $mapper->RetrieveSpecialDetailsById($splIdObj,false);
			$this->view->result = $result;
			$this->view->restid = $restid;
			$this->view->splid = $splid;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetauthdetailconfirmationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$payStat = 'false';
			$payAmt = '';
			if($request->specialid){	
				$splService = new Application_Service_Deals();	
				$splResult = $splService->GetSpecialDetailsById($request,false);
				$this->view->splpricetype = $splResult->getSpecialpricetypeCode();
				if($splResult->getCatTypeCode() == 'SP'){
					$payStat = 'true';
					$payAmt = $splResult->getPricewithdiscount();
					$this->view->payAmt = $payAmt;
				}else if($splResult->getCatTypeCode() == 'CP'){
					$payService = new Application_Service_Renumeration();
					$payResult = $payService->GetRestaurantPaymentSettingsByResId($request->restaurantid,$weekdate);	
					$payType = '';
					if($payResult){
						$payType = $payResult['rpsnoshow_type'];
						$this->view->payType = $payType;
						$this->view->paydesc = $payResult['rpsdesc'];
						$payAmt = $payResult['payamount'];
						$this->view->payAmt = $payAmt;
						if($request->respax >= $payResult['paypax']){		
							$payStat = 'true';
						}
					}
				}
			}
			
			$resDataMapper = new FirmManagement_Model_FirmDataMapper();
			$restid = new FirmManagement_Model_FirmById();
			$restid->setRestaurantId($request->restaurantid);
			$resDetails = $resDataMapper->getRestaurantById($restid);
			$this->view->resDetails = $resDetails;
			
			$this->view->resname = $resDetails->getRestaurantname();
			$this->view->resaddress = $resDetails->getRestaddress();
			$this->view->restaurantid = $request->restaurantid;
			$this->view->specialid = $request->specialid;
			$this->view->paymentStatus = $payStat;
			$this->view->ressplName = $splResult->getSpecialtitle();
			$this->view->restime = $request->restime;
			$this->view->resdate = $request->resdate;
			$this->view->respax = $request->respax;
			$this->view->bookingstatus = $request->bookingstatus;
			$this->view->nooftables = $request->nooftables;
			$this->view->tablesize = $request->tablesize;
			$this->view->inventoryid = $request->inventoryid;
	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetauthconsumerdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$respl = $request->ressplName;
			$stateId = "";
			$cityId = "";
			$regionId = "";
			
			if($this->getRequest()->isPost()){
				if($result = $this->_reservationService->BookingDetails($this->getRequest()->getPost(),$stateId,$cityId,$regionId)){
					if($result){
						if(!$result['result']){
							$form = $this->_reservationService->getBookingDetailsForm();
							$payStat = 'false';
							if($request->specialid){	
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
								
								$splService = new Application_Service_Deals();	
								$splResult = $splService->GetWidgetSpecialDetailsById($request->restaurantid,$request->specialid,false);
								if($splResult->getCatTypeCode() == 'SP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';
								}else if($splResult->getCatTypeCode() == 'CP'){
									$payService = new Application_Service_Renumeration();		
									$payResult = $payService->GetRestaurantPaymentSettingsByResId($request->restaurantid,$weekdate);	
									$payType = '';
									if($payResult){
										$this->view->splTransactType = 'SPL';
										$payType = $payResult['rpsnoshow_type'];
										$this->view->payType = $payType; 
										$this->view->payAmt = $payResult['payamount'];
										if($request->respax >= $payResult['paypax']){		
											$payStat = 'true';
										}
									}
								}
							}
							
							$request = $this->getRequest();
							$formData  = array('resId'=>(int)$request->restaurantid,
				                           'resName'=>$request->resname,
				                           'resAddress'=>$request->resaddress,
				                           'resDate'=>$request->resdate,
				                           'resTime'=>$request->restime,
				                           'pax'=>$request->respax,
										   'inventoryid'=>$request->inventoryid,
										   'paymentStatus'=>$payStat
				
							);				
					
							$this->view->resdate = date('D d M Y',$s);
							$this->view->date = $weekdate;
							$this->view->resname = $request->resname;
							$this->view->resaddress = $request->resaddress;
							$this->view->restime = $request->restime;
							$this->view->respax = $request->respax;
							$this->view->bookingstatus = $request->bookingstatus;
							$this->view->restaurantid = $request->restaurantid;
							$this->view->tablesize = $request->tablesize;
							$this->view->nooftables = $request->nooftables;
							$this->view->specialid  = $request->specialid;
							$this->view->booktype   = $request->booktype;
							$this->view->specialamt = $request->specialamt;
							$this->view->ressplName = $request->ressplName;
							$form->populate($formData);
							$this->view->form = $form;
						}else{
							$paymentStatus = $request->paymentStatus;
							if($request->specialid){	
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
								$splService = new Application_Service_Deals();	
								$splResult = $splService->GetWidgetSpecialDetailsById($request->restaurantid,$request->specialid,false);
								if($splResult->getCatTypeCode() == 'SP'){
									$payStat = 'true';
									$this->view->splTransactType = 'SPLPAID';
								}else if($splResult->getCatTypeCode() == 'CP'){
									$payService = new Application_Service_Renumeration();		
									$payResult = $payService->GetRestaurantPaymentSettingsByResId($request->restaurantid,$weekdate);	
									$payType = '';
									if($payResult){
										$this->view->splTransactType = 'SPL';
									}
								}
							}
							if($paymentStatus == 'true'){
								$this->view->cusprofId = $result['profileId'];
								$this->view->paymentprofId = $result['payment'];
								$this->view->bookingid = $result['result'];
								$this->view->userid = $result['userId'];
								$this->view->resid = $request->restaurantid;
								$this->view->specialid = $request->specialid;
							}else{
								$bookedData = $result['result'];
								$resid = $request->restaurantid;
								$respl = $request->ressplName;
								$this->_helper->redirector('dealwidgetreservationconfirmation','Reservation','Reservation',array('bokid'=>$bookedData,'resid'=>$resid,'ressplName'=>$request->ressplName,'bokstat'=>true));
							} 
						}
					}
				}
			}else{			
				$form = $this->_reservationService->getBookingDetailsForm();
			
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				$payStat = 'false';
				if($request->specialid){	
					$splService = new Application_Service_Deals();	
					$splResult = $splService->GetWidgetSpecialDetailsById($request->restaurantid ,$request->specialid,false);
					if($splResult->getCatTypeCode() == 'SP'){
						$payStat = 'true';
						$this->view->splTransactType = 'SPLPAID';
					}else if($splResult->getCatTypeCode() == 'CP'){
						$payService = new Application_Service_Renumeration();		
						$payResult = $payService->GetRestaurantPaymentSettingsByResId($request->restaurantid,$weekdate);	
						$payType = '';
						if($payResult){
							$this->view->splTransactType = 'SPL';
							$payType = $payResult['rpsnoshow_type'];
							$this->view->payType = $payType; 
							$this->view->payAmt = $payResult['payamount'];
							if($request->respax >= $payResult['paypax']){		
								$payStat = 'true';
							}
						}
					}
				}			
				$request = $this->getRequest();
				$formData  = array('resId'=>(int)$request->restaurantid,
	                           'resName'=>$request->resname,
	                           'resAddress'=>$request->resaddress,
	                           'resDate'=>$request->resdate,
	                           'resTime'=>$request->restime,
	                           'pax'=>$request->respax,
							   'inventoryid'=>$request->inventoryid,
							   'paymentStatus'=>$payStat
	
				);
	
				$this->view->resdate = date('D d M Y',$s);
				$this->view->resname = $request->resname;
				$this->view->resaddress = $request->resaddress;
				$this->view->restime = $request->restime;
				$this->view->date = $weekdate;
				$this->view->respax = $request->respax;
				$this->view->bookingstatus = $request->bookingstatus;
				$this->view->restaurantid = $request->restaurantid;
				$this->view->tablesize = $request->tablesize;
				$this->view->nooftables = $request->nooftables;
				$this->view->specialid  = $request->specialid;
				$this->view->booktype   = $request->booktype;
				$this->view->specialamt = $request->specialamt;
				$this->view->ressplName = $request->ressplName;
				
				$resservice = new Application_Service_Firm();
				$optionsetting = $resservice->getBookingOptionsSetting($request->restaurantid);
				if($optionsetting->resbookingoption_setting){
					$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
					if(count($bookingoptions) > 1){
						$form->bokoptions->addMultiOptions($bookingoptions);
						$this->view->bokoptionsts   = true;
					}else{
						$this->view->bokoptionsts   = false;
					}							
				}else{
					$this->view->bokoptionsts   = false;
				}
				$form->populate($formData);
				$this->view->form = $form;		
			}	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetspldetailsAction()
	{
		try{
		$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$stateId = "";
			$cityId = "";
			$regionId = "";
			if($this->getRequest()->isPost()){
				if($result = $this->_reservationService->BookingDetails($this->getRequest()->getPost(),$stateId,$cityId,$regionId)){
					if($result){
						if(!$result['result']){
							$form = $this->_reservationService->getBookingDetailsForm();
							$payStat = 'false';
							if(!$request->specialid){
								$payService = new Application_Service_Renumeration();
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
								
								$payResult = $payService->GetRestaurantPaymentSettingsByResId($request->restaurantid,$weekdate);	
								$payStat = 'false';
								$payType = '';
								if($payResult){
									$payType = $payResult['rpsnoshow_type'];
									$this->view->payType = $payType; 
									$this->view->payAmt = $payResult['payamount'];
									if($request->respax >= $payResult['paypax']){		
										$payStat = 'true';
									}
								}
							}
							
							$request = $this->getRequest();
							$formData  = array('resId'=>(int)$request->restaurantid,
				                           'resName'=>$request->resname,
				                           'resAddress'=>$request->resaddress,
				                           'resDate'=>$request->resdate,
				                           'resTime'=>$request->restime,
				                           'pax'=>$request->respax,
										   'inventoryid'=>$request->inventoryid,
										   'paymentStatus'=>$payStat
				
							);			
					
							$this->view->resdate = date('D d M Y',$s);
							$this->view->resname = $request->resname;
							$this->view->resaddress = $request->resaddress;
							$this->view->restime = $request->restime;
							$this->view->respax = $request->respax;
							$this->view->bookingstatus = $request->bookingstatus;
							$this->view->restaurantid = $request->restaurantid;
							$this->view->tablesize = $request->tablesize;
							$this->view->nooftables = $request->nooftables;
							$this->view->specialid  = $request->specialid;
							$this->view->booktype   = $request->booktype;
							$this->view->specialamt = $request->specialamt;
				
							$form->populate($formData);
							$this->view->form = $form;
						}else{
							$paymentStatus = $request->paymentStatus;
							if($paymentStatus == 'true'){
								$this->view->cusprofId = $result['profileId'];
								$this->view->paymentprofId = $result['payment'];
								$this->view->bookingid = $result['result'];
								$this->view->userid = $result['userId'];
								$this->view->resid = $request->restaurantid;
							}else{
								$bookedData = $result['result'];
								$resid = $request->restaurantid;
								$this->_helper->redirector('dealwidgetsplbookingconfirmation','Reservation','Reservation',array('bokid'=>$bookedData,'resid'=>$resid,'bokstat'=>true));
							}
						}
					}
				}
			}else{
				$form = $this->_reservationService->getBookingDetailsForm();
			
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				$payStat = 'false';
				if(!$request->specialid){			
					$payService = new Application_Service_Renumeration();
					$payResult = $payService->GetRestaurantPaymentSettingsByResId($request->restaurantid,$weekdate);	
					$payStat = 'false';
					$payType = '';
					if($payResult){
						$payType = $payResult['rpsnoshow_type'];
						$this->view->payType = $payType; 
						$this->view->payAmt = $payResult['payamount'];
						if($request->respax >= $payResult['paypax']){		
							$payStat = 'true';
						}
					}
				}
				
				$request = $this->getRequest();
				$formData  = array('resId'=>(int)$request->restaurantid,
	                           'resName'=>$request->resname,
	                           'resAddress'=>$request->resaddress,
	                           'resDate'=>$request->resdate,
	                           'resTime'=>$request->restime,
	                           'pax'=>$request->respax,
							   'inventoryid'=>$request->inventoryid,
							   'paymentStatus'=>$payStat
	
				);
	
				$this->view->resdate = date('D d M Y',$s);
				$this->view->resname = $request->resname;
				$this->view->resaddress = $request->resaddress;
				$this->view->restime = $request->restime;
				$this->view->respax = $request->respax;
				$this->view->bookingstatus = $request->bookingstatus;
				$this->view->restaurantid = $request->restaurantid;
				$this->view->tablesize = $request->tablesize;
				$this->view->nooftables = $request->nooftables;
				$this->view->specialid  = $request->specialid;
				$this->view->booktype   = $request->booktype;
				$this->view->specialamt = $request->specialamt;
				
				$form->populate($formData);
				$resservice = new Application_Service_Firm();
				$bokoptionstatus = $resservice->getBookingOptionsSetting($request->restaurantid);
				if($bokoptionstatus->resbookingoption_setting){
					$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
					if(count($bookingoptions) > 1){
						$form->bokoptions->addMultiOptions($bookingoptions);
						$this->view->bokoptionsts   = true;
					}else{
						$this->view->bokoptionsts   = false;
					}							
				}else{
					$this->view->bokoptionsts   = false;
				}
	
				$this->view->form = $form;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function dealwidgetsplbookingconfirmationAction()
	{
		try{
			$this->_helper->layout->disableLayout();

			$request = $this->getRequest();
			if(isset($request->bokstat)){
				$this->view->bokStat = $request->bokstat;
			}else{
				$this->view->bokStat = '';
			}
			$restId = $request->resid;
			$bokid   = $request->bokid;
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$this->view->bookedData = $result;
			$this->view->restaurantid = $restId;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}
	
	public function dealwidgetreservationconfirmationAction()
	{
		try{
			$this->_helper->layout->disableLayout();

			$request = $this->getRequest();
			if(isset($request->bokstat)){
				$this->view->bokStat = $request->bokstat;
			}else{
				$this->view->bokStat = '';
			}
			$restId = $request->resid;
			$bokid   = $request->bokid;
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$this->view->bookedData = $result;
			$this->view->restaurantid = $restId;
			$this->view->ressplName = $request->ressplName;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function syncreservationswithappAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->MigrateBookings($request);
			echo json_encode($result);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function reservationappsyncAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->BookingWebSync($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode(array('result'=>'f'));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateblockedscheduleappAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->ManageFreezeFromNative($request);
			echo json_encode($result);
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());	
		}
	}
	public function retreivereservationbyidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->GetBookingDetailsCusByBokid($request);
			echo json_encode($result);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivemealoffirmAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getMealTypeByRestid($request);
			if(count($result)>0){
				echo json_encode($result);
			}else{
				echo json_encode('f');;
			}			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());	
		}
	}
	
	public function socialreservationwidgetAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$restService = new Application_Service_Firm();

			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->userlogstat = 'true';
			}else{
				$this->view->userlogstat = 'false';
			}
			//$form = new Application_Form_Search();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
                        $dwusrc ='';                        
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
                        /*Changing source for diningwithus for thier customer website and facebook*/
                        if($request->dwusrc){
                           $dwusrc = $request->dwusrc;                           
                        }
			$this->view->dwusrc = $dwusrc;
                       
                        /*Changing source for diningwithus for thier customer website end*/
			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($resid);
			date_default_timezone_set($timezone);

			$specialserv = new Application_Service_Deals();
			/*code to retrive the tagline*/
			$splTag = '';
			$tagline = $specialserv->GetSpecialTagLineByResId($resid);
			if($tagline){
				$splTag=$tagline->spl_tag_tagline;
			}
			$this->view->tagLine=$splTag;
			//-------------------------------//
			
			/*special status by date*/
//			$splStat = $specialserv->getRestaurantSpecialByDate($request);
			$restDataMapper = new FirmManagement_Model_FirmDataMapper();
			$splstatus = $restDataMapper->GetSpecialSetting($resid);
			$splcheck = $splstatus->resspecialsetting;
			$this->view->splStat = 1;
			$this->view->splcheck = $splcheck;
			
			$widsettings = $this->_restService->getRestaurantCustomizeWidgetByResid($resid);
			if($widsettings){
				$this->view->widsettings = $widsettings;
			}	
			
			if($this->getRequest()->isPost() && $request->date){
				$postBool = true;
				
					
				$maxPartyRes = "";
				$maxParty = "";
				$maxPartyAllowed = "Yes";
				$minParty = "";
				// BEGIN Getting Max and Min Party Sizes Day Wise//	
				$dateSplit = explode("-",$request->date);
				$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));	 
				
				$object = new FirmManagement_Model_FirmDayPartySettings();
				$object->setrdpsfk_restaurants($resid);	
				$mapper = new FirmManagement_Model_FirmDayPartySettingsMapper();
				$resultArray = $mapper->GetDayPartySize($object);
				$maxallowedsize = $resultArray['ressize'];
				$tempdata = $resultArray['times'];
				foreach($tempdata as $item)
				{
					$x=strtoupper($item['day']);
					$y=strtoupper($weekday);
					$z = strcmp ($x,$y);
					if(!$z){
						if($item['daystatus'])
						{
							$maxParty = $item['maxsize'];
							$minParty = $item['minsize'];
							
						}else{
							
							$maxParty = $maxallowedsize;
							$minParty = 1;
							
						}
						break;
					}else{
							
							$maxParty = $maxallowedsize;
							$minParty = 1;
							
						}
				}
				
				if(!$resultArray){
						$maxParty = $maxallowedsize;
						$minParty = 1;
				}
				if(($request->pax > $maxParty || $request->pax < $minParty)){
					$maxPartyAllowed = "No";	
				}
				// END Getting Max and Min Party Sizes Day Wise//		
					$searchList = $this->_reservationService->GetRestTimingsFromWidget($request, $resid);
				$index = 0; 
				if($searchList){
					foreach($searchList as $listval){
						if($listval['status'] == 'WAL'){
							continue;
						}else{
							$searchListArr[$index] = $listval;
							$index++;
						} 
					}
				}else{
					$frezresult = $this->_reservationService->getFreezeTypeByDate($request);
					if($frezresult && $frezresult['type'] == 'All'){
						$frzdescMap = $this->_reservationService->getFreezeDesc($request);
						if($frzdescMap && $frzdescMap->rfdm_desc){
							$this->view->freezedesc = $frzdescMap->rfdm_desc;
						}else{
							$serv = new Application_Service_Firm();
							$msg = $serv->getRestaurantTimeSearchMessage($resid);
							$this->view->freezedesc = $msg->resbooking_search_msg;
						}
					}else{
						$serv = new Application_Service_Firm();
						$msg = $serv->getRestaurantTimeSearchMessage($resid);
						$this->view->freezedesc = $msg->resbooking_search_msg;
					}
				}
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				
				
				$this->view->searchlist = $searchListArr;
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->mealtype = $request->mealtype;
				$this->view->forDate = $weekdate;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
								
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->resPhone	= $resDetails->getRestphone();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
				$this->view->maxPartyStatus = $maxPartyAllowed;
				$this->view->maxParty = $maxParty;
				$this->view->minParty = $minParty;
				$this->view->resCompanyid = $resDetails->getcompanyid();
				
			}else{
				$this->view->restid = $resid;
				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resCompanyid = $resDetails->getcompanyid();
				$this->view->resDetails = $resDetails;
				$this->view->mealTypes = $this->_reservationService->getRestaurantMealTypes($request);
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$owner = new FirmManagement_Model_OwnerByRestaurantId();
				$owner->setRestaurantId($resid);
				$resownername = $mapper->getOwnerByRestId($owner);
				$restList = '';
				if($resownername){
					$restNameByOwnObj = new FirmManagement_Model_FirmNamesByOwnerId();
					$restNameByOwnObj->setRestOwnerId($resownername->getRestUser());
					$restList   = $mapper->getRestaurantDataByOwnerId($restNameByOwnObj);
					$this->view->restList = $restList;
				}
				$this->view->postBool = $postBool;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialreservationwidgetrestlocationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$searchListArr = array();
			$searchList = $this->_reservationService->GetRestTimingsOnLocFromWidget($request);
			$index = 0;
			if($searchList){
				foreach($searchList as $key=>$listval){
					if($listval['sch']){
						$searchArr = array();
						foreach ($listval['sch'] as $searchData){
							if($searchData['status'] == 'WAL'){
								continue;
							}else{
								$searchArr[$index] = $searchData;
								$index++;
							}
						}
						$searchListArr[$key]['sch'] = $searchArr;
						$searchListArr[$key]['details'] = $listval['details'];
					}
				}
			}
			echo json_encode($searchListArr);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialreservationdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$stateId = "";
			$cityId = "";
			$regionId = "";
			$payResult ="";
                        $dwusrc ="";                        
			/* Get Widget Theme Start */
			$restService = new Application_Service_Firm();
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;			
                        $this->view->rescompanyid = $request->rescompanyid;
			/* Get Widget Theme End */
                        
                        /* Get source for diningwithus customers */
                        if($request->dwusrc) {
                           $dwusrc =  $request->dwusrc;
                        }
                        $this->view->dwusrc = $dwusrc;	                        
                        /* Get source for diningwithus customers end */
			$restid = $request->restaurantid;
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$result = $mapper->GetSpecialRequestSetting($restid);
			$this->view->splreq = $result->resspecial_request;
			$widsettings = $this->_restService->getRestaurantCustomizeWidgetByResid($restid);
			if($widsettings){
				$this->view->widsettings = $widsettings;
			}
			$otpmapper = new FirmManagement_Model_FirmDataMapper();
			$otpResult = $otpmapper->GetOtpSettingStatus($restid);
			if($otpResult->resotp_setting){
				$this->view->otpresult = 'true';
			}else{
				$this->view->otpresult = 'false';
			}
			
			$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
	    	$CountryCode = $CountryCodeMapper->fetchAll();
	    	$CodeList = array();
	    	$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
	    	foreach($CountryCode as $listcode){
	    		$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
	    	}
		    	
	    	$this->view->codelist = $CodeList;
			
			if($this->getRequest()->isPost()){
				if($result = $this->_reservationService->BookingDetails($this->getRequest()->getPost(),$stateId,$cityId,$regionId,'widget')){
					if($result){
						if(!$result['result']){
							$form = $this->_reservationService->getBookingDetailsForm();
							$payStat = 'false';
							if(!$request->specialid){
								$payService = new Application_Service_Renumeration();
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
								
//								$payResult = $payService->GetRestaurantPaymentSettingsByResId($request->restaurantid,$weekdate);	
								$payStat = 'false';
								$payType = '';
								if($payResult){
									$payType = $payResult['rpsnoshow_type'];
									$this->view->payType = $payType; 
									$this->view->payAmt = $payResult['payamount'];
									if($request->respax >= $payResult['paypax']){		
										$payStat = 'true';
									}
								}
							}
							
							$request = $this->getRequest();
							$formData  = array('resId'=>(int)$request->restaurantid,
				                           'resName'=>$request->resname,
				                           'resAddress'=>$request->resaddress,
				                           'resDate'=>$request->resdate,
				                           'resTime'=>$request->restime,
				                           'pax'=>$request->respax,
										   'inventoryid'=>$request->inventoryid,
										   'paymentStatus'=>$payStat
				
							);
				
					
							$this->view->resdate = date('l, F j Y',$s);
							$this->view->resname = $request->resname;
							$this->view->resaddress = $request->resaddress;
							$this->view->restime = $request->restime;
							$this->view->respax = $request->respax;
							$this->view->bookingstatus = $request->bookingstatus;
							$this->view->restaurantid = $request->restaurantid;
							$this->view->tablesize = $request->tablesize;
							$this->view->nooftables = $request->nooftables;
							$this->view->specialid  = $request->specialid;
							$this->view->booktype   = $request->booktype;
							$this->view->specialamt = $request->specialamt;
							$this->view->mealtype = $request->mealtype;
							
							$auth = Zend_Auth::getInstance();
							$data = array();
							if($auth->hasIdentity()){
								$storage = new Zend_Auth_Storage_Session();
								$data = $storage->read();
								$this->view->userdata = $data;
								$formData['firstName'] = $data['Firstname'];
								$formData['lastName'] = $data['LastName'];
								$formData['number'] = $data['Phone'];
								$formData['email'] = $data['Email'];
								$formData['userid'] = $data['User_Id'];
								//$formData['notificationType'] = ;
																
								$codemapper = new User_Model_ClientDataMapper();
								$usercountrycode = $codemapper->getCountrycodebyUserid($data['User_Id'],$data['Usertype'],$request->restaurantid);
								if($usercountrycode){
									$formData['countryCode'] =  $usercountrycode;
								}											
							}else{						
								$codemapper = new FirmManagement_Model_FirmDataMapper();
								$countrycode = $codemapper->getCountrycodebyId($request->restaurantid);
								if($countrycode){
									$formData['countryCode'] =  $countrycode;
									$this->view->countrycode = $countrycode;
								}
							}	
							$form->populate($formData);
							//$form->setDefaults(array('notificationType'	=>	'email'));
				
							$this->view->form = $form;
						}else{
							$paymentStatus = $request->paymentStatus;
							if($paymentStatus == 'true'){
								$this->view->cusprofId = $result['profileId'];
								$this->view->paymentprofId = $result['payment'];
								$this->view->bookingid = $result['result'];
								$this->view->userid = $result['userId'];
								$this->view->resid = $request->restaurantid;
							}else{
								$bookedData = $result['result'];
								$resid = $request->restaurantid;
                                                                if($dwusrc != null){                                                                
                                                                $this->_helper->redirector('socialreservationwidgetconfirmation','Reservation','Reservation',array('bokid'=>$bookedData,'resid'=>$resid,'bokstat'=>true, 'dwusrc' => $dwusrc));  
                                                                }                                                             
                                                                else{
                                                                $this->_helper->redirector('socialreservationwidgetconfirmation','Reservation','Reservation',array('bokid'=>$bookedData,'resid'=>$resid,'bokstat'=>true));    
                                                                }
								
							}
						}
					}
				}
			}else{
				$form = $this->_reservationService->getBookingDetailsForm();
			
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				$payStat = 'false';
				if(!$request->specialid){			
					$payService = new Application_Service_Renumeration();
					$payStat = 'false';
					$payType = '';
					if($payResult){
						$payType = $payResult['rpsnoshow_type'];
						$this->view->payType = $payType; 
						$this->view->payAmt = $payResult['payamount'];
						if($request->respax >= $payResult['paypax']){		
							$payStat = 'true';
						}
					}
				}
				
				$request = $this->getRequest();
				$formData  = array('resId'=>(int)$request->restaurantid,
	                           'resName'=>$request->resname,
	                           'resAddress'=>$request->resaddress,
	                           'resDate'=>$request->resdate,
	                           'resTime'=>$request->restime,
	                           'pax'=>$request->respax,
							   'inventoryid'=>$request->inventoryid,
							   'paymentStatus'=>$payStat
	
				);
	
				$this->view->resdate = date('D d M Y',$s);
				$this->view->resname = $request->resname;
				$this->view->resaddress = $request->resaddress;
				$this->view->restime = $request->restime;
				$this->view->respax = $request->respax;
				$this->view->bookingstatus = $request->bookingstatus;
				$this->view->restaurantid = $request->restaurantid;
				$this->view->tablesize = $request->tablesize;
				$this->view->nooftables = $request->nooftables;
				$this->view->specialid  = $request->specialid;
				$this->view->booktype   = $request->booktype;
				$this->view->specialamt = $request->specialamt;
				$this->view->mealtype = $request->mealtype; 
				
				$auth = Zend_Auth::getInstance();
				$data = array();
				if($auth->hasIdentity()){
					$storage = new Zend_Auth_Storage_Session();
					$data = $storage->read();
					$this->view->userdata = $data;
					$formData['firstName'] = $data['Firstname'];
					$formData['lastName'] = $data['LastName'];
					$formData['number'] = $data['Phone'];
					$formData['email'] = $data['Email'];
					$formData['userid'] = $data['User_Id'];
					//$formData['notificationType'] = ;
										
				}
	
			 	$codemapper = new FirmManagement_Model_FirmDataMapper();
				$countrycode = $codemapper->getOwnerCountrycodebyId($request->restaurantid);
				if($countrycode){
					$formData['countryCode'] =  $countrycode;
				}	
				
				$form->populate($formData);
				$resservice = new Application_Service_Firm();
				$bokoptionstatus = $resservice->getBookingOptionsSetting($request->restaurantid);
				if($bokoptionstatus->resbookingoption_setting){
					$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
					$secbookingoptions = $this->_reservationService->getSecBookingOptionsByresId($request);
					if(count($bookingoptions) > 1){
						$form->bokoptions->addMultiOptions($bookingoptions);
						$this->view->bokoptionsts   = true;
					}else{
						$this->view->bokoptionsts   = false;
					}
					if(count($secbookingoptions) > 1){
						$form->boksecoptions->addMultiOptions($secbookingoptions);
						$this->view->secbokoptionsts   = true;
					}else{
						$this->view->secbokoptionsts   = false;
					}							
				}else{
					$this->view->bokoptionsts   = false;
					$this->view->boksecoptionsts   = false;
				}
				$this->view->form = $form;
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialreservationwidgetconfirmationAction()
	{
		try{
			$this->_helper->layout->disableLayout();

			$request = $this->getRequest();
                        
                        /*Getting source for diningWithUsCus Start*/                       
                        $dwusrc ='';                       
                        if($request->dwusrc){
                           $dwusrc = $request->dwusrc;
                        }
                        $this->view->dwusrc = $dwusrc;                                                 
                        /*Getting source for diningWithUsCus End*/
                        
			if(isset($request->bokstat)){
				$this->view->bokStat = $request->bokstat;
			}else{
				$this->view->bokStat = '';
			}
			
			/* Get Widget Theme Start */
			$restService = new Application_Service_Firm();
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			
			$restId = $request->resid;
			$widsettings = $this->_restService->getRestaurantCustomizeWidgetByResid($restId);
			if($widsettings){
				$this->view->widsettings = $widsettings;
			}
			$bokid   = $request->bokid;
			$notStatus = $this->_reservationService->CheckReservationNotificationStatusByBokPhraseId($bokid);
			$this->view->notStatus = $notStatus;
			$this->view->phraseId = $bokid;
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$this->view->bookedData = $result;
                        $autoconfStatus = $this->_reservationService->GetAutoConfirmStatusByResid($restId);
			$this->view->autoconfirm = $autoconfStatus;
			$this->view->restaurantid = $restId;
                        
                        $restid = new FirmManagement_Model_FirmById();
			$restid->setRestaurantId($restId);
                        $mapper = new FirmManagement_Model_FirmDataMapper();
			$resDetails = $mapper->getRestaurantById($restid);
			$this->view->resCompanyid = $resDetails->getcompanyid();
                        $this->view->resName = $resDetails->getRestaurantname();
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}
	
	public function retreivefloordataAction()
	{
		try{
			$request = $this->getRequest();
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			if($request){
				$result = $this->_reservationService->GetDiningTabData($request);
			}
			$resultArr = array();
			$bokResult = '';
			if($request->bookingid){
				$bokResult = $this->_reservationService->ValidateBookingTableAvailability($request->bookingid);
			}
			if($result){
					$resultArr = array('layout' => $result['Layout'], 'entrance' => $result['Entrance'],'seperator' => $result['FloorSep'],'availability'=>'');
			}
			if($bokResult){//table availability 
				$resultArr['availability'] = $bokResult;
			}		
			echo json_encode($resultArr); 
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}
	
	public function retreivemessagesofreservationsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
    	    $result = $this->_reservationService->getSmsHistoryByBookingId($request);	
    	    if($result){
    	    	echo json_encode($result);
    	    }else{
    	    	echo json_encode(array('f'));
    	    }
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());	
		}
	}
	public function dealwidgetsearchforreservationAction()
	{
		try{
		$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			$check = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->userlogstat = 'true';
			}else{
				$this->view->userlogstat = 'false';
			}
			$restService = new Application_Service_Firm();

			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			if($this->getRequest()->isPost()){
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype($request->splFrom);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$specialMapper = new Application_Service_Deals();
				$specialCount = new Deals_Model_RestaurantSpecialCounter();
				$specialCount->setSpecialId($request->splid)
							 ->setRestaurantid($resid);
				$specialCounter = $specialMapper->SpecialCountIncrementer($specialCount);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$offset = '';
				$limit = '';
				$statLtd = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;
					}else{
						$limit = 2;	
					}
				
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$statLtd = 'true';
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				
				$this->view->searchlist = $searchList[0];
				if($statLtd){
					$this->view->check = $check;
				}else{
					$this->view->check = 'false';
				}
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->page = $page;
				$this->view->splFrom = $request->splFrom;
				$this->view->splid = $request->splid;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}else{
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$todDate = date('m-d-Y');
				$todTime = date('h:i A');
				$resttimings->setDate($todDate);
				$resttimings->setRestId($resid);
				$resttimings->setTime(date('h:i A'));
				$resttimings->setpartysize(2);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype('viewall');
				$resttimings->setschtype('viewall');
				if($todDate){
					$dateSplit = explode("-",$todDate);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$specialMapper = new Application_Service_Deals();
				$specialCount = new Deals_Model_RestaurantSpecialCounter();
				$specialCount->setSpecialId($request->splid)
							 ->setRestaurantid($resid);
				$specialCounter = $specialMapper->SpecialCountIncrementer($specialCount);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$offset = '';
				$limit = '';
				$statLtd = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;
					}else{
						$limit = 2;	
					}
				
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$statLtd = 'true';
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}

				$dateSplit = explode("-",$todDate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
			
				$this->view->searchlist = $searchList[0];
				if($statLtd){
					$this->view->check = $check;
				}else{
					$this->view->check = 'false';
				}
				$this->view->restid = $resid;
				$pax = 2;
				$date = $todDate;
				$this->view->pax = 2;
				$this->view->date = $todDate;
				$this->view->time = $todTime;
//				$this->view->paymentStatus = $payStat;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->page = $page;
				$this->view->splFrom = 'viewall';
				$this->view->splid = $request->splid;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function socialdealwidgetsearchforreservationAction()
	{
		try{
		$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			$check = '';
			if($request->where){
				$resid = $request->where;
			}else{
				$resid = $request->restid;
			}
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->userlogstat = 'true';
			}else{
				$this->view->userlogstat = 'false';
			}
			$restService = new Application_Service_Firm();

			/* Get Widget Theme Start */
			
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			if($this->getRequest()->isPost()){
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$resttimings->setDate($request->date);
				$resttimings->setRestId($resid);
				$resttimings->setTime($request->time);
				$resttimings->setpartysize($request->pax);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype($request->splFrom);
				$resttimings->setschtype('viewall');
				if($request->date){
					$dateSplit = explode("-",$request->date);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$specialMapper = new Application_Service_Deals();
				$specialCount = new Deals_Model_RestaurantSpecialCounter();
				$specialCount->setSpecialId($request->splid)
							 ->setRestaurantid($resid);
				$specialCounter = $specialMapper->SpecialCountIncrementer($specialCount);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$offset = '';
				$limit = '';
				$statLtd = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;
					}else{
						$limit = 2;	
					}
				
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$statLtd = 'true';
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				
				$this->view->searchlist = $searchList[0];
				if($statLtd){
					$this->view->check = $check;
				}else{
					$this->view->check = 'false';
				}
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->page = $page;
				$this->view->splFrom = $request->splFrom;
				$this->view->splid = $request->splid;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}else{
				$postBool = true;
				$resttimings = new Reservation_Model_GetRestaurantTimings();
				$todDate = date('m-d-Y');
				$todTime = date('h:i A');
				$resttimings->setDate($todDate);
				$resttimings->setRestId($resid);
				$resttimings->setTime(date('h:i A'));
				$resttimings->setpartysize(2);
				$resttimings->setSplId($request->splid);
				$resttimings->setschtype('viewall');
				$resttimings->setschtype('viewall');
				if($todDate){
					$dateSplit = explode("-",$todDate);
					$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
					
					$weekRecurrObj    = new Application_Model_WeekRecurr();
					$weekRecurrMapper = new Application_Model_WeekRecurrDataMapper();
					$weekRecurrObj->setcode(strtolower($weekday));
					$weekRecurrRes = $weekRecurrMapper->getWeekDayIdByCode($weekRecurrObj);
					$resttimings->setDay(strtolower($weekday));																
					$resttimings->setWeekDayId($weekRecurrRes->getId());				
				}
				$page = '';
				if($request->page){
					$page = $request->page;
				}else{
					$page = 1;
				}
				$specialMapper = new Application_Service_Deals();
				$specialCount = new Deals_Model_RestaurantSpecialCounter();
				$specialCount->setSpecialId($request->splid)
							 ->setRestaurantid($resid);
				$specialCounter = $specialMapper->SpecialCountIncrementer($specialCount);
				
				$detailsMapper = new Reservation_Model_SearchListViewDataMapper();
				$searchList = $detailsMapper->getRestSplTimings($resttimings,$page);
				$index = 0; 
				$val = 0;
				$offset = '';
				$limit = '';
				$statLtd = '';
				if($searchList[0]){
					$offset = count($searchList[0]);
					if($theme && $theme['rwt_theme_style'] == 'H'){
						$limit = 1;
					}else{
						$limit = 2;	
					}
				
					
					foreach($searchList[0] as $listval){
						$val++;
						
						if($listval->getTimesArray()){
							foreach($listval->getTimesArray() as $value){
								if($value['status'] == 'WAL'){
									continue;
								}else{
									$searchListArr[$index] = $value;
									$index++;
								} 
							}
							$statLtd = 'true';
							$listval->setTimesArray($searchListArr);
						}
						
					}
				}

				$dateSplit = explode("-",$todDate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
			
				$this->view->searchlist = $searchList[0];
				if($statLtd){
					$this->view->check = $check;
				}else{
					$this->view->check = 'false';
				}
				$this->view->restid = $resid;
				$pax = 2;
				$date = $todDate;
				$this->view->pax = 2;
				$this->view->date = $todDate;
				$this->view->time = $todTime;
//				$this->view->paymentStatus = $payStat;
				$this->view->offset = $offset;
				$this->view->limit = $limit;
				$this->view->page = $page;
				$this->view->splFrom = 'viewall';
				$this->view->splid = $request->splid;

				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function customercontactphonesearchpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$text = trim($request->inputtext);
			$phone = trim($request->inputphone);
			$email = trim($request->inputemail);
			$restid = $request->restaurantid;
			$result = $this->_restService->searchCusContactByPhone($text,$phone,$email,$restid);
			if($result){
				$jsonObj = json_encode($result);
				echo $jsonObj;
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function customerlookupthroughemailAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$text = trim($request->inputtext);
			$restid = $request->restaurantid;
			$result = $this->_restService->searchCusContactByEmail($text,$restid);
			$list = array();
			$cusListArr = null;
			if($result){
				foreach($result as $key=>$value){
					$list[] = array('rgu' => array("key"=>$key,"value"=>$value));
				}
			}
			if(count($list) > 0){
				$cusListArr = array('cuslist'=>$list);
				$cusJson = json_encode($cusListArr);
				echo $cusJson;
			}else{
				//$test = "f";
				$cusJson = json_encode("f");
				echo $cusJson;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function getpastmonthsreservationchartAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$timeresult = $this->_reservationService->Gettimeslotsforchart($request);
			if($timeresult){
				echo json_encode($timeresult);
			
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getusergeneratechartAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$timeresult = $this->_reservationService->Gettimeslotsforchart($request);
			if($timeresult){
				echo json_encode($timeresult);
			
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getpastmonthsreservationoriginchartAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$timeresult = $this->_reservationService->Gettimeslotsfororiginchart($request);
			if($timeresult){
				echo json_encode($timeresult);
			
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getusergenerateoriginchartAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$timeresult = $this->_reservationService->Gettimeslotsfororiginchart($request);
			if($timeresult){
				echo json_encode($timeresult);
			
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
		
	public function changecustdetailsbyidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			if($request->customerid){
				$result = $this->_restService->updateCustomerDetails($request);
				echo json_encode($result);

			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
		
	public function retreivereservationshistoryAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$page = $this->_request->getParam('page');
				if (empty($page)){
					$page = 1;
				}
			if($request){
				$result = $this->_reservationService->getpastandfuturereservations($request,$page);
				echo json_encode($result);

			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function restaurantfreezemanagementAction()
	{
		try{			
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();				
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				if($request->restaurantid){
					$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
				}else{
					$resStat = false;
				}
				if($resStat){
					$form = $this->_reservationService->getMakeReservationForm();	
					$waitingForm = $this->_reservationService->getWaitingReservForm();
					$walkinForm = $this->_reservationService->getWalkInReservForm();
					$bokform = $this->_reservationService->getBlockReservForm();	
					$mealsettings = $this->_reservationService->ChekRestMealSettings($request);
					$this->view->mealsettings = $mealsettings;
					$result = $this->_reservationService->RetrieveBookingsWeekView($request);
					$userService = new Application_Service_Client();
					$restUsers = $userService->getRestaurantOwnersAndUsersByRestId($request->restaurantid);
					$this->view->partysizecount = $result['partysizecountArr'];
					$this->view->bookingcount = $result['bookingcount'];
					$this->view->date = $result['today'];
					$this->view->formDateVal = $result['todaydate'];
					$form->reservationInitials->addMultiOptions($restUsers);
					$form->setDefaults(array('reservationInitials'=> $data['User_Id']));
					$this->view->defaultview = $data['DefaultView'];	
					
					$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
			    	$CountryCode = $CountryCodeMapper->fetchAll();
			    	$CodeList = array();
			    	$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
			    	foreach($CountryCode as $listcode){
			    		$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
			    	}				    	
			    	$this->view->codelist = $CodeList;
					
					$restownerId = new User_Model_ManagerDataMapper();
					$countrycode = $restownerId->getOwnerCountrycodebyId($data['User_Id']);
					if($countrycode){
						$formValues = array('countryCode' => $countrycode->getres_country_code());
						$this->view->countrycode = $countrycode->getres_country_code();
						$form->populate($formValues);
						$waitingForm->populate($formValues);											
					}
					$this->view->MakeResForm   = $form;
					$this->view->MakeWaitingResForm = $waitingForm;
					$this->view->MakewalkinForm = $walkinForm;
					$this->view->blockform = $bokform;
					if(isset($request->bokstat)){
						$this->view->bokStat = $request->bokstat;
					}else{
						$this->view->bokStat = '';
					}
					$monthviewcounts = $this->_reservationService->RetrieveBookingsMonthView($request);
					$this->view->datesarray = $monthviewcounts;
					$this->view->restaurantid = $request->restaurantid;
				}
				$this->view->secureLoginStatus = $resStat;
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreiveblockedschedulebydateandidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getFreezeDataByDateandRestaurantidajax($request);
			if($result){
				echo json_encode($result);			
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function retreivecustomerbyreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getCustomerDetailsbybookingdata($request);
			echo json_encode($result);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function managereservationoptionspostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();	
				$request = $this->getRequest();
				$operation = $request->operation;
				switch($operation){
					case 'ADD'	:
						$result = $this->_reservationService->addBookingOptions($this->getRequest()->getPost(),$data,$request);
						if($result['status']){
							echo json_encode($result);
							break;					
						}else{
							echo json_encode('f');
							break;
						}
					case 'EDIT' :
						$editDetails = $this->_reservationService->EditBookingOptions($this->getRequest()->getPost(),$data,$request);
						if($editDetails['status']){
							echo json_encode($editDetails);
							break;
						}else{
							echo json_encode($editDetails);
							break;
						}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getrestimesbydatepaxAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$resid = $request->restaurantid;
			$results = $this->_reservationService->GetRestTimingsFromWidget($request, $resid);
			$searchListArr = array();
			if(isset($results)){
				$index = 0;		

				if($results === false){
					
				}else{
					foreach($results as $listval){
						if($listval['status'] == 'WAL'){
							continue;
						}else{
							$searchListArr[$index] = $listval;
							$index++;
						}
					}
				}
			}			
			echo json_encode($searchListArr);
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	} 
	
	public function guestreportAction(){
		try{
			$request = $this->getRequest();
			$rest_result = $this->_reservationService->GetReservationsForChitsAndDupes($request);
			$resServ = new Application_Service_Firm();
			$timeZone = $resServ->GetRestaurantTimeZone($request->restaurantid);
			date_default_timezone_set($timeZone);
			if($rest_result){
				$this->view->result = $rest_result;
				$this->view->restaurantid = $request->restaurantid;
			}
			if($request->date){
				$tSel = explode('-',$request->date);
				$date = date("d M Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
				$this->view->date = $date;
			}else{
				$date = date('d-M-Y');
				$this->view->date = $date;
			}
		}catch (Exception $ex){			
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function webbookingdetailsAction()
	{
		try{
			
			$request = $this->getRequest();
			$bookingid   = $request->bookingid;
			if(isset($request->category)){
				$this->view->category = $request->category;
				$QuotedList	=	array();
				$quoteMapper = new Application_Model_WaitingQuoteTimeDataMapper();
				$quoteResult = $quoteMapper->fetchAll();
				$this->view->quoteResult = $quoteResult;
				$this->_helper->layout()->setLayout('ddwebwaitlayout');
			}else{
				$this->_helper->layout()->setLayout('ddweblayout');
			}
			
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bookingid);
			$this->view->bookedData = $result;
			$curResid = $result->getbokfk_restaurant();
			
			$request->setParam('restaurantid',$result->getbokfk_restaurant());
			$restDetails = $this->_reservationService->GetRestaurantDetails($request);
			$this->view->restGallery = $this->_reservationService->getGalleryByRestaurantId($curResid);
			$this->view->restdetails = $restDetails;
			
			$fbevent = $this->_reservationService->getBookFbEvent($result->getbokid());
			if($fbevent){
				$this->view->fbevent = $fbevent;
			}			
			$emailevent = $this->_reservationService->getBookEmailEventStatus($result->getbokid());
			if($emailevent){
				$this->view->emailevent = $emailevent;
			}
			$menuList = $this->_reservationService->getRestaurantMenu($request);
			$this->view->menuList = $menuList;
			
			$selectedMenu = $this->_reservationService->getSelectedMenuByBookingId($result->getbokid());
			if (!empty($selectedMenu)) {
				$this->view->selectedMenu = $selectedMenu;
			}
			$referer = $_SERVER['SERVER_NAME'];
			$this->view->referer = $referer;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function cancelreservationfromweburlAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->CancelReservationCon($request);
			if($result['status']){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function reschedulereservationfromwebAction()
	{
		try{
			$stateId = "";
			$cityId = "";
			$regionId = "";
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();		
			if($bookedData = $this->_reservationService->UpdateBookingDetails($request,$stateId,$cityId,$regionId,$request->bokid,'widget')){
				if($bookedData['result']){
					echo $bookedData['result'];
				}else{
					echo 'f';
				}
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getinvitedguestinfoAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$resultArr = $this->_reservationService->getInvitedGuestInfo($request);
			if(count($resultArr) > 0){
				echo json_encode($resultArr);
			}else{
				echo json_encode('f');
			}			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function createbookeventAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			
			$bokid = $request->bokid;
			$restid = $request->restid;
			$namespace = new Zend_Session_Namespace(); 
			if(!isset($namespace->bokid)){				
				$namespace->bokid = $bokid;
				$namespace->restid = $restid; 
			}
			$referer = $_SERVER['SERVER_NAME'];
			//$frndlist_url = "http://$referer/Reservation/Reservation/createfbbevent";
			
			if(isset($request->error_reason) && isset($request->error)){
				$auth->clearIdentity();
				echo "<script type=\"text/javascript\">";
    			echo "window.close(); </script>";
			}else{
				/* facebook*/	
			 	$app_id = "174154322766851";
			   	$app_secret = "1b3d72b533301ed3332c344db134c94d";
			   
			   	$my_url = "http://$referer/Reservation/Reservation/createbookevent";
			   				   	
			   	$code = $request->code;
				
			   	if(empty($code)) {
			    	$namespace->state = md5(uniqid(rand(), TRUE)); // CSRF protection
			     	$dialog_url = "https://www.facebook.com/dialog/oauth?domain=$referer&locale=en_US&client_id=" 
							       . $app_id . "&redirect_uri=" . urlencode($my_url) . "&scope=user_events,friends_events,publish_actions,friends_hometown,friends_location,friends_about_me,user_about_me,user_hometown,user_location,user_birthday,friends_birthday,manage_pages,publish_stream,create_event,rsvp_event&state="
							       . $namespace->state;
			
					echo $dialog_url; 
			   	}
			   	if(isset($namespace->state) && ($namespace->state === $request->state)) {
			    	$token_url = "https://graph.facebook.com/oauth/access_token?"
						       . "client_id=" . $app_id . "&redirect_uri=" . urlencode($my_url)
						       . "&client_secret=" . $app_secret . "&code=" . $code."&scope=user_events,friends_events,publish_actions,friends_hometown,friends_location,friends_about_me,user_about_me,user_hometown,user_location,user_birthday,friends_birthday,manage_pages,publish_stream,create_event,rsvp_event";
			
					try{
				     	$response = file_get_contents($token_url);
				     	$params = null;
				     	parse_str($response, $params);
				
				     	$namespace->access_token = $params['access_token'];
				
				     	$graph_url = "https://graph.facebook.com/me?access_token=" 
				       				. $params['access_token'];
				
						
						$restid = $namespace->restid;
						$bokid = $namespace->bokid;
						
						include('facebook/src/facebook.php');	
						$facebookObj = new Facebook(array(
						    'appId'  => '174154322766851',
						    'secret' => '1b3d72b533301ed3332c344db134c94d',
							'cookie'     => false,
							'fileUpload' => true 
						));
						$userObj = $facebookObj->api('/me',array('access_token'=>$params['access_token']));
						
						$storage = new Zend_Auth_Storage_Session();
						$loginProfile = $storage->read();
						$loginProfile['access_token'] = $params['access_token'];
						$loginProfile['fbuser'] =  $userObj['id'];;
						$loginProfile['reference'] = 'fb';
						$storage->write($loginProfile);
						
						echo "<script type=\"text/javascript\">";
						if($request->from == 'guest'){
							$guestid = $request->guest;
							echo "window.opener.location.href = 'http://$referer/booking/$bokid/geust/$guestid';window.close(); </script>";
						}else{
							echo "window.opener.location.href = 'http://$referer/booking/$bokid';window.close(); </script>";
						}						
					}catch(Exception $e){
						unset($namespace->access_token);
						$storage->write($loginProfile);
					}
			   	}
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	} 
	
	public function createfbeventAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			
			$bokid = $request->bokid;
			$restid = $request->restid;			
			/* Get Reservation details */
			 
			$bookedData = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read(); 
			
			if(isset($data['reference']) && isset($data['access_token'])){
				include('facebook/src/facebook.php');	
				$facebookObj = new Facebook(array(
				    'appId'  => '174154322766851',
				    'secret' => '1b3d72b533301ed3332c344db134c94d',
					'cookie'     => false,
					'fileUpload' => true 
				));
				
				$resServ = new Application_Service_Firm();
				$timeZone = $resServ->GetRestaurantTimeZone($restid);
				date_default_timezone_set($timeZone);
				$startevent = date(DATE_ISO8601, strtotime(date('Y-m-d',strtotime($bookedData->getbokbooking_date())).' '. $bookedData->getbokbooking_timings()));
				$endevent = date(DATE_ISO8601, strtotime(date('Y-m-d',strtotime($bookedData->getbokbooking_date())).' '. $bookedData->getbokbooking_timings()) +  60*60);
				$attachment = array(
								"name"				=>	'Invitation for Reservation',
								"access_token"		=>	$data['access_token'],
								"start_time"		=>	$startevent,
								"location"			=>	$bookedData->getresrestaurant_name().', '.$bookedData->getresaddress(),
								"end_time"			=>	$endevent,
								"description"		=>	"You have been invited to a reservation by " . $bookedData->getbokfirst_name(). " ". $bookedData->getboklast_name().
														" at ". $bookedData->getresrestaurant_name() . ", ".
														$bookedData->getresaddress(). ", ".
														$bookedData->getResNeighborhood() . ", ".
														$bookedData->getResCity() . " - ".
														$bookedData->getResZipcode() . ", ".
														$bookedData->getResPhone() . ", ".
														$bookedData->getResEmail() . ". On ".
														$bookedData->getbokbooking_date() . ", ".
														$bookedData->getbokbooking_timings()
							);
				$result = $facebookObj->api('/me/events/', 'post', $attachment);
				echo $result['id'];	
			}			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function savebookfbeventAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->SaveBookingFbEvent($request);
			if($result){
				echo 't';
			}else{
				echo 'f';
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}		
	}
	
	public function savebookfbinvitesAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->SaveBookingFbInvites($request);
			if($result){
				echo 't';
			}else{
				echo 'f';
			}			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}

	public function getfbfriendslistAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			
			$access_token = $request->access_token;
			
			include('facebook/src/facebook.php');	
			$facebookObj = new Facebook(array(
			    'appId'  => '174154322766851',
			    'secret' => '1b3d72b533301ed3332c344db134c94d',
				'cookie'     => false,
				'fileUpload' => true 
			));
			
			$friends = $facebookObj->api('/me/friends',array('access_token'=>$access_token,'fields'=>'id,name,birthday,gender,username,hometown,bio,age_range,location'));
			echo json_encode($friends);
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function getbookfbeventdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			
			$access_token = $request->access_token;
			$eventid = $request->eventid;
			$eventArr = array();
			try{
				$Invited = @file_get_contents('https://graph.facebook.com/' . $eventid.'/invited?access_token=' . $access_token);
		        if ( empty($Invited) ) {
	                return false;
		        }
		        $params = @json_decode($Invited);
		        $eventArr['invited'] = $params;
		        $attending = @file_get_contents('https://graph.facebook.com/' . $eventid.'/attending?access_token=' . $access_token);
		        if ( empty($attending) ) {
	                return false;
		        }
		        $params = null;
				$params = @json_decode($attending);
				$eventArr['attending'] = $params;
		        $maybe = @file_get_contents('https://graph.facebook.com/' . $eventid.'/maybe?access_token=' . $access_token);
		        if ( empty($maybe) ) {
	                return false;
		        }
		        $params = null;
		        $params = @json_decode($maybe);
				$eventArr['maybe'] = $params;
		        $declined = @file_get_contents('https://graph.facebook.com/' . $eventid.'/declined?access_token=' . $access_token);
		        if ( empty($declined) ) {
	                return false;
		        }
		        $params = null;
		        $params = @json_decode($declined);
				$eventArr['declined'] = $params;
		        $noreply = @file_get_contents('https://graph.facebook.com/' . $eventid.'/noreply?access_token=' . $access_token);
		        if ( empty($noreply) ) {
	                return false;
		        }
		        $params = null;
		        $params = @json_decode($noreply);
				$eventArr['noreply'] = $params;
			}catch(Exception $e){
				$eventArr = array();
			}
			echo json_encode($eventArr);
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function checkfbeventcreatedbybookingidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$fbevent = $this->_reservationService->getBookFbEvent($request->bookingid);
			if($fbevent){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}	
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function savemenucartdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$status = $this->_reservationService->saveMenuCartDetails($request);
			if($status){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}	
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	public function webinvitedguestdetailsAction()
	{
		try{
//			$this->_helper->layout()->setLayout('dinedesk');
 			$this->_helper->layout()->setLayout('ddweblayout');
			$request = $this->getRequest();
			$bookingid   = $request->bookingid;
			$guestid = $request->guestid;
			$this->view->guestid = $guestid; 
			$this->view->status = $request->constat; 
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bookingid);
			$this->view->bookedData = $result;
			
			$request->setParam('restaurantid',$result->getbokfk_restaurant());
			$restDetails = $this->_reservationService->GetRestaurantDetails($request);
			$this->view->restdetails = $restDetails;
			
			$this->_reservationService->updateInvitationStatus($result,$request);
			
			$fbevent = $this->_reservationService->getBookFbEvent($result->getbokid());
			if($fbevent){
				$this->view->fbevent = $fbevent;
			}
						
			$emailevent = $this->_reservationService->getBookEventStatusForGuest($result->getbokid(),$guestid);
			if($emailevent){
				$this->view->emailevent = $emailevent;
			}
			
			$selectedMenu = $this->_reservationService->getSelectedMenuByBookingId($result->getbokid());
			if (!empty($selectedMenu)) {
				$this->view->selectedMenu = $selectedMenu;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function replyhostinvitationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			
			$bokid   = $request->bookingid;
			$guestid = $request->guestid;
			$constat = $request->constat;
			$bokresult = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$notificationService = new Application_Service_Communication();
			$status = $notificationService->NotifyConfirmation($bokresult,$request);
			if($status){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
			//$this->_redirect($this->view->url(array('module'=>'Reservation','controller'=>'Reservation','action'=>'webinvitedguestdetails','bookingid'=>$bokid,'guestid'=>$request->guestid),'guest',true));
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function selectedmenuforreservationAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			
			$bookingid   = $request->bookingid;
			$selectedMenu = $this->_reservationService->getSelectedMenuByBookingId($bookingid);
			if(count($selectedMenu)){
				echo json_encode($selectedMenu);
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getcustomerdetailsbybookingidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getCustomerDetailsByBookingId($request);
			if(count($result)>0){
				echo json_encode($result);
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	public function getserverbybookingidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getServerByBookingid($request);
			if(count($result)>0){
				echo json_encode($result);
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function updateserveridbybookingidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->updateServeridByBookingid($request);
			if($result){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updatecontactidbybookingidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->updateContactIdByBookingid($request);
			if($result){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updatebookinginfoAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->updateBookingInfoByBookingid($request);
			if($result){
				echo json_encode('t');
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getspecialdeatailsbybokidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getSpecialDetailsByBokid($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function instantfeedbackAction()
	{
		try{
                        $auth = Zend_Auth::getInstance();
			$this->_helper->layout->disableLayout();                        
                        $request = $this->getRequest();
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read(); 
                        if($auth->hasIdentity()){
                        $resultset = $this->_reservationService->ReservationDesk($request,$data);
                        $TableLayoutStr            = $resultset['Layout'];
                        $this->view->diningares	   = $resultset['diningareas'];
                        $this->view->diningid	   = $resultset['diningid'];                        
                        $this->view->Seated =        $resultset['Completed'];                       
                        $this->view->finalStr 	   = $TableLayoutStr['finalStr'];
                        $this->view->floorSepStr   = $resultset['FloorSep'];
                        $this->view->etnStr 	   = $TableLayoutStr['etnStr'];
                        $this->view->TableStatus   = $resultset['TableStatus'];
                        }
                        $resDataMapper = new FirmManagement_Model_FirmDataMapper();
                        $restid = new FirmManagement_Model_FirmById();                                                
                        
			if(!isset($request->restaurantid)){
				$request->setParam('restaurantid',$data['RestId']);
                                $restid->setRestaurantId($data['RestId']);
			}
                        else
                        {
                                $restid->setRestaurantId($request->restaurantid);
                        }
			if(isset($request->bookingid)){
				$result = $this->_reservationService->getCustomerDetailsByBookingId($request);
				$this->view->bookingResult = $result;
				$this->view->bookingid = $request->bookingid;
			}
                        
                        
                        $resDetails = $resDataMapper->getRestaurantById($restid);
                        $this->view->resCompanyid = $resDetails->getcompanyid();
                        
			$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
			$CountryCode = $CountryCodeMapper->fetchAll();
			$CodeList = array();
			$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
			foreach($CountryCode as $listcode){
				$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
			}
				
			$this->view->codelist = $CodeList;
			$restDataMapper = new FirmManagement_Model_FirmDataMapper();
			$countrycode = $restDataMapper->getCountrycodebyId($request->restaurantid);
			if($countrycode){
				$this->view->countrycode = $countrycode;
			}
			$result = $this->_reservationService->getFeedbackFormByRestaurantId($request);
			$this->view->feedbackForm = $result;
			$this->view->restaurantid = $request->restaurantid;    
                        			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function sendfeedbackformtocustomerAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->sendFeedbackFormToCustomer($request);
			if($result){
				echo json_encode($result);			
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getfeedbackformbyrestaurantidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getFeedbackFormByRestaurantId($request);
			if($result){
				echo json_encode($result);			
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getbookingfeedbackhistoryAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getBookingFeedbackHistory($request);
			if($result){
				echo json_encode($result);			
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	public function retrievefeedbackinfobybookidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getFeedbackHistoryofBookingId($request);
			if($result){
				echo json_encode($result);			
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function feedbackreportAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read(); 
			$request = $this->getRequest();
			if($auth->hasIdentity()){
				if(isset($request->restaurantid)){
					$restId = $request->restaurantid;
				}else{
					$restId = $data['RestId'];
					$request->setParam('restaurantid',$restId);
				}
				$this->view->restaurantid = $request->restaurantid;
				if($request->restaurantid){
					$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
				}else{
					$resStat = false;
				}
				$this->view->secureLoginStatus = $resStat;
				$this->_helper->layout->disableLayout();
				$request = $this->getRequest();		
				if($request->date){		
					$this->view->date = $request->date;
				}
				$result = $this->_reservationService->getFeedbackReportHistoryofRestaurant($request,$data);
				$this->view->result = $result;
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function feedbackreviewsAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read(); 
			$request = $this->getRequest();
			$this->_helper->layout->disableLayout();
			if(isset($request->restaurantid)){
				$restId = $request->restaurantid;
			}else{
				$restId = $data['RestId'];
				$request->setParam('restaurantid',$restId);
			}
			$this->view->restaurantid = $request->restaurantid;
			if($auth->hasIdentity()){
				if($request->restaurantid){
					$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
				}else{
					$resStat = false;
				}
				$this->view->secureLoginStatus = $resStat;
				$this->_helper->layout->disableLayout();
				$request = $this->getRequest();		
				if($request->date){		
					$this->view->date = $request->date;
				}
				$result = $this->_reservationService->getFeedbackReviewsHistoryofRestaurant($request,$data);
				$this->view->result = $result;
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function feedbackreviewscommAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			$request = $this->getRequest();
			$this->_helper->layout->disableLayout();
			if(isset($request->restaurantid)){
				$restId = $request->restaurantid;
			}else{
				$restId = $data['RestId'];
				$request->setParam('restaurantid',$restId);
			}
			$this->view->restaurantid = $request->restaurantid;
// 			if($auth->hasIdentity()){
				if($request->restaurantid){
					$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
				}else{
					$resStat = false;
				}
				$this->view->secureLoginStatus = $resStat;
				$request = $this->getRequest();
				if($request->date){
					$this->view->date = $request->date;
				}
				$this->view->replyby = $request->replyBy;
				$result = $this->_reservationService->getFeedbackReviewsById($request,$data);
				$this->view->result = $result;
// 			}else{
// 				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
// 			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function feedbackreviewscommajaxAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			$request = $this->getRequest();
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
// 			if(isset($request->restaurantid)){
// 				$restId = $request->restaurantid;
// 			}else{
// 				$restId = $data['RestId'];
// 				$request->setParam('restaurantid',$restId);
// 			}
// 			$this->view->restaurantid = $request->restaurantid;
			// 			if($auth->hasIdentity()){
// 			if($request->restaurantid){
// 				$resStat = $this->_restService->AuthenticateRestByAuth($data,$request->restaurantid);
// 			}else{
// 				$resStat = false;
// 			}
// 			$this->view->secureLoginStatus = $resStat;
			$result = $this->_reservationService->FeedbackReviewsCommunication($request,$data);
			echo $result;
			// 			}else{
			// 				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			// 			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function wixwidgetAction() 
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$restService = new Application_Service_Firm();

			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->userlogstat = 'true';
			}else{
				$this->view->userlogstat = 'false';
			}
			$result = '';
			$result = $this->_reservationService->getWixWidgetRestaurantid($request);
			$sessionData = new Zend_Session_Namespace();
			if($request->compId){
				$this->view->compId = $request->compId;
				
			}else{
				$resid = $result;
				$request->setParam('compId',$sessionData->compId);
			}			
			if(!isset($sessionData->deviceType)){
				if($request->deviceType){
					$sessionData->deviceType = $request->deviceType;
				}else{
					$sessionData->deviceType = 'desk';
				}
			}
			$searchList = array();
			$searchListArr = array();
			$postBool = false;
			$resid = '';
			if($result != 0){
				$resid = $result;
				$request->setParam('restid',$resid);
			}else{
				$resid = 1;
				$request->setParam('restid',$resid);
			}			
						
			$this->view->deviceType = $request->deviceType;
//			/* Get Widget Theme Start */
//			$theme = $restService->GetWidgetThemeByRestId($request);
//			$this->view->theme = $theme;
			/* Get Widget Theme End */
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($resid);
			date_default_timezone_set($timezone);
			
			
			$restDataMapper = new FirmManagement_Model_FirmDataMapper();
			$splstatus = $restDataMapper->GetSpecialSetting($resid);
			$splcheck = $splstatus->resspecialsetting;
			$this->view->splStat = 1;
			$this->view->splcheck = $splcheck;
			
			$widsettings = $this->_restService->getRestaurantCustomizeWidgetByResid($resid);
			if($widsettings){
				$this->view->widsettings = $widsettings;
			}
			
			if($this->getRequest()->isPost()){
				$postBool = true;
				$maxPartyRes = "";
				$maxParty = "";
				$maxPartyAllowed = "Yes";
				$minParty = "";
				// BEGIN Getting Max and Min Party Sizes Day Wise//	
				$dateSplit = explode("-",$request->date);
				$weekday = date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));	 
				
				$object = new FirmManagement_Model_FirmDayPartySettings();
				$object->setrdpsfk_restaurants($resid);	
				$mapper = new FirmManagement_Model_FirmDayPartySettingsMapper();
				$resultArray = $mapper->GetDayPartySize($object);
				$maxallowedsize = $resultArray['ressize'];
				$tempdata = $resultArray['times'];
				foreach($tempdata as $item)
				{
					$x=strtoupper($item['day']);
					$y=strtoupper($weekday);
					$z = strcmp ($x,$y);
					if(!$z){
						if($item['daystatus'])
						{
							$maxParty = $item['maxsize'];
							$minParty = $item['minsize'];
						}else{
							$maxParty = $maxallowedsize;
							$minParty = 1;
						}
						break;
					}else{
						$maxParty = $maxallowedsize;
						$minParty = 1;	
					}
				}
				
				if(!$resultArray){
					$maxParty = $maxallowedsize;
					$minParty = 1;
				}
				if(($request->pax > $maxParty || $request->pax < $minParty)){
					$maxPartyAllowed = "No";	
				}
				// END Getting Max and Min Party Sizes Day Wise//	
				$searchList = $this->_reservationService->GetRestTimingsFromWidget($request, $resid);
				$index = 0;  
				if($searchList){
					foreach($searchList as $listval){
						if($listval['status'] == 'WAL'){
							continue;
						}else{
							$searchListArr[$index] = $listval;
							$index++;
						}
					}
				}else{
					$frezresult = $this->_reservationService->getFreezeTypeByDate($request);
					if($frezresult){

						$this->view->freezedesc = $frezresult['desc'];
					}else{
						$serv = new Application_Service_Firm();
						$msg = $serv->getRestaurantTimeSearchMessage($request->restid);
						$this->view->freezedesc = $msg->resbooking_search_msg;
					}
				}
				$dateSplit = explode("-",$request->date);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				
				$this->view->searchlist = $searchListArr;
				$this->view->restid = $resid;
				$pax = $request->pax;
				$date = $request->date;
				$this->view->pax = $request->pax;
				$this->view->date = $request->date;
				$this->view->time = $request->time;
				$this->view->mealtype = $request->mealtype;
				
				$this->view->forDate = $weekdate;
				if(!isset($sessionData->compId)){
					if($request->compId){
						$sessionData->compId = $request->compId;
					}else{
						$sessionData->compId = 1;
					}
				}else{
					if($sessionData->compId != $request->compId){
						$sessionData->compId = $request->compId;
					}
				}
				if(!isset($sessionData->titleColor)){
					if($request->wixtitleColor){
						$sessionData->titleColor = $request->wixtitleColor;
					}else{
						$sessionData->titleColor = '#000';
					}
				}else{
					if($request->wixtitleColor && $sessionData->titleColor != $request->wixtitleColor){
						$sessionData->titleColor = $request->wixtitleColor;
					}
				}
				if(!isset($sessionData->deviceType)){
					if($request->deviceType){
						$sessionData->deviceType = $request->deviceType;
					}else{
						$sessionData->deviceType = 'desk';
					}
				}
				if(!isset($sessionData->fontColor)){
					if($request->wixfontColor){
						$sessionData->fontColor = $request->wixfontColor;
					}else{
						$sessionData->fontColor = '#000';
					}
				}else{
					if($request->wixfontColor && $sessionData->fontColor != $request->wixfontColor){
						$sessionData->fontColor = $request->wixfontColor;
					}
				}
				if(!isset($sessionData->widimage)){
					if($request->wixwidimage){
						$sessionData->widimage = $request->wixwidimage;
					}else{
						$sessionData->widimage = '#b2e6cf';
					}
				}else{
					if($request->wixwidimage && $sessionData->widimage != $request->wixwidimage){
						$sessionData->widimage = $request->wixwidimage;
					}
				}
				if(!isset($sessionData->widBtn)){
					if($request->wixwidBtn){
						$sessionData->widBtn = $request->wixwidBtn;
					}else{
						$sessionData->widBtn = '#c8b26b';
					}
				}else{
					if($request->wixwidBtn && $sessionData->widBtn != $request->wixwidBtn){
						$sessionData->widBtn = $request->wixwidBtn;
					}
				}			
				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$restid = new FirmManagement_Model_FirmById();
				$restid->setRestaurantId($resid);
				$resDetails = $resDataMapper->getRestaurantById($restid);
								
				$this->view->resDetails = $resDetails;
				$this->view->resName = $resDetails->getRestaurantname();
				$this->view->resAddress = $resDetails->getRestaddress();
				$this->view->resPhone	= $resDetails->getRestphone();
				$this->view->restid = $resid;
				$this->view->postBool = $postBool;
				$this->view->maxPartyStatus = $maxPartyAllowed;
				$this->view->maxParty = $maxParty;
				$this->view->minParty = $minParty;
				$this->view->resCompanyid = $resDetails->getcompanyid();
			}else{
				$this->view->restid = $resid;
				$this->view->mealTypes = $this->_reservationService->getRestaurantMealTypes($request);
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$owner = new FirmManagement_Model_OwnerByRestaurantId();
				$owner->setRestaurantId($resid);
				$resownername = $mapper->getOwnerByRestId($owner);
				$restList = '';
				if($resownername){
					$restNameByOwnObj = new FirmManagement_Model_FirmNamesByOwnerId();
					$restNameByOwnObj->setRestOwnerId($resownername->getRestUser());
					$restList   = $mapper->getRestaurantDataByOwnerId($restNameByOwnObj);
					$this->view->restList = $restList;
				}
				$this->view->postBool = $postBool;
				
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function wixwidgetappsettingssessionAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$sessionData = new Zend_Session_Namespace();
			$request = $this->getRequest();
			if($request->compId){
				$this->view->compId = $request->compId;
				
			}else{
				$request->setParam('compId',$sessionData->compId);
			}
			
			if(!isset($sessionData->deviceType)){
				if($request->deviceType){
					$sessionData->deviceType = $request->deviceType;
				}else{
					$sessionData->deviceType = 'desk';
				}
			}else{
				if($sessionData->deviceType != $request->deviceType){
					$sessionData->deviceType = $request->deviceType;
				}
			}
			if(!isset($sessionData->compId)){
				if($request->compId){
					$sessionData->compId = $request->compId;
				}else{
					$sessionData->compId = 1;
				}
			}else{
				if($sessionData->compId != $request->compId){
					$sessionData->compId = $request->compId;
				}
			}
			if(!isset($sessionData->titleColor)){
				if($request->wixtitleColor){
					$sessionData->titleColor = $request->wixtitleColor;
				}else{
					$sessionData->titleColor = '#000';
				}
			}else{
				if($sessionData->titleColor != $request->wixtitleColor){
					$sessionData->titleColor = $request->wixtitleColor;
				}
			}
			if(!isset($sessionData->fontColor)){
				if($request->wixfontColor){
					$sessionData->fontColor = $request->wixfontColor;
				}else{
					$sessionData->fontColor = '#000';
				}
			}else{
				if($sessionData->fontColor != $request->wixfontColor){
					$sessionData->fontColor = $request->wixfontColor;
				}
			}
			if(!isset($sessionData->widimage)){
				if($request->wixwidimage){
					$sessionData->widimage = $request->wixwidimage;
				}else{
					$sessionData->widimage = '#b2e6cf';
				}
			}else{
				if($sessionData->widimage != $request->wixwidimage){
					$sessionData->widimage = $request->wixwidimage;
				}
			}
			if(!isset($sessionData->widBtn)){
				if($request->wixwidBtn){
					$sessionData->widBtn = $request->wixwidBtn;
				}else{
					$sessionData->widBtn = '#c8b26b';
				}
			}else{
				if($sessionData->widBtn != $request->wixwidBtn){
					$sessionData->widBtn = $request->wixwidBtn;
				}
			}	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function wixwidgetreservationdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$stateId = "";
			$cityId = "";
			$regionId = "";
			
			/* Get Widget Theme Start */
			$restService = new Application_Service_Firm();
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			$this->view->deviceType = $request->deviceType;
			/* Get Widget Theme End */
			
			$restid = $request->restaurantid;
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$result = $mapper->GetSpecialRequestSetting($restid);
			$this->view->splreq = $result->resspecial_request;
			$widsettings = $this->_restService->getRestaurantCustomizeWidgetByResid($restid);
			if($widsettings){
				$this->view->widsettings = $widsettings;
			}
			$otpmapper = new FirmManagement_Model_FirmDataMapper();
			$otpResult = $otpmapper->GetOtpSettingStatus($restid);
			if($otpResult->resotp_setting){
				$this->view->otpresult = 'true';
			}else{
				$this->view->otpresult = 'false';
			}
			
			$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
	    	$CountryCode = $CountryCodeMapper->fetchAll();
	    	$CodeList = array();
	    	$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
	    	foreach($CountryCode as $listcode){
	    		$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
	    	}
		    	
	    	$this->view->codelist = $CodeList;
			
			if($this->getRequest()->isPost()){
				if($result = $this->_reservationService->BookingDetails($this->getRequest()->getPost(),$stateId,$cityId,$regionId,'widget')){
					if($result){
						if(!$result['result']){
							$form = $this->_reservationService->getBookingDetailsForm();
							$payStat = 'false';
							if(!$request->specialid){
								$payService = new Application_Service_Renumeration();
								$dateSplit = explode("-",$request->resdate);
								$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								$weekdate = date("Y-m-d", $s);
									
								$payStat = 'false';
								$payType = '';
								if($payResult){
									$payType = $payResult['rpsnoshow_type'];
									$this->view->payType = $payType; 
									$this->view->payAmt = $payResult['payamount'];
									if($request->respax >= $payResult['paypax']){		
										$payStat = 'true';
									}
								}
							}
							
							$request = $this->getRequest();
							$formData  = array('resId'=>(int)$request->restaurantid,
				                           'resName'=>$request->resname,
				                           'resAddress'=>$request->resaddress,
				                           'resDate'=>$request->resdate,
				                           'resTime'=>$request->restime,
				                           'pax'=>$request->respax,
										   'inventoryid'=>$request->inventoryid,
										   'resCompanyid'=>$request->rescompanyid,
										   'paymentStatus'=>$payStat
				
							);
				
					
							$dateSplit = explode("-",$request->resdate);
							$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
								
							$this->view->resdate = date('l, F j Y',$s);
							$this->view->resname = $request->resname;
							$this->view->resaddress = $request->resaddress;
							$this->view->rescompanyid = $request->rescompanyid;
							$this->view->restime = $request->restime;
							$this->view->respax = $request->respax;
							$this->view->bookingstatus = $request->bookingstatus;
							$this->view->restaurantid = $request->restaurantid;
							$this->view->tablesize = $request->tablesize;
							$this->view->nooftables = $request->nooftables;
							$this->view->specialid  = $request->specialid;
							$this->view->booktype   = $request->booktype;
							$this->view->specialamt = $request->specialamt;
							$this->view->mealtype = $request->mealtype;
							
							$auth = Zend_Auth::getInstance();
							$data = array();
							if($auth->hasIdentity()){
								$storage = new Zend_Auth_Storage_Session();
								$data = $storage->read();
								$this->view->userdata = $data;
								$formData['firstName'] = $data['Firstname'];
								$formData['lastName'] = $data['LastName'];
								$formData['number'] = $data['Phone'];
								$formData['email'] = $data['Email'];
								$formData['userid'] = $data['User_Id'];
								//$formData['notificationType'] = ;
															
								$codemapper = new User_Model_ClientDataMapper();
								$usercountrycode = $codemapper->getCountrycodebyUserid($data['User_Id'],$data['Usertype'],$request->restaurantid);
								if($usercountrycode){
										$formData['countryCode'] =  $usercountrycode;
									}											
								}else{						
									$codemapper = new FirmManagement_Model_FirmDataMapper();
									$countrycode = $codemapper->getCountrycodebyId($request->restaurantid);
									if($countrycode){
										$formData['countryCode'] =  $countrycode;
										$this->view->countrycode = $countrycode;
									}
								}
							$form->populate($formData);
							$this->view->form = $form;
						}else{
							$paymentStatus = $request->paymentStatus;
							if($paymentStatus == 'true'){
								$this->view->cusprofId = $result['profileId'];
								$this->view->paymentprofId = $result['payment'];
								$this->view->bookingid = $result['result'];
								$this->view->userid = $result['userId'];
								$this->view->resid = $request->restaurantid;
							}else{
								$bookedData = $result['result'];
								$resid = $request->restaurantid;
								$this->_helper->redirector('wixwidgetconfirmation','Reservation','Reservation',array('bokid'=>$bookedData,'resid'=>$resid,'bokstat'=>true,'deviceType'=>$request->deviceType));
							}
						}
					}
				}
			}else{
				$form = $this->_reservationService->getBookingDetailsForm();
			
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$weekdate = date("Y-m-d", $s);
				$payStat = 'false';
				if(!$request->specialid){			
					$payService = new Application_Service_Renumeration();
					$payResult = '';	
					$payStat = 'false';
					$payType = '';
					if($payResult){
						$payType = $payResult['rpsnoshow_type'];
						$this->view->payType = $payType; 
						$this->view->payAmt = $payResult['payamount'];
						if($request->respax >= $payResult['paypax']){		
							$payStat = 'true';
						}
					}
				}
				
				$request = $this->getRequest();
				$formData  = array('resId'=>(int)$request->restaurantid,
	                           'resName'=>$request->resname,
	                           'resAddress'=>$request->resaddress,
	                           'resDate'=>$request->resdate,
	                           'resTime'=>$request->restime,
	                           'pax'=>$request->respax,
							   'inventoryid'=>$request->inventoryid,
							   'resCompanyid'=>$request->rescompanyid,	
							   'paymentStatus'=>$payStat
	
				);
	
				$dateSplit = explode("-",$request->resdate);
				$s = mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]);
				$this->view->resdate = date('D d M Y',$s);
				$this->view->resname = $request->resname;
				$this->view->resaddress = $request->resaddress;
				$this->view->rescompanyid = $request->rescompanyid;
				$this->view->restime = $request->restime;
				$this->view->respax = $request->respax;
				$this->view->bookingstatus = $request->bookingstatus;
				$this->view->restaurantid = $request->restaurantid;
				$this->view->tablesize = $request->tablesize;
				$this->view->nooftables = $request->nooftables;
				$this->view->specialid  = $request->specialid;
				$this->view->booktype   = $request->booktype;
				$this->view->specialamt = $request->specialamt;
				$this->view->mealtype = $request->mealtype; 
				
				$auth = Zend_Auth::getInstance();
				$data = array();
				if($auth->hasIdentity()){
					$storage = new Zend_Auth_Storage_Session();
					$data = $storage->read();
					if($data['User_Id']){
						$this->view->userdata = $data;
						$formData['firstName'] = $data['Firstname'];
						$formData['lastName'] = $data['LastName'];
						$formData['number'] = $data['Phone'];
						$formData['email'] = $data['Email'];
						$formData['userid'] = $data['User_Id'];
						//$formData['notificationType'] = ;
						$codemapper = new User_Model_ClientDataMapper();
						$usercountrycode = $codemapper->getCountrycodebyUserid($data['User_Id'],$data['Usertype'],$request->restaurantid);		
						if($usercountrycode){
							$formData['countryCode'] =  $usercountrycode;
						}
					}else{
						$codemapper = new FirmManagement_Model_FirmDataMapper();
						$countrycode = $codemapper->getCountrycodebyId($request->restaurantid);
						if($countrycode){
							$formData['countryCode'] =  $countrycode;
						}	
					}
				}else{
					$codemapper = new FirmManagement_Model_FirmDataMapper();
					$countrycode = $codemapper->getCountrycodebyId($request->restaurantid);
					if($countrycode){
						$formData['countryCode'] =  $countrycode;
					}	
				}
				$form->populate($formData);
				$resservice = new Application_Service_Firm();
				$bokoptionstatus = $resservice->getBookingOptionsSetting($request->restaurantid);
				if($bokoptionstatus->resbookingoption_setting){
					$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
					if(count($bookingoptions) > 1){
						$form->bokoptions->addMultiOptions($bookingoptions);
						$this->view->bokoptionsts   = true;
					}else{
						$this->view->bokoptionsts   = false;
					}							
				}else{
					$this->view->bokoptionsts   = false;
				}
	
				$this->view->form = $form;
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function wixwidgetconfirmationAction()
	{
		try{
			$this->_helper->layout->disableLayout();

			$request = $this->getRequest();
			if(isset($request->bokstat)){
				$this->view->bokStat = $request->bokstat;
			}else{
				$this->view->bokStat = '';
			}
			$this->view->deviceType = $request->deviceType;
			
			/* Get Widget Theme Start */
			$restService = new Application_Service_Firm();
			$theme = $restService->GetWidgetThemeByRestId($request);
			$this->view->theme = $theme;
			
			/* Get Widget Theme End */
			
			$restId = $request->resid;
			$widsettings = $this->_restService->getRestaurantCustomizeWidgetByResid($restId);
			if($widsettings){
				$this->view->widsettings = $widsettings;
			}
			$bokid   = $request->bokid;
			$notStatus = $this->_reservationService->CheckReservationNotificationStatusByBokPhraseId($bokid);
			$this->view->notStatus = $notStatus;
			$this->view->phraseId = $bokid;
			$result = $this->_reservationService->GetBookingDetailsByPhraseId($bokid);
			$this->view->bookedData = $result;
			$this->view->restaurantid = $restId;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}

	public function changewidgetrestidusingwixjsAction() 
	{
		$this->_helper->layout->disableLayout(); 
		$request = $this->getRequest();
		$result = $this->_reservationService->getWixWidgetUsingorigCompId($request);
		$this->view->result = $result;
	}
	
	public function savewixwidgetdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->saveWixWidgetDetails($request);
			if($result){
				echo json_encode('t');		
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function deletewixwidgetdetailsAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->deleteWixWidgetDetails($request);
			if($result){
				echo json_encode('t');		
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getrestaurantinfobyidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getRestaurantInfoById($request);
			if(count($result) > 0){
				echo json_encode($result);		
			}else{
				echo json_encode('f');
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	public function checkstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read(); 
                        $resDataMapper = new FirmManagement_Model_FirmDataMapper();
                        $restid = new FirmManagement_Model_FirmById();
			if(!isset($request->restaurantid)){
				$request->setParam('restaurantid',$data['RestId']);
                                $restid->setRestaurantId($data['RestId']);
			}
                        else{
                            $restid->setRestaurantId($request->restaurantid);
                        }
                        $resDetails = $resDataMapper->getRestaurantById($restid);
                        $this->view->resCompanyid = $resDetails->getcompanyid();
			$this->view->restaurantid = $request->restaurantid;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getbookingdetailsbybookingandrestidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getBookingDetailsBybookingidAndrestid($request);
			if($result){
				echo json_encode($result);		
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * 	action to display the widget of the restaurant's whatsnew posts
	 */
	public function whatsnewpostswidgetAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$request = $this->getRequest();
			$restService = new Application_Service_Firm();

			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$this->view->userlogstat = 'true';
			}else{
				$this->view->userlogstat = 'false';
			}
			$result = $this->_reservationService->getRestaurantWhatsNewPostsByResId($request);
			$this->view->resultSetMedia = $result['result1']; 
			$this->view->resultSetSms = $result['result2'];			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

/**
	 * 		retreive the reservation report of the restaurant by resid in admin panel
	 */	
	public function getreservationreportbyresidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();

			$result = $this->_reservationService->GetReservationReportByResid($request);
			if($result){
				echo json_encode($result);		
			}else{
				echo json_encode('f');
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * 		retreive the feedback phone numbers of the restaurant by resid 
	 */	
	public function retreivephonenumsoffeedbackpostAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->GetFeedbackPhoneNumbersOfRestaurant($request);
			if(!empty($result)){
				echo json_encode($result);
			}else{
				echo json_encode("f");
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function addfeedbackphonenumAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();	
			$result = $this->_restService->AddFeedbackPhoneNum($request);
			if($result){
				echo $result;
			}else{
				echo "f";
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
/**	
	 * 	action to update the restaurants feedback phone numbers using ajax call
	 */	
	public function editfeedbackphonenumAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			
			$result = $this->_restService->UpdateRestFeedbackPhoneNumById($request);
			if($result){
				echo "t";
			}else{
				echo "f";
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function managefeedbacknotificationstatusAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->updateFeebackNotificationStatus($request);
			if($result){
				echo 't';

			}else{
				echo 'f';
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getfdbackemailandstatusbyresidAction()
	{
		try{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->GetFeedbackEmailStatus($request);
			if($result){
				echo json_encode($result);
			}else{
				echo json_encode("f");
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function floorplanminAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$this->_helper->layout->disableLayout();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$this->view->companyid = $data['companyid'];
				$this->view->userStatus = $data['Usertype'];
				$this->view->userPermissions = $data['Permissions'];
				
				if($data['Usertype'] == "RSO" || $data['Usertype'] == "ADM" || $data['Usertype'] == "ADU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "RSU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "SRU"){
					$restNameList = $data['restList'];
				}
				
				if(isset($request->restaurantid)){
					$restId = $request->restaurantid;
				}else{
					$restId = $data['RestId'];
					$request->setParam('restaurantid',$restId);
					$x = $request->restaurantid;
				}
				$menu = $this->_reservationService->getReservationMenu($restId);
				$this->view->menu = $menu;
				$NameList = array();
				
				foreach($restNameList as $resNameVal){
					$NameList[$resNameVal['key']] = $resNameVal['value'];
				}
				$timeSettingsResult = $this->_reservationService->reteriveWaitingreservationQuoteTimes($request);
				$this->view->timeSettingsResult = $timeSettingsResult;
				$form = $this->_reservationService->getQuoteTimeSettingsForm();
				$this->view->quoteform = $form;
				$userService = new Application_Service_Client();
				$restUsers = $userService->getRestaurantOwnersAndUsersByRestId($restId);
				if($request){
					if(array_key_exists($restId,$NameList)){
						$result = $this->_reservationService->ReservationDesk($request,$data);
						$this->view->InQueueList   = $result['InQueue'];
						$this->view->AttendingList = $result['Attending'];
						$this->view->WaitingList   = $result['WaitingList'];
						$this->view->Completed = $result['Completed'];
						$this->view->CompletedList = $result['CompletedList'];
						$this->view->reservCount 	= $result['reservCount'];
						$this->view->selectedTab = $request->selTab;
						$this->view->serverList = $result['ServerList'];
						$this->view->restaurantid  = $request->restaurantid;
						
						$this->view->secureLoginStatus = 'true';
					}else{
						$restDetails = $this->_reservationService->GetRestaurantDetails($request);
						$this->view->restdetails = $restDetails;
						$this->view->restaurantid  = $request->restaurantid;
						
						$this->view->secureLoginStatus = 'false';
					}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getreservationlogbybokidAction()
	{
		try{
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				$this->_helper->layout->disableLayout();
				$this->_helper->viewRenderer->setNoRender();
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$result = $this->_reservationService->getReservationLogByBokid($request);
				echo json_encode($result);
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * GET ALL RESERVARTION HISTORY
	 */
	public function getallreservationhistoryAction()
	{
		try
		{
			$this->_helper->layout->disableLayout();
		//	$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getAllReservationReport($request);
			$this->view->startdata = $request->bokstartdate;
			$this->view->enddate = $request->bokenddate;
			$this->view->starttime = $request->bokstarttime;
			$this->view->endtime = $request->bokendtime;
			$this->view->rowSet = $result['RowSet'];
			$this->view->counts = $result['Count'];
		}
		catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * GET ALL RESERVARTION HISTORY
	 */
	public function getallreservationhistorydownloadAction()
	{
		try
		{
			$this->_helper->layout->disableLayout();
		//	$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$result = $this->_reservationService->getAllReservationReport($request);
			$this->view->startdata = $request->bokstartdate;
			$this->view->enddate = $request->bokenddate;
			$this->view->starttime = $request->bokstarttime;
			$this->view->endtime = $request->bokendtime;
			$this->view->rowSet = $result['RowSet'];
			$this->view->counts = $result['Count'];
		}
		catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/*
		TEST FLOOR PLAN
	 */
	/** 
	 * display all the reservations of the restaurant for that day and dining areas
	 */
	public function floorplan2Action()
	{
		try{
			$this->view->todaydate = date("m-d-Y");
			$auth = Zend_Auth::getInstance();
			if($auth->hasIdentity()){
				$request = $this->getRequest();
				//$this->_helper->layout()->setLayout('desklayout');
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$this->view->companyid = $data['companyid'];
				$this->view->userStatus = $data['Usertype'];
				$this->view->userPermissions = $data['Permissions'];
				if(array_key_exists('LastLoginDate', $data))
				{
					$this->view->lastLogin = $data['LastLoginDate'];
				}
				else
				{
					$this->view->lastLogin = '';
				}
				if($data['Usertype'] == "RSO" || $data['Usertype'] == "ADM" || $data['Usertype'] == "ADU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "RSU"){
					$restNameList = $this->_restService->GetRestNameById($data);
				}else if($data['Usertype'] == "SRU"){
					$restNameList = $data['restList'];
				}
				
				if(isset($request->restaurantid)){
					$restId = $request->restaurantid;
				}else{
					$restId = $data['RestId'];
					$request->setParam('restaurantid',$restId);
					$x = $request->restaurantid;
				}
				$menu = $this->_reservationService->getReservationMenu($restId);
				$this->view->menu = $menu;
				$NameList = array();
				
				foreach($restNameList as $resNameVal){
					$NameList[$resNameVal['key']] = $resNameVal['value'];
				}
				$timeSettingsResult = $this->_reservationService->reteriveWaitingreservationQuoteTimes($request);
				$this->view->timeSettingsResult = $timeSettingsResult;
				$form = $this->_reservationService->getQuoteTimeSettingsForm();
				$this->view->quoteform = $form;
				$userService = new Application_Service_Client();
				$restUsers = $userService->getRestaurantOwnersAndUsersByRestId($restId);
				if($request){
					if(array_key_exists($restId,$NameList)){
						$form = $this->_reservationService->getMakeReservationForm();
						$waitingForm = $this->_reservationService->getWaitingReservForm();
						$walkinForm = $this->_reservationService->getWalkInReservForm();
						$bokform = $this->_reservationService->getBlockReservForm();
						$result = $this->_reservationService->ReservationDesk($request,$data);
						$TableLayoutStr 		   = $result['Layout'];
						$this->view->finalStr 	   = $TableLayoutStr['finalStr'];
						$this->view->floorSepStr   = $result['FloorSep'];
						$this->view->etnStr 	   = $TableLayoutStr['etnStr'];
						$this->view->diningares	   = $result['diningareas'];
						$this->view->diningid	   = $result['diningid'];
						$this->view->InQueueList   = $result['InQueue'];
						$this->view->TableStatus   = $result['TableStatus'];
						$this->view->AttendingList = $result['Attending'];
						$this->view->WaitingList   = $result['WaitingList'];
//						$this->view->OverBooking   = $result['OverBooking'];
						$this->view->FreezeStatus  = $result['FreezeStatus'];
						$this->view->RestLogo      = $result['RestLogo'];
						$this->view->FreezedDates = $result['FreezedDates'];
						$this->view->NoShowCount = $result['No-Show'];
						$this->view->Completed = $result['Completed'];
						$this->view->CompletedList = $result['CompletedList'];
						$this->view->mealType 		= $result['mealType'];
						$this->view->reservCount 	= $result['reservCount'];
						if(isset($result['mealCount'])){
							$this->view->mealCount = $result['mealCount'];
						}
//						$this->view->quotedList = $result['quotedList'];
						if($result['Alert']){
							$this->view->Alertmessage = $result['Alert'];
						}
//						$this->view->AlertStstus   = $result['AlertStstus'];
						$this->view->usertype 	   = $result['Alertusertype'];
//						$this->view->paymentstatus = $result['paymentstatus'];
						if(isset($result['chartImg'])){
							$this->view->chartImg = $result['chartImg'];
						}else{
							$this->view->chartImg = "";
						}
						$this->view->selectedTab = $request->selTab;
						if(isset($request->bokstat)){
							$this->view->bokStat = $request->bokstat;
						}else{
							$this->view->bokStat = '';
						}
						if(isset($request->act)){
							$this->view->act = $request->act;
						}
						$form->reservationInitials->addMultiOptions($restUsers);
						if($data['Usertype'] == 'ADM' || $data['Usertype'] == 'ADU'){
							$form->setDefaults(array('reservationInitials'=> $data['restownerId']));
						}else{
							$form->setDefaults(array('reservationInitials'=> $data['User_Id']));
						}						
						$restDetails = $this->_reservationService->GetRestaurantDetails($request);
						$this->view->restdetails = $restDetails;
						if($restDetails->getresbookingoption_setting()){
							$bookingoptions = $this->_reservationService->getBookingOptionsByresId($request);
							if(count($bookingoptions) > 1){
								$form->bokoptions->addMultiOptions($bookingoptions);
								$this->view->bokoptionsts   = true;
							}else{
								$this->view->bokoptionsts   = false;
							}							
						}else{
							$this->view->bokoptionsts   = false;
						}
						
						$CountryCodeMapper = new Application_Model_CountryCodeDataMapper();
				    	$CountryCode = $CountryCodeMapper->fetchAll();
				    	$CodeList = array();
				    	$CodeList[] = array('key'=>'','value'=>'Select Country Flag');
				    	foreach($CountryCode as $listcode){
				    		$CodeList[] = array('key'=>$listcode->getCountry_dial_code(),'value'=>$listcode->getCountry_flag());
				    	}
					    	
				    	$this->view->codelist = $CodeList;
						
						$restDataMapper = new FirmManagement_Model_FirmDataMapper();
						$countrycode = $restDataMapper->getCountrycodebyId($restId);
						if($countrycode){
							$formValues = array('countryCode' => $countrycode);
							$this->view->countrycode = $countrycode;
							$form->populate($formValues);
							$waitingForm->populate($formValues);	
							$walkinForm->populate($formValues);	
							$bokform->populate($formValues);				
						}
				    	
						$this->view->MakeResForm   = $form;
						$this->view->MakeWaitingResForm = $waitingForm;
						$this->view->MakewalkinForm = $walkinForm;
						$this->view->blockform = $bokform;
						$addcontactform = $this->_reservationService->getAddCustomerContactForm();
						$this->view->addcontact = $addcontactform;
						$this->view->restaurantid  = $request->restaurantid;
						
						if($request->date){
							$tSel = explode('-',$request->date);
							if($tSel[0] > 12){
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
							}else {
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
							}
						}else{
							$this->view->date = date("m-d-Y");
							$this->view->formDateVal = date("d M Y");
						}
						if(isset($request->makereservationstatus)){
							$this->view->makereservationstatus = $request->makereservationstatus;
						}
						$this->view->secureLoginStatus = 'true';
					}else{
						$restDetails = $this->_reservationService->GetRestaurantDetails($request);
						$this->view->restdetails = $restDetails;
						$this->view->restaurantid  = $request->restaurantid;
						
						if($request->date){
							$tSel = explode('-',$request->date);
							if($tSel[0] > 12){
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
							}else {
								$this->view->date = date("m-d-Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
								$this->view->formDateVal = date("d M Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
							}
						}else{
							$this->view->date = date("m-d-Y");
							$this->view->formDateVal = date("d M Y");
						}
						$this->view->secureLoginStatus = 'false';
					}
				}
			}else{
				$this->_redirect($this->view->url(array('module'=>'User','controller'=>'Login', 'action'=>'signin'),'login',true));
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
		/**
	GET MEAL TIMES FOR THE RESERVATION POPUP
	**/
	public function getrestimesajaxAction()
	{
		try
		{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$mealsData = $this->_reservationService->getMealsByResid($request->resid,'settings');
			echo json_encode($mealsData);
		}
		catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}

	}

	
	/**
	 * SEND REMINDER SMS API
	 */
	public function sendremindersmsapiAction()
	{
		try
		{
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$request = $this->getRequest();
			$userid = $request->userid;
			if(!isset($userid))
			{
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				$userid = $data['User_Id'];
			}
			$response = $this->_reservationService->sendReminderSMS($request->bokid,$userid);
			echo json_encode(array('status'=>$response['status'],'error'=>$response['error']));
		}
		catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}


	public function clearcacheAction()
	{
		try {
			$this->_helper->layout->disableLayout();
			$this->_helper->viewRenderer->setNoRender();
			$cache = new Uss_Helper_CacheManager();
			$cache->clean(Zend_Cache::CLEANING_MODE_ALL);
		} catch (Exception $ex) {
			
		}
	}
	
}
