<?php
/**
*	Name			: ReservationDataMapper.php
*	Author			: snehal
*	Creation Date	: 9/30/2010
*	Path 			: application/modules/Reservation/models/ReservationDataMapper.php
*	Description		: This is the datamapper class for the booking table.
*					   	
*/
class Reservation_Model_ReservationDataMapper
{
	/**
	 * Instance variable of the booking table
	 * @var object
	 */
	protected $_dbTable;

	/**
     * @param instance of DbTable booking $dbTable
     * @return self
     */
	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	/**
     * @return instance of DbTable booking
     */
	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Reservation_Model_DbTable_Reservation');
		}
		return $this->_dbTable;
	}

	/**
	 * retreives the booking history of the customer for  mobile and desktop versions
	 */
	public function getCustBookingHistory(Reservation_Model_CustBookHist $bookhist,$offset)
	{
		try{
			$limit = 4;
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);

			$select->from(array('book'=>'mt.booking'),array('bokid','bokfirst_name','boklast_name','bokbooking_date','bokbooking_timings','bokbooking_phrase','bokparty_size','bokbooking_status_id','bokbooked_status','bokbooking_made_on','bokbooking_made_time'));
			$select->join(array('rest'=>'mt.restaurant'),'rest.resid = book.bokfk_restaurant',array('resrestaurant_name'));
			$select->join(array('bokbd'=>'mt.booking_status_bd'),'bokbd.id = book.bokbooking_status_id',array('code as bokstatuscode','description as bookingStatus'));
			$select->join(array('boktyp'=>'mt.booking_type_bd'),'book.bokbooking_type_id = boktyp.id',array('code as boktypecode','description as boktypedesc'));

			if($bookhist->getBookingId()){
				$select->where('book.bokid = ?',$bookhist->getBookingId());
			}
			if($bookhist->getStartDate() && $bookhist->getEndDate()){
				$select->where('book.bokbooking_date >= ?',$bookhist->getStartDate());
				$select->where('book.bokbooking_date <= ?',$bookhist->getEndDate());
			}else if($bookhist->getStartDate()){
				$select->where('book.bokbooking_date = ?',$bookhist->getStartDate());
			}else{
				$select->where('book.bokbooking_date >= ?',date('Y-m-d'));
			}
			if($bookhist->getRestName()){
				$select->where('rest.resrestaurant_name ilike ?','%'.trim($bookhist->getRestName()).'%');
			}
			
			$user = $bookhist->getUserId();
			$emai = $bookhist->getEmail();
			$select->where("book.bokuserid = $user or book.bokemail = '$emai'");
			$select->where('book.bokuserid = ?',$bookhist->getUserId());
			
			if($bookhist->getPatronName()){
				$s = "book.bokfirst_name||' '||book.boklast_name";
				$select->where($s.' ILIKE(?)','%'.$bookhist->getPatronName().'%');
			}
			
			if($bookhist->getSorting()){
				$explode = explode(',',$bookhist->getSorting());
				if(isset($explode[1])){
					$sorton = array($explode[0],$explode[1]);
				}else if($explode[0]){
					$sorton = array($explode[0]);
				}else{
					$sorton = array('book.bokbooking_date DESC','book.bokid DESC');
				}
			}else{
				 $sorton = array('book.bokbooking_date DESC','book.bokid DESC');
			}
			$select->order($sorton);
			
			//$rowset = $table->fetchAll($select);
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);

			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
/**
	 * retreives the booking history of the customer for  mobile and desktop versions
	 */
	public function getCustBookingHistoryForMobile(Reservation_Model_CustBookHist $bookhist,$offset)
	{
		try{
			$limit = 4;
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);

			$select->from(array('book'=>'mt.booking'),array('bokid','bokfirst_name','boklast_name','bokbooking_date','bokbooking_timings','bokbooking_phrase','bokparty_size','bokbooking_status_id','bokbooked_status','bokbooking_made_on','bokbooking_made_time'));
			$select->join(array('rest'=>'mt.restaurant'),'rest.resid = book.bokfk_restaurant',array('resrestaurant_name'));
			$select->join(array('bokbd'=>'mt.booking_status_bd'),'bokbd.id = book.bokbooking_status_id',array('code as bokstatuscode','description as bookingStatus'));
			$select->join(array('boktyp'=>'mt.booking_type_bd'),'book.bokbooking_type_id = boktyp.id',array('code as boktypecode','description as boktypedesc'));

			$tab = $bookhist->getSorting();
			if($tab == 'tab2'){
				$select->where('book.bokbooking_date < ?',date('Y-m-d'));
			}else{
				$select->where('book.bokbooking_date >= ?',date('Y-m-d'));
			}
			$user = $bookhist->getUserId();
			$emai = $bookhist->getEmail();
			$select->where("book.bokuserid = $user or book.bokemail = '$emai'");
			$select->where('book.bokuserid = ?',$bookhist->getUserId());
			$select->order(array('book.bokbooking_date DESC','book.bokid DESC'));
			
			
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setPageRange(1);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);

			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of booking details
	 * function to save the datails of the reservation 
	 */
	public function saveBookingDetails(Reservation_Model_Reservation $bookdetails,$formdata = array(),$source = 'web')
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();

			if($bookdetails->getbokuserid()){
				$userid = $bookdetails->getbokuserid();
			}else{
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				if(isset($data['User_Id'])){
					$userid =$data['User_Id'];
				}else{
					$userid = null;
				}
			}
			$guestid = '';
			$db->beginTransaction();
			$restservice = new Application_Service_Firm();
                        $restaurantid = $bookdetails->getbokfk_restaurant();
                        $bokbooking_confirm_status='';
                        $auto_confirmstatus = $restservice->GetAutoConfirmStatus($restaurantid);
                        if($auto_confirmstatus){
                           $bokbooking_confirm_status='resvconfirm';
                        }
                        
			if($formdata){
				$guestid = $restservice->AddCustomerContact($formdata,'');
			}
			$table = $this->getDbTable();
			$data = array(
			  'bokfk_restaurant' 	   		=> $bookdetails->getbokfk_restaurant(), 
			  'bokemail'		 	   		=> $bookdetails->getbokemail(),
			  'bokfirst_name' 		   		=> $bookdetails->getbokfirst_name(),
			  'boklast_name' 		   		=> $bookdetails->getboklast_name(),
			  'bokparty_size' 		   		=> $bookdetails->getbokparty_size(),
			  'bokphone' 			   		=> $bookdetails->getbokphone(),
	          'bokcountrycode'				=> $bookdetails->getbokcountry_code(),
			  'bokrestaurant_note'         	=> $bookdetails->getbokspecial_request(),
		      'bokbooking_date'		   		=> $bookdetails->getbokbooking_date(),
			  'bokbooking_timings' 	   		=> $bookdetails->getbokbooking_timings(),
			  'bokbooking_status_id'       	=> $bookdetails->getbokbooking_status_id(),
			  'bokbooked_status'			=> $bookdetails->getbokbooking_status(),
			  'bokbooking_made_on' 	   		=> $bookdetails->getbokbooking_made_on(),
			  'bokbooking_made_time'       	=> $bookdetails->getBookingMadeTime(),
			  'bokuserid' 		   			=> $userid,			  
			  'bokbooking_type_id'         	=> $bookdetails->getbokbooking_type_id(),
			  'bokreservation_mode_id' 	   	=> $bookdetails->getbokreservation_mode_id(),
			  'boknotification_type'       	=> $bookdetails->getNotificationType(),
			  'bokbooking_phrase'			=> $bookdetails->getbokbookingphrase(),
			  'bokcompany_id'				=> $bookdetails->getbokcompany_id(),
                          'bokbooking_confirm_status' =>        $bokbooking_confirm_status
			);
			if($guestid){
				$data['bok_contactid'] = $guestid;
			}
			if($bookdetails->getbok_restsch_setting_id()){
				$data['bok_restsch_setting_id'] = $bookdetails->getbok_restsch_setting_id();
			}
			if($bookdetails->getbok_restsch_setting_type() != 'SAC'){
				$data['bokfk_rest_sch_table'] = $bookdetails->getInventoryId();
			}
			if($bookdetails->getbokbooking_confirm_status()){
				$data['bokbooking_confirm_status'] = $bookdetails->getbokbooking_confirm_status();
			}
			if($bookdetails->getRescheduleCode() && $bookdetails->getRescheduleCode()== 'RES'){
				/* Chech the stautus of rescheduled reservation and if it is waiting list do not decrement the count. */
				$resvstatus = "";
	
				$statusSelect = $table->select();
				$statusSelect->setIntegrityCheck(false);
				$statusSelect->from(array('bok'=>'mt.booking'),array('bokid'))
							 ->join(array('boksts'=>'mt.booking_status_bd'),'boksts.id = bok.bokbooking_status_id',array('code as bookcode'))
							 ->where('bok.bokid = ?',$bookdetails->getbokid());
				$bookStatusRow = $table->fetchRow($statusSelect);
				$resvstatus = $bookStatusRow->bookcode;
				
				$timezone = "";
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$timezone = $mapper->GetRestaurantTimeZone($bookdetails->getbokfk_restaurant());
				date_default_timezone_set($timezone);				
				
				$set = array('bokbooking_status_id' => $bookdetails->getRessch_Status_Id(),
							 'bokrestaurant_note'   => $bookdetails->getbokrestaurant_note(),
							 'bokupdated_date'			=> date('Y-m-d'),
							 'bokupdateddatetime'		=> date("H:i:s",time()),
							 'bokupdatedby_userid'		=> $userid, 
							 'boksync_status'			=> 'C');

				$where = $db->quoteInto('bokid = ?',$bookdetails->getbokid());
				$row_affected = $table->update($set,$where);

				$result = $table->insert($data);
				/* Decrement the booking count upon reschedule start */
				if($resvstatus != "" && $resvstatus != "WAL" && $bookdetails->getbokbooking_status_code() != 'OVB'){
					if($bookdetails->getbok_restsch_setting_type() == 'SAC'){
						$status = $this->ResetAccumulativeBookingCount($bookdetails);
					}else{
						$status = $this->ResetBookingCount($bookdetails);
					}
				}
			}else{
				$result = $this->getDbTable()->insert($data);
				$bookdetails->setbokid($result); 
				if($guestid){
					$groupUsersDataMapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
					$groupUsersDataMapper->updateGuestReservationCount($guestid, 'RSD',$bookdetails->getbokreservation_mode_id());
				}
			}
			
			if($bookdetails->getbokoptions()){
				$bokoptionsmapper = new Reservation_Model_ReservationOptionsMapDataMapper();
				$bokoptionsmapper->saveBookingOptions($result, $bookdetails->getbokoptions());
			}
			if($bookdetails->getboksecoptions()){
				$bokoptionsmapper = new Reservation_Model_ReservationOptionsMapDataMapper();
				$bokoptionsmapper->saveBookingOptions($result, $bookdetails->getboksecoptions());
			}
						
			if($bookdetails->getbokbooking_type_code() == 'SPL' || $bookdetails->getbokbooking_type_code() == 'SPLPAID'){
				$splData = array('bksfk_booking' => $result,
								 'bksspecial_id' => $bookdetails->getSpecialId(),
								 'bksamount'     => $bookdetails->getSpecialPrice());
				
				$bookSplMapper = new Reservation_Model_ReservationSpecialDataMapper();
				$bookSplTable = $bookSplMapper->getDbTable();
				$bookSplTable->insert($splData);
				
			}

			/* Retrieve schedule id by inventory id */
			$schIdRow = "";
			$schIdRowArr = array();
			if($bookdetails->getInventoryId()){
				$restSchTblMapperObj = new FirmManagement_Model_FirmScheduleTableDataMapper();
				if($bookdetails->getbok_restsch_setting_type() == 'SAC'){
					$invArr = explode(',',$bookdetails->getInventoryId());
					$restSchTbl = $restSchTblMapperObj->getDbTable();
					$restSchTblSelect = $restSchTbl->select();
	
					$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule'))
									 ->where('rstid IN (?)',$invArr);
									 
				    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);
				}else{
					$restSchTbl = $restSchTblMapperObj->getDbTable();
					$restSchTblSelect = $restSchTbl->select();
	
					$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule'))
									 ->where('rstid = ?',$bookdetails->getInventoryId());
									 
				    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);
				}
			}
			if($schIdRow){
				$table = $this->getDbTable();
				if($bookdetails->getbok_restsch_setting_type() == 'SAC'){
					$bookAccMapper = new Reservation_Model_ReservationAccumulativeInventoryMapper();
					$accTable = $bookAccMapper->getDbTable();
					$invArr = explode(',',$bookdetails->getInventoryId());
					$tableSizeArr = explode(',',$bookdetails->getTableSize());
					$nooftablesArr = explode(',',$bookdetails->getNoOfTables());
					foreach($tableSizeArr as $key=>$value){						
						$accData = array(
										'bai_fk_booking'	=>	$result,
  										'bai_inventory'		=>	$invArr[$key],
  										'bai_status'		=>	'T'
						);
						$accResult = $accTable->insert($accData); 
						$select = $table->select();
						$select->setIntegrityCheck(false);
						$select->from(array('btc'=>'mt.booking_time_count'),array('count(btcid) as countbtc','btcid','btcbooking_count','btc.boktablesize'))
						->where('btc.btcfkres_id = ?',$bookdetails->getbokfk_restaurant())
						->where('btc.btcbooking_timings = ?',$bookdetails->getbokbooking_timings())
						->where('btc.btcbooking_date = ?',$bookdetails->getbokbooking_date())
						->where('btc.boktablesize = ?',$value);
						if($schIdRow){
							$select->where('btc.btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
						}				   
					    $select->group(array('btcid','btcbooking_count','btc.boktablesize'));
			
						$bookingCountId = 0;
						$bookingId= 0;
						$bookingCount = 0;
			
						$row = $table->fetchRow($select);
			
						$bookingCountId = $row['countbtc'];
						$bookingId = $row['btcid'];
						$bookingCount = (int)$row['btcbooking_count'];
			
						$mapper = new Reservation_Model_ReservationCountDataMapper();
						if($bookingCountId != 0){
								
							$bookingCount++;
							$set = array('btcbooking_count' => $bookingCount);
							$where = array('btcid = ?' => $bookingId,
										   'btcfk_restaurant_schedule = ?' => $schIdRow->rstfk_restaurant_schedule);
							
							//$where = $db->quoteInto('btcid = ?',);
			
							$mapper->getDbTable()->update($set,$where);
								
						}else{
							$data = array(
									'btcbooking_count'    => 1,
									'btcbooking_timings'  => $bookdetails->getbokbooking_timings(),
							        'btcbooking_date' 	  => $bookdetails->getbokbooking_date(),
			 						'btcfkres_id'    	  => $bookdetails->getbokfk_restaurant(),
									'boktablesize'		  => $value,
						  			'boknooftables'		  => $nooftablesArr[$key],
									'btcfk_restaurant_schedule'	=> $schIdRow->rstfk_restaurant_schedule
							);
							$mapper->getDbTable()->insert($data);
						}
					}
				}else{
					$select = $table->select();
					$select->setIntegrityCheck(false);
					$select->from(array('btc'=>'mt.booking_time_count'),array('count(btcid) as countbtc','btcid','btcbooking_count','btc.boktablesize'))
					->where('btc.btcfkres_id = ?',$bookdetails->getbokfk_restaurant())
					->where('btc.btcbooking_timings = ?',$bookdetails->getbokbooking_timings())
					->where('btc.btcbooking_date = ?',$bookdetails->getbokbooking_date())
					->where('btc.boktablesize = ?',$bookdetails->getTableSize());
					if($schIdRow){
						$select->where('btc.btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
					}				   
				    $select->group(array('btcid','btcbooking_count','btc.boktablesize'));
		
					$bookingCountId = 0;
					$bookingId= 0;
					$bookingCount = 0;
		
					$row = $table->fetchRow($select);
		
					$bookingCountId = $row['countbtc'];
					$bookingId = $row['btcid'];
					$bookingCount = (int)$row['btcbooking_count'];
		
					$mapper = new Reservation_Model_ReservationCountDataMapper();
					if($bookingCountId != 0){
							
						$bookingCount++;
						$set = array('btcbooking_count' => $bookingCount);
						$where = array('btcid = ?' => $bookingId,
									   'btcfk_restaurant_schedule = ?' => $schIdRow->rstfk_restaurant_schedule);
						
						//$where = $db->quoteInto('btcid = ?',);
		
						$mapper->getDbTable()->update($set,$where);
							
					}else{
						$data = array(
								'btcbooking_count'    => 1,
								'btcbooking_timings'  => $bookdetails->getbokbooking_timings(),
						        'btcbooking_date' 	  => $bookdetails->getbokbooking_date(),
		 						'btcfkres_id'    	  => $bookdetails->getbokfk_restaurant(),
								'boktablesize'		  => $bookdetails->getTableSize(),
					  			'boknooftables'		  => $bookdetails->getNoOfTables(),
								'btcfk_restaurant_schedule'	=> $schIdRow->rstfk_restaurant_schedule
						);
						$mapper->getDbTable()->insert($data);
					}
				}
			}
			$countMapper = new Reservation_Model_ReservationsCountDataMapper();
			$countResult = $countMapper->saveReservationsCount($bookdetails->getbokfk_restaurant(),$bookdetails->getbokparty_size());
			
			$bokStat = $this->getBookingPrevStatus($bookdetails->getbokid());
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($bookdetails->getbokid())
					->setbok_log_booked_type($bokStat)
					->setbok_log_bok_status($bookdetails->getbokbooking_status_id())
					->setbok_log_book_message('Reservation Done')
					->setbok_log_updated_by($bookdetails->getbokcreatedby())
					->setbok_log_updated_at(date('Y-m-d H:i:s'));
			if($source == 'web'){
				$bokLog->setbok_log_update_done_by('RES');
			}else{
				$bokLog->setbok_log_update_done_by('CUS');
			}
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			$db->commit();
			return $result;


		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of booking 
	 * retreives the booking details	
	 */
	public function getBookingDetails(Reservation_Model_Reservation $bookingdetails)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$bookOptionsMapper = new Reservation_Model_ReservationOptionsMapDataMapper();
			$bookOptions       = $bookOptionsMapper->getDbTable();
			$bookOptionsSelect = $bookOptions->select(); 
			$bookOptionsSelect->setIntegrityCheck(false);
			$bookOptionsSelect->from(array('bom'=>'mt.booking_options_map'),array('bopmbokid','bopmbok_optionsid'))
							  ->join(array('bop'=>'mt.booking_options'),'bop.boptid = bom.bopmbok_optionsid',array('boptdescription','boptid'))
							  ->where('bopmbokid = ?',$bookingdetails->getbokid());

			$select->from(array('bok'=>'mt.booking'),array('bokuserid','bokfk_restaurant','bokbooking_type_id','bokemail','bokfirst_name','boklast_name','bokparty_size','bokphone','bokbooking_date','bokbooking_timings','bokid','bokspecial_request','boknotification_type','bokreservation_mode_id','bokrestaurant_note','bokfk_rest_sch_table','bokbooked_status','bokresv_confirm_status','bokbooking_confirm_status','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status','bokbooking_block_status','bokbooking_block_desc','bokbooking_block_amount','bokcreatedby','bokseat_start','bokbooking_phrase','bokseat_end','bokcountrycode','bok_contactid','bokresv_runninglate_status'))
					->join(array('res'=>'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('resrestaurant_name','resaddress','resphone','resemail','reszipcode','res_countrycode','resimage','res_company_resid','res_company_url'))
					->join(array('bst'=>'mt.booking_status_bd'),'bst.id = bok.bokbooking_status_id',array('code as stat','description'))
					->join(array('boktyp'=>'mt.booking_type_bd'),'bok.bokbooking_type_id = boktyp.id',array('code as boktypecode','description as boktypedesc'))
					->join(array('rmb'=>'mt.reservation_mode_bd'),'rmb.id = bok.bokreservation_mode_id',array('code','description as mode'))
					->join(array('cty'=>'mt.city_bd'),'cty.id = res.rescity_id',array('description as rescity'))
					->joinLeft(array('ngbh'=>'mt.neighborhood_bd'),'ngbh.id = res.resneighborhood_id',array('description as neighbor'))
					->joinLeft(array('bookopt'=>$bookOptionsSelect),'bookopt.bopmbokid = bok.bokid',array('boptdescription as bookoption','boptid'))
					->where('bok.bokid = ?',$bookingdetails->getbokid());

			$resultSet = $table->fetchRow($select);
			
			$status = "";
			$boknotify = "";
			if($resultSet->boknotification_type != "" && $resultSet->boknotification_type != null)
			{	
				$status = array($resultSet->boknotification_type);
				
				if($status != "" && $status != null){
					$bookNotifyTypeMapper = new Application_Model_NotificationTypeDataMapper();
					$bookNotifyType = $bookNotifyTypeMapper->GetNotificationTypeByCode($status);
					$boknotify = $bookNotifyType[$resultSet->boknotification_type];
				}
			}
			$timeValue = explode(':',$resultSet->bokbooking_timings);
			if($timeValue[0] >=12){
				if((int)$timeValue[0] != 12){
					(int)$timeValue[0] -= 12;
				}
				$timeValue[2] = 'PM';
				$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
			}else{
				$timeValue[2] = 'AM';
				$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
			}
			
			$bookingdetails->setbokid($resultSet->bokid);
			$bookingdetails->setbokbookingphrase($resultSet->bokbooking_phrase);
			$bookingdetails->setbokuserid($resultSet->bokuserid);
			$bookingdetails->setbokfirst_name($resultSet->bokfirst_name);
			$bookingdetails->setboklast_name($resultSet->boklast_name);
			$bookingdetails->setbokparty_size($resultSet->bokparty_size);
			$bookingdetails->setbokbooking_date($resultSet->bokbooking_date);
			$bookingdetails->setbokbooking_timings($finalTimeValue);
			$bookingdetails->setbokphone($resultSet->bokphone);
			$bookingdetails->setbokcountry_code($resultSet->bokcountrycode);
			$bookingdetails->setbokemail($resultSet->bokemail);
			$bookingdetails->setbokspecial_request($resultSet->bokspecial_request);
			$bookingdetails->setbokfk_restaurant($resultSet->bokfk_restaurant);
			$bookingdetails->setresrestaurant_name($resultSet->resrestaurant_name);
			$bookingdetails->setresaddress($resultSet->resaddress);
			$bookingdetails->setbokbooking_status_desc($resultSet->description);
			$bookingdetails->setbokbooking_status_code($resultSet->stat);
			$bookingdetails->setNotificationType($resultSet->boknotification_type);			
			$bookingdetails->setbokreservation_mode_code($resultSet->code);
			$bookingdetails->setbokbooking_type_id($resultSet->bokbooking_type_id);
			$bookingdetails->setbokbooking_type_code($resultSet->boktypecode);
			$bookingdetails->setbokbooking_type_desc($resultSet->boktypedesc);
			$bookingdetails->setbokreservation_mode_desc($resultSet->mode);
			$bookingdetails->setbokrestaurant_note($resultSet->bokrestaurant_note);
			$bookingdetails->setResPhone($resultSet->resphone);
			$bookingdetails->setResCountrycode($resultSet->res_countrycode);
			$bookingdetails->setResEmail($resultSet->resemail);
			$bookingdetails->setInventoryId($resultSet->bokfk_rest_sch_table);
			$bookingdetails->setbokbooking_status($resultSet->bokbooked_status);
			$bookingdetails->setResCity($resultSet->rescity);
			$bookingdetails->setResNeighborhood($resultSet->neighbor);
			$bookingdetails->setResZipcode($resultSet->reszipcode);
			$bookingdetails->setbokresv_confirm_status($resultSet->bokresv_confirm_status);
			$bookingdetails->setbokbooking_confirm_status($resultSet->bokbooking_confirm_status);
			$bookingdetails->setblockStatus($resultSet->bokbooking_block_status);
			$bookingdetails->setblockAmount($resultSet->bokbooking_block_amount);
			$bookingdetails->setblockDescription($resultSet->bokbooking_block_desc);
			$bookingdetails->setbokcreatedby($resultSet->bokcreatedby);
			$bookingdetails->setbokseat_start($resultSet->bokseat_start);
			$bookingdetails->setbokseat_end($resultSet->bokseat_end);
			$bookingdetails->setbokresv_partialarrived_status($resultSet->bokresv_partialarrived_status);
			$bookingdetails->setbokresv_allarrived_status($resultSet->bokresv_allarrived_status);
			$bookingdetails->setbokresv_runninglate_status($resultSet->bokresv_runninglate_status);
			$bookingdetails->setbokbooking_confirm_status($resultSet->bokbooking_confirm_status);
			$bookingdetails->setres_company_resid($resultSet->res_company_resid);
			$bookingdetails->setres_company_url($resultSet->res_company_url);
			if($resultSet->bok_contactid){
				$bookingdetails->setbokcontactid($resultSet->bok_contactid);
			}
			$bookingdetails->setRestimage($resultSet->resimage);
			if($resultSet->bookoption){
				$bookingdetails->setbokoptions($resultSet->bookoption);
				$bookingdetails->setbokoptionsid($resultSet->boptid);
			}			
			$bookingdetails->setbokresv_checkedin_status($resultSet->bokresv_checkedin_status);
						
			if($boknotify != "" && $boknotify != null){
				$bookingdetails->setNotificationTypeDesc($boknotify->getDescription());
			}			
				
			return $bookingdetails;

		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getBookingDetailsByBookingIdArray(Reservation_Model_Reservation $bookingdetails)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$bokidArr= array();
			$bokidArr = $bookingdetails->getbokid();

			$select->from(array('bok'=>'mt.booking'),array('bokuserid','bokfk_restaurant','bokbooking_type_id','bokemail','bokfirst_name','boklast_name','bokparty_size','bokphone','bokbooking_date','bokbooking_timings','bokid','bokspecial_request','boknotification_type','bokreservation_mode_id','bokrestaurant_note','bokfk_rest_sch_table','bokbooked_status','bokresv_confirm_status','bokbooking_confirm_status','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status'))
					->join(array('res'=>'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('resrestaurant_name','resaddress','resphone','resemail','reszipcode'))
					->join(array('bst'=>'mt.booking_status_bd'),'bst.id = bok.bokbooking_status_id',array('id as statusid','code as stat','description'))
					->join(array('boktyp'=>'mt.booking_type_bd'),'bok.bokbooking_type_id = boktyp.id',array('code as boktypecode','description as boktypedesc'))
					->join(array('rmb'=>'mt.reservation_mode_bd'),'rmb.id = bok.bokreservation_mode_id',array('code','description as mode'))
					->join(array('cty'=>'mt.city_bd'),'cty.id = res.rescity_id',array('description as rescity'))
					->join(array('ngbh'=>'mt.neighborhood_bd'),'ngbh.id = res.resneighborhood_id',array('description as neighbor'))
					->where('bok.bokid IN (?)',$bokidArr);

			$resultSet = $table->fetchAll($select);
			
			$status = "";
			$boknotify = "";
			$result = array();
			foreach($resultSet as $row){
				if($row->boknotification_type != "" && $row->boknotification_type != null)
				{	
					$status = array($row->boknotification_type);
					
					if($status != "" && $status != null){
						$bookNotifyTypeMapper = new Application_Model_NotificationTypeDataMapper();
						$bookNotifyType = $bookNotifyTypeMapper->GetNotificationTypeByCode($status);
						$boknotify = $bookNotifyType[$row->boknotification_type];
					}
				}
				$timeValue = explode(':',$row->bokbooking_timings);
				if($timeValue[0] >=12){
					if((int)$timeValue[0] != 12){
						(int)$timeValue[0] -= 12;
					}
					$timeValue[2] = 'PM';
					$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
				}else{
					$timeValue[2] = 'AM';
					$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
				}
				$bookDetails = new Reservation_Model_Reservation();
				$bookDetails->setbokid($row->bokid);
				$bookDetails->setbokuserid($row->bokuserid);
				$bookDetails->setbokfirst_name($row->bokfirst_name);
				$bookDetails->setboklast_name($row->boklast_name);
				$bookDetails->setbokparty_size($row->bokparty_size);
				$bookDetails->setbokbooking_date($row->bokbooking_date);
				$bookDetails->setbokbooking_timings($finalTimeValue);
				$bookDetails->setbokphone($row->bokphone);
				$bookDetails->setbokemail($row->bokemail);
				$bookDetails->setbokspecial_request($row->bokspecial_request);
				$bookDetails->setbokfk_restaurant($row->bokfk_restaurant);
				$bookDetails->setresrestaurant_name($row->resrestaurant_name);
				$bookDetails->setresaddress($row->resaddress);
				$bookDetails->setbokbooking_status_desc($row->description);
				$bookDetails->setbokbooking_status_code($row->stat);
				$bookDetails->setbokbooking_status_id($row->statusid);
				$bookDetails->setNotificationType($row->boknotification_type);			
				$bookDetails->setbokreservation_mode_code($row->code);
				$bookDetails->setbokbooking_type_id($row->bokbooking_type_id);
				$bookDetails->setbokbooking_type_code($row->boktypecode);
				$bookDetails->setbokreservation_mode_desc($row->mode);
				$bookDetails->setbokrestaurant_note($row->bokrestaurant_note);
				$bookDetails->setResPhone($row->resphone);
				$bookDetails->setResEmail($row->resemail);
				$bookDetails->setInventoryId($row->bokfk_rest_sch_table);
				$bookDetails->setbokbooking_status($row->bokbooked_status);
				$bookDetails->setResCity($row->rescity);
				$bookDetails->setResNeighborhood($row->neighbor);
				$bookDetails->setResZipcode($row->reszipcode);
				$bookDetails->setbokresv_confirm_status($row->bokresv_confirm_status);
				$bookDetails->setbokbooking_confirm_status($row->bokbooking_confirm_status);
				//$bookDetails->setbokresv_checkedin_status($row->bokresv_checkedin_status);
							
				if($boknotify != "" && $boknotify != null){
					$bookDetails->setNotificationTypeDesc($boknotify->getDescription());
				}
				$result[] = $bookDetails;	
			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function getRegionBaseData()
	{
		try{
			$regionBdMapper = new Application_Model_RegionDataMapper();
			$regionBd		  = $regionBdMapper->fetchAll();
			$regionBdMapper = null;
			return $regionBd;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	/**
	 * @return city basedata
	 */
	public function getCityBaseData()
	{
		try{
			$cityBdMapper = new Application_Model_CityDataMapper();
			$cityBd		  = $cityBdMapper->fetchAll();
			$cityBdMapper = null;
			return $cityBd;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	
	
	/**
	 * @return neighborhood basedata
	 */
	public function getNeighborhodBaseData()
	{
		try{
			$neighborBdMapper = new Application_Model_NeighborhoodDataMapper();
			$neighborBd       = $neighborBdMapper->fetchAll();
			$neighborBdMapper = null;
			return $neighborBd;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @return restauranttype basedata
	 */
	public function getRestaurantTypeBaseData()
	{
		try{
			$restTypeBdMapper = new Application_Model_RestaurantTypeDataMapper();
			$restTypeBd       = $restTypeBdMapper->getRestauranttypeBD();
			$restTypeBdMapper = null;
			return $restTypeBd;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @return price basedata
	 */
	public function getRestaurantPriceBaseData()
	{
		try{
			$restPriceBdMapper = new Application_Model_PriceDataMapper();
			$restPriceBd = $restPriceBdMapper->fetchAll();
			$restPriceBdMapper = null;
			return $restPriceBd;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of inQueuelist
	 * retreive all the reservations with status block
	 */
	public function getInQueueList(Reservation_Model_GetInQueueList $inqueuelst)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$statusId = array();

			$bookStatusRes = $inqueuelst->getBookStatus();
			foreach($bookStatusRes as $key=>$value){
				$statusId[] = $value->getId();
			}
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$inqueuelst->getRestaurantId())
							  ->where('rda_status = ?',true);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note','bokbooking_status_id','bokresv_confirm_status','bokbooking_confirm_status','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status','bokcreatedby'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bkt_dining_id'))
				   ->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))
				   ->joinLeft(array('ini'=>'mt.restaurant_user_initials'),'ini.rsui_fk_user = bok.bokbooking_user_initials',array('rsui_initial as initial'))
				   ->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
				   ->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokstatuscode'))
				   ->joinLeft(array('rst'=>'mt.restaurant_schedule_table'),'rst.rstid = bokfk_rest_sch_table',array('rstid'))
				   ->joinLeft(array('rss'=>'mt.restaurant_schedule'),'rss.rssid = rst.rstfk_restaurant_schedule',array('rss.rssid'))
				 //->where('rss.rssid IN(?)',$inqueuelst->getSchId())
//				   ->where('rss.rssstatus = ?',true)
//					->where('ini.rsui_fk_restaurant = ?',$inqueuelst->getRestaurantId())
				   ->where('bok.bokfk_restaurant = ?',$inqueuelst->getRestaurantId())
				   ->where('bok.bokbooking_date = ?',$inqueuelst->getDate())
			  	 //->where('bok.bokbooking_status_id = ?',$inqueuelst->getBookStatus())
				   ->where('bok.bokbooking_status_id IN(?)',$statusId);
				   
			if($inqueuelst->getSortOrder()){
				$order  = $inqueuelst->getSortOrder();
				$sorton = $inqueuelst->getSortOn();
				
				if($order == "ASC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings ASC','bokparty_size ASC'));	
				}else if($order == "DESC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings DESC','bokparty_size DESC'));					
				}else if($order == "ASC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned ASC','bokbooking_timings ASC','bokparty_size ASC'));	
				}else if($order == "DESC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned DESC','bokbooking_timings DESC','bokparty_size DESC'));		
				}else if($order == "ASC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size ASC','bokbooking_timings ASC'));
				}else if($order == "DESC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size DESC','bokbooking_timings DESC'));
				}				
			}else{
				$select->order(array('bokbooking_timings'));
			}			

			$rowset = $table->fetchAll($select);
			$prevBokidArr		= array();			
			$bokid 				= "";	
			$previd				= "";
			$firstname			= "";
			$lastname 			= "";					
			$bokuserid 			= "";
			$bokfk_restaurant 	= "";						
			$customername 		= "";							
			$name_on_resvnote   = ""; 					
			$bokparty_size 		= "";
			$bokbooking_timings = "";
			$bokspecial_request = "";
			$boktypcode 		= "";
			$boktypdesc 		= "";
			$bokresmodecode 	= "";
			$bokresmodedesc 	= "";
			$bokrestaurant_note = "";
			$bokstatusid		= "";
			$bokstatuscode      = "";
			$boktablenumber 	= "";
			$boktablenumArr     = array();
			$dinigid 			= "";
			$resvconfirmstatus  = "";
			$bokconfirmstatus	= "";
			$resvcheckedin		= "";
			$allarrived			= '';
			$partialarr			= '';
			$initial			= '';
			$bokcreatedby		= '';
			
			if($inqueuelst->getIsAjaxCall()){
				
				foreach($rowset as $row)
				{
					if($previd == ""){
						
						$bokid 				= $row->bokid;
						$previd				= $row->bokid;											
						$bokuserid 			= $row->bokuserid;
						$bokfk_restaurant 	= $row->bokfk_restaurant;						
						$customername 		= strtoupper($row->bokfirst_name." ".$row->boklast_name);							
						$name_on_resvnote   = $row->bokfirst_name." ".$row->boklast_name; 					
						$bokparty_size 		= $row->bokparty_size;
						$bokbooking_timings = $row->bokbooking_timings;
						$bokspecial_request = $row->bokspecial_request;
						$boktypcode 		= $row->boktypcode;
						$boktypdesc 		= $row->boktypdesc;
						$bokresmodecode 	= $row->bokresmodecode;
						$bokresmodedesc 	= $row->bokresmodedesc;
						$bokrestaurant_note = $row->bokrestaurant_note;
						$bokstatusid		= $row->bokbooking_status_id;
						$bokstatuscode      = $row->bokstatuscode;
						$boktablenumber 	= $row->bktbtable_no_assigned;
						$boktablenumArr[]	= $row->bktbtable_no_assigned;
						$dinigid			= $row->rda_diningdisplyname;
						$resvconfirmstatus  = $row->bokresv_confirm_status;
						$bokconfirmstatus	= $row->bokbooking_confirm_status;
						$resvcheckedin		= $row->bokresv_checkedin_status;
						$allarrived			= $row->bokresv_allarrived_status;
						$partialarr			= $row->bokresv_partialarrived_status;	
						$prevBokidArr[]		= $bokid;
						$initial			= $row->initial;
						$bokcreatedby		= $row->bokcreatedby;
						
					}else{
						$bokid = $row->bokid;
						if(in_array($bokid,$prevBokidArr)){
							$boktablenumArr[]	= $row->bktbtable_no_assigned;
						}else{
							array_push($resultSet, array('bokid'	   => $previd,
											 	 'bokuserid' 		   => $bokuserid,
											 	 'bokfk_restaurant'    => $bokfk_restaurant,
											 	 'bokfirst_name' 	   => $customername,
											 	 'boknameonresvnote'   => $name_on_resvnote,											 
											 	 'bokparty_size' 	   => $bokparty_size,
											 	 'bokbooking_timings'  => date("h:i A",strtotime($bokbooking_timings)),
											 	 'bokspecial_request'  => $bokspecial_request,
											 	 'boktypcode' 		   => $boktypcode,
											 	 'boktypdesc' 		   => $boktypdesc,
											 	 'bokresmodecode' 	   => $bokresmodecode,
												 'bokresmodedesc'		=> $bokresmodedesc,
											 	 'boktablenumber'	   => $boktablenumber,
											 	 'bokrestaurant_note'  => $bokrestaurant_note,
											 	 'bokbooking_status_id'=> $bokstatusid,
											 	 'bokstatuscode'       => $bokstatuscode,
												 'boktablenumArr'	   => $boktablenumArr,
												 'diningid'			   => $dinigid,
												 'resvconfirmstatus'   => $resvconfirmstatus,
												 'bokconfirmstatus'	   => $bokconfirmstatus,
												 'resvcheckedin'	   => $resvcheckedin,
												 'allarrived'		   => $allarrived,
												 'partialarr'		   => $partialarr,
												 'initial'				=> $initial,
												 'bokcreatedby'			=> $bokcreatedby));
							
							$previd             = $bokid;
							$boktablenumArr     = null;	
							$lastname 			= "";					
							$bokuserid 			= $row->bokuserid;
							$bokfk_restaurant 	= $row->bokfk_restaurant;						
							$customername 		= strtoupper($row->bokfirst_name." ".$row->boklast_name);							
							$name_on_resvnote   = $row->bokfirst_name." ".$row->boklast_name; 					
							$bokparty_size 		= $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatusid		= $row->bokbooking_status_id;
							$bokstatuscode      = $row->bokstatuscode;
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$boktablenumArr[]	= $row->bktbtable_no_assigned;
							$dinigid			= $row->rda_diningdisplyname;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBokidArr[]		= $bokid;
							$initial			= $row->initial;
							$bokcreatedby		= $row->bokcreatedby;
							
						}	
					}					
				}
				$date = "";
				if($bokbooking_timings){
					$date = date("h:i A",strtotime($bokbooking_timings));
				}
				array_push($resultSet, array('bokid'	   => $bokid,
								 	 'bokuserid' 		   => $bokuserid,
								 	 'bokfk_restaurant'    => $bokfk_restaurant,
								 	 'bokfirst_name' 	   => $customername,
								 	 'boknameonresvnote'   => $name_on_resvnote,											 
								 	 'bokparty_size' 	   => $bokparty_size,
								 	 'bokbooking_timings'  => $date,
								 	 'bokspecial_request'  => $bokspecial_request,
								 	 'boktypcode' 		   => $boktypcode,
								 	 'boktypdesc' 		   => $boktypdesc,
								 	 'bokresmodecode' 	   => $bokresmodecode,
									 'bokresmodedesc'		=> $bokresmodedesc,
								 	 'boktablenumber'	   => $boktablenumber,
								 	 'bokrestaurant_note'  => $bokrestaurant_note,
								 	 'bokbooking_status_id'=> $bokstatusid,
								 	 'bokstatuscode'       => $bokstatuscode,
									 'boktablenumArr'	   => $boktablenumArr,
									 'diningid'			  => $dinigid,
									 'resvconfirmstatus'   => $resvconfirmstatus,
									 'bokconfirmstatus'	   => $bokconfirmstatus,
									 'resvcheckedin'	   => $resvcheckedin,
									 'allarrived'		   => $allarrived,
									 'partialarr'		   => $partialarr,
									 'initial'				=>	$initial,
									 'bokcreatedby'			=>	$bokcreatedby));
				
			}else{
				
				foreach($rowset as $row)
				{
					if($previd == ""){
						$bokid 				= $row->bokid;
						$previd				= $row->bokid;
						$firstname			= $row->bokfirst_name;	
						$lastname 			= $row->boklast_name;					
						$bokuserid 			= $row->bokuserid;
						$bokfk_restaurant 	= $row->bokfk_restaurant;										
						$bokparty_size 		= $row->bokparty_size;
						$bokbooking_timings = $row->bokbooking_timings;
						$bokspecial_request = $row->bokspecial_request;
						$boktypcode 		= $row->boktypcode;
						$boktypdesc 		= $row->boktypdesc;
						$bokresmodecode 	= $row->bokresmodecode;
						$bokresmodedesc		= $row->bokresmodedesc;
						$bokrestaurant_note = $row->bokrestaurant_note;
						$bokstatusid		= $row->bokbooking_status_id;
						$bokstatuscode      = $row->bokstatuscode;
						$boktablenumber 	= $row->bktbtable_no_assigned;
						$boktablenumArr[]	= $row->bktbtable_no_assigned;
						$dinigid			= $row->rda_diningdisplyname;
						$resvconfirmstatus  = $row->bokresv_confirm_status;
						$bokconfirmstatus	= $row->bokbooking_confirm_status;
						$resvcheckedin		= $row->bokresv_checkedin_status;
						$allarrived			= $row->bokresv_allarrived_status;
						$partialarr			= $row->bokresv_partialarrived_status;
						$prevBokidArr[]		= $bokid;
						$initial			= $row->initial;
						$bokcreatedby		= $row->bokcreatedby;
						
					}else {
						$bokid = $row->bokid;
						if(in_array($bokid,$prevBokidArr)){
							$boktablenumArr[] = $row->bktbtable_no_assigned;
						}else{
							$tblNumStr = "";
							$tblNumStr = implode(',',$boktablenumArr);							
							$bookObj = new Reservation_Model_Reservation();
							$bookObj->setbokid($previd)
									->setbokuserid($bokuserid)
									->setbokfk_restaurant($bokfk_restaurant)
									->setbokfirst_name($firstname)
									->setboklast_name($lastname)
									->setbokparty_size($bokparty_size)
									->setbokbooking_timings($bokbooking_timings)
									->setbokspecial_request($bokspecial_request)
									->setbokbooking_type_code($boktypcode)
									->setbokbooking_type_desc($boktypdesc)
									->setbokreservation_mode_code($bokresmodecode)
									->setbokrestaurant_note($bokrestaurant_note)
									->setbokbooking_status_id($bokstatusid)
									->setbokbooking_status_code($bokstatuscode)
									->setboktablenumber($boktablenumber)
									->setTableNoArray($tblNumStr)
									->setDiningId($dinigid)
									->setbokresv_confirm_status($resvconfirmstatus)
									->setbokbooking_confirm_status($bokconfirmstatus)
									->setbokresv_checkedin_status($resvcheckedin)
									->setbokresv_allarrived_status($allarrived)
									->setbokresv_partialarrived_status($partialarr)									
									->setbokbooking_user_initials($initial)
									->setbokcreatedby($bokcreatedby);
							$resultSet[] = $bookObj;
							
							$boktablenumArr 	= null;
							$previd             = $bokid;
							$firstname			= $row->bokfirst_name;	
							$lastname 			= $row->boklast_name;					
							$bokuserid 			= $row->bokuserid;
							$bokfk_restaurant 	= $row->bokfk_restaurant;										
							$bokparty_size 		= $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc 	= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatusid		= $row->bokbooking_status_id;
							$bokstatuscode      = $row->bokstatuscode;
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$boktablenumArr[]	= $row->bktbtable_no_assigned;
							$dinigid			= $row->rda_diningdisplyname;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBokidArr[]		= $bokid;
							$initial			= $row->initial;
							$bokcreatedby		= $row->bokcreatedby;
						}
					}
					
				}
					$tblNumStr = "";
					$tblNumStr = implode(',',$boktablenumArr);							
					$bookObj = new Reservation_Model_Reservation();
					$bookObj->setbokid($bokid)
							->setbokuserid($bokuserid)
							->setbokfk_restaurant($bokfk_restaurant)
							->setbokfirst_name($firstname)
							->setboklast_name($lastname)
							->setbokparty_size($bokparty_size)
							->setbokbooking_timings($bokbooking_timings)
							->setbokspecial_request($bokspecial_request)
							->setbokbooking_type_code($boktypcode)
							->setbokbooking_type_desc($boktypdesc)
							->setbokreservation_mode_code($bokresmodecode)
							->setbokrestaurant_note($bokrestaurant_note)
							->setbokbooking_status_id($bokstatusid)
							->setbokbooking_status_code($bokstatuscode)
							->setboktablenumber($boktablenumber)
							->setTableNoArray($tblNumStr)
							->setDiningId($dinigid)
							->setbokresv_confirm_status($resvconfirmstatus)
							->setbokbooking_confirm_status($bokconfirmstatus)
							->setbokresv_checkedin_status($resvcheckedin)
							->setbokresv_allarrived_status($allarrived)
							->setbokresv_partialarrived_status($partialarr)
							->setbokbooking_user_initials($initial)
							->setbokcreatedby($bokcreatedby);
					$resultSet[] = $bookObj;
			}

			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of attendinglist
	 * retreive all the reservations with status reserved
	 */
	public function getAttendingList(Reservation_Model_GetAttendingList $attendinglist)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$statusId = array();
			$status = $attendinglist->getBookStatus();
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$attendinglist->getRestaurantId())
							  ->where('rda_status = ?',true);
			
			$initialTableMapper = new User_Model_PatronCodesDataMapper(); 
			$initialTableSelect = $initialTableMapper->getDbTable()->select();
			$initialTableSelect->from($initialTableMapper->getDbTable(),array('rsui_fk_user','rsui_initial'))
								->where('rsui_fk_restaurant = ?',$attendinglist->getRestaurantId());
								
			$bookOptionsMapper = new Reservation_Model_ReservationOptionsMapDataMapper();
			$bookOptions       = $bookOptionsMapper->getDbTable();
			$bookOptionsSelect = $bookOptions->select(); 
			$bookOptionsSelect->setIntegrityCheck(false);
			$bookOptionsSelect->from(array('bom'=>'mt.booking_options_map'),array('bopmbokid','bopmbok_optionsid'))
							  ->join(array('bop'=>'mt.booking_options'),'bop.boptid = bom.bopmbok_optionsid',array('boptdescription','boptid','boptcode'));
							
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note','bokresv_confirm_status','bokbooking_confirm_status','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status','bokcreatedby','bokseat_start','bokseat_end','bokresv_runninglate_status','bokfeedback_status'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
				   ->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))				   				   
				   ->joinLeft(array('ini'=>$initialTableSelect),'ini.rsui_fk_user = bok.bokbooking_user_initials',array('rsui_initial as initial'))
				   ->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
				   ->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokstatuscode'))
				   ->joinLeft(array('bookopt'=>$bookOptionsSelect),'bookopt.bopmbokid = bok.bokid',array('array_agg(boptdescription) as bookoption','array_agg(boptid) as boptid','array_agg(boptcode) as boptcode'))				   
				   ->where('bok.bokfk_restaurant = ?',$attendinglist->getRestaurantId())
//				   ->where('ini.rsui_fk_restaurant = ?',$attendinglist->getRestaurantId())
				   ->where('bok.bokbooking_date = ?',$attendinglist->getDate())				   
				   ->where('bok.bokbooking_status_id IN(?)',$statusId);
			/**ADD MEAL PERIOD FILTERS **/
			$starttime = $attendinglist->getStartTime();
			$endtime = $attendinglist->getEndTime();
			if((isset($starttime))&&(isset($endtime)))
			{
				$select = $select->where('bokbooking_timings >= ? ',$starttime);
				$select = $select->where('bokbooking_timings <= ?',$endtime);
			}
			/**END ADD MEAL PERIOD FILTERS **/
			$select->group(array('bokid','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id','rda_diningdisplyname','rsui_initial','boktyp.code','boktyp.description','resmode.code','resmode.description','boksts.code'));
			if($attendinglist->getSortOrder()){
				$order  = $attendinglist->getSortOrder();
				$sorton = $attendinglist->getSortOn();
				
				if($order == "ASC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));					
				}else if($order == "ASC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned ASC','bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned DESC','bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));		
				}else if($order == "ASC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size ASC','bokbooking_timings ASC','boklast_name ASC'));
				}else if($order == "DESC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size DESC','bokbooking_timings DESC','boklast_name DESC'));
				}				
			}else{
				$select->order(array('bokbooking_timings','bokid'));
			}

			$rowset = $table->fetchAll($select);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($attendinglist->getRestaurantId());
			date_default_timezone_set($timezone);
			
			$seatStart = strtotime(date('Y-m-d H:i:s'));
			
			if(count($rowset)>0){
				if($attendinglist->getIsAjaxCall()){	
					$prevBokidArr = array();
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokresmodedesc = '';
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$tablNoArr = array();
					$dinigid = "";
					$resvconfirmstatus  = "";
					$resvnoanwser = "";
					$resvcheckedin = "";
					$bokconfirmstatus = "";
					$allarrived	= '';
					$partialarr	= '';
					$initial = '';
					$bokoption = "";
					$bokoptioncode = "";
					$bokoptionArr = "";
					$bokoptioncodeArr = "";
					$bokcreatedby = "";
					$bokseat_start = '';
					$bokseat_end = '';
					$bokseat_duration = '';
					$bokresv_runninglate_status = '';
					$bokfeedback_status = '';
					foreach($rowset as $row)
					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = strtoupper($row->bokfirst_name." ".$row->boklast_name);				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBookid		    = $bokid;	
							$prevBokidArr[]		= $bokid;
							$initial			= $row->initial;
							$bokoptionArr		= explode(',',substr($row->bookoption,1,-1));
							$bokoptioncodeArr	= explode(',',substr($row->boptcode,1,-1));	
							if($bokoptionArr[0] && $bokoptionArr[0] != 'NULL' && $bokoptionArr[0] != "''"){
								$bokoption		= $bokoptionArr;
								$bokoptioncode	= $bokoptioncodeArr;	
							}else{
								$bokoption			= "";
								$bokoptioncode 		= "";
							}
							$bokcreatedby		= $row->bokcreatedby;
							$bokfeedback_status = $row->bokfeedback_status;
							$bokresv_runninglate_status = $row->bokresv_runninglate_status;
							if($row->bokseat_start && $row->bokseat_end){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
							}else if($row->bokseat_start){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
							}else{
								$bokseat_start		= '' ;
								$bokseat_duration	= '';
							}
						}else{
							$bokid = $row->bokid;
							
							if(in_array($bokid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}
								
								array_push($resultSet,array('bokid' 			  => $prevBookid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
				 											'bokfirst_name' 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $boktablenumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
															'bokresmodedesc'		=> $bokresmodedesc,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'diningid'			  => $dinigid,
															'resvconfirmstatus'   => $resvconfirmstatus,
															'bokconfirmstatus'	  => $bokconfirmstatus,
															'resvcheckedin'	   	  => $resvcheckedin,
															'allarrived'		   => $allarrived,
												 			'partialarr'		   => $partialarr,
															'initial'			  => $initial,
															'bokoption'			  => $bokoption,
															'bokoptioncode'		  => $bokoptioncode,
															'bokcreatedby'		  => $bokcreatedby,
															'bokseat_start'		  => $bokseat_start,
															'bokseat_duration'	  => $bokseat_duration,
															'bokfeedback_status'  => $bokfeedback_status,
															'bokresv_runninglate_status'=>$bokresv_runninglate_status));
								
									
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = strtoupper($row->bokfirst_name." ".$row->boklast_name);				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;
								$prevBookid		    = $bokid;
								$tablNoArr[] = $row->bktbtable_no_assigned;	
								$prevBokidArr[]		= $bokid;
								$initial			= $row->initial;
								$bokoptionArr		= explode(',',substr($row->bookoption,1,-1));
								$bokoptioncodeArr	= explode(',',substr($row->boptcode,1,-1));	
								if($bokoptionArr[0] && $bokoptionArr[0] != 'NULL' && $bokoptionArr[0] != "''"){
									$bokoption		= $bokoptionArr;
									$bokoptioncode	= $bokoptioncodeArr;	
								}else{
									$bokoption			= "";
									$bokoptioncode 		= "";
								}
								$bokcreatedby		= $row->bokcreatedby;
								$bokresv_runninglate_status = $row->bokresv_runninglate_status;
								$bokfeedback_status = $row->bokfeedback_status;
								if($row->bokseat_start && $row->bokseat_end){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
								}else if($row->bokseat_start){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
								}else{
									$bokseat_start		= '' ;
									$bokseat_duration	= '';
								}
							}
						}
					}
					$date = "";
					if($bokbooking_timings){
						$date = date("h:i A",strtotime($bokbooking_timings));
					}
					array_push($resultSet,array('bokid' 			  => $bokid,
		 							 			'bokuserid' 		  => $bokuserid,
		 							 			'bokfk_restaurant'    => $bokfk_restaurant,
	 											'bokfirst_name' 	  => $bokfirst_name,				 							 
	 											'bokparty_size' 	  => $bokparty_size,
		 							 			'bokbooking_timings'  => $date,
		 							 			'bokspecial_request'  => $bokspecial_request,
		 							 			'boktypcode'		  => $boktypcode,
		 							 			'boktablenumber'	  => $boktablenumber,
		 							 			'boktableid' 		  => $boktableid,
												'bokjointableno'	  => $bokjointableno,
		 							 			'bokresmodecode' 	  => $bokresmodecode,
												'bokresmodedesc'	  => $bokresmodedesc,
		 							 			'bokrestaurant_note'  => $bokrestaurant_note,
									 			'bokstatuscode'       => $bokstatuscode,
												'tableNoArr'		  => $tablNoArr,
												'diningid'			  => $dinigid,
												'resvconfirmstatus'   => $resvconfirmstatus,
												'bokconfirmstatus'	  => $bokconfirmstatus,
												'resvcheckedin'	   	  => $resvcheckedin,
												'allarrived'		   => $allarrived,
												 'partialarr'		   => $partialarr,
												'initial'			  => $initial,
												'bokoption'			  => $bokoption,
												'bokoptioncode'		  => $bokoptioncode,
												'bokcreatedby'		  => $bokcreatedby,
												'bokseat_start'		  => $bokseat_start,
												'bokseat_duration'	  => $bokseat_duration,
												'bokfeedback_status'  => $bokfeedback_status,
												'bokresv_runninglate_status'=>$bokresv_runninglate_status));					
				
				}else {
					$prevBookid         = "";
					$bokid	   	        = "";
					$bokuserid 	        = "";
					$bokfk_restaurant   = "";
					$bokfirst_name 	    = "";
					$boklast_name  	    = "";
					$bokparty_size 	    = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode 		= "";
					$boktypdesc 		= "";
					$boktablenumber 	= "";
					$bokjointableno 	= "";
					$boktableid 		= "";
					$bokresmodecode 	= "";
					$bokresmodedesc		= '';
					$bokrestaurant_note = "";
					$bokstatuscode 		= "";				
					$tablNoArr 			= array();
					$dinigid			= "";
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";
					$resvcheckedin		= "";
					$prevBokidArr 		= array();
					$initial			= '';
					$bokoption			= "";
					$bokoptioncode 		= "";
					$bokoptionArr = "";
					$bokoptioncodeArr = "";
					$bokcreatedby		= '';
					$bokseat_start		= '';
					$bokseat_duration	= '';
					$bokresv_runninglate_status = '';
					$bokfeedback_status = '';
					foreach($rowset as $row)
					{
						
						if($prevBookid == ""){	
							
							$bookid			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name;						
							$boklast_name		= $row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$prevBookid		    = $bookid;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;	
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBokidArr[]		= $bookid;
							$initial			= $row->initial;
							$bokoptionArr		= explode(',',substr($row->bookoption,1,-1));
							$bokoptioncodeArr	= explode(',',substr($row->boptcode,1,-1));	
							if($bokoptionArr[0] && $bokoptionArr[0] != 'NULL' && $bokoptionArr[0] != "''"){
								$bokoption		= $bokoptionArr;
								$bokoptioncode	= $bokoptioncodeArr;	
							}else{
								$bokoption			= "";
								$bokoptioncode 		= "";
							}
							$bokcreatedby		= $row->bokcreatedby;
							$bokresv_runninglate_status = $row->bokresv_runninglate_status;
							$bokfeedback_status = $row->bokfeedback_status;
							if($row->bokseat_start && $row->bokseat_end){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
							}else if($row->bokseat_start){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
							}else{
								$bokseat_start		= '' ;
								$bokseat_duration	= '';
							}
						}else{
							$bookid = $row->bokid;
							if(in_array($bookid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								
								$bookObj = new Reservation_Model_Reservation();							
								$bookObj->setbokid($prevBookid)
										->setbokuserid($bokuserid)
										->setbokfk_restaurant($bokfk_restaurant)
										->setbokfirst_name($bokfirst_name)
										->setboklast_name($boklast_name)
										->setbokparty_size($bokparty_size)
										->setbokbooking_timings($bokbooking_timings)
										->setbokspecial_request($bokspecial_request)
										->setbokbooking_type_code($boktypcode)
										->setbokbooking_type_desc($boktypdesc)
										->setboktablenumber($boktablenumber)
										->setboktableid($boktableid)
										->setJoinTableNo($bokjointableno)
										->setbokreservation_mode_code($bokresmodecode)
										->setbokrestaurant_note($bokrestaurant_note)
										->setbokbooking_status_code($bokstatuscode)
										->setTableNoArray($tablNoArr)
										->setDiningId($dinigid)
										->setbokresv_confirm_status($resvconfirmstatus)
										->setbokbooking_confirm_status($bokconfirmstatus)
										->setbokresv_checkedin_status($resvcheckedin)
										->setbokresv_allarrived_status($allarrived)
										->setbokresv_partialarrived_status($partialarr)
										->setbokbooking_user_initials($initial)
										->setbokoptions($bokoption)
										->setbokoptioncode($bokoptioncode)
										->setbokcreatedby($bokcreatedby)
										->setbokseat_start($bokseat_start)
										->setbokseat_duration($bokseat_duration)
										->setfeedback_status($bokfeedback_status)
										->setbokresv_runninglate_status($bokresv_runninglate_status);
										
								$resultSet[] = $bookObj;
	
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name;						
								$boklast_name		= $row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$tablNoArr[]		= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;	
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;		
								$prevBookid		    = $bookid;	
								$prevBokidArr[]		= $bookid;
								$initial			= $row->initial;
								$bokoptionArr		= explode(',',substr($row->bookoption,1,-1));
								$bokoptioncodeArr	= explode(',',substr($row->boptcode,1,-1));	
								if($bokoptionArr[0] && $bokoptionArr[0] != 'NULL' && $bokoptionArr[0] != "''"){
									$bokoption		= $bokoptionArr;
									$bokoptioncode	= $bokoptioncodeArr;	
								}else{
									$bokoption			= "";
									$bokoptioncode 		= "";
								}
								$bokcreatedby		= $row->bokcreatedby;
								$bokresv_runninglate_status = $row->bokresv_runninglate_status;
								$bokfeedback_status = $row->bokfeedback_status;
								if($row->bokseat_start && $row->bokseat_end){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
								}else if($row->bokseat_start){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
								}else{
									$bokseat_start		= '' ;
									$bokseat_duration	= '';
								}
							}
						}							
					}
					$bookObj = new Reservation_Model_Reservation();							
					$bookObj->setbokid($bookid)
							->setbokuserid($bokuserid)
							->setbokfk_restaurant($bokfk_restaurant)
							->setbokfirst_name($bokfirst_name)
							->setboklast_name($boklast_name)
							->setbokparty_size($bokparty_size)
							->setbokbooking_timings($bokbooking_timings)
							->setbokspecial_request($bokspecial_request)
							->setbokbooking_type_code($boktypcode)
							->setbokbooking_type_desc($boktypdesc)
							->setboktablenumber($boktablenumber)
							->setboktableid($boktableid)
							->setJoinTableNo($bokjointableno)
							->setbokreservation_mode_code($bokresmodecode)
							->setbokrestaurant_note($bokrestaurant_note)
							->setbokbooking_status_code($bokstatuscode)
							->setTableNoArray($tablNoArr)
							->setDiningId($dinigid)
							->setbokresv_confirm_status($resvconfirmstatus)
							->setbokbooking_confirm_status($bokconfirmstatus)
							->setbokresv_checkedin_status($resvcheckedin)
							->setbokresv_allarrived_status($allarrived)
							->setbokresv_partialarrived_status($partialarr)
							->setbokbooking_user_initials($initial)
							->setbokoptions($bokoption)
							->setbokoptioncode($bokoptioncode)
							->setbokcreatedby($bokcreatedby)
							->setbokseat_start($bokseat_start)
							->setbokseat_duration($bokseat_duration)
							->setfeedback_status($bokfeedback_status)
							->setbokresv_runninglate_status($bokresv_runninglate_status);
										
					$resultSet[] = $bookObj;
				}
			}

		return $resultSet;
		
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of attendinglist
	 * retreive all the reservations with status reserved
	 */
	public function getDealsList(Reservation_Model_GetAttendingList $attendinglist)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$statusId = array();
			$status = $attendinglist->getBookStatus();
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			$bookTypeMapper = new Application_Model_ReservationTypeDataMapper();
			$bookTypeArr = array(); 
			$bookType = $bookTypeMapper->GetBookingTypeByCode('SPLPAID');
			$bookTypeArr[] = $bookType->getid();
			$bookType = $bookTypeMapper->GetBookingTypeByCode('SPL');
			$bookTypeArr[] = $bookType->getid();
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$attendinglist->getRestaurantId())
							  ->where('rda_status = ?',true);
			
			$initialTableMapper = new User_Model_PatronCodesDataMapper(); 
			$initialTableSelect = $initialTableMapper->getDbTable()->select();
			$initialTableSelect->from($initialTableMapper->getDbTable(),array('rsui_fk_user','rsui_initial'))
								->where('rsui_fk_restaurant = ?',$attendinglist->getRestaurantId());
								
			$bookOptionsMapper = new Reservation_Model_ReservationOptionsMapDataMapper();
			$bookOptions       = $bookOptionsMapper->getDbTable();
			$bookOptionsSelect = $bookOptions->select(); 
			$bookOptionsSelect->setIntegrityCheck(false);
			$bookOptionsSelect->from(array('bom'=>'mt.booking_options_map'),array('bopmbokid','bopmbok_optionsid'))
							  ->join(array('bop'=>'mt.booking_options'),'bop.boptid = bom.bopmbok_optionsid',array('boptdescription','boptid','boptcode'));
							
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note','bokresv_confirm_status','bokbooking_confirm_status','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status','bokcreatedby','bokseat_start','bokseat_end','bokresv_runninglate_status'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
				   ->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))				   				   
				   ->joinLeft(array('ini'=>$initialTableSelect),'ini.rsui_fk_user = bok.bokbooking_user_initials',array('rsui_initial as initial'))
				   ->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
				   ->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokstatuscode'))
				   ->joinLeft(array('bookopt'=>$bookOptionsSelect),'bookopt.bopmbokid = bok.bokid',array('boptdescription as bookoption','boptid','boptcode'))				   
				   ->where('bok.bokfk_restaurant = ?',$attendinglist->getRestaurantId())
//				   ->where('ini.rsui_fk_restaurant = ?',$attendinglist->getRestaurantId())
				   ->where('bok.bokbooking_date = ?',$attendinglist->getDate())				   
				   ->where('bok.bokbooking_status_id IN(?)',$statusId)
				   ->where('bok.bokbooking_type_id IN (?)',$bookTypeArr);
			if($attendinglist->getSortOrder()){
				$order  = $attendinglist->getSortOrder();
				$sorton = $attendinglist->getSortOn();
				
				if($order == "ASC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));					
				}else if($order == "ASC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned ASC','bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned DESC','bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));		
				}else if($order == "ASC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size ASC','bokbooking_timings ASC','boklast_name ASC'));
				}else if($order == "DESC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size DESC','bokbooking_timings DESC','boklast_name DESC'));
				}				
			}else{
				$select->order(array('bokbooking_timings','bokid'));
			}

			$rowset = $table->fetchAll($select);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($attendinglist->getRestaurantId());
			date_default_timezone_set($timezone);
			
			$seatStart = strtotime(date('Y-m-d H:i:s'));
			
			if(count($rowset)>0){
				if($attendinglist->getIsAjaxCall()){	
					$prevBokidArr = array();
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokresmodedesc = '';
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$tablNoArr = array();
					$dinigid = "";
					$resvconfirmstatus  = "";
					$resvnoanwser = "";
					$resvcheckedin = "";
					$bokconfirmstatus = "";
					$allarrived	= '';
					$partialarr	= '';
					$initial = '';
					$bokoption = "";
					$bokoptioncode = "";
					$bokcreatedby = "";
					$bokseat_start = '';
					$bokseat_end = '';
					$bokseat_duration = '';
					$bokresv_runninglate_status = '';
					foreach($rowset as $row)
					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = strtoupper($row->bokfirst_name." ".$row->boklast_name);				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBookid		    = $bokid;	
							$prevBokidArr[]		= $bokid;
							$initial			= $row->initial;
							$bokoption			= $row->bookoption;
							$bokoptioncode		= $row->boptcode;	
							$bokcreatedby		= $row->bokcreatedby;
							$bokresv_runninglate_status = $row->bokresv_runninglate_status;
							if($row->bokseat_start && $row->bokseat_end){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
							}else if($row->bokseat_start){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
							}else{
								$bokseat_start		= '' ;
								$bokseat_duration	= '';
							}
						}else{
							$bokid = $row->bokid;
							
							if(in_array($bokid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}
								
								array_push($resultSet,array('bokid' 			  => $prevBookid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
				 											'bokfirst_name' 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $boktablenumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
															'bokresmodedesc'		=> $bokresmodedesc,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'diningid'			  => $dinigid,
															'resvconfirmstatus'   => $resvconfirmstatus,
															'bokconfirmstatus'	  => $bokconfirmstatus,
															'resvcheckedin'	   	  => $resvcheckedin,
															'allarrived'		   => $allarrived,
												 			'partialarr'		   => $partialarr,
															'initial'			  => $initial,
															'bokoption'			  => $bokoption,
															'bokoptioncode'		  => $bokoptioncode,
															'bokcreatedby'		  => $bokcreatedby,
															'bokseat_start'		  => $bokseat_start,
															'bokseat_duration'	  => $bokseat_duration,
															'bokresv_runninglate_status'=>$bokresv_runninglate_status));
								
									
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = strtoupper($row->bokfirst_name." ".$row->boklast_name);				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;
								$prevBookid		    = $bokid;
								$tablNoArr[]        = $row->bktbtable_no_assigned;	
								$prevBokidArr[]		= $bokid;
								$initial			= $row->initial;
								$bokoption			= $row->bookoption;
								$bokoptioncode		= $row->boptcode;
								$bokcreatedby		= $row->bokcreatedby;
								$bokresv_runninglate_status = $row->bokresv_runninglate_status;
								if($row->bokseat_start && $row->bokseat_end){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
								}else if($row->bokseat_start){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
								}else{
									$bokseat_start		= '' ;
									$bokseat_duration	= '';
								}
							}
						}
					}
					$date = "";
					if($bokbooking_timings){
						$date = date("h:i A",strtotime($bokbooking_timings));
					}
					array_push($resultSet,array('bokid' 			  => $bokid,
		 							 			'bokuserid' 		  => $bokuserid,
		 							 			'bokfk_restaurant'    => $bokfk_restaurant,
	 											'bokfirst_name' 	  => $bokfirst_name,				 							 
	 											'bokparty_size' 	  => $bokparty_size,
		 							 			'bokbooking_timings'  => $date,
		 							 			'bokspecial_request'  => $bokspecial_request,
		 							 			'boktypcode'		  => $boktypcode,
		 							 			'boktablenumber'	  => $boktablenumber,
		 							 			'boktableid' 		  => $boktableid,
												'bokjointableno'	  => $bokjointableno,
		 							 			'bokresmodecode' 	  => $bokresmodecode,
												'bokresmodedesc'		=> $bokresmodedesc,
		 							 			'bokrestaurant_note'  => $bokrestaurant_note,
									 			'bokstatuscode'       => $bokstatuscode,
												'tableNoArr'		  => $tablNoArr,
												'diningid'			  => $dinigid,
												'resvconfirmstatus'   => $resvconfirmstatus,
												'bokconfirmstatus'	  => $bokconfirmstatus,
												'resvcheckedin'	   	  => $resvcheckedin,
												'allarrived'		   => $allarrived,
												 'partialarr'		   => $partialarr,
												'initial'			  => $initial,
												'bokoption'			  => $bokoption,
												'bokoptioncode'		  => $bokoptioncode,
												'bokcreatedby'		  => $bokcreatedby,
												'bokseat_start'		  => $bokseat_start,
												'bokseat_duration'	  => $bokseat_duration,
												'bokresv_runninglate_status'=>$bokresv_runninglate_status));					
				
				}else {
					$prevBookid         = "";
					$bokid	   	        = "";
					$bokuserid 	        = "";
					$bokfk_restaurant   = "";
					$bokfirst_name 	    = "";
					$boklast_name  	    = "";
					$bokparty_size 	    = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode 		= "";
					$boktypdesc 		= "";
					$boktablenumber 	= "";
					$bokjointableno 	= "";
					$boktableid 		= "";
					$bokresmodecode 	= "";
					$bokresmodedesc		= '';
					$bokrestaurant_note = "";
					$bokstatuscode 		= "";				
					$tablNoArr 			= array();
					$dinigid			= "";
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";
					$resvcheckedin		= "";
					$prevBokidArr 		= array();
					$initial			= '';
					$bokoption			= "";
					$bokoptioncode 		= "";
					$bokcreatedby		= '';
					$bokseat_start		= '';
					$bokseat_duration	= '';
					$bokresv_runninglate_status = '';
					foreach($rowset as $row)
					{
						
						if($prevBookid == ""){	
							
							$bookid			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name;						
							$boklast_name		= $row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$prevBookid		    = $bookid;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;	
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBokidArr[]		= $bookid;
							$initial			= $row->initial;
							$bokoption			= $row->bookoption;
							$bokoptioncode		= $row->boptcode;
							$bokcreatedby		= $row->bokcreatedby;
							$bokresv_runninglate_status = $row->bokresv_runninglate_status;
							if($row->bokseat_start && $row->bokseat_end){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
							}else if($row->bokseat_start){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
							}else{
								$bokseat_start		= '' ;
								$bokseat_duration	= '';
							}
						}else{
							$bookid = $row->bokid;
							if(in_array($bookid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								
								$bookObj = new Reservation_Model_Reservation();							
								$bookObj->setbokid($prevBookid)
										->setbokuserid($bokuserid)
										->setbokfk_restaurant($bokfk_restaurant)
										->setbokfirst_name($bokfirst_name)
										->setboklast_name($boklast_name)
										->setbokparty_size($bokparty_size)
										->setbokbooking_timings($bokbooking_timings)
										->setbokspecial_request($bokspecial_request)
										->setbokbooking_type_code($boktypcode)
										->setbokbooking_type_desc($boktypdesc)
										->setboktablenumber($boktablenumber)
										->setboktableid($boktableid)
										->setJoinTableNo($bokjointableno)
										->setbokreservation_mode_code($bokresmodecode)
										->setbokrestaurant_note($bokrestaurant_note)
										->setbokbooking_status_code($bokstatuscode)
										->setTableNoArray($tablNoArr)
										->setDiningId($dinigid)
										->setbokresv_confirm_status($resvconfirmstatus)
										->setbokbooking_confirm_status($bokconfirmstatus)
										->setbokresv_checkedin_status($resvcheckedin)
										->setbokresv_allarrived_status($allarrived)
										->setbokresv_partialarrived_status($partialarr)
										->setbokbooking_user_initials($initial)
										->setbokoptions($bokoption)
										->setbokoptioncode($bokoptioncode)
										->setbokcreatedby($bokcreatedby)
										->setbokseat_start($bokseat_start)
										->setbokseat_duration($bokseat_duration)
										->setbokresv_runninglate_status($bokresv_runninglate_status);
										
								$resultSet[] = $bookObj;
	
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name;						
								$boklast_name		= $row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$tablNoArr[]		= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;			
								$prevBookid		    = $bookid;	
								$prevBokidArr[]		= $bookid;
								$initial			= $row->initial;
								$bokoption			= $row->bookoption;
								$bokoptioncode		= $row->boptcode;
								$bokcreatedby		= $row->bokcreatedby;
								$bokresv_runninglate_status = $row->bokresv_runninglate_status;
								if($row->bokseat_start && $row->bokseat_end){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
								}else if($row->bokseat_start){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
								}else{
									$bokseat_start		= '' ;
									$bokseat_duration	= '';
								}
							}
						}							
					}
					$bookObj = new Reservation_Model_Reservation();							
					$bookObj->setbokid($bookid)
							->setbokuserid($bokuserid)
							->setbokfk_restaurant($bokfk_restaurant)
							->setbokfirst_name($bokfirst_name)
							->setboklast_name($boklast_name)
							->setbokparty_size($bokparty_size)
							->setbokbooking_timings($bokbooking_timings)
							->setbokspecial_request($bokspecial_request)
							->setbokbooking_type_code($boktypcode)
							->setbokbooking_type_desc($boktypdesc)
							->setboktablenumber($boktablenumber)
							->setboktableid($boktableid)
							->setJoinTableNo($bokjointableno)
							->setbokreservation_mode_code($bokresmodecode)
							->setbokrestaurant_note($bokrestaurant_note)
							->setbokbooking_status_code($bokstatuscode)
							->setTableNoArray($tablNoArr)
							->setDiningId($dinigid)
							->setbokresv_confirm_status($resvconfirmstatus)
							->setbokbooking_confirm_status($bokconfirmstatus)
							->setbokresv_checkedin_status($resvcheckedin)
							->setbokresv_allarrived_status($allarrived)
							->setbokresv_partialarrived_status($partialarr)
							->setbokbooking_user_initials($initial)
							->setbokoptions($bokoption)
							->setbokoptioncode($bokoptioncode)
							->setbokcreatedby($bokcreatedby)
							->setbokseat_start($bokseat_start)
							->setbokseat_duration($bokseat_duration)
							->setbokresv_runninglate_status($bokresv_runninglate_status);
										
					$resultSet[] = $bookObj;
				}
			}

		return $resultSet;
		
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function getDayViewList(Reservation_Model_GetDayViewList  $dayviewlist,$meal)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$statusId = array();
			$status = $dayviewlist->getBookStatus();
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			$mealKeys = array_keys($meal);
			$meal_0 = array();
			foreach($meal as $key=>$value){
				${'meal_' . $key} = array();
			}
			
			$seatStart = strtotime(date('Y-m-d H:i:s'));
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$dayviewlist->getRestaurantId())
							  ->where('rda_status = ?',true);
			
			$initialTableMapper = new User_Model_PatronCodesDataMapper(); 
			$initialTableSelect = $initialTableMapper->getDbTable()->select();
			$initialTableSelect->from($initialTableMapper->getDbTable(),array('rsui_fk_user','rsui_initial'))
								->where('rsui_fk_restaurant = ?',$dayviewlist->getRestaurantId());

			$mealMapper = new FirmManagement_Model_FirmMealTypeDataMapper();
			$mealSelect = $mealMapper->getDbTable()->select();
			$mealSelect->from($mealMapper->getDbTable(),array('rmt_id','rmt_start_time','rmt_end_time'))
						->where('rmt_restaurant = ?',$dayviewlist->getRestaurantId())
						 ->where('rmt_status = ?','Y');
						 
			$bookOptionsMapper = new Reservation_Model_ReservationOptionsMapDataMapper();
			$bookOptions       = $bookOptionsMapper->getDbTable();
			$bookOptionsSelect = $bookOptions->select(); 
			$bookOptionsSelect->setIntegrityCheck(false);
			$bookOptionsSelect->from(array('bom'=>'mt.booking_options_map'),array('bopmbokid','bopmbok_optionsid'))
							  ->join(array('bop'=>'mt.booking_options'),'bop.boptid = bom.bopmbok_optionsid',array('boptdescription','boptid','boptcode'));
						
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note','bokresv_confirm_status','bokbooking_confirm_status','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status','bokcreatedby','bokresv_runninglate_status','bokseat_start','bokseat_end','bokfeedback_status'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
				   ->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))				   				   
				   ->joinLeft(array('ini'=>$initialTableSelect),'ini.rsui_fk_user = bok.bokbooking_user_initials',array('rsui_initial as initial'))
				   ->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
				   ->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokstatuscode'))				   
				   ->joinLeft(array('meal'=>$mealSelect),'bok.bokbooking_timings >= meal.rmt_start_time and bok.bokbooking_timings <= meal.rmt_end_time',array('rmt_id','rmt_start_time','rmt_end_time'))
				   ->joinLeft(array('bookopt'=>$bookOptionsSelect),'bookopt.bopmbokid = bok.bokid',array('array_agg(boptdescription) as bookoption','array_agg(boptid) as boptid','array_agg(boptcode) as boptcode'))
				   ->joinLeft(array('par'=>'mt.company'),'par.com_companyname = resmode.description',array('com_id','com_logo'))
				   ->where('bok.bokfk_restaurant = ?',$dayviewlist->getRestaurantId())
//				   ->where('bok.bokbooking_timings > meal.rmt_start_time')
//				   ->where('bok.bokbooking_timings < meal.rmt_end_time')
				   ->where('bok.bokbooking_date = ?',$dayviewlist->getDate())				   
				   ->where('bok.bokbooking_status_id IN(?)',$statusId);
				   /**ADD MEAL PERIOD FILTERS **/
			$starttime = $dayviewlist->getStartTime();
			$endtime = $dayviewlist->getEndTime();
			if((isset($starttime))&&(isset($endtime)))
			{
				$select = $select->where('bokbooking_timings >= ? ',$starttime);
				$select = $select->where('bokbooking_timings <= ?',$endtime);
			}
			/**END ADD MEAL PERIOD FILTERS **/	
			$select->group(array('bokid','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id','rda_diningdisplyname','rsui_initial','boktyp.code','boktyp.description','resmode.code','resmode.description','boksts.code','rmt_id','rmt_start_time','rmt_end_time','com_id','com_logo'));	   
//			$select->order(array('bok.bokbooking_status_id','bokid'));
//$select->group(array('bok.bokbooking_status_id','bokid'));
				   
			
			if($dayviewlist->getSortOrder()){
				$order  = $dayviewlist->getSortOrder();
				$sorton = $dayviewlist->getSortOn();
				
				if($order == "ASC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));					
				}else if($order == "ASC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned ASC','bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned DESC','bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));		
				}else if($order == "ASC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size ASC','bokbooking_timings ASC','boklast_name ASC'));
				}else if($order == "DESC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size DESC','bokbooking_timings DESC','boklast_name DESC'));
				}				
			}else{
				$select->order(array('bokbooking_timings','bokid'));
			}

			$rowset = $table->fetchAll($select);
			if(count($rowset)>0){
				if($dayviewlist->getIsAjaxCall()){
					$prevBokidArr = array();
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokresmodedesc = '';
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$tablNoArr = array();
					$dinigid = "";
					$resvconfirmstatus  = "";
					$resvnoanwser = "";
					$resvcheckedin = "";
					$bokconfirmstatus = "";
					$allarrived	= '';
					$partialarr	= '';
					$initial = '';
					$mealid = '';
					$mealArr = array();
					$bokoption	= "";
					$bokoptioncode = "";
					$bokcreatedby = '';
					$bokseat_start		= '';
					$bokseat_duration	= '';
					$bokresv_runninglate_status = "";
					$bokfeedback_status = "";
					$com_logo = '';
					foreach($rowset as $row)
					{
						if($prevBookid == ""){
							$bokid 			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBookid		    = $bokid;	
							$prevBokidArr[]		= $bokid;
							$initial			= $row->initial;	
							$mealid				= $row->rmt_id;
							$mealArr[] 			= $mealid;
							$bokoption			= $row->bookoption;
							$bokoptioncode		= $row->boptcode;
							$bokcreatedby		= $row->bokcreatedby;
							$com_logo			= $row->com_logo;
							$bokresv_runninglate_status = $row->bokresv_runninglate_status;
							$bokfeedback_status = $row->bokfeedback_status; 
							if($row->bokseat_start && $row->bokseat_end){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
							}else if($row->bokseat_start){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
							}else{
								$bokseat_start		= '' ;
								$bokseat_duration	= '';
							}
						}else{
							$bokid = $row->bokid;
							if(in_array($bokid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}
								if($mealid){
									array_push(${'meal_'.$mealid},array('bokid' 			  => $prevBookid,
								 							 			'bokuserid' 		  => $bokuserid,
								 							 			'bokfk_restaurant'    => $bokfk_restaurant,
							 											'bokfirst_name' 	  => $bokfirst_name,				 							 
							 											'bokparty_size' 	  => $bokparty_size,
								 							 			'bokbooking_timings'  => $date,
								 							 			'bokspecial_request'  => $bokspecial_request,
								 							 			'boktypcode'		  => $boktypcode,
								 							 			'boktablenumber'	  => $boktablenumber,
								 							 			'boktableid' 		  => $boktableid,
																		'bokjointableno'	  => $bokjointableno,
								 							 			'bokresmodecode' 	  => $bokresmodecode,
																		'bokresmodedesc'		=> $bokresmodedesc,
								 							 			'bokrestaurant_note'  => $bokrestaurant_note,
															 			'bokstatuscode'       => $bokstatuscode,
																		'tableNoArr'		  => $tablNoArr,
																		'diningid'			  => $dinigid,
																		'resvconfirmstatus'   => $resvconfirmstatus,
																		'bokconfirmstatus'	  => $bokconfirmstatus,
																		'resvcheckedin'	   	  => $resvcheckedin,
																		'allarrived'		   => $allarrived,
												 						'partialarr'		   => $partialarr,
																		'initial'			  => $initial,
																		'mealid'		      => $mealid,
																		'bokoption'			  => $bokoption,
																		'bokoptioncode'		  => $bokoptioncode,
																		'bokcreatedby'		  => $bokcreatedby,
																		'bokseat_start'		  => $bokseat_start,
																		'bokseat_duration'	  => $bokseat_duration,
																		'bokfeedback_status'  => $bokfeedback_status,
																		'bokresv_runninglate_status'=>$bokresv_runninglate_status,
																		'com_logo'			=> $com_logo));
									
								}else{
									array_push($meal_0,array('bokid' 			  => $prevBookid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
				 											'bokfirst_name' 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $boktablenumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
															'bokresmodedesc'		=> $bokresmodedesc,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'diningid'			  => $dinigid,
															'resvconfirmstatus'   => $resvconfirmstatus,
															'bokconfirmstatus'	  => $bokconfirmstatus,
															'resvcheckedin'	   	  => $resvcheckedin,
															'allarrived'		   => $allarrived,
												 			'partialarr'		   => $partialarr,
															'initial'			  => $initial,
															'mealid'		      => $mealid,
															'bokoption'			  => $bokoption,
															'bokoptioncode'		  => $bokoptioncode,
															'bokcreatedby'		  => $bokcreatedby,
															'bokseat_start'		  => $bokseat_start,
															'bokseat_duration'	  => $bokseat_duration,
															'bokfeedback_status'  => $bokfeedback_status,
															'bokresv_runninglate_status'=>$bokresv_runninglate_status,
															'com_logo'			=> $com_logo
									));
									
								}
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;
								$prevBookid		    = $bokid;
								$tablNoArr[] = $row->bktbtable_no_assigned;	
								$prevBokidArr[]		= $bokid;
								$initial			= $row->initial;
								$mealid				= $row->rmt_id;
								$bokoption			= $row->bookoption;
								$bokoptioncode		= $row->boptcode;
								$bokcreatedby		= $row->bokcreatedby;
								$bokfeedback_status = $row->bokfeedback_status;
								$com_logo			= $row->com_logo;
								$bokresv_runninglate_status = $row->bokresv_runninglate_status;
								if($row->bokseat_start && $row->bokseat_end){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
								}else if($row->bokseat_start){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
								}else{
									$bokseat_start		= '' ;
									$bokseat_duration	= '';
								}
							}
						}
					}
//					$date = "";
//					if(in_array($bokid,$prevBokidArr)){
//						$tablNoArr[] = $row->bktbtable_no_assigned;
//					}else{
						if($bokbooking_timings){
							$date = date("h:i A",strtotime($bokbooking_timings));
						}
						if($mealid){
							array_push(${'meal_'.$mealid},array('bokid' 			  => $bokid,
						 							 			'bokuserid' 		  => $bokuserid,
						 							 			'bokfk_restaurant'    => $bokfk_restaurant,
					 											'bokfirst_name' 	  => $bokfirst_name,				 							 
					 											'bokparty_size' 	  => $bokparty_size,
						 							 			'bokbooking_timings'  => $date,
						 							 			'bokspecial_request'  => $bokspecial_request,
						 							 			'boktypcode'		  => $boktypcode,
						 							 			'boktablenumber'	  => $boktablenumber,
						 							 			'boktableid' 		  => $boktableid,
																'bokjointableno'	  => $bokjointableno,
						 							 			'bokresmodecode' 	  => $bokresmodecode,
																'bokresmodedesc'		=> $bokresmodedesc,
						 							 			'bokrestaurant_note'  => $bokrestaurant_note,
													 			'bokstatuscode'       => $bokstatuscode,
																'tableNoArr'		  => $tablNoArr,
																'diningid'			  => $dinigid,
																'resvconfirmstatus'   => $resvconfirmstatus,
																'bokconfirmstatus'	  => $bokconfirmstatus,
																'resvcheckedin'	   	  => $resvcheckedin,
																'allarrived'		   => $allarrived,
												 				'partialarr'		   => $partialarr,
																'initial'			  => $initial,
																'mealid'		      => $mealid,
																'bokoption'			  => $bokoption,
																'bokoptioncode'		  => $bokoptioncode,
																'bokcreatedby'		  => $bokcreatedby,
																'bokseat_start'		  => $bokseat_start,
																'bokseat_duration'	  => $bokseat_duration,
																'bokfeedback_status'  => $bokfeedback_status,
																'bokresv_runninglate_status'=>$bokresv_runninglate_status,
																'com_logo'				=> $com_logo
							));
						}else{
							array_push($meal_0,array('bokid' 			  => $bokid,
			 							 			'bokuserid' 		  => $bokuserid,
			 							 			'bokfk_restaurant'    => $bokfk_restaurant,
		 											'bokfirst_name' 	  => $bokfirst_name,				 							 
		 											'bokparty_size' 	  => $bokparty_size,
			 							 			'bokbooking_timings'  => $date,
			 							 			'bokspecial_request'  => $bokspecial_request,
			 							 			'boktypcode'		  => $boktypcode,
			 							 			'boktablenumber'	  => $boktablenumber,
			 							 			'boktableid' 		  => $boktableid,
													'bokjointableno'	  => $bokjointableno,
			 							 			'bokresmodecode' 	  => $bokresmodecode,
													'bokresmodedesc'	  => $bokresmodedesc,
			 							 			'bokrestaurant_note'  => $bokrestaurant_note,
										 			'bokstatuscode'       => $bokstatuscode,
													'tableNoArr'		  => $tablNoArr,
													'diningid'			  => $dinigid,
													'resvconfirmstatus'   => $resvconfirmstatus,
													'bokconfirmstatus'	  => $bokconfirmstatus,
													'resvcheckedin'	   	  => $resvcheckedin,
													'allarrived'		   => $allarrived,
												 	'partialarr'		   => $partialarr,
													'initial'			  => $initial,
													'mealid'		      => $mealid,
													'bokoption'			  => $bokoption,
													'bokoptioncode'		  => $bokoptioncode,
													'bokcreatedby'		  => $bokcreatedby,
													'bokseat_start'		  => $bokseat_start,
													'bokseat_duration'	  => $bokseat_duration,
													'bokfeedback_status'  => $bokfeedback_status,
													'bokresv_runninglate_status'=>$bokresv_runninglate_status,
													'com_logo'			=>	$com_logo
							));
						}	
//					}
										
				}else {
					$prevBookid         = "";
					$bokid	   	        = "";
					$bokuserid 	        = "";
					$bokfk_restaurant   = "";
					$bokfirst_name 	    = "";
					$boklast_name  	    = "";
					$bokparty_size 	    = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode 		= "";
					$boktypdesc 		= "";
					$boktablenumber 	= "";
					$bokjointableno 	= "";
					$boktableid 		= "";
					$bokresmodecode 	= "";
					$bokresmodedesc		= '';
					$bokrestaurant_note = "";
					$bokstatuscode 		= "";				
					$tablNoArr 			= array();
					$dinigid			= "";
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";
					$resvcheckedin		= "";
					$prevBokidArr 		= array();
					$initial			= '';
					$mealid				= '';
					$bokoption			= "";
					$bokoptioncode		= "";
					$bokcreatedby		= '';
					$bokseat_start		= '';
					$bokseat_duration	= '';
					$bokfeedback_status = "";
					$bokresv_runninglate_status = "";
					$com_logo = '';
					foreach($rowset as $row)
					{
						
						if($prevBookid == ""){	
							
							$bookid			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name;						
							$boklast_name		= $row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$prevBookid		    = $bookid;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;	
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBokidArr[]		= $bookid;
							$initial			= $row->initial;
							$mealid				= $row->rmt_id;
							$bokoption			= $row->bookoption;
							$bokoptioncode		= $row->boptcode;
							$bokcreatedby		= $row->bokcreatedby;
							$bokfeedback_status = $row->bokfeedback_status;
							$bokresv_runninglate_status = $row->bokresv_runninglate_status;
							
							if($row->bokseat_start && $row->bokseat_end){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
							}else if($row->bokseat_start){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
							}else{
								$bokseat_start		= '' ;
								$bokseat_duration	= '';
							}
						}else{
							$bookid = $row->bokid;
							if(in_array($bookid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								if($mealid){
									$bookObj = new Reservation_Model_Reservation();							
									$bookObj->setbokid($prevBookid)
											->setbokuserid($bokuserid)
											->setbokfk_restaurant($bokfk_restaurant)
											->setbokfirst_name($bokfirst_name)
											->setboklast_name($boklast_name)
											->setbokparty_size($bokparty_size)
											->setbokbooking_timings($bokbooking_timings)
											->setbokspecial_request($bokspecial_request)
											->setbokbooking_type_code($boktypcode)
											->setbokbooking_type_desc($boktypdesc)
											->setboktablenumber($boktablenumber)
											->setboktableid($boktableid)
											->setJoinTableNo($bokjointableno)
											->setbokreservation_mode_code($bokresmodecode)
											->setbokrestaurant_note($bokrestaurant_note)
											->setbokbooking_status_code($bokstatuscode)
											->setTableNoArray($tablNoArr)
											->setDiningId($dinigid)
											->setbokresv_confirm_status($resvconfirmstatus)
											->setbokbooking_confirm_status($bokconfirmstatus)
											->setbokresv_checkedin_status($resvcheckedin)
											->setbokresv_allarrived_status($allarrived)
											->setbokresv_partialarrived_status($partialarr)
											->setbokbooking_user_initials($initial)
											->setReservationMeal($mealid)
											->setbokoptions($bokoption)
											->setbokoptioncode($bokoptioncode)
											->setbokcreatedby($bokcreatedby)
											->setbokresv_runninglate_status($bokresv_runninglate_status)
											->setbokseat_start($bokseat_start)
											->setfeedback_status($bokfeedback_status)
											->setbokseat_duration($bokseat_duration);
											
									array_push(${'meal_'.$mealid},$bookObj);							
								}else{
									$bookObj = new Reservation_Model_Reservation();							
									$bookObj->setbokid($prevBookid)
											->setbokuserid($bokuserid)
											->setbokfk_restaurant($bokfk_restaurant)
											->setbokfirst_name($bokfirst_name)
											->setboklast_name($boklast_name)
											->setbokparty_size($bokparty_size)
											->setbokbooking_timings($bokbooking_timings)
											->setbokspecial_request($bokspecial_request)
											->setbokbooking_type_code($boktypcode)
											->setbokbooking_type_desc($boktypdesc)
											->setboktablenumber($boktablenumber)
											->setboktableid($boktableid)
											->setJoinTableNo($bokjointableno)
											->setbokreservation_mode_code($bokresmodecode)
											->setbokrestaurant_note($bokrestaurant_note)
											->setbokbooking_status_code($bokstatuscode)
											->setTableNoArray($tablNoArr)
											->setDiningId($dinigid)
											->setbokresv_confirm_status($resvconfirmstatus)
											->setbokbooking_confirm_status($bokconfirmstatus)
											->setbokresv_checkedin_status($resvcheckedin)
											->setbokresv_allarrived_status($allarrived)
											->setbokresv_partialarrived_status($partialarr)
											->setbokbooking_user_initials($initial)
											->setReservationMeal($mealid)
											->setbokoptions($bokoption)
											->setbokoptioncode($bokoptioncode)
											->setbokcreatedby($bokcreatedby)
											->setbokresv_runninglate_status($bokresv_runninglate_status)
											->setbokseat_start($bokseat_start)
											->setfeedback_status($bokfeedback_status)
											->setbokseat_duration($bokseat_duration);
											
									array_push($meal_0,$bookObj);
								}
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name;						
								$boklast_name		= $row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$tablNoArr[]		= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;		
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;	
								$prevBookid		    = $bookid;	
								$prevBokidArr[]		= $bookid;
								$initial			= $row->initial;
								$mealid				= $row->rmt_id;
								$bokoption			= $row->bookoption;
								$bokoptioncode		= $row->boptcode;
								$bokcreatedby		= $row->bokcreatedby;
								$bokfeedback_status = $row->bokfeedback_status;
								$bokresv_runninglate_status = $row->bokresv_runninglate_status;
								if($row->bokseat_start && $row->bokseat_end){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
								}else if($row->bokseat_start){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
								}else{
									$bokseat_start		= '' ;
									$bokseat_duration	= '';
								}
							}
						}							
					}
					if($mealid){
						$bookObj = new Reservation_Model_Reservation();							
						$bookObj->setbokid($bookid)
								->setbokuserid($bokuserid)
								->setbokfk_restaurant($bokfk_restaurant)
								->setbokfirst_name($bokfirst_name)
								->setboklast_name($boklast_name)
								->setbokparty_size($bokparty_size)
								->setbokbooking_timings($bokbooking_timings)
								->setbokspecial_request($bokspecial_request)
								->setbokbooking_type_code($boktypcode)
								->setbokbooking_type_desc($boktypdesc)
								->setboktablenumber($boktablenumber)
								->setboktableid($boktableid)
								->setJoinTableNo($bokjointableno)
								->setbokreservation_mode_code($bokresmodecode)
								->setbokrestaurant_note($bokrestaurant_note)
								->setbokbooking_status_code($bokstatuscode)
								->setTableNoArray($tablNoArr)
								->setDiningId($dinigid)
								->setbokresv_confirm_status($resvconfirmstatus)
								->setbokbooking_confirm_status($bokconfirmstatus)
								->setbokresv_checkedin_status($resvcheckedin)
								->setbokresv_allarrived_status($allarrived)
								->setbokresv_partialarrived_status($partialarr)
								->setbokbooking_user_initials($initial)
								->setReservationMeal($mealid)
								->setbokoptions($bokoption)
								->setbokoptioncode($bokoptioncode)
								->setbokcreatedby($bokcreatedby)
								->setbokseat_start($bokseat_start)
								->setbokseat_duration($bokseat_duration)
								->setfeedback_status($bokfeedback_status)
								->setbokresv_runninglate_status($bokresv_runninglate_status);
											
						array_push(${'meal_'.$mealid},$bookObj);
					}else{
						$bookObj = new Reservation_Model_Reservation();							
						$bookObj->setbokid($bookid)
								->setbokuserid($bokuserid)
								->setbokfk_restaurant($bokfk_restaurant)
								->setbokfirst_name($bokfirst_name)
								->setboklast_name($boklast_name)
								->setbokparty_size($bokparty_size)
								->setbokbooking_timings($bokbooking_timings)
								->setbokspecial_request($bokspecial_request)
								->setbokbooking_type_code($boktypcode)
								->setbokbooking_type_desc($boktypdesc)
								->setboktablenumber($boktablenumber)
								->setboktableid($boktableid)
								->setJoinTableNo($bokjointableno)
								->setbokreservation_mode_code($bokresmodecode)
								->setbokrestaurant_note($bokrestaurant_note)
								->setbokbooking_status_code($bokstatuscode)
								->setTableNoArray($tablNoArr)
								->setDiningId($dinigid)
								->setbokresv_confirm_status($resvconfirmstatus)
								->setbokbooking_confirm_status($bokconfirmstatus)
								->setbokresv_checkedin_status($resvcheckedin)
								->setbokresv_allarrived_status($allarrived)
								->setbokresv_partialarrived_status($partialarr)
								->setbokbooking_user_initials($initial)
								->setReservationMeal($mealid)
								->setbokoptions($bokoption)
								->setbokoptioncode($bokoptioncode)
								->setbokcreatedby($bokcreatedby)
								->setbokseat_start($bokseat_start)
								->setbokseat_duration($bokseat_duration)
								->setfeedback_status($bokfeedback_status)
								->setbokresv_runninglate_status($bokresv_runninglate_status);
											
						array_push($meal_0,$bookObj);
					}
				}
			}
			
			foreach($meal as $key=>$value){
				if($key != 'count' && ${'meal_' . $key}){
					$resultSet['meal_' . $key] = ${'meal_' . $key};
				}
			}
			if($meal_0){
				$resultSet['meal_0'] = $meal_0;
			}
			return $resultSet;
		
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getWaitingListForDayView(Reservation_Model_GetWaitingList $waitinglist,$meal)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$statusId = array();
			$status = $waitinglist->getBookStatus();
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($waitinglist->getRestaurantId());
			date_default_timezone_set($timezone);
			
			$presenttime = strtotime(date('Y-m-d H:i:s'));
			
			foreach($meal as $key=>$value){
				${'meal_' . $key} = array();
			}
			$meal_0 = array();
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$waitinglist->getRestaurantId())
							  ->where('rda_status = ?',true);
							  
			$mealMapper = new FirmManagement_Model_FirmMealTypeDataMapper();
			$mealSelect = $mealMapper->getDbTable()->select();
			$mealSelect->from($mealMapper->getDbTable(),array('rmt_id','rmt_start_time','rmt_end_time'))
						->where('rmt_restaurant = ?',$waitinglist->getRestaurantId())
						 ->where('rmt_status = ?','Y');	  
							
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note','bokbooking_status_id','bokquoted_time','boknotification_type','bokresv_confirm_status','bokbooking_confirm_status','bokbooking_date','bokfeedback_status'))
					->distinct()
					->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
					->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))
					->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
					->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
					->join(array('bokstat'=>'mt.booking_status_bd'),'bokstat.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
					->joinLeft(array('quote'=>'mt.quoted_time_bd'),'quote.id = bok.bokquoted_time',array('description as Quote'))
					->joinLeft(array('meal'=>$mealSelect),'bok.bokbooking_timings >= meal.rmt_start_time and bok.bokbooking_timings <= meal.rmt_end_time',array('rmt_id','rmt_start_time','rmt_end_time'))
					->joinLeft(array('par'=>'mt.company'),'par.com_companyname = resmode.description',array('com_id','com_logo'))
					->where('bok.bokfk_restaurant = ?',$waitinglist->getRestaurantId())
					->where('bok.bokbooking_date = ?',$waitinglist->getDate())
					->where('bok.bokbooking_status_id IN(?)',$statusId);
			/**ADD MEAL PERIOD FILTERS **/
			$starttime = $waitinglist->getStartTime();
			$endtime = $waitinglist->getEndTime();
			if((isset($starttime))&&(isset($endtime)))
			{
				$select = $select->where('bok.bokbooking_timings >= ? ',$starttime);
				$select = $select->where('bok.bokbooking_timings <= ?',$endtime);
			}
			/**END ADD MEAL PERIOD FILTERS **/	 
			if($waitinglist->getBookingId()){
				$select->where('bok.bokid = ?',$waitinglist->getBookingId());
			}
			if($waitinglist->getSortOrder()){
				$order = $waitinglist->getSortOrder();
				if($order == "ASC"){
					$select->order(array('bokbooking_timings ASC'));	
				}else if($order == "DESC"){
					$select->order(array('bokbooking_timings DESC'));	
				}				
			}else{
				$select->order(array('bokbooking_timings'));
			}
			
			$rowset = $table->fetchAll($select);
			$tablNoArr = array();
			$prevBookid = "";
			if(count($rowset)>0){
				if($waitinglist->getIsAjaxCall()){
					$prevBokidArr = array();
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokresmodedesc	= '';
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$quotedtime = '';
					$boknotification = '';
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";					
					$tablNoArr = array();
					$dinigid = "";
					$mealid	= '';
					$bokfeedback_status = '';
					$bokwaittime_start = "";
					$com_logo = '';
					foreach($rowset as $row)
					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
							$prevBokidArr[]		= $bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;	
							$dinigid 			= $row->rda_diningdisplyname;
							$mealid				= $row->rmt_id;
							$bokfeedback_status = $row->bokfeedback_status;
							$com_logo = $row->com_logo;
							if($row->Quote){
								$quotedtime			= $row->Quote;
							}else{
								$quotedtime			= '';
							}
							$boknotification	= $row->boknotification_type;
							$prevBookid		    = $bokid;
							if($row->bokbooking_timings){
								$bokwaittime_start 	= round(abs($presenttime-strtotime($row->bokbooking_date.' '.$row->bokbooking_timings)) / 60,0);
							}						
							
						}else{
							$bokid = $row->bokid;
							
							if(in_array($bokid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}
								if($mealid){
									array_push(${'meal_'.$mealid},array('bokid' 			  => $prevBookid,
								 							 			'bokuserid' 		  => $bokuserid,
								 							 			'bokfk_restaurant'    => $bokfk_restaurant,
							 											'bokfirst_name' 	  => $bokfirst_name,				 							 
							 											'bokparty_size' 	  => $bokparty_size,
								 							 			'bokbooking_timings'  => $date,
								 							 			'bokspecial_request'  => $bokspecial_request,
								 							 			'boktypcode'		  => $boktypcode,
								 							 			'boktablenumber'	  => $boktablenumber,
								 							 			'boktableid' 		  => $boktableid,
																		'bokjointableno'	  => $bokjointableno,
								 							 			'bokresmodecode' 	  => $bokresmodecode,
																		'bokresmodedesc'		=> $bokresmodedesc,
								 							 			'bokrestaurant_note'  => $bokrestaurant_note,
															 			'bokstatuscode'       => $bokstatuscode,
																		'tableNoArr'		  => $tablNoArr,
																		'diningid'			  => $dinigid,
																		'quoted_time'		  => $quotedtime,
																		'boknotificationtype' => $boknotification,
																		'resvconfirmstatus'   => $resvconfirmstatus,
																		'bokconfirmstatus'	  => $bokconfirmstatus,
																		'bokwaittime_start'	  => $bokwaittime_start,
																		'bokfeedback_status'  => $bokfeedback_status,
																		'mealid'			  => $mealid,
																		'com_logo'				=> $com_logo
									));
								}else{
									array_push($meal_0,array('bokid' 			  => $prevBookid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
				 											'bokfirst_name' 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $boktablenumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
															'bokresmodedesc'		=> $bokresmodedesc,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'diningid'			  => $dinigid,
															'quoted_time'		  => $quotedtime,
															'boknotificationtype' => $boknotification,
															'resvconfirmstatus'   => $resvconfirmstatus,
															'bokconfirmstatus'	  => $bokconfirmstatus,
															'bokwaittime_start'	  => $bokwaittime_start,
															'bokfeedback_status'  => $bokfeedback_status,
															'mealid'			  => $mealid,
															'com_logo'			=> $com_logo
									));
								}
									
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;	
								$bokfeedback_status = $row->bokfeedback_status;
								$prevBookid		    = $bokid;
								$prevBokidArr[]		= $bokid;
								$mealid				= $row->rmt_id;
								$com_logo = $row->com_logo;
								if($row->Quote){
									$quotedtime			= $row->Quote;
								}else{
									$quotedtime			= '';
								}
								$boknotification	= $row->boknotification_type;
								$tablNoArr[] = $row->bktbtable_no_assigned;							
								$dinigid 			= $row->rda_diningdisplyname;
								if($row->bokbooking_timings){
									$bokwaittime_start 	= round(abs($presenttime-strtotime($row->bokbooking_date.' '.$row->bokbooking_timings)) / 60,0);
								}
							}
						}
					}
					$date = "";
					if($bokbooking_timings){
						$date = date("h:i A",strtotime($bokbooking_timings));
					}
					if($mealid){
						array_push(${'meal_'.$mealid},array('bokid' 			  => $bokid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
				 											'bokfirst_name' 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $boktablenumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
															'bokresmodedesc'	  => $bokresmodedesc,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'diningid'			  => $dinigid,
															'quoted_time'		  => $quotedtime,
															'boknotificationtype' => $boknotification,
															'resvconfirmstatus'   => $resvconfirmstatus,
															'bokconfirmstatus'	  => $bokconfirmstatus,
															'bokwaittime_start'	  => $bokwaittime_start,
															'bokfeedback_status'  => $bokfeedback_status,
															'mealid'			  => $mealid,
															'com_logo'			=> $com_logo
						));		
					}else{
						array_push($meal_0,array('bokid' 			  => $bokid,
		 							 			'bokuserid' 		  => $bokuserid,
		 							 			'bokfk_restaurant'    => $bokfk_restaurant,
	 											'bokfirst_name' 	  => $bokfirst_name,				 							 
	 											'bokparty_size' 	  => $bokparty_size,
		 							 			'bokbooking_timings'  => $date,
		 							 			'bokspecial_request'  => $bokspecial_request,
		 							 			'boktypcode'		  => $boktypcode,
		 							 			'boktablenumber'	  => $boktablenumber,
		 							 			'boktableid' 		  => $boktableid,
												'bokjointableno'	  => $bokjointableno,
		 							 			'bokresmodecode' 	  => $bokresmodecode,
												'bokresmodedesc'	  => $bokresmodedesc,
		 							 			'bokrestaurant_note'  => $bokrestaurant_note,
									 			'bokstatuscode'       => $bokstatuscode,
												'tableNoArr'		  => $tablNoArr,
												'diningid'			  => $dinigid,
												'quoted_time'		  => $quotedtime,
												'boknotificationtype' => $boknotification,
												'resvconfirmstatus'   => $resvconfirmstatus,
												'bokconfirmstatus'	  => $bokconfirmstatus,
												'bokwaittime_start'	  => $bokwaittime_start,
												'bokfeedback_status'  => $bokfeedback_status,
												'mealid'			  => $mealid,
												'com_logo'			=> $com_logo
						));	
					}	
				
				}else {
					$prevBookid         = "";
					$bokid	   	        = "";
					$bokuserid 	        = "";
					$bokfk_restaurant   = "";
					$bokfirst_name 	    = "";
					$boklast_name  	    = "";
					$bokparty_size 	    = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode 		= "";
					$boktypdesc 		= "";
					$boktablenumber 	= "";
					$bokjointableno 	= "";
					$boktableid 		= "";
					$bokresmodecode 	= "";
					$bokresmodedesc		= '';
					$bokrestaurant_note = "";
					$bokstatuscode 		= "";	
					$quotedtime			= '';
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";			
					$tablNoArr 			= array();
					$dinigid			= "";
					$prevBokidArr		= array();
					$mealid				= '';
					$bokwaittime_start = "";
					$bokfeedback_status  = "";
					
					foreach($rowset as $row)
					{
						
						if($prevBookid == ""){	
							
							$bookid			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name;						
							$boklast_name		= $row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$dinigid 			= $row->rda_diningdisplyname;
							$mealid				= $row->rmt_id;	
							$bokfeedback_status = $row->bokfeedback_status;
							$prevBokidArr[]		= $bookid;
							
							if($row->Quote){
								$quotedtime			= $row->Quote;
							}else{
								$quotedtime			= '';
							}
							$boknotification	= $row->boknotification_type;
							$prevBookid		    = $bookid;
							if($row->bokbooking_timings){
								$bokwaittime_start 	= round(abs($presenttime-strtotime($row->bokbooking_date.' '.$row->bokbooking_timings)) / 60,0);
							}					
					
						}else{
							$bookid = $row->bokid;
							if(in_array($bookid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								if($mealid){
									$bookObj = new Reservation_Model_Reservation();							
									$bookObj->setbokid($prevBookid)
											->setbokuserid($bokuserid)
											->setbokfk_restaurant($bokfk_restaurant)
											->setbokfirst_name($bokfirst_name)
											->setboklast_name($boklast_name)
											->setbokparty_size($bokparty_size)
											->setbokbooking_timings($bokbooking_timings)
											->setbokspecial_request($bokspecial_request)
											->setbokbooking_type_code($boktypcode)
											->setbokbooking_type_desc($boktypdesc)
											->setboktablenumber($boktablenumber)
											->setboktableid($boktableid)
											->setJoinTableNo($bokjointableno)
											->setbokreservation_mode_code($bokresmodecode)
											->setbokrestaurant_note($bokrestaurant_note)
											->setbokbooking_status_code($bokstatuscode)
											->setTableNoArray($tablNoArr)
											->setDiningId($dinigid)
											->setQuotedTime($quotedtime)
											->setNotificationType($boknotification)
											->setbokresv_confirm_status($resvconfirmstatus)
											->setbokbooking_confirm_status($bokconfirmstatus)
											->setReservationMeal($mealid)
											->setfeedback_status($bokfeedback_status)
											->setbokwaittime_start($bokwaittime_start);
											
									array_push(${'meal_'.$mealid},$bookObj);
								}else{
									$bookObj = new Reservation_Model_Reservation();							
									$bookObj->setbokid($prevBookid)
											->setbokuserid($bokuserid)
											->setbokfk_restaurant($bokfk_restaurant)
											->setbokfirst_name($bokfirst_name)
											->setboklast_name($boklast_name)
											->setbokparty_size($bokparty_size)
											->setbokbooking_timings($bokbooking_timings)
											->setbokspecial_request($bokspecial_request)
											->setbokbooking_type_code($boktypcode)
											->setbokbooking_type_desc($boktypdesc)
											->setboktablenumber($boktablenumber)
											->setboktableid($boktableid)
											->setJoinTableNo($bokjointableno)
											->setbokreservation_mode_code($bokresmodecode)
											->setbokrestaurant_note($bokrestaurant_note)
											->setbokbooking_status_code($bokstatuscode)
											->setTableNoArray($tablNoArr)
											->setDiningId($dinigid)
											->setQuotedTime($quotedtime)
											->setNotificationType($boknotification)
											->setbokresv_confirm_status($resvconfirmstatus)
											->setbokbooking_confirm_status($bokconfirmstatus)
											->setReservationMeal($mealid)
											->setfeedback_status($bokfeedback_status)
											->setbokwaittime_start($bokwaittime_start);
											
									array_push($meal_0,$bookObj);
								}
	
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name;						
								$boklast_name		= $row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$tablNoArr[]		= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$dinigid 			= $row->rda_diningdisplyname;
								$mealid				= $row->rmt_id;
								$bokfeedback_status = $row->bokfeedback_status;
								if($row->Quote){
									$quotedtime			= $row->Quote;
								}else{
									$quotedtime			= '';
								}
								$boknotification	= $row->boknotification_type;
								$prevBookid		    = $bookid;	
								$prevBokidArr[]		= $bookid;
								if($row->bokbooking_timings){
									$bokwaittime_start 	= round(abs($presenttime-strtotime($row->bokbooking_date.' '.$row->bokbooking_timings)) / 60,0);
								}
							}
						}							
					}
					if($mealid){
						$bookObj = new Reservation_Model_Reservation();							
						$bookObj->setbokid($bookid)
								->setbokuserid($bokuserid)
								->setbokfk_restaurant($bokfk_restaurant)
								->setbokfirst_name($bokfirst_name)
								->setboklast_name($boklast_name)
								->setbokparty_size($bokparty_size)
								->setbokbooking_timings($bokbooking_timings)
								->setbokspecial_request($bokspecial_request)
								->setbokbooking_type_code($boktypcode)
								->setbokbooking_type_desc($boktypdesc)
								->setboktablenumber($boktablenumber)
								->setboktableid($boktableid)
								->setJoinTableNo($bokjointableno)
								->setbokreservation_mode_code($bokresmodecode)
								->setbokrestaurant_note($bokrestaurant_note)
								->setbokbooking_status_code($bokstatuscode)
								->setTableNoArray($tablNoArr)
								->setDiningId($dinigid)
								->setQuotedTime($quotedtime)
								->setNotificationType($boknotification)
								->setbokresv_confirm_status($resvconfirmstatus)
								->setbokbooking_confirm_status($bokconfirmstatus)
								->setReservationMeal($mealid)
								->setfeedback_status($bokfeedback_status)
								->setbokwaittime_start($bokwaittime_start);
											
						array_push(${'meal_'.$mealid},$bookObj);
					}else{
						$bookObj = new Reservation_Model_Reservation();							
						$bookObj->setbokid($bookid)
								->setbokuserid($bokuserid)
								->setbokfk_restaurant($bokfk_restaurant)
								->setbokfirst_name($bokfirst_name)
								->setboklast_name($boklast_name)
								->setbokparty_size($bokparty_size)
								->setbokbooking_timings($bokbooking_timings)
								->setbokspecial_request($bokspecial_request)
								->setbokbooking_type_code($boktypcode)
								->setbokbooking_type_desc($boktypdesc)
								->setboktablenumber($boktablenumber)
								->setboktableid($boktableid)
								->setJoinTableNo($bokjointableno)
								->setbokreservation_mode_code($bokresmodecode)
								->setbokrestaurant_note($bokrestaurant_note)
								->setbokbooking_status_code($bokstatuscode)
								->setTableNoArray($tablNoArr)
								->setDiningId($dinigid)
								->setQuotedTime($quotedtime)
								->setNotificationType($boknotification)
								->setbokresv_confirm_status($resvconfirmstatus)
								->setbokbooking_confirm_status($bokconfirmstatus)
								->setReservationMeal($mealid)
								->setfeedback_status($bokfeedback_status)
								->setbokwaittime_start($bokwaittime_start);
											
						array_push($meal_0,$bookObj);
					}
				}
			}
			foreach($meal as $key=>$value){
				if($key != 'count' && ${'meal_' . $key}){
					$resultSet['meal_' . $key] = ${'meal_' . $key};
				}
			}
			if($meal_0){
				$resultSet['meal_0'] = $meal_0;
			}
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	

	/**
	 * @param instance of waiting list
	 * retreives all the reservations with status waiting
	 */
	public function getWaitingList(Reservation_Model_GetWaitingList $waitinglist)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$statusId = array();
			$status = $waitinglist->getBookStatus();
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($waitinglist->getRestaurantId());
			date_default_timezone_set($timezone);
			
			$presenttime = strtotime(date('Y-m-d H:i:s'));
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$waitinglist->getRestaurantId())
							  ->where('rda_status = ?',true);
							
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note','bokbooking_status_id','bokquoted_time','boknotification_type','bokresv_confirm_status','bokbooking_confirm_status','bokbooking_date','bokfeedback_status'))
					->distinct()
					->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
					->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))
					->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
					->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
					->join(array('bokstat'=>'mt.booking_status_bd'),'bokstat.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
					->joinLeft(array('quote'=>'mt.quoted_time_bd'),'quote.id = bok.bokquoted_time',array('description as Quote'))
					->where('bok.bokfk_restaurant = ?',$waitinglist->getRestaurantId())
					->where('bok.bokbooking_date = ?',$waitinglist->getDate())
					->where('bok.bokbooking_status_id IN(?)',$statusId);
			/**ADD MEAL PERIOD FILTERS **/
			$starttime = $waitinglist->getStartTime();
			$endtime = $waitinglist->getEndTime();
			if((isset($starttime))&&(isset($endtime)))
			{
				$select = $select->where('bokbooking_timings >= ? ',$starttime);
				$select = $select->where('bokbooking_timings <= ?',$endtime);
			}
			/**END ADD MEAL PERIOD FILTERS **/	 
			if($waitinglist->getBookingId()){
				$select->where('bok.bokid = ?',$waitinglist->getBookingId());
			}
			if($waitinglist->getSortOrder()){
				$order = $waitinglist->getSortOrder();
				if($order == "ASC"){
					$select->order(array('bokbooking_timings ASC'));	
				}else if($order == "DESC"){
					$select->order(array('bokbooking_timings DESC'));	
				}				
			}else{
				$select->order(array('bokbooking_timings'));
			}
			
			$rowset = $table->fetchAll($select);
			$tablNoArr = array();
			$prevBookid = "";
			if(count($rowset)>0){
				if($waitinglist->getIsAjaxCall()){
					$prevBokidArr = array();
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokresmodedesc = '';
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$quotedtime = '';
					$boknotification = '';
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";					
					$tablNoArr = array();
					$dinigid = "";
					$bokwaittime_start = "";
					$bokfeedback_status = "";
					
					foreach($rowset as $row)
					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
							$prevBokidArr[]		= $bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = strtoupper($row->bokfirst_name." ".$row->boklast_name);				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;	
							$dinigid 			= $row->rda_diningdisplyname;
							$bokfeedback_status = $row->bokfeedback_status;
							if($row->Quote){
								$quotedtime			= $row->Quote;
							}else{
								$quotedtime			= '';
							}
							$boknotification	= $row->boknotification_type;
							$prevBookid		    = $bokid;						
							if($row->bokbooking_timings){
								$bokwaittime_start 	= round(abs($presenttime-strtotime($row->bokbooking_date.' '.$row->bokbooking_timings)) / 60,0);
							}
							
						}else{
							$bokid = $row->bokid;
							
							if(in_array($bokid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}
								
								array_push($resultSet,array('bokid' 			  => $prevBookid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
				 											'bokfirst_name' 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $boktablenumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
															'bokresmodedesc'	  => $bokresmodedesc,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'diningid'			  => $dinigid,
															'quoted_time'		  => $quotedtime,
															'boknotificationtype' => $boknotification,
															'resvconfirmstatus'   => $resvconfirmstatus,
															'bokwaittime_start'	  => $bokwaittime_start,
															'bokfeedback_status'  => $bokfeedback_status,
															'bokconfirmstatus'	   => $bokconfirmstatus));
								
									
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = strtoupper($row->bokfirst_name." ".$row->boklast_name);				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;	
								$prevBookid		    = $bokid;
								$prevBokidArr[]		= $bokid;
								$bokfeedback_status  = $row->bokfeedback_status;
								if($row->Quote){
									$quotedtime			= $row->Quote;
								}else{
									$quotedtime			= '';
								}
								$boknotification	= $row->boknotification_type;
								$tablNoArr[] = $row->bktbtable_no_assigned;							
								$dinigid 			= $row->rda_diningdisplyname;
								if($row->bokbooking_timings){
									$bokwaittime_start 	= round(abs($presenttime-strtotime($row->bokbooking_date.' '.$row->bokbooking_timings)) / 60,0);
								}
							}
						}
					}
					$date = "";
					if($bokbooking_timings){
						$date = date("h:i A",strtotime($bokbooking_timings));
					}
					array_push($resultSet,array('bokid' 			  => $bokid,
		 							 			'bokuserid' 		  => $bokuserid,
		 							 			'bokfk_restaurant'    => $bokfk_restaurant,
	 											'bokfirst_name' 	  => $bokfirst_name,				 							 
	 											'bokparty_size' 	  => $bokparty_size,
		 							 			'bokbooking_timings'  => $date,
		 							 			'bokspecial_request'  => $bokspecial_request,
		 							 			'boktypcode'		  => $boktypcode,
		 							 			'boktablenumber'	  => $boktablenumber,
		 							 			'boktableid' 		  => $boktableid,
												'bokjointableno'	  => $bokjointableno,
		 							 			'bokresmodecode' 	  => $bokresmodecode,
												'bokresmodedesc'		=> $bokresmodedesc,
		 							 			'bokrestaurant_note'  => $bokrestaurant_note,
									 			'bokstatuscode'       => $bokstatuscode,
												'tableNoArr'		  => $tablNoArr,
												'diningid'			  => $dinigid,
												'quoted_time'		  => $quotedtime,
												'boknotificationtype' => $boknotification,
												'resvconfirmstatus'   => $resvconfirmstatus,
												'bokwaittime_start'	  => $bokwaittime_start,
												'bokfeedback_status'  => $bokfeedback_status,
												'bokconfirmstatus'	   => $bokconfirmstatus));			
				
				}else {
					$prevBookid         = "";
					$bokid	   	        = "";
					$bokuserid 	        = "";
					$bokfk_restaurant   = "";
					$bokfirst_name 	    = "";
					$boklast_name  	    = "";
					$bokparty_size 	    = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode 		= "";
					$boktypdesc 		= "";
					$boktablenumber 	= "";
					$bokjointableno 	= "";
					$boktableid 		= "";
					$bokresmodecode 	= "";
					$bokresmodedesc		= '';
					$bokrestaurant_note = "";
					$bokstatuscode 		= "";	
					$quotedtime			= '';
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";			
					$tablNoArr 			= array();
					$dinigid			= "";
					$prevBokidArr		= array();
					$bokwaittime_start  = "";
					$bokfeedback_status = "";
					foreach($rowset as $row)
					{
						
						if($prevBookid == ""){	
							
							$bookid			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name;						
							$boklast_name		= $row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$dinigid 			= $row->rda_diningdisplyname;	
							$prevBokidArr[]		= $bookid;
							$bokfeedback_status = $row->bokfeedback_status;
							
							if($row->Quote){
								$quotedtime			= $row->Quote;
							}else{
								$quotedtime			= '';
							}
							$boknotification	= $row->boknotification_type;
							$prevBookid		    = $bookid;
							if($row->bokbooking_timings){
								$bokwaittime_start 	= round(abs($presenttime-strtotime($row->bokbooking_date.' '.$row->bokbooking_timings)) / 60,0);
							}					
					
						}else{
							$bookid = $row->bokid;
							if(in_array($bookid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								
								$bookObj = new Reservation_Model_Reservation();							
								$bookObj->setbokid($prevBookid)
										->setbokuserid($bokuserid)
										->setbokfk_restaurant($bokfk_restaurant)
										->setbokfirst_name($bokfirst_name)
										->setboklast_name($boklast_name)
										->setbokparty_size($bokparty_size)
										->setbokbooking_timings($bokbooking_timings)
										->setbokspecial_request($bokspecial_request)
										->setbokbooking_type_code($boktypcode)
										->setbokbooking_type_desc($boktypdesc)
										->setboktablenumber($boktablenumber)
										->setboktableid($boktableid)
										->setJoinTableNo($bokjointableno)
										->setbokreservation_mode_code($bokresmodecode)
										->setbokrestaurant_note($bokrestaurant_note)
										->setbokbooking_status_code($bokstatuscode)
										->setTableNoArray($tablNoArr)
										->setDiningId($dinigid)
										->setQuotedTime($quotedtime)
										->setNotificationType($boknotification)
										->setbokresv_confirm_status($resvconfirmstatus)
										->setbokbooking_confirm_status($bokconfirmstatus)
										->setfeedback_status($bokfeedback_status)
										->setbokwaittime_start($bokwaittime_start);
										
								$resultSet[] = $bookObj;
	
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name;						
								$boklast_name		= $row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$tablNoArr[]		= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$dinigid 			= $row->rda_diningdisplyname;
								$bokfeedback_status = $row->bokfeedback_status;
								if($row->Quote){
									$quotedtime			= $row->Quote;
								}else{
									$quotedtime			= '';
								}
								$boknotification	= $row->boknotification_type;
								$prevBookid		    = $bookid;	
								$prevBokidArr[]		= $bookid;
								if($row->bokbooking_timings){
									$bokwaittime_start 	= round(abs($presenttime-strtotime($row->bokbooking_date.' '.$row->bokbooking_timings)) / 60,0);
								}
							}
						}							
					}
					$bookObj = new Reservation_Model_Reservation();							
					$bookObj->setbokid($bookid)
							->setbokuserid($bokuserid)
							->setbokfk_restaurant($bokfk_restaurant)
							->setbokfirst_name($bokfirst_name)
							->setboklast_name($boklast_name)
							->setbokparty_size($bokparty_size)
							->setbokbooking_timings($bokbooking_timings)
							->setbokspecial_request($bokspecial_request)
							->setbokbooking_type_code($boktypcode)
							->setbokbooking_type_desc($boktypdesc)
							->setboktablenumber($boktablenumber)
							->setboktableid($boktableid)
							->setJoinTableNo($bokjointableno)
							->setbokreservation_mode_code($bokresmodecode)
							->setbokrestaurant_note($bokrestaurant_note)
							->setbokbooking_status_code($bokstatuscode)
							->setTableNoArray($tablNoArr)
							->setDiningId($dinigid)
							->setQuotedTime($quotedtime)
							->setNotificationType($boknotification)
							->setbokresv_confirm_status($resvconfirmstatus)
							->setbokbooking_confirm_status($bokconfirmstatus)
							->setfeedback_status($bokfeedback_status)
							->setbokwaittime_start($bokwaittime_start);
										
					$resultSet[] = $bookObj;
				}
			}
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of overbooking list
	 * retreives all the reservations with status  overbooked
	 */
	public function getOverBookingList(Reservation_Model_GetOverBookingList $overbookinglist)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no'))
							->where('status = ?',true);
							
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note','bokbooking_status_id','bokresv_confirm_status','bokbooking_confirm_status'))
			->distinct()
			->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no'))
			->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
			->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
			->join(array('bokstat'=>'mt.booking_status_bd'),'bokstat.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
			->where('bok.bokfk_restaurant = ?',$overbookinglist->getRestaurantId())
			->where('bok.bokbooking_date = ?',$overbookinglist->getDate())
			->where('bok.bokbooking_status_id = ?',$overbookinglist->getBookStatus());
			
			if($overbookinglist->getSortOrder()){
				$order = $overbookinglist->getSortOrder();
				if($order == "ASC"){
					$select->order(array('bokbooking_timings ASC'));	
				}else if($order == "DESC"){
					$select->order(array('bokbooking_timings DESC'));	
				}				
			}else{
				$select->order(array('bokbooking_timings'));
			}


			$rowset = $table->fetchAll($select);
			$tablNoArr = array();
			$prevBookid = "";
			if(count($rowset)>0){
				if($overbookinglist->getIsAjaxCall()){
					$prevBokidArr = array();
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokresmodedesc = '';
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";					
					$tablNoArr = array();
					
					foreach($rowset as $row)

					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$bokstatuscode      = $row->bokstatuscode;
							$prevBookid		    = $bokid;	
							$prevBokidArr[]		= $bokid;
							
						}else{
							$bokid = $row->bokid;
							
							if(in_array($bokid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}
								
								array_push($resultSet,array('bokid' 			  => $prevBookid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
				 											'bokfirst_name' 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $boktablenumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
															'bokresmodedesc'		=> $bokresmodedesc,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'resvconfirmstatus'   => $resvconfirmstatus,
															'bokconfirmstatus'	   => $bokconfirmstatus));
								
									
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc 	= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$prevBookid		    = $bokid;
								$tablNoArr[] = $row->bktbtable_no_assigned;
								$prevBokidArr[]		= $bokid;
								
							}
						}
					}
					$date = "";
					if($bokbooking_timings){
						$date = date("h:i A",strtotime($bokbooking_timings));
					}
					array_push($resultSet,array('bokid' 			  => $bokid,
		 							 			'bokuserid' 		  => $bokuserid,
		 							 			'bokfk_restaurant'    => $bokfk_restaurant,
	 											'bokfirst_name' 	  => $bokfirst_name,				 							 
	 											'bokparty_size' 	  => $bokparty_size,
		 							 			'bokbooking_timings'  => $date,
		 							 			'bokspecial_request'  => $bokspecial_request,
		 							 			'boktypcode'		  => $boktypcode,
		 							 			'boktablenumber'	  => $boktablenumber,
		 							 			'boktableid' 		  => $boktableid,
												'bokjointableno'	  => $bokjointableno,
		 							 			'bokresmodecode' 	  => $bokresmodecode,
												'bokresmodedesc'		=> $row->bokresmodedesc,
		 							 			'bokrestaurant_note'  => $bokrestaurant_note,
									 			'bokstatuscode'       => $bokstatuscode,
												'tableNoArr'		  => $tablNoArr,
												'resvconfirmstatus'   => $resvconfirmstatus,
												'bokconfirmstatus'	   => $bokconfirmstatus));				
				
				}else {
					$prevBookid         = "";
					$bokid	   	        = "";
					$bokuserid 	        = "";
					$bokfk_restaurant   = "";
					$bokfirst_name 	    = "";
					$boklast_name  	    = "";
					$bokparty_size 	    = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode 		= "";
					$boktypdesc 		= "";
					$boktablenumber 	= "";
					$bokjointableno 	= "";
					$boktableid 		= "";
					$bokresmodecode 	= "";
					$bokresmodedesc		= '';
					$bokrestaurant_note = "";
					$bokstatuscode 		= "";	
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";			
					$tablNoArr 			= array();
					$prevBokidArr		= array();
					foreach($rowset as $row)
					{						
						if($prevBookid == ""){	
							
							$bookid			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name;						
							$boklast_name		= $row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$prevBookid		    = $bookid;	
							$prevBokidArr[]		= $bookid;				
					
						}else{
							$bookid = $row->bokid;
							if(in_array($bookid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								
								$bookObj = new Reservation_Model_Reservation();							
								$bookObj->setbokid($prevBookid)
										->setbokuserid($bokuserid)
										->setbokfk_restaurant($bokfk_restaurant)
										->setbokfirst_name($bokfirst_name)
										->setboklast_name($boklast_name)
										->setbokparty_size($bokparty_size)
										->setbokbooking_timings($bokbooking_timings)
										->setbokspecial_request($bokspecial_request)
										->setbokbooking_type_code($boktypcode)
										->setbokbooking_type_desc($boktypdesc)
										->setboktablenumber($boktablenumber)
										->setboktableid($boktableid)
										->setJoinTableNo($bokjointableno)
										->setbokreservation_mode_code($bokresmodecode)
										->setbokrestaurant_note($bokrestaurant_note)
										->setbokbooking_status_code($bokstatuscode)
										->setbokresv_confirm_status($resvconfirmstatus)
										->setbokbooking_confirm_status($bokconfirmstatus)
										->setTableNoArray($tablNoArr);
										
								$resultSet[] = $bookObj;
	
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name;						
								$boklast_name		= $row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$tablNoArr[]		= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$prevBookid		    = $bookid;	
								$prevBokidArr[]		= $bookid;
								
							}
						}							
					}
					$bookObj = new Reservation_Model_Reservation();							
					$bookObj->setbokid($bookid)
							->setbokuserid($bokuserid)
							->setbokfk_restaurant($bokfk_restaurant)
							->setbokfirst_name($bokfirst_name)
							->setboklast_name($boklast_name)
							->setbokparty_size($bokparty_size)
							->setbokbooking_timings($bokbooking_timings)
							->setbokspecial_request($bokspecial_request)
							->setbokbooking_type_code($boktypcode)
							->setbokbooking_type_desc($boktypdesc)
							->setboktablenumber($boktablenumber)
							->setboktableid($boktableid)
							->setJoinTableNo($bokjointableno)
							->setbokreservation_mode_code($bokresmodecode)
							->setbokrestaurant_note($bokrestaurant_note)
							->setbokbooking_status_code($bokstatuscode)
							->setbokresv_confirm_status($resvconfirmstatus)
							->setbokbooking_confirm_status($bokconfirmstatus)	
							->setTableNoArray($tablNoArr);
										
					$resultSet[] = $bookObj;
				}
			}

			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of table status
	 * retreives the table status
	 */
	public function getTableStatus(Reservation_Model_GetTableStatus $getTableStatus)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$selectBlockTable = $table->select();
			$select->setIntegrityCheck(false);
			$selectBlockTable->setIntegrityCheck(false);
			$resultSet = array();

			$statusId = array();

			$bookStatusRes = $getTableStatus->getBookStatus();
			foreach($bookStatusRes as $key=>$value){
				$statusId[] = $value->getId();
			}

			$statusIdArray = $getTableStatus->getBookStatus();
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokuserid','bokbooking_type_id','bokfeedback_status'))
				   ->joinLeft(array('bktb'=>'mt.booking_tables'),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no'))
				   ->where('bktb.status = ?',true)
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokStatusCode','description as bokStatusDesc'))
				   ->where('bok.bokfk_restaurant = ?',$getTableStatus->getRestaurantId())
				   ->where('bok.bokbooking_date = ?',$getTableStatus->getDate())
				   ->where('bok.bokbooking_status_id IN(?)',$statusId);

			$selectBlockTable->from(array('rts'=>'mt.restaurant_table_status'),array('rtsfk_tableid'))
							 ->join(array('boksts'=>'mt.booking_status_bd'),'rts.rtsfk_statusid = boksts.id',array('code as bokStatusCode','description as bokStatusDesc'))
							 ->where('rts.rtsfk_restaurantid = ?',$getTableStatus->getRestaurantId());


			$rowSet = $table->fetchAll($select);
			$rowBlockSet = $table->fetchAll($selectBlockTable);

			if($getTableStatus->getIsAjaxCall()){
				foreach($rowSet as $row){
					$bokid         = $row->bokid;
					$bokuserid     = $row->bokuserid;
					$boktableid    = $row->bktbtableid;
					$boktableno    = $row->bktbtable_no_assigned;
					$bokStatusCode = $row->bokStatusCode;
					$bokStatusDesc = $row->bokStatusDesc;
					$bokfeedback_status = $row->bokfeedback_status;
					$bookJoinTableNo = 0;
					if($row->bktb_join_table_no){
						$bookJoinTableNo = $row->bktb_join_table_no;	
					}
					
					if(array_key_exists($boktableid,$resultSet)){
						$resultSet[$boktableid] =  array($resultSet[$boktableid],array($bokStatusCode,$bookJoinTableNo,$bokid,$bokfeedback_status));
					}else{
						$resultSet[$boktableid] =  array($bokStatusCode,$bookJoinTableNo,$bokid,$bokfeedback_status);
					}
				}
				foreach($rowBlockSet as $row){
					$boktableid    = $row->rtsfk_tableid;
					$bokStatusCode = $row->bokStatusCode;
					if(array_key_exists($boktableid,$resultSet)){
						$resultSet[$boktableid] =  array($resultSet[$boktableid],$bokStatusCode);
					}else{
						$resultSet[$boktableid] =  $bokStatusCode;
					}
				}

			}else{
				foreach($rowSet as $row){
					$bookObj = new Reservation_Model_Reservation();
					$bookJoinTableNo = 0;
					if($row->bktb_join_table_no){
						$bookJoinTableNo = $row->bktb_join_table_no;	
					}
					$bookObj->setbokid($row->bokid)
							->setbokuserid($row->bokuserid)
							->setboktableid($row->bktbtableid)
							->setboktable_no_assigned($row->bktbtable_no_assigned)
							->setbokbooking_status_code($row->bokStatusCode)
							->setbokbooking_status_desc($row->bokStatusDesc)
							->setJoinTableNo($bookJoinTableNo)
							->setfeedback_status($row->bokfeedback_status);

					$resultSet[] = $bookObj;
				}
				foreach($rowBlockSet as $row){
					$bookObj = new Reservation_Model_Reservation();
					$bookObj->setboktableid($row->rtsfk_tableid)
							->setbokbooking_status_code($row->bokStatusCode);

					$resultSet[] = $bookObj;
				}
			}

			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of allocate seat
	 * function to allocate table for the reservation
	 */
	public function allocateSeat(Reservation_Model_AllocateSeat $assigntable)
	{
		try{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$db->beginTransaction();
			
			$table = $this->getDbTable();
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($assigntable->getRestId());
			date_default_timezone_set($timezone);
			
			$serverTableMap = new Server_Model_ServerTableMapDataMapper();
			$serverid = $serverTableMap->getServerIdByTableIds($assigntable->getBookTableId(),$assigntable->getDiningId());
			
			$seatStart = date('Y-m-d H:i:s');
			/* Update Booking Status */
			$set = array(
						'bokbooking_status_id'	  	=> $assigntable->getBookStatus(),
					    'bokseat_start'			  	=> $seatStart,
						'bokupdatedby_userid'		=> $assigntable->getUserId(),
						'bokupdated_date'			=> date('Y-m-d'),
						'bokupdateddatetime'		=> date("H:i:s",time()),
						'boksync_status'			=> 'C');
			if($serverid){
				$set['bok_serverid'] = $serverid;
			}			
		    $where = array('bokid = ?' 			  => $assigntable->getBookId(),
					   	   'bokfk_restaurant = ?' => $assigntable->getRestId());
			  
		    $rows_affected = $table->update($set,$where);
	
		    
		    /* Check Whether any pre allocated seats are there if yes update the status to inactive */
		    
		    $bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
		    $bookTable  = $bookTableMapper->getDbTable();
		    $tblSet = array('status' => 0);
		    $where = array('bktbfk_booking = ?' => $assigntable->getBookId());	    
		    $bookTable->update($tblSet,$where);
		    
		    /* Inserting Table no's */    
		    
		    $count = 0;		     
		    $tableIdArr = array();
		    $tableNoArr = array();
		    
		    $tableIdArr = $assigntable->getBookTableId();
		    $tableNoArr = $assigntable->getBookTableNo();
		    
		    
		    /* Check Whether Count is Greater than 1 */		    
		    $count = count($tableIdArr);		    
		    if($count > 1){
		    	
		    	/* Check the previous join table no's */
		    	
		    	$joinTableNo = "";
		    	
		    	$joinTableNo = $this->CheckJoinTableNo($assigntable->getBookId(),$assigntable->getRestId());
		    	if($joinTableNo){
		    		$joinTableNo++;
		    	}else if($joinTableNo == 0 || $joinTableNo == null){
		    		$joinTableNo++;
		    	}
		    	
		    	for($item = 0; $item < $count; $item++){
		    		$data = array('bktbfk_booking'        => $assigntable->getBookId(),
		    					  'bkt_dining_id'		  => $assigntable->getDiningId(),
		    					  'bktbtableid' 		  => $tableIdArr[$item],
		    					  'bktbtable_no_assigned' => $tableNoArr[$item],
		    					  'bktb_join_table_no'    => $joinTableNo,
		    					  'status'                => true);
		    		$id = $bookTable->insert($data);	    		
		    	}
		    }else{/* If count of table is equal to one no join table no is required */
				for($item = 0; $item < $count; $item++){
		    		$data = array('bktbfk_booking'        => $assigntable->getBookId(),
		    					  'bkt_dining_id'		  => $assigntable->getDiningId(),
		    					  'bktbtableid' 		  => $tableIdArr[$item],
		    					  'bktbtable_no_assigned' => $tableNoArr[$item],		    					  
		    					  'status'                => true);
		    		$id = $bookTable->insert($data);	    		
		    	}	    	
		    }
		    
		    $bokStat = $this->getBookingPrevStatus($assigntable->getBookId());
		    $bokLog = new Reservation_Model_BookingLog();
		    $bokLog->setbok_log_fk_booking($assigntable->getBookId())
		    ->setbok_log_booked_type($bokStat)
				    ->setbok_log_bok_status($assigntable->getBookStatus())
				    ->setbok_log_book_message('Reservation Seated')
				    ->setbok_log_updated_by($assigntable->getUserId())
				    ->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
		    $bokLogMapper = new Reservation_Model_BookingLogMapper();
		    $bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
		    
		    $db->commit();
			$status = true;
			return $status;
			
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of allocate seat
	 * function to pre-allocate the reservation 
	 */
	public function preallocateSeat(Reservation_Model_AllocateSeat $assigntable)
	{
		try{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$db->beginTransaction();
			
			$table = $this->getDbTable();
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($assigntable->getRestId());
			date_default_timezone_set($timezone);
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
			$bookTable  = $bookTableMapper->getDbTable();
			
			$serverTableMap = new Server_Model_ServerTableMapDataMapper();
			$serverid = $serverTableMap->getServerIdByTableIds($assigntable->getBookTableId(),$assigntable->getDiningId());
			
			$set = array(
						'bokupdatedby_userid'		=> $assigntable->getUserId(),
						'bokupdated_date'			=> date('Y-m-d'),
						'bokupdateddatetime'		=> date("H:i:s",time()),
						'boksync_status'			=> 'C');
			
			if($serverid){
				$set['bok_serverid'] = $serverid;
			}
			
		    $where = array('bokid = ?' 			  => $assigntable->getBookId(),
					   	   'bokfk_restaurant = ?' => $assigntable->getRestId());
			  
		    $rows_affected = $table->update($set,$where);
			
			/* Reterieve table no by table id from restaurant_tables table */
			
			$resttableMapper = new FirmManagement_Model_FirmTableDataMapper();
			$resttable = $resttableMapper->getDbTable();
			$restTableSelect = $resttable->select();
			$tableIdNumArr 	 = array();
			$restTableSelect->from($resttable,array('rstid','rsttable_number'))
							->where('rstid IN(?)',$assigntable->getBookTableId());
			$restTblRow = $resttable->fetchAll($restTableSelect);							
			
			foreach($restTblRow as $tblRow){
				$tableIdNumArr[$tblRow->rstid] = $tblRow->rsttable_number; 
			}
			
			/* Check Whether previous record exists */
			
			$bookSelect = $bookTable->select();
			$bookSelect->from($bookTable,array('COUNT(bktbid) as count'))
					   ->where('bktbfk_booking = ?',$assigntable->getBookId())
					   ->where('status = ?',true);
					   
			$rowSetCount = $bookTable->fetchAll($bookSelect);
			$count = 0;
			foreach($rowSetCount as $rowCount){
				$count = $rowCount->count;
			}						   
			if($count){
				/* Inactive the previously preAllocated records */
				
				$set = array('status' => 0);
				$where = array('bktbfk_booking = ?' => $assigntable->getBookId());
				$bookTable->update($set,$where);

				foreach($tableIdNumArr as $key=>$value){
					$data = array('bktbfk_booking'        => $assigntable->getBookId(),
								  'bkt_dining_id'		  => $assigntable->getDiningId(),
    					  	  	  'bktbtableid' 		  => $key,
    					  	  	  'bktbtable_no_assigned' => $value,		    					  
    					  	      'status'                => true);
					$id = $bookTable->insert($data);		
				}
							
			}else{
				foreach($tableIdNumArr as $key=>$value){
					$data = array('bktbfk_booking'        => $assigntable->getBookId(),
								  'bkt_dining_id'		  => $assigntable->getDiningId(),
    					  	  	  'bktbtableid' 		  => $key,
    					  	  	  'bktbtable_no_assigned' => $value,		    					  
    					  	      'status'                => true);
					$id = $bookTable->insert($data);		
				}				
			}
			$bokStat = $this->getBookingPrevStatus($assigntable->getBookId());
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($assigntable->getBookId())
					->setbok_log_booked_type($bokStat)
					->setbok_log_book_message('Pre Allocation')
					->setbok_log_updated_by($assigntable->getUserId())
					->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			$db->commit();
			$status = true;
			return $status;
			
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of reservation id
	 * function to cancel pre-allocation of the reservation
	 */
	public function CancelPreAllocation($bokid)
	{
		try{
			$table  = $this->getDbTable();
			
			$restid = $this->getRestIdByBookId($bokid);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			
			$bokset = array(
							'boksync_status'		=> 'C',
							'bok_serverid'			=> null,
							'bokupdated_date'		=> date('Y-m-d'),
							'bokupdatedby_userid'	=> $data['User_Id'],
							'bokupdateddatetime'	=> date("H:i:s",time())
						);
			$bokwhere = array('bokid = ?'=>$bokid);
			$table->update($bokset,$bokwhere);
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
			$bookTable  = $bookTableMapper->getDbTable();
			$set = array('status' => 0);
			$where = array('bktbfk_booking = ?' => $bokid);
			$bookTable->update($set,$where);
			$status = true;
			return $status;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of move party
	 * function to move the party to a different table
	 */
	public function MoveParty(Reservation_Model_MoveParty $moveParty)
	{
		try{
			$status = false;
			$db = Zend_Db_Table::getDefaultAdapter();			
			$db->beginTransaction();
			$table = $this->getDbTable();
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($moveParty->getRestId());
			date_default_timezone_set($timezone);
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			$serverTableMap = new Server_Model_ServerTableMapDataMapper();
			$serverid = $serverTableMap->getServerIdByTableIds($moveParty->getBookTableId(),$moveParty->getDiningId());
			
			$set = array(
						'bokupdated_date'			=> date('Y-m-d'),
						'bokupdateddatetime'		=> date("H:i:s",time()),
						'bokupdatedby_userid'		=> $userdata['User_Id'],
						'boksync_status'			=> 'C');
			
			if($serverid){
				$set['bok_serverid'] = $serverid;
			}
			
		    $where = array('bokid = ?' 			  => $moveParty->getBookId(),
					   	   'bokfk_restaurant = ?' => $moveParty->getRestId());
			  
		    $rows_affected = $table->update($set,$where);
			
			 /* Check Whether any reservation is multi table if yes get join table no */		
		    
		    $bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
		    $bookTable  = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select();
			
			$bookTableSelect->from($bookTable,array('bktb_join_table_no'))
			                ->where('bktbfk_booking = ?',$moveParty->getBookId())
			                ->where('status = ?',true);
            
			$row = $bookTable->fetchRow($bookTableSelect);                
            
			$joinTableNo = null;
			
			if($row->bktb_join_table_no){
				$joinTableNo = $row->bktb_join_table_no;
			}
			
			/* Update previous assigned table num records to false */
			$set   = array('status' => 0);
			$where = array('bktbfk_booking = ?' => $moveParty->getBookId());
			
			$bookTable->update($set,$where);
			
			/* Insert new table num's assigned */
			$count = 0;
			$tableIdArr = array();
			$tableNoArr = array();
			$tableIdArr = $moveParty->getBookTableId();
			$tableNoArr = $moveParty->getBookTableNo();
			$count = count($tableIdArr);			
			if($count > 1){
				/*Check joinTableNo exist or not */				
				if($joinTableNo){
					for($i=0;$i<$count;$i++){
						$data = array('bktbfk_booking'		  => $moveParty->getBookId(),
									  'bkt_dining_id'		  => $moveParty->getDiningId(),	 
							  	  	  'bktbtableid'   		  => $tableIdArr[$i],
							  	      'bktbtable_no_assigned' => $tableNoArr[$i],
							  	      'bktb_join_table_no'	  => $joinTableNo,
							  	      'status'				  => true);				
				
						$bookTable->insert($data);				
					}
				}else{
					
					$joinTableNo = $this->CheckJoinTableNo($moveParty->getBookId(),$moveParty->getRestId());
		    		if($joinTableNo){
		    			$joinTableNo++;
		    		}else if($joinTableNo == 0 || $joinTableNo == null){
		    			$joinTableNo++;
		    		}
					for($i=0;$i<$count;$i++){
						$data = array('bktbfk_booking'		  => $moveParty->getBookId(),
									  'bkt_dining_id'		  => $moveParty->getDiningId(),	 
							  	  	  'bktbtableid'   		  => $tableIdArr[$i],
							  	      'bktbtable_no_assigned' => $tableNoArr[$i],
							  	      'bktb_join_table_no'	  => $joinTableNo,
							  	      'status'				  => true);				
				
						$bookTable->insert($data);				
					}	
				}
					
			}else{
				for($i=0;$i<$count;$i++){
					$data = array('bktbfk_booking'		  => $moveParty->getBookId(),
								  'bkt_dining_id'		  => $moveParty->getDiningId(),	 
							  	  'bktbtableid'   		  => $tableIdArr[$i],
							  	  'bktbtable_no_assigned' => $tableNoArr[$i],							  	  
							  	  'status'				  => true);				
				
					$bookTable->insert($data);				
				}
			}
			
			$bokStat = $this->getBookingPrevStatus($moveParty->getBookId());
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($moveParty->getBookId())
					->setbok_log_booked_type($bokStat)
					->setbok_log_book_message('Move Party')
					->setbok_log_updated_by($userdata['User_Id'])
					->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			
			$db->commit();
			$status = true;
			return $status;
			
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of allocate seat
	 * function to change the table status of the reservation seated
	 */
	public function ChangeTableStatus(Reservation_Model_AllocateSeat $bookingObj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			$status = false;
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($bookingObj->getRestId());
			date_default_timezone_set($timezone);
			
			if($bookingObj->getBookStatusCode() == "RSD"){						
				$table = $this->getDbTable();		
				/* Update reservation status */
				$set 	= array(
								'bokbooking_status_id'	=> $bookingObj->getBookStatus(),
								'bokupdated_date'		=> date('Y-m-d'),
								'bokupdateddatetime'	=> date("H:i:s",time()),
								'boksync_status'		=> 'C'
							 );
				if($bookingObj->getUserId())
				{
					$set['bokupdatedby_userid'] = $bookingObj->getUserId();
				}
				$where 	= array('bokid = ?' => $bookingObj->getBookId(),'bokfk_restaurant = ?'=> $bookingObj->getRestId());

				$rows_affected = $table->update($set,$where);
				
				/* Inactivate the tables allocated for reservation */
				$bokTblMapper = new Reservation_Model_ReservationTableMapper();
				$bokTbl = $bokTblMapper->getDbTable();
				
				$tblSet = array('status' => 0);
				$where  = array('bktbfk_booking = ?'=>$bookingObj->getBookId());
				
				$bokTbl->update($tblSet,$where);
							   
				$status = true;
			}else if($bookingObj->getBookStatusCode() == "WIN"){
				$table  = $this->getDbTable();
				$set 	= array(
								'bokbooking_status_id'	=> 10,
								'bokupdated_date'		=> date('Y-m-d'),
								'bokupdateddatetime'	=> date("H:i:s",time()),
								'boksync_status'		=> 'C'
							   );
				if($bookingObj->getUserId())
				{
					$set['bokupdatedby_userid'] = $bookingObj->getUserId();
				}							   
				if($bookingObj->getRestId()){
					$where 	= array('bokid = ?' => $bookingObj->getBookId(),'bokfk_restaurant = ?'=> $bookingObj->getRestId());	
				}else{
					$where 	= array('bokid = ?' => $bookingObj->getBookId());
				}				

				$rows_affected = $table->update($set,$where);

				if($rows_affected){
					$status = true;
				}		
			}else if($bookingObj->getBookStatusCode() == "COM"){
				$table  = $this->getDbTable();
				$set 	= array(
									'bokbooking_status_id'	=> $bookingObj->getBookStatus(),
									'bokupdated_date'		=> date('Y-m-d'),
									'bokupdateddatetime'	=> date("H:i:s",time()),
									'bokseat_end'			=> date('Y-m-d H:i:s'), 
									'boksync_status'		=> 'C'
								);
				if($bookingObj->getUserId())
				{
					$set['bokupdatedby_userid'] = $bookingObj->getUserId();
				}
				if($bookingObj->getRestId()){
					$where 	= array('bokid = ?' => $bookingObj->getBookId(),'bokfk_restaurant = ?'=> $bookingObj->getRestId());	
				}else{
					$where 	= array('bokid = ?' => $bookingObj->getBookId());
				}				

				$rows_affected = $table->update($set,$where);

				if($rows_affected){
					$status = true;
				}		
			}else{				
				$table  = $this->getDbTable();
				$set 	= array(
									'bokbooking_status_id'	=> $bookingObj->getBookStatus(),
									'bokupdated_date'		=> date('Y-m-d'),
									'bokupdateddatetime'	=> date("H:i:s",time()),
									'boksync_status'		=> 'C'
								);
				if($bookingObj->getUserId())
				{
					$set['bokupdatedby_userid'] = $bookingObj->getUserId();
				}
				if($bookingObj->getRestId()){
					$where 	= array('bokid = ?' => $bookingObj->getBookId(),'bokfk_restaurant = ?'=> $bookingObj->getRestId());	
				}else{
					$where 	= array('bokid = ?' => $bookingObj->getBookId());
				}				

				$rows_affected = $table->update($set,$where);
			
				if($rows_affected){
					if($bookingObj->getBookStatus() == 14 && $bookingObj->getContactid()){
						$groupUsersDataMapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
						$groupUsersDataMapper->updateGuestReservationCount($bookingObj->getContactid(), 'NOS','');
					}
					$status = true;
				}			
			}
			if($rows_affected && $status){
				$statusArr[] = $bookingObj->getBookStatusCode();
				$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
				$bookStatusRes = $bookStatusMapper->GetBookingStatusByCode($statusArr);
				$bookStatusRes = $bookStatusRes[$bookingObj->getBookStatusCode()];
				
				$bokStat = $this->getBookingPrevStatus($bookingObj->getBookId());
				$bokLog = new Reservation_Model_BookingLog();
				$bokLog->setbok_log_fk_booking($bookingObj->getBookId())
						->setbok_log_booked_type($bokStat)
						->setbok_log_bok_status($bookingObj->getBookStatus())
						->setbok_log_book_message($bookStatusRes->getDescription())
						->setbok_log_updated_by($bookingObj->getUserId())
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
				$bokLogMapper = new Reservation_Model_BookingLogMapper();
				$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			}
			$db->commit();
			return $status;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of booking
	 * function to save the reservation made by the restaurant authorities 
	 */
	public function saveMakeReservationDetails(Reservation_Model_Reservation $bookdetails,$status,$formdata = array())
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$userid = null;
			if($bookdetails->getbokuserid()){
				$userid = $bookdetails->getbokuserid();
			}else{
				$storage = new Zend_Auth_Storage_Session();
				$data = $storage->read();
				if(isset($data['User_Id'])){
					$userid = $data['User_Id'];
				}else{
					$userid = null;
				}
			}
			//echo '<pre>'; print_r($formdata); exit;
			$inventId = null;
			if($bookdetails->getInventoryId()){
				$inventId = $bookdetails->getInventoryId();
			}
			$guestid = '';
			$db->beginTransaction();
			$restservice = new Application_Service_Firm();
			if($status == 'waiting' && $formdata['waitnumber'] != ""){
      //echo '<pre>'; echo 'rr'; exit;
				$formdata['waitcontactInfo'] = '';
				$guestid = $restservice->AddWaitingCustomerContact($formdata);
			}else if($status == 'walkin'){
				$status = 'reserv';
				if($formdata->winfirstName != '' && $formdata->winlastName != ''){
					if($formdata->winemail != '' || $formdata->winnumber != ''){
						$formdata->setParam('wincontactInfo','');
						$guestid = $restservice->AddWalkinCustomerContact($formdata);
					}
				}
			}else{
				$guestid = $restservice->AddCustomerContact($formdata,'');
			}
			//echo '<pre>'; echo "r-2"; exit;
			$table  = $this->getDbTable();
			$bookId = '';
			$data = array(
				  'bokfk_restaurant' 			=> $bookdetails->getbokfk_restaurant(), 
				  'bokemail'		 	 		=> $bookdetails->getbokemail(),
				  'bokfirst_name' 		 		=> $bookdetails->getbokfirst_name(),
				  'boklast_name' 		 		=> $bookdetails->getboklast_name(),
				  'bokparty_size' 		 		=> $bookdetails->getbokparty_size(), 
				  'bokphone' 			 		=> str_replace("-","",$bookdetails->getbokphone()),
				  'bokrestaurant_note' 	 		=> $bookdetails->getbokspecial_request(),
		      	  'bokbooking_date'		 		=> $bookdetails->getbokbooking_date(),
				  'bokbooking_timings' 	 		=> $bookdetails->getbokbooking_timings(),
				  'bokbooking_status_id' 		=> $bookdetails->getbokbooking_status_id(),
				  'bokbooked_status'			=> $bookdetails->getbokbooking_status(),
				  'bokbooking_made_on' 	 		=> $bookdetails->getbokbooking_made_on(),
				  'bokbooking_made_time'   		=> $bookdetails->getBookingMadeTime(), 
				  'bokuserid' 					=> $userid,			  
				  'bokbooking_type_id'   		=> $bookdetails->getbokbooking_type_id(),
				  'bokcontact_information'  	=> $bookdetails->getbokcontact_information(),
				  'bokreservation_mode_id'  	=> $bookdetails->getbokreservation_mode_id(),
				  'boknotification_type'		=> $bookdetails->getNotificationType(),
				  //'bokrestaurant_note'	 		=> $bookdetails->getbokrestaurant_note(),
				  'bokbooking_phrase'			=> $bookdetails->getbokbookingphrase(),
			      'bokcountrycode' 				=> $bookdetails->getbokcountry_code()
			);
			if($guestid){
				$data['bok_contactid'] = $guestid;
			}
			if($bookdetails->getbok_restsch_setting_type() != 'SAC'){
				$data['bokfk_rest_sch_table'] = $inventId;
			}
			if($bookdetails->getbok_restsch_setting_id()){
				$data['bok_restsch_setting_id'] = $bookdetails->getbok_restsch_setting_id();
			}
			if($bookdetails->getbokbooking_type_code() == 'PAID'){
				if($bookdetails->getblockStatus()){
					$data['bokbooking_block_status'] = $bookdetails->getblockStatus();
					$data['bokbooking_block_amount'] = $bookdetails->getblockAmount();
					$data['bokbooking_block_desc'] = $bookdetails->getblockDescription();
				}
			}
			if($bookdetails->getbokbooking_user_initials()){
//				$data['bokbooking_user_initials'] = $bookdetails->getbokbooking_user_initials();
				$data['bokbooking_user_initials'] = null;
			}
			if($bookdetails->getbokcreatedby()){
				$data['bokcreatedby'] = $bookdetails->getbokcreatedby();
			}
			if($bookdetails->getbokseat_start()){
				$data['bokseat_start'] = $bookdetails->getbokseat_start();
			}
			if($status == 'waiting'){
				$data['bokquoted_time'] = $bookdetails->getQuotedTime();
			}
			//echo '<pre>'; echo "r-3";
			/* Retrieve schedule id by inventory id */
			$schIdRow = "";
			if($bookdetails->getInventoryId() && $bookdetails->getInventoryId() != ''){
				$restSchTblMapperObj = new FirmManagement_Model_FirmScheduleTableDataMapper();
				
				if($bookdetails->getbok_restsch_setting_type() == 'SAC'){
					$invArr = explode(',',$bookdetails->getInventoryId());
					$restSchTbl = $restSchTblMapperObj->getDbTable();
					$restSchTblSelect = $restSchTbl->select();
	
					$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule'))
									 ->where('rstid IN (?)',$invArr);
									 
				    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);
				}else{
					$restSchTbl = $restSchTblMapperObj->getDbTable();
					$restSchTblSelect = $restSchTbl->select();
	
					$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule'))
									 ->where('rstid = ?',$bookdetails->getInventoryId());
									 
				    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);
				}
			}
			//echo '<pre>'; echo "r-4";
			if($bookdetails->getRescheduleCode() && $bookdetails->getRescheduleCode()== 'RES'){
				/* Chech the stautus of rescheduled reservation and if it is waiting list do not decrement the count. */
				$resvstatus = "";
				
				$statusSelect = $table->select();
				$statusSelect->setIntegrityCheck(false);
				$statusSelect->from(array('bok'=>'mt.booking'),array('bokid'))
							 ->join(array('boksts'=>'mt.booking_status_bd'),'boksts.id = bok.bokbooking_status_id',array('code as bookcode'))
							 ->where('bok.bokid = ?',$bookdetails->getbokid());
				$bookStatusRow = $table->fetchRow($statusSelect);
				$resvstatus = $bookStatusRow->bookcode;
				
				$timezone = "";
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$timezone = $mapper->GetRestaurantTimeZone($bookdetails->getbokfk_restaurant());
				date_default_timezone_set($timezone);
				
				$set = array('bokbooking_status_id' 	=>  $bookdetails->getRessch_Status_Id(),
							 'bokrestaurant_note'   	=>  $bookdetails->getbokrestaurant_note(),
							 'bokupdated_date'			=>  date('Y-m-d'),
							 'bokupdateddatetime'		=>  date("H:i:s",time()),
						     'bokupdatedby_userid'		=>  $userid,
							 'boksync_status'			=>  'C');

				$where = $db->quoteInto('bokid = ?',$bookdetails->getbokid());
				$row_affected = $table->update($set,$where);

				$result = $table->insert($data);
				/* Decrement the booking count upon reschedule start */
				if($resvstatus != "" && $resvstatus != "WAL" && $bookdetails->getbokbooking_status_code() != 'OVB'){
					if($bookdetails->getbok_restsch_setting_type() == 'SAC'){
						$status = $this->ResetAccumulativeBookingCount($bookdetails);
					}else{
						$status = $this->ResetBookingCount($bookdetails);
					}
				}
				//echo '<pre>'; echo "r-5";
			}else{
				$result = $table->insert($data);
				$bookdetails->setbokid($result);
				if($guestid){
					$groupUsersDataMapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
					$groupUsersDataMapper->updateGuestReservationCount($guestid, 'RSD',$bookdetails->getbokreservation_mode_id());
				}
				//echo '<pre>'; echo "r-6";
			}
			
			if($bookdetails->getbokoptions()){
				$bokoptionsmapper = new Reservation_Model_ReservationOptionsMapDataMapper();
				$bokoptionsmapper->saveBookingOptions($result, $bookdetails->getbokoptions());
			}
			
			if($status == 'waiting'){
				$quote = new Reservation_Model_ReservationWaitingQuoteMap();
				$quote->setBookId($result);
				$quote->setQuoteId($bookdetails->getQuotedTime());
				$quoteMapper = new Reservation_Model_ReservationWaitingQuoteMapDataMapper();
				$quoteResult = $quoteMapper->InsertQuotedTimes($quote);
			}
			//echo '<pre>'; echo "r-7";
			if($schIdRow){
				
				if($bookdetails->getbok_restsch_setting_type() == 'SAC'){
					$bookAccMapper = new Reservation_Model_ReservationAccumulativeInventoryMapper();
					$accTable = $bookAccMapper->getDbTable();
					$invArr = explode(',',$bookdetails->getInventoryId());
					$tableSizeArr = explode(',',$bookdetails->getTableSize());
					$nooftablesArr = explode(',',$bookdetails->getNoOfTables());
					foreach($tableSizeArr as $key=>$value){						
						$accData = array(
										'bai_fk_booking'	=>	$result,
  										'bai_inventory'		=>	$invArr[$key],
  										'bai_status'		=>	'T'
						);
						$accResult = $accTable->insert($accData); 
						$select = $table->select();
						$select->setIntegrityCheck(false);
						$select->from(array('btc'=>'mt.booking_time_count'),array('count(btcid) as countbtc','btcid','btcbooking_count','btc.boktablesize'))
						->where('btc.btcfkres_id = ?',$bookdetails->getbokfk_restaurant())
						->where('btc.btcbooking_timings = ?',$bookdetails->getbokbooking_timings())
						->where('btc.btcbooking_date = ?',$bookdetails->getbokbooking_date())
						->where('btc.boktablesize = ?',$value);
						if($schIdRow){
							$select->where('btc.btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
						}				   
					    $select->group(array('btcid','btcbooking_count','btc.boktablesize'));
			
						$bookingCountId = 0;
						$bookingId= 0;
						$bookingCount = 0;
			
						$row = $table->fetchRow($select);
			
						$bookingCountId = $row['countbtc'];
						$bookingId = $row['btcid'];
						$bookingCount = (int)$row['btcbooking_count'];
			
						$mapper = new Reservation_Model_ReservationCountDataMapper();
						if($bookingCountId != 0){
								
							$bookingCount++;
							$set = array('btcbooking_count' => $bookingCount);
							$where = array('btcid = ?' => $bookingId,
										   'btcfk_restaurant_schedule = ?' => $schIdRow->rstfk_restaurant_schedule);
							
							//$where = $db->quoteInto('btcid = ?',);
			
							$mapper->getDbTable()->update($set,$where);
								
						}else{
							$data = array(
									'btcbooking_count'    => 1,
									'btcbooking_timings'  => $bookdetails->getbokbooking_timings(),
							        'btcbooking_date' 	  => $bookdetails->getbokbooking_date(),
			 						'btcfkres_id'    	  => $bookdetails->getbokfk_restaurant(),
									'boktablesize'		  => $value,
						  			'boknooftables'		  => $nooftablesArr[$key],
									'btcfk_restaurant_schedule'	=> $schIdRow->rstfk_restaurant_schedule
							);
							$mapper->getDbTable()->insert($data);
						}
					}
				}else{
					$bookCountMapper = new Reservation_Model_ReservationCountDataMapper();
					$bookCountTable = $bookCountMapper->getDbTable();
					$bookCountSelect = $bookCountTable->select();
	
					$bookCountSelect->from($bookCountTable,array('btcid','btcbooking_count','boktablesize'))
					->where('btcfkres_id = ?',$bookdetails->getbokfk_restaurant())
					->where('btcbooking_timings = ?',$bookdetails->getbokbooking_timings())
					->where('btcbooking_date = ?',$bookdetails->getbokbooking_date())
									->where('boktablesize = ?',$bookdetails->getTableSize())
									->where('btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
	
	
					$bookingCountId = 0;
					$bookingId= 0;
					$bookingCount = 0;
	
					$bookCountRow = $bookCountTable->fetchRow($bookCountSelect);
	
					if($bookCountRow){
						$bookingId = $bookCountRow->btcid;
						$bookingCount = $bookCountRow->btcbooking_count;
	
						$bookingCount++;
						$set = array('btcbooking_count' => $bookingCount);
						$where = array('btcid = ?'=> $bookingId,
									   'btcfk_restaurant_schedule = ?' => $schIdRow->rstfk_restaurant_schedule);
	//					$where = $db->quoteInto('btcid = ?',$bookingId);
	
						$bookCountMapper->getDbTable()->update($set,$where);
	
					}else{
						$data = array(
							'btcbooking_count'    => 1,
							'btcbooking_timings'  => $bookdetails->getbokbooking_timings(),
					        'btcbooking_date' 	  => $bookdetails->getbokbooking_date(),
	 						'btcfkres_id'    	  => $bookdetails->getbokfk_restaurant(),
							'boktablesize'		  => $bookdetails->getTableSize(),
				  			'boknooftables'		  => $bookdetails->getNoOfTables(),
							'btcfk_restaurant_schedule' => $schIdRow->rstfk_restaurant_schedule	
						);
						$bookCountMapper->getDbTable()->insert($data);
					}
				}
			}
			$countMapper = new Reservation_Model_ReservationsCountDataMapper();
			$countResult = $countMapper->saveReservationsCount($bookdetails->getbokfk_restaurant(),$bookdetails->getbokparty_size());
			
			$bokStat = $this->getBookingPrevStatus($bookdetails->getbokid());
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($bookdetails->getbokid())
					->setbok_log_booked_type($bokStat)
					->setbok_log_bok_status($bookdetails->getbokbooking_status_id())
					->setbok_log_book_message('Reservation Done')
					->setbok_log_updated_by($userid)
					->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			$db->commit();
			return $result;

		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of reservation list
	 * function to get the reservations list
	 */
	public function ReservationList(Reservation_Model_ReservationList $obj)
	{
		try{
			/* Getting day from the given date start */

			$dateSplit = explode("-",$obj->getDate());
			$weekday = strtolower(date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2])));
			$date = date("Y-m-d", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));

			/* Getting day from the given date start */

			$resId = $obj->getRestaurantId();
			$schMapper = new FirmManagement_Model_FirmScheduleDataMapper();

			$schtable  = $schMapper->getDbTable();
			$schSelect = $schtable->select();

			/* SetIntegrityCheck should be set to false in order to do joins with other tables */
			$schSelect->setIntegrityCheck(false);

			/* Reteriving the schedule count */
			$count = null;
			$count = $this->ReservationListCount($obj);

			$offset = 0;
			$limit = 9;

			/* Reteriving the previous offset */
			if($obj->getoffset() && $obj->getoffset() != 0){
				$offset = $obj->getoffset();
			}
			/* If next link or arrow is clicked this if condition is executed. */
			if($obj->getevent() == 'next'){

				if($count >= $offset + 9){

					$offset = $offset + 9;

					if($offset + 9 >= $count){
						$result['next'] = false;
					}else{
						$result['next'] = true;
					}
				}
				if($offset >= 9){
					$result['prev'] = true;
				}

			}/* if previous link is clicked this if condition is executed. */
			elseif($obj->getevent() == 'prev'){

				$offset = $offset - 9;

				if($offset == 0 || $offset < 9){
					$result['prev'] = false;
				}else{
					$result['prev'] = true;
				}
				if($count > $offset){

					$result['next'] = true;
				}

			}/* This else part is executed on first call of this function. */
			else{
				if($count > 9){
					/* if count is greater than 9 show the next link */
					$result['next'] = true;
					$result['prev'] = false;
				}else{
					/* if count is less than 9 then no links are shown. */
					$result['next'] = false;
					$result['prev'] = false;
				}

			}

			/* the offset value is stored and send to phtml page and
			 * upon next or previous action the increment or
			 * decrement of offset is done on this value */
			$result['offset'] = $offset;
			/* Check Whether the selected date contains any special schedule */
			
			$restSpecialSchObject = new FirmManagement_Model_FirmSpecialSchedule();
			$restSpecialSchObject->setrsesfk_restaurant($resId);
			$restSpecialSchObject->setrseseventdate($date);
			
			$restSplSchMapperObj = new FirmManagement_Model_FirmSpecialScheduleMapper();			
			$splSchRow = $restSplSchMapperObj->CheckSpecialScheduleAvilable($restSpecialSchObject);
			$schSelect->from(array('rss'=>'mt.restaurant_schedule'),array('rssid','rssstart_time','rssend_time'))
					  ->where('rss.rssday_of_week = ?',$weekday)
					  ->where('rss.rssfk_restaurant = ?',$resId)
					  ->where('rss.rssstatus = ?',true);					  
			if($splSchRow){
				$schSelect->where('rss.rssscheduletype_id = ?',2);
				$schSelect->where('rss.rssfk_special_event_schedule = ?',$splSchRow->rsesid);	
			}else{
				$schSelect->where('rss.rssscheduletype_id = ?',1);
			}
									  
			$schSelect->order(array('rss.rssstart_time'));
			$schSelect->limit($limit,$offset);			
			$schRowset = $schtable->fetchAll($schSelect);
			$timeArray = array();
			foreach($schRowset as $schRow){
				$timeArray[] = $schRow->rssstart_time;
			}
			$timeArrayCount = null;
			$timeArrayCount = count($timeArray);
			$timeBlockArr = array();
			if($timeArrayCount){
				/* Reteriving Bookings */
				$startTime = null;
				foreach($timeArray as $time){
					
					$bookSeatsMapper = new Reservation_Model_ReservationTableMapper();
					$bookSeatsTable  = $bookSeatsMapper->getDbTable();
					$bookSeatsSelect = $bookSeatsTable->select();
			
					$bookSeatsSelect->from($bookSeatsTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no'))
									->where('status = ?',true);
									
					$startTime = $time;
					$bookTable = $this->getDbTable();
					$bookSelect = $bookTable->select();
					$bookSelect->setIntegrityCheck(false);
					$bookSelect->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note'))
							   ->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
							   ->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
							   ->join(array('bokstbd'=>'mt.booking_status_bd'),'bokstbd.id = bok.bokbooking_status_id',array('code as bokstatuscode'))
							   ->joinLeft(array('bktb'=>$bookSeatsSelect),' bok.bokid = bktb.bktbfk_booking',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no'))

							   ->where('bok.bokfk_restaurant = ?',$obj->getRestaurantId())
							   ->where('bok.bokbooking_date = ?',$date)
							   ->where('bok.bokbooking_timings = ?',$startTime)
							   ->where('bokstbd.code <> ?','COM')
							   ->where('bokstbd.code <> ?','RES')
							   ->where('bokstbd.code <> ?','CAN')
							   ->order(array('bok.bokbooking_timings','bok.bokid'));

					$bookRowset = $bookTable->fetchAll($bookSelect);
					$bookingArr = array();
					
					$bokId 	   		  	   = "";
					$prevBokId			   = "";
					$bokuserid 		  	   = "";
					$bokfk_restaurant 	   = "";
					$bokfirst_name	  	   = "";
					$boklast_name	  	   = "";
					$bokparty_size	  	   = "";
					$bokbooking_timings    = "";
					$bokspecial_request    = "";
					$bokspecial_reques	   = "";
					$boktypcode			   = "";
					$boktypdesc			   = "";
					$bokresmodecode		   = "";
					$bktbtable_no_assigned = "";
					$bktbtableid		   = "";
					$bktb_join_table_no	   = "";
					$bokstatuscode		   = "";
					$bokrestaurant_note    = ""; 
					$tableNoArr 		   = array();
					
					foreach($bookRowset as $row){
						if($prevBokId == ""){
						   $bokId 		          = $row->bokid;
						   $prevBokId			  = $row->bokid;
						   $bokuserid 	          = $row->bokuserid;
						   $bokfk_restaurant      = $row->bokfk_restaurant;
						   $bokfirst_name         = $row->bokfirst_name;
						   $boklast_name          = $row->boklast_name;
						   $bokparty_size	      = $row->bokparty_size;
						   $bokbooking_timings    = $row->bokbooking_timings;
						   $bokspecial_request    = $row->bokspecial_request;
						   $boktypcode 		      = $row->boktypcode;
						   $boktypdesc		      = $row->boktypdesc;
						   $bokresmodecode	      = $row->bokresmodecode;
						   $bktbtable_no_assigned = $row->bktbtable_no_assigned;
						   $tableNoArr[]		  = $row->bktbtable_no_assigned;
						   $bktbtableid			  = $row->bktbtableid;
						   $bktb_join_table_no	  = $row->bktb_join_table_no;
						   $bokstatuscode		  = $row->bokstatuscode;
						   $bokrestaurant_note    = $row->bokrestaurant_note;
						   
						}else {
							$bokId = $row->bokid;
							if($prevBokId == $bokId){
								$tableNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$implodedString = "";
								$implodedString = implode(',',$tableNoArr);
								$bookObj = new Reservation_Model_Reservation();
								$bookObj->setbokid($prevBokId)
										->setbokuserid($bokuserid)
										->setbokfk_restaurant($bokfk_restaurant)
										->setbokfirst_name($bokfirst_name)
										->setboklast_name($boklast_name)
										->setbokparty_size($bokparty_size)
										->setbokbooking_timings($bokbooking_timings)
										->setbokspecial_request($bokspecial_request)
										->setbokbooking_type_code($boktypcode)
										->setbokbooking_type_desc($boktypdesc)
										->setbokreservation_mode_code($bokresmodecode)
										->setboktablenumber($bktbtable_no_assigned)
										->setboktableid($bktbtableid)
										->setJoinTableNo($bktb_join_table_no)
										->setbokbooking_status_code($bokstatuscode)
										->setbokrestaurant_note($bokrestaurant_note)
										->setTableNoArray($implodedString);
								$bookingArr[] = $bookObj;
								
								$tableNoArr = null;
							    $prevBokId			   = $bokId;
							    $bokuserid 	           = $row->bokuserid;
							    $bokfk_restaurant      = $row->bokfk_restaurant;
							    $bokfirst_name         = $row->bokfirst_name;
							    $boklast_name          = $row->boklast_name;
							    $bokparty_size	       = $row->bokparty_size;
							    $bokbooking_timings    = $row->bokbooking_timings;
							    $bokspecial_request    = $row->bokspecial_request;
							    $boktypcode 		   = $row->boktypcode;
							    $boktypdesc		       = $row->boktypdesc;
							    $bokresmodecode	       = $row->bokresmodecode;
							    $bktbtable_no_assigned = $row->bktbtable_no_assigned;
							    $tableNoArr[]		   = $row->bktbtable_no_assigned;
							    $bktbtableid		   = $row->bktbtableid;
							    $bktb_join_table_no	   = $row->bktb_join_table_no;
							    $bokstatuscode		   = $row->bokstatuscode;
							    $bokrestaurant_note    = $row->bokrestaurant_note;
							    
							}							
						}					
					}
					$implodedString = "";
					$implodedString = implode(',',$tableNoArr);
					$bookObj = new Reservation_Model_Reservation();
					$bookObj->setbokid($bokId)
							->setbokuserid($bokuserid)
							->setbokfk_restaurant($bokfk_restaurant)
							->setbokfirst_name($bokfirst_name)
							->setboklast_name($boklast_name)
							->setbokparty_size($bokparty_size)
							->setbokbooking_timings($bokbooking_timings)
							->setbokspecial_request($bokspecial_request)
							->setbokbooking_type_code($boktypcode)
							->setbokbooking_type_desc($boktypdesc)
							->setbokreservation_mode_code($bokresmodecode)
							->setboktablenumber($bktbtable_no_assigned)
							->setboktableid($bktbtableid)
							->setJoinTableNo($bktb_join_table_no)
							->setbokbooking_status_code($bokstatuscode)
							->setbokrestaurant_note($bokrestaurant_note)
							->setTableNoArray($implodedString);
					$bookingArr[] = $bookObj;

					$time_12hr_format = explode(":",$startTime);
					$s = mktime($time_12hr_format[0],$time_12hr_format[1],$time_12hr_format[2],0,0,0);
					$timeBlockArr[date("h:i A",$s)]['slot'] = $bookingArr;
					$result['timeBlockArr'] = $timeBlockArr;
				}

			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of reservation list
	 * function to get the reservation list count
	 */
	public function ReservationListCount(Reservation_Model_ReservationList $obj)
	{
		try{
			$count = 0;
			$dateSplit = explode("-",$obj->getDate());
			$weekday = strtolower(date("D", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2])));
			$date = date("Y-m-d", mktime(0,0,0,$dateSplit[0],$dateSplit[1],$dateSplit[2]));
			$resId = $obj->getRestaurantId();
			$schMapper = new FirmManagement_Model_FirmScheduleDataMapper();
			$schtable  = $schMapper->getDbTable();
			$schSelect = $schtable->select();
			$schSelect->setIntegrityCheck(false);

			$schSelect->from(array('rss'=>'mt.restaurant_schedule'),array('count(rssid) as schedule_count'))
			->where('rss.rssday_of_week = ?',$weekday)
			->where('rss.rssfk_restaurant = ?',$resId);

			$rowset = $schtable->fetchAll($schSelect);
			foreach($rowset as $row){
				$count = $row->schedule_count;
			}

			return $count;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of reservation note
	 * function to add the reservation note
	 */
	public function AddReservationNote(Reservation_Model_AddReservationNote $bookingObj)
	{
		try{
			$table  = $this->getDbTable();
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($bookingObj->getResId());
			date_default_timezone_set($timezone);
			
			$set 	= array(
								'bokrestaurant_note'		=> $bookingObj->getNote(),
								'bokspecial_request'		=> $bookingObj->getguestNote(),
								'bokupdated_date'			=> date('Y-m-d'),
								'bokupdateddatetime'		=> date("H:i:s",time()),
								'boksync_status'			=> 'C'
						   );
			$where 	= array('bokid = ?' => $bookingObj->getBookingId(),'bokfk_restaurant = ?'=> $bookingObj->getResId());

			$rows_affected = $table->update($set,$where);
			
			$bokStat = $this->getBookingPrevStatus($bookingObj->getBookingId());
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($bookingObj->getBookingId())
					->setbok_log_booked_type($bokStat)
					->setbok_log_book_message('Reservation note added')
					->setbok_log_updated_by($bookingObj->getUserId())
					->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);

			if($rows_affected){
				return true;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of reservation report
	 * retreives the reservation report based on the search
	 */
	public function ReservationReport(Reservation_Model_GetReservationReport $reservationreport,$offset = null,$bookStatusRes)
	{
		try{
			$statusId = array();
			$status = $bookStatusRes;
			foreach($status as $key=>$value){
				$statusId[$value->getId()] = $value->getId();
			}
			
			$table = $this->getDbTable();
			$limit = 100;
			$select = $table->select();
			$select->setIntegrityCheck(false);
      /* Code added by Pratik */
      if($reservationreport->getRestaurantId()){
			  $rest_id = $reservationreport->getRestaurantId();
      }else{
        $rest_id = 0;
      }
      /*---*/
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no'))
							->where('status = ?',true);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokuserid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokbooking_made_time','bokspecial_request','bokbooking_status_id','bokrestaurant_note','bokcreatedby','bokcountrycode','bokupdatedby_userid','bokupdated_date'))
				   ->where('bok.bokfk_restaurant = ?',$rest_id)
				   ->joinLeft(array('restowner'=>'mt.restaurant_owner'),'restowner.rsofk_user = bok.bokuserid',array('rsofirst_name','rsolast_name','rsophone'))
				   ->joinLeft(array('resuser'=>'mt.restaurant_user'), 'bok.bokuserid = resuser.rsufk_user', array('rsufirst_name','rsulast_name'))
				   ->joinLeft(array('cus'=>'mt.customer'), 'bok.bokuserid = cus.cusfk_user', array('cusfirst_name','cuslast_name'))
				   ->joinLeft(array('restowner1'=>'mt.restaurant_owner'),'restowner1.rsofk_user = bok.bokupdatedby_userid',array('rsofirst_name as updatersofname','rsolast_name as updatersolname','rsophone as updatersophone'))
				   ->joinLeft(array('resuser1'=>'mt.restaurant_user'), 'bok.bokupdatedby_userid = resuser1.rsufk_user', array('rsufirst_name as updateuserfname','rsulast_name as updateuserlname'))
				   ->joinLeft(array('cus1'=>'mt.customer'), 'bok.bokupdatedby_userid = cus1.cusfk_user', array('cusfirst_name as updatecusfname','cuslast_name as updatecuslname'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtable_no_assigned'))
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id',array('code as resvmode','description as resvDesc'))
				   ->joinLeft(array('par'=>'mt.company'),'par.com_companyname = mode.description',array('com_id','com_logo'));
			$statRec = false;
			if($reservationreport->getReservationId()){
				$select->where('bok.bokid =?',$reservationreport->getReservationId());
				$statRec = true;
			}
			if($reservationreport->getBookStatus()){
				$statRec = true;
				$arr = array();
				$arr = $reservationreport->getBookStatus();
				if(in_array("RSD", $arr))
				{
					$arr[] = 'OVB';
					$select->where('bkstatus.code IN(?)',$arr);
				}else{
					$select->where('bkstatus.code IN(?)',$reservationreport->getBookStatus());
				}
			}
			if($reservationreport->getOrigin()){
				$select->where('mode.code IN(?)',$reservationreport->getOrigin());
			}

			if($reservationreport->getBookStartDate() && $reservationreport->getBookEndDate()){
				$select->where('bok.bokbooking_date >= ?',$reservationreport->getBookStartDate());
				$select->where('bok.bokbooking_date <= ?',$reservationreport->getBookEndDate());
			}else if($reservationreport->getBookStartDate()){
				$select->where('bok.bokbooking_date = ?',$reservationreport->getBookStartDate());
			}else{
				$date = date('Y-m-d');
				$select->where('bok.bokbooking_date = ?',$date);
			}			
			if($reservationreport->getBookStartTime() && $reservationreport->getBookEndTime())
			{
				$select->where('bok.bokbooking_timings >= ?',$reservationreport->getBookStartTime());
				$select->where('bok.bokbooking_timings <= ?',$reservationreport->getBookEndTime());
			}else if($reservationreport->getBookStartTime()){
				$select->where('bok.bokbooking_timings = ?',$reservationreport->getBookStartTime());
			}			
			$sorton = 'bok.bokid DESC';
			if($reservationreport->getReportSortOn() && $reservationreport->getReportSortOrder()){
				$sorton = $reservationreport->getReportSortOn().' '.$reservationreport->getReportSortOrder();
			}
			$select->order($sorton);
			$rowSet = $table->fetchAll($select);
      
			if($offset!=null)
			{
				$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			}
			else
			{
				$resultSet = $rowSet;
			}
			
			$totalcount = 0;
			$rescount	= 0;
			$cancount   = 0;
			$rsdcount   = 0;
			$comcount   = 0;
			$walkin		= 0;
			$web		= 0;
			$facebook	= 0;
			$pplseated 	= 0;
			$seated 	= 0;
			$noshow 	= 0;
			$waitcount 	= 0;
			$previd = "";
			$bokid = "";
			$tableidArr = array();
			$finaltablenoArr = array();
			$previd = "";
			foreach($rowSet as $row){
        
				if($previd == ""){
					$previd = $row->bokid;
					$tableidArr[] = $row->bktbtable_no_assigned;
					$totalcount++;
					if($row->bokstatuscode == 'RSD' || $row->bokstatuscode == 'OVB' || $row->bokstatuscode == "BKD"){
						$rescount += $row->bokparty_size;
					}else if($row->bokstatuscode == 'CAN'){
						$cancount += $row->bokparty_size;
					}else if($row->bokstatuscode == 'COM'){
						$comcount += $row->bokparty_size;
					}else if($row->bokstatuscode == 'RES'){
						$rsdcount += $row->bokparty_size;
					}else if($row->bokstatuscode == 'NOS'){
						$noshow += $row->bokparty_size;
					}else if($row->bokstatuscode == 'ALC' || $row->bokstatuscode == 'DES' || $row->bokstatuscode == 'BOK' || $row->bokstatuscode == 'PTS' || $row->bokstatuscode == 'CRD'){
						$seated += $row->bokparty_size;
					}else if($row->bokstatuscode == "WAL" || $row->bokstatuscode == "QUOTE" || $row->bokstatuscode == "READY" || $row->bokstatuscode == 'BACK' || $row->bokstatuscode == 'BAR' || $row->bokstatuscode == 'NEXT' || $row->bokstatuscode == 'CANCUS'){
						$waitcount += $row->bokparty_size;
					}
					
					if($row->resvmode == 'INAT'){
						$web += $row->bokparty_size;;
					}else if($row->resvmode == 'WIN'){
						$walkin += $row->bokparty_size;;
					}else if($row->resvmode == 'FB'){
						$facebook += $row->bokparty_size;;
					}
					if(array_key_exists($row->bokbooking_status_id,$statusId)){
						if($row->bokstatuscode != 'NOS'){
							$pplseated = $pplseated + $row->bokparty_size;
						}
					}
				}else{
					$bokid = $row->bokid;
					if($previd == $bokid){
						$tableidArr[] = $row->bktbtable_no_assigned;
					}else{
						$finaltablenoArr[] = array('key'=>$previd,'value'=>$tableidArr);
						$tableidArr = array();
						$previd = $row->bokid;
						$tableidArr[] = $row->bktbtable_no_assigned;
						$totalcount++;
						if($row->bokstatuscode == 'RSD' || $row->bokstatuscode == 'OVB' || $row->bokstatuscode == "BKD"){
							$rescount += $row->bokparty_size;
						}else if($row->bokstatuscode == 'CAN'){
							$cancount += $row->bokparty_size;
						}else if($row->bokstatuscode == 'COM'){
							$comcount += $row->bokparty_size;
						}else if($row->bokstatuscode == 'RES'){
							$rsdcount += $row->bokparty_size;
						}else if($row->bokstatuscode == 'NOS'){
							$noshow += $row->bokparty_size;
						}else if($row->bokstatuscode == 'ALC' || $row->bokstatuscode == 'DES' || $row->bokstatuscode == 'BOK' || $row->bokstatuscode == 'PTS' || $row->bokstatuscode == 'CRD'){
							$seated += $row->bokparty_size;
						}else if($row->bokstatuscode == "WAL" || $row->bokstatuscode == "QUOTE" || $row->bokstatuscode == "READY" || $row->bokstatuscode == 'BACK' || $row->bokstatuscode == 'BAR' || $row->bokstatuscode == 'NEXT' || $row->bokstatuscode == 'CANCUS'){
							$waitcount += $row->bokparty_size;
						}
						
						if($row->resvmode == 'INAT'){
							$web += $row->bokparty_size;;
						}else if($row->resvmode == 'WIN'){
							$walkin += $row->bokparty_size;;
						}else if($row->resvmode == 'FB'){
							$facebook += $row->bokparty_size;;
						}
						if(array_key_exists($row->bokbooking_status_id,$statusId)){
							if($row->bokstatuscode != 'NOS'){
								$pplseated = $pplseated + $row->bokparty_size;
							}
						}
					}
				}
			}
			$finaltablenoArr[] = array('key'=>$previd,'value'=>$tableidArr);
		
			if($offset!=null)
			{
				$resultSet->setItemCountPerPage($limit);
				$resultSet->setCurrentPageNumber($offset);
			}
			$result = array();
			$result['data'] = $resultSet;
			$result['count'] = array('totalcount' => $totalcount,
									 'seated'	  => $seated,
									 'resv'       => $rescount,
									 'cancount'   => $cancount,
									 'rsdcount'   => $rsdcount,
									 'comcount'   => $comcount,
									 'noshow'     => $noshow,
									 'waitcount'  => $waitcount,
									 'web'		  => $web,
									 'walkin'	  => $walkin,
									 'facebook'	  => $facebook,
									 'pplseated'  => $pplseated,
									 'tablenoass' => $finaltablenoArr);
			//echo '<pre>'; print_r($result); exit;
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of restaurantid
	 * fucntion to retreive the restaurant logo
	 */
	public function GetRestaurantLogo($restaurantid)
	{
		try{
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$table = $mapper->getDbTable();
			$select = $table->select();
			$select->from($table,array('resrestaurant_name','reslogo','resimage'))
			->where('resid = ?',$restaurantid);
			$row = $table->fetchRow($select);
			if($row){
				return $row;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of booking
	 * function to cancel the reservation note by booking id
	 */
	public function CancelNoteByBookingId(Reservation_Model_Reservation $bookingObj)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		$table  = $this->getDbTable();
		
		$timezone = "";
		$mapper = new FirmManagement_Model_FirmDataMapper();
		$timezone = $mapper->GetRestaurantTimeZone($bookingObj->getbokfk_restaurant());
		date_default_timezone_set($timezone);
		$storage = new Zend_Auth_Storage_Session();
		$data = $storage->read();
		$set 	= array('bokbooking_status_id'	=> $bookingObj->getbokbooking_status_id(),
						'bokrestaurant_note'	=> $bookingObj->getbokrestaurant_note(),
						'bokupdated_date'		=> date('Y-m-d'),
						'bokupdateddatetime'	=> date('H:i:s',time()),
						'bokupdatedby_userid'	=> $data['User_Id'],
						'boksync_status'		=> 'C'	
					);
		$status =false;
		try{
			$db->beginTransaction();

			$where 	= array('bokid = ?' => $bookingObj->getbokid(),'bokfk_restaurant = ?'=> $bookingObj->getbokfk_restaurant());
			$rows_affected = $table->update($set,$where);
			if($rows_affected){
				if($bookingObj->getbokbooking_status_id() == 4 && $bookingObj->getbokcontactid()){
					$groupUsersDataMapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
					$groupUsersDataMapper->updateGuestReservationCount($bookingObj->getbokcontactid(), 'CAN','');
				}
				$status = true;
			}
			if($bookingObj->getbokbooking_status_desc() != "WAL" && $bookingObj->getbokbooking_status_desc() != "OVB"){
				$resDataMapper = new FirmManagement_Model_FirmDataMapper();
				$settingArr = $resDataMapper->getScheduleSettingTypeByresId($bookingObj->getbokfk_restaurant());
				if($settingArr['settingType'] == 'SAC'){
					$this->ResetAccumulativeBookingCount($bookingObj);
				}else{
					$this->ResetBookingCount($bookingObj);
				}
			}
			$bokStat = $this->getBookingPrevStatus($bookingObj->getbokid());
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($bookingObj->getbokid())
					->setbok_log_booked_type($bokStat)
					->setbok_log_bok_status($bookingObj->getbokbooking_status_id())
					->setbok_log_book_message('Reservation Note Cancel')
					->setbok_log_updated_by($data['User_Id'])
					->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('CUS');
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			$db->commit();
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of booking
	 * function to cancel the reservation by the customer with reservation id 
	 */
	public function CancelCusResvByBookingId(Reservation_Model_Reservation $bookingObj)
	{
		
			$db = Zend_Db_Table::getDefaultAdapter();
			$table  = $this->getDbTable();
			
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			$bookStatusMapper 	= new Application_Model_ReservationStatusDataMapper();
			$bookStatus			= $bookStatusMapper->GetBookingStatusByCode(array('CAN'));
			$bookStatusObj 	  = $bookStatus['CAN'];
			$set 	= array('bokbooking_status_id'	=> $bookStatusObj->getId());
			try{
				$db->beginTransaction();
				$where 	= array('bokid = ?' => $bookingObj->getbokid());
				$rows_affected = $table->update($set,$where);
				if($rows_affected){
					$status = true;
					
					$bokStat = $this->getBookingPrevStatus($bookingObj->getbokid());
					$bokLog = new Reservation_Model_BookingLog();
					$bokLog->setbok_log_fk_booking($bookingObj->getbokid())
							->setbok_log_booked_type($bokStat)
							->setbok_log_bok_status($bookStatusObj->getId())
							->setbok_log_book_message('Reservation Cancelled')
							->setbok_log_updated_by($userdata['User_Id'])
							->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    				->setbok_log_update_done_by('RES');
					$bokLogMapper = new Reservation_Model_BookingLogMapper();
					$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
				}
				$db->commit();
				return $status;
			}catch (Exception $ex){
				throw new Exception($ex->getMessage()) ;
			}
	}

	/**
	 * @param instance of booking
	 * function to reset the booking count
	 */
	public function ResetBookingCount(Reservation_Model_Reservation $bookdetails)
	{
		try{
			$bookid = $bookdetails->getbokid();
			$schTableMapper = new FirmManagement_Model_FirmScheduleTableDataMapper();
			$schTable = $schTableMapper->getDbTable();
			$schTableSelect = $schTable->select();
			$schTableSelect->setIntegrityCheck(false);
			$schTableSelect->from(array('rst'=>'mt.restaurant_schedule_table'),array('rsttable_pax','rstno_of_tables'))
						   ->join(array('bok'=>'mt.booking'),'bok.bokfk_rest_sch_table = rst.rstid',array('bok.bokid','bokbooking_timings','bokbooking_date','bokfk_rest_sch_table'))
			->where('bok.bokid = ?',$bookid);

			$schTableRow = $schTable->fetchRow($schTableSelect);

			if($schTableRow){
				/* Retrieve schedule id by inventory id */
				$schIdRow = "";
				if($schTableRow->bokfk_rest_sch_table){
					$restSchTblMapperObj = new FirmManagement_Model_FirmScheduleTableDataMapper();
					$restSchTbl = $restSchTblMapperObj->getDbTable();
					$restSchTblSelect = $restSchTbl->select();
	
					$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule'))
									 ->where('rstid = ?',$schTableRow->bokfk_rest_sch_table);
									 
				    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);				
				}
				if($schIdRow){
					$actualTableSize = $schTableRow->rsttable_pax;
					$oldBookTimings = $schTableRow->bokbooking_timings;
					$bookingDate = $schTableRow->bokbooking_date;
	
					$bookCountMapper = new Reservation_Model_ReservationCountDataMapper();
					$bookCountTable = $bookCountMapper->getDbTable();
					$bookCountSelect = $bookCountTable->select();
	
					$bookCountSelect->from($bookCountTable,array('btcid','btcbooking_count','boktablesize'))
					->where('btcfkres_id = ?',$bookdetails->getbokfk_restaurant())
					->where('btcbooking_timings = ?',$oldBookTimings)
					->where('btcbooking_date = ?',$bookingDate)
									->where('boktablesize = ?',$actualTableSize)
									->where('btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
	
					$tableCountRow = $bookCountTable->fetchRow($bookCountSelect);
	
					if($tableCountRow){
						$bookCount = $tableCountRow->btcbooking_count;
						$bookCountId = $tableCountRow->btcid;
						if($bookCount > 1){
							$bookCount--;
							$set = array('btcbooking_count'=>$bookCount);
							$where = array('btcid = ?'=>$bookCountId);
							$rows_affected = $bookCountTable->update($set,$where);
							return $rows_affected;
						}else if($bookCount == 1){
							$where = array('btcid = ?'=>$bookCountId);
							$status = $bookCountTable->delete($where);
							return $status;
						}
					}
				}				
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function ResetAccumulativeBookingCount(Reservation_Model_Reservation $bookdetails)
	{
		try{
			$bookid = $bookdetails->getbokid();
			$schTableMapper = new FirmManagement_Model_FirmScheduleTableDataMapper();
			$schTable = $schTableMapper->getDbTable();
			
			$schTableSelect = $schTable->select();
			$schTableSelect->setIntegrityCheck(false);
			$schTableSelect->from(array('bok'=>'mt.booking'),array('bok.bokid','bokbooking_timings','bokbooking_date'))
						   ->joinLeft(array('acc'=>'mt.booking_accumulative_inventory'),'acc.bai_fk_booking = bok.bokid',array(''))
						   ->joinLeft(array('rst'=>'mt.restaurant_schedule_table'),'bok.bokfk_rest_sch_table = rst.rstid or acc.bai_inventory = rst.rstid',array('rstid','rsttable_pax','rstno_of_tables'))
						   ->where('bok.bokid = ?',$bookid);

			$schTableRow = $schTable->fetchAll($schTableSelect);
			$status = '';
			$rows_affected ='';
			foreach($schTableRow as $row){
				if($row){
					/* Retrieve schedule id by inventory id */
					$schIdRow = "";
					if($row->rstid){
						$restSchTblMapperObj = new FirmManagement_Model_FirmScheduleTableDataMapper();
						$restSchTbl = $restSchTblMapperObj->getDbTable();
						$restSchTblSelect = $restSchTbl->select();
		
						$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule'))
										 ->where('rstid = ?',$row->rstid);
										 
					    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);				
					}
					if($schIdRow){
						$actualTableSize = $row->rsttable_pax;
						$oldBookTimings = $row->bokbooking_timings;
						$bookingDate = $row->bokbooking_date;
		
						$bookCountMapper = new Reservation_Model_ReservationCountDataMapper();
						$bookCountTable = $bookCountMapper->getDbTable();
						$bookCountSelect = $bookCountTable->select();
		
						$bookCountSelect->from($bookCountTable,array('btcid','btcbooking_count','boktablesize'))
						->where('btcfkres_id = ?',$bookdetails->getbokfk_restaurant())
						->where('btcbooking_timings = ?',$oldBookTimings)
						->where('btcbooking_date = ?',$bookingDate)
										->where('boktablesize = ?',$actualTableSize)
										->where('btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
		
						$tableCountRow = $bookCountTable->fetchRow($bookCountSelect);
		
						if($tableCountRow){
							$bookCount = $tableCountRow->btcbooking_count;
							$bookCountId = $tableCountRow->btcid;
							if($bookCount > 1){
								$bookCount--;
								$set = array('btcbooking_count'=>$bookCount);
								$where = array('btcid = ?'=>$bookCountId);
								$rows_affected = $bookCountTable->update($set,$where);
							}else if($bookCount == 1){
								$where = array('btcid = ?'=>$bookCountId);
								$status = $bookCountTable->delete($where);
							}
						}
					}
				}
			}
			if($status || $rows_affected){
				$accMapper = new Reservation_Model_ReservationAccumulativeInventoryMapper();
				$where = array('bai_fk_booking = ?'=>$bookid);
				$status = $accMapper->getDbTable()->delete($where);
				return $status;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of reservations
	 * function to retreive the reservations
	 */
	public function ReteriveReservations(Reservation_Model_GetReservations $object)
	{
		try{
			$bookTable = $this->getDbTable();
			$bookTableSelect = $bookTable->select();
			$bookTableSelect->setIntegrityCheck(false);
			
			/* Left Join on Booking_Table resultset */
			
			$bookSeatsMapper = new Reservation_Model_ReservationTableMapper();
			$bookSeatsTable  = $bookSeatsMapper->getDbTable();
			$bookSeatsSelect = $bookSeatsTable->select();
			
			$bookSeatsSelect->from($bookSeatsTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$object->getRestId())
							  ->where('rda_status = ?',true);
			
			$bookTableSelect->from(array('bok'=>'mt.booking'),array('bokid','bokfirst_name','boklast_name','bokparty_size','bokspecial_request','bokrestaurant_note','bokbooking_timings'))
							->joinLeft(array('bktb'=>$bookSeatsSelect),' bok.bokid = bktb.bktbfk_booking',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no'))
							->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))							
							->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bok.bokbooking_type_id',array('code as booktypecode','description as booktypedesc'))
							->join(array('resvmod'=>'mt.reservation_mode_bd'),'resvmod.id = bok.bokreservation_mode_id',array('code as resvmodcode','description as resvmoddesc'))
							->join(array('rst'=>'mt.restaurant_schedule_table'),'rst.rstid = bok.bokfk_rest_sch_table',array('rstid','rsttable_pax','rstno_of_tables'))
							->join(array('boksts'=>'mt.booking_status_bd'),'boksts.id = bokbooking_status_id',array('code as bokstscode','description as bokstsdesc'))
							->join(array('rss'=>'mt.restaurant_schedule'),'rss.rssid = rst.rstfk_restaurant_schedule',array('rssid'))
							->where('rss.rssid IN(?)',$object->getSchId())
							->where('bok.bokfk_restaurant = ?',$object->getRestId())
							->where('bok.bokbooking_date = ?',$object->getBookDate())
							->where('bok.bokbooking_status_id IN(?)',$object->getBookStatus())
							->where('bok.bokbooked_status != ?',11)
							->order(array('bokbooking_timings','bokid'));
			$row_set = $bookTable->fetchAll($bookTableSelect);

			$resultArray 	 = array();
			
			$prevBookid   = "";
			$bookid	      = "";			
			$username  	  = "";
			$partysize 	  = "";
			$resvnote 	  = "";					
			$restnote 	  = "";
			$tableno 	  = "";
			$tablenoArr	  = array();
			$resvtime 	  = "";
			$booktypecode = "";
			$booktypedesc = "";
			$resvmodcode  = "";
			$resvmoddesc  = "";
			$inventoryid  = "";
			$tablesize    = "";
			$nooftables   = "";
			$bokstscode   = "";
			$bokstsdesc   = "";
			$dinigid 	  = "";
			
			$count = 0;
			$count = count($row_set);
			$i = 0;
			if($count > 0){
				foreach($row_set as $row){
					$i++;
					if($prevBookid == ""){
						$time = date("g:i A", strtotime($row->bokbooking_timings));
						$username = "";
						if($row->bokstscode == "BKD"){
							$username = "Blocked by ".$row->bokfirst_name.' '.$row->boklast_name;	
						}else{
							$username = $row->bokfirst_name.' '.$row->boklast_name;
						}
						$bookid	   	  = $row->bokid;			
						$username 	  = $username;
						$partysize    = $row->bokparty_size;
						$resvnote 	  = $row->bokspecial_request;					
						$restnote	  = $row->bokrestaurant_note;
						$tableno 	  = $row->bktbtable_no_assigned;
						$tablenoArr[] = $row->bktbtable_no_assigned;
						$resvtime	  = $time;
						$booktypecode = $row->booktypecode;
						$booktypedesc = $row->booktypedesc;
						$resvmodcode  = $row->resvmodcode;
						$resvmoddesc  = $row->resvmoddesc;
						$inventoryid  = $row->rstid;
						$tablesize    = $row->rsttable_pax;
						$nooftables   = $row->rstno_of_tables;
						$bokstscode   = $row->bokstscode;
						$bokstsdesc   = $row->bokstsdesc;
						$dinigid	  = $row->rda_diningdisplyname;
						$prevBookid   = $bookid;
						
					}else{
						$bookid	= $row->bokid;
						if($prevBookid == $bookid){
							$tablenoArr[] = $row->bktbtable_no_assigned;
						}else{
							$resultArray[] = array('bookid'   	  => $prevBookid,	   	 
								   		       	   'username'     => $username, 	 
								   			       'partysize'	  => $partysize,  
							   				       'resvnote' 	  => $resvnote, 	 
								   			       'restnote' 	  => $restnote,	 
							   			           'tableno'      => $tableno,
												   'tablenoarr'	  => $tablenoArr, 
							   			           'resvtime'     => $resvtime,	 
							   			           'booktypecode' => $booktypecode,
								   		           'booktypedesc' => $booktypedesc,
								   		           'resvmodcode'  => $resvmodcode, 
								   		   		   'resvmoddesc'  => $resvmoddesc, 
								   		   		   'inventoryid'  => $inventoryid, 
							   		   			   'tablesize'    => $tablesize,   
								   		           'nooftables'   => $nooftables,  
								   		   		   'bokstscode'	  => $bokstscode,  
								   		   		   'bokstsdesc'	  => $bokstsdesc,
												   'diningid'	  => $dinigid);
							
							$time = date("g:i A", strtotime($row->bokbooking_timings));
							$username = "";
							if($row->bokstscode == "BKD"){
								$username = "Blocked by ".$row->bokfirst_name.' '.$row->boklast_name;	
							}else{
								$username = $row->bokfirst_name.' '.$row->boklast_name;
							}	

							$tablenoArr	  = null;
							$username 	  = $username;
							$partysize    = $row->bokparty_size;
							$resvnote 	  = $row->bokspecial_request;					
							$restnote	  = $row->bokrestaurant_note;
							$tableno 	  = $row->bktbtable_no_assigned;
							$tablenoArr[] = $row->bktbtable_no_assigned;
							$resvtime	  = $time;
							$booktypecode = $row->booktypecode;
							$booktypedesc = $row->booktypedesc;
							$resvmodcode  = $row->resvmodcode;
							$resvmoddesc  = $row->resvmoddesc;
							$inventoryid  = $row->rstid;
							$tablesize    = $row->rsttable_pax;
							$nooftables   = $row->rstno_of_tables;
							$bokstscode   = $row->bokstscode;
							$bokstsdesc   = $row->bokstsdesc;
							$dinigid	  = $row->rda_diningdisplyname;
							$prevBookid   = $bookid;
							 
						}
					}
				}
				$resultArray[] = array('bookid'   	  => $bookid,	   	 
					   		       	   'username'     => $username, 	 
					   			       'partysize'	  => $partysize,  
				   				       'resvnote' 	  => $resvnote, 	 
					   			       'restnote' 	  => $restnote,	 
				   			           'tableno'      => $tableno,	
									   'tablenoarr'	  => $tablenoArr,  
				   			           'resvtime'     => $resvtime,	 
				   			           'booktypecode' => $booktypecode,
					   		           'booktypedesc' => $booktypedesc,
					   		           'resvmodcode'  => $resvmodcode, 
					   		   		   'resvmoddesc'  => $resvmoddesc, 
					   		   		   'inventoryid'  => $inventoryid, 
				   		   			   'tablesize'    => $tablesize,   
					   		           'nooftables'   => $nooftables,  
					   		   		   'bokstscode'	  => $bokstscode,  
					   		   		   'bokstsdesc'	  => $bokstsdesc,
									   'diningid'	  => $dinigid);
			}			
			return $resultArray;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param instance of customer booking history
	 * function to get the customer booking history by owner id
	 */
	public function getCustBookingHistoryByOwnerId(Reservation_Model_CustBookHist $bookhist,$offset)
	{
		try{
			$limit = 10;
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);

			$select->from(array('book'=>'mt.booking'),array('bokid','bokfirst_name','boklast_name','bokbooking_date','bokbooking_timings','bokfk_restaurant','bokbooking_phrase'));
			$select->join(array('rest'=>'mt.restaurant'),'rest.resid = book.bokfk_restaurant',array('resrestaurant_name'));
			$select->join(array('bokbd'=>'mt.booking_status_bd'),'bokbd.id = book.bokbooking_status_id',array('description as bookingStatus'));
			$select->join(array('boktyp'=>'mt.booking_type_bd'),'book.bokbooking_type_id = boktyp.id',array('code as boktypecode','description as boktypedesc'));
			$select->where('book.bokuserid = ?',$bookhist->getUserId());
//			$select->orwhere('book.bokphone = ?',$bookhist->getPhone());
			$select->orwhere('book.bokemail = ?',$bookhist->getEmail());
			$select->where('book.bokbooking_status_id != ?', 4);
//			$select->order('book.bokbooking_date DESC');
			$select->order('book.bokid DESC');
			//$rowset = $table->fetchAll($select);
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);

			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * @param array
	 * function to save the block reservation details
	 */
	public function saveBlockReservationDetails(array $RestaurantBookings)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();

			$db->beginTransaction();
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			foreach($RestaurantBookings as $bookdetails){

				if($bookdetails->getbokuserid()){
					$userid = $bookdetails->getbokuserid();
				}else{
					$userid = null;
				}

				$data = array(
					  'bokfk_restaurant'  	   => $bookdetails->getbokfk_restaurant(), 
					  'bokemail'		 	   => $bookdetails->getbokemail(),
					  'bokfirst_name' 		   => $bookdetails->getbokfirst_name(),
					  'boklast_name' 		   => $bookdetails->getboklast_name(),
					  'bokparty_size' 		   => $bookdetails->getbokparty_size(),
					  'bokphone' 			   => str_replace("-","",$bookdetails->getbokphone()),
					  'bokspecial_request'     => $bookdetails->getbokspecial_request(),
				      'bokbooking_date'		   => $bookdetails->getbokbooking_date(),
					  'bokbooking_timings' 	   => $bookdetails->getbokbooking_timings(),
					  'bokbooking_status_id'   => $bookdetails->getbokbooking_status_id(),
					  'bokbooked_status'	   => $bookdetails->getbokbooking_status(),
					  'bokbooking_made_on' 	   => $bookdetails->getbokbooking_made_on(),
				 	  'bokbooking_made_time'   => $bookdetails->getBookingMadeTime(),
					  'bokuserid' 			   => $userid,			  
					  'bokbooking_type_id'     => $bookdetails->getbokbooking_type_id(),
					  'bokreservation_mode_id' => $bookdetails->getbokreservation_mode_id(),
					  'boknotification_type'   => $bookdetails->getNotificationType(),
					  'bokfk_rest_sch_table'   => $bookdetails->getInventoryId(),
					  'bokbooking_phrase'	   => $bookdetails->getbokbookingphrase()
				);
				if($bookdetails->getbok_restsch_setting_id()){
					$data['bok_restsch_setting_id'] = $bookdetails->getbok_restsch_setting_id();
				}
				$result = $this->getDbTable()->insert($data);
				$bookdetails->setbokid($result);
				/* Check whether reservation is blocked from layout table if yes insert table no */
				if($bookdetails->getboktable_no_assigned()){
					$bookTabledata = array('bktbfk_booking' 	   => $result,
										   'bktbtableid'   		   => $bookdetails->getboktableid(),
										   'bktbtable_no_assigned' => $bookdetails->getboktable_no_assigned(),
										   'bkt_dining_id'		   => $bookdetails->getDiningId(),
										   'status'				   => true
										  );
										  
					$bokTblMapper = new Reservation_Model_ReservationTableMapper();
					$bokTbl = $bokTblMapper->getDbTable();
					$bokTbl->insert($bookTabledata);
				}
				
				$schIdRow = "";
				if($bookdetails->getInventoryId()){
					$restSchTblMapperObj = new FirmManagement_Model_FirmScheduleTableDataMapper();
					$restSchTbl = $restSchTblMapperObj->getDbTable();
					$restSchTblSelect = $restSchTbl->select();
	
					$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule'))
									 ->where('rstid = ?',$bookdetails->getInventoryId());
									 
				    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);				
				
					$table = $this->getDbTable();
					$select = $table->select();
					$select->setIntegrityCheck(false);
					$select->from(array('btc'=>'mt.booking_time_count'),array('count(btcid) as countbtc','btcid','btcbooking_count','btc.boktablesize'))
					->where('btc.btcfkres_id = ?',$bookdetails->getbokfk_restaurant())
					->where('btc.btcbooking_timings = ?',$bookdetails->getbokbooking_timings())
					->where('btc.btcbooking_date = ?',$bookdetails->getbokbooking_date())
					->where('btc.boktablesize = ?',$bookdetails->getTableSize())
						   ->where('btc.btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
					$select->group(array('btcid','btcbooking_count','btc.boktablesize'));
	
					$bookingCountId = 0;
					$bookingId= 0;
					$bookingCount = 0;
	
					$row = $table->fetchRow($select);
	
					$bookingCountId = $row['countbtc'];
					$bookingId = $row['btcid'];
					$bookingCount = (int)$row['btcbooking_count'];
	
					$mapper = new Reservation_Model_ReservationCountDataMapper();
					if($bookdetails->getbokbooking_status_id() != 11){
						if($bookingCountId != 0){
		
							$bookingCount++;
							$set = array('btcbooking_count' => $bookingCount);
							$where = array('btcid = ?'=>$bookingId,
										   'btcfk_restaurant_schedule = ?'=>$schIdRow->rstfk_restaurant_schedule);
							//$where = $db->quoteInto('btcid = ?',$bookingId);
		
							$mapper->getDbTable()->update($set,$where);
		
						}else{
							$data = array(
								'btcbooking_count'    => 1,
								'btcbooking_timings'  => $bookdetails->getbokbooking_timings(),
						        'btcbooking_date' 	  => $bookdetails->getbokbooking_date(),
		 						'btcfkres_id'    	  => $bookdetails->getbokfk_restaurant(),
								'boktablesize'		  => $bookdetails->getTableSize(),
					  			'boknooftables'		  => $bookdetails->getNoOfTables(),
								'btcfk_restaurant_schedule'	=> $schIdRow->rstfk_restaurant_schedule
							);
							$mapper->getDbTable()->insert($data);
						}
					}
				}
				
				$bokStat = $this->getBookingPrevStatus($bookdetails->getbokid());
				$bokLog = new Reservation_Model_BookingLog();
				$bokLog->setbok_log_fk_booking($bookdetails->getbokid())
						->setbok_log_booked_type($bokStat)
						->setbok_log_bok_status($bookdetails->getbokbooking_status_id())
						->setbok_log_book_message('Block Reservation Details Entered')
						->setbok_log_updated_by($userdata['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
				$bokLogMapper = new Reservation_Model_BookingLogMapper();
				$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			}
			$db->commit();
			return $result;

		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function UnBlockTables($bookingDetails)
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();
			$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
			$bookStatus 	  = $bookStatusMapper->GetBookingStatusByCode(array("CAN"));
			$bookStatusObj 	  = $bookStatus["CAN"];
			
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			foreach($bookingDetails as $bookingObj){
				$table  = $this->getDbTable();
				$set 	= array('bokbooking_status_id'	=> $bookStatusObj->getId(),
							'bokrestaurant_note'=> $bookingObj->getbokrestaurant_note());
				$status =false;
				
				$where 	= array('bokid = ?' => $bookingObj->getbokid(),'bokfk_restaurant = ?'=> $bookingObj->getbokfk_restaurant());
				$rows_affected = $table->update($set,$where);
				if($rows_affected){
					$status = true;
				}
				if($bookingObj->getbokbooking_status_desc() != "WAL" && $bookingObj->getbokbooking_status_desc() != "OVB" && $bookingObj->getInventoryId()){
					$resDataMapper = new FirmManagement_Model_FirmDataMapper();
					$settingArr = $resDataMapper->getScheduleSettingTypeByresId($bookingObj->getbokfk_restaurant());
					if($settingArr['settingType'] == 'SAC'){
						$this->ResetAccumulativeBookingCount($bookingObj);
					}else{
							$this->ResetBookingCount($bookingObj);
					}
				}
				
				$bokStat = $this->getBookingPrevStatus($bookingObj->getbokid());
				$bokLog = new Reservation_Model_BookingLog();
				$bokLog->setbok_log_fk_booking($bookingObj->getbokid())
						->setbok_log_booked_type($bokStat)
						->setbok_log_bok_status($bookStatusObj->getId())
						->setbok_log_book_message('Block Reservation Cancelled')
						->setbok_log_updated_by($userdata['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
				$bokLogMapper = new Reservation_Model_BookingLogMapper();
				$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			}
			$db->commit();
			return $status;
		}catch(Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of request, reservation id and status id
	 * function to save the customer reservation details for block
	 */
	public function saveBlockCustReservationDetails(Reservation_Model_Reservation $bookdetails,$request="")
	{
		$db = Zend_Db_Table::getDefaultAdapter();
		try{
			$db->beginTransaction();	
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			
			$restservice = new Application_Service_Firm();
			$guestid = $restservice->AddBlocktoReservContact($request);		
			$set = array('bokfirst_name'			=> $bookdetails->getbokfirst_name(),
						 'boklast_name'				=> $bookdetails->getboklast_name(),
						 'bokphone'					=> str_replace("-","",$bookdetails->getbokphone()),
						 'bokemail'					=> $bookdetails->getbokemail(),
						 'bokbooking_status_id'     => $bookdetails->getbokbooking_status_id(),
						 'bokbooked_status'			=> $bookdetails->getbokbooking_status(),
						 'boknotification_type'		=> $bookdetails->getNotificationType(),
						 'bokbooking_made_time'		=> date("h:i",time()),
						 'bokbooking_made_on'		=> date('Y-m-d h:i:s'),
						 'bokupdated_date'			=> date('Y-m-d'),
					     'bokupdateddatetime'		=> date("H:i:s",time()),
						 'bokupdatedby_userid'		=> $data['User_Id'],
						 'boksync_status'			=> 'C',
						 'bokcountrycode'			=> $bookdetails->getbokcountry_code(),
					);
			if($guestid){
				$set['bok_contactid'] = $guestid;
			}
			$where = $db->quoteInto('bokid = ?',$bookdetails->getbokid());
			$result = $this->getDbTable()->update($set,$where);
			if($result){
				if($guestid){
					$groupUsersDataMapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
					$groupUsersDataMapper->updateGuestReservationCount($guestid, 'RSD',2);
				}
				$countMapper = new Reservation_Model_ReservationsCountDataMapper();
				$countResult = $countMapper->saveReservationsCount($bookdetails->getbokfk_restaurant(),$bookdetails->getbokparty_size());
			}
			
			$bokStat = $this->getBookingPrevStatus($bookdetails->getbokid());
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($bookdetails->getbokid())
					->setbok_log_booked_type($bokStat)
					->setbok_log_bok_status($bookdetails->getbokbooking_status_id())
					->setbok_log_book_message('Block Reservation Customer Details entered')
					->setbok_log_updated_by($data['User_Id'])
					->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			$db->commit();
			return $result;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of restaurant id
	 * function to retreive the restaurant information
	 */
	public function ReterieveRestInfo($restid)
	{
		$restMapper	= new FirmManagement_Model_FirmDataMapper();
		$restTable  = $restMapper->getDbTable();
		$restSelect = $restTable->select();
		
		$restSelect->from('mt.restaurant',array('resemail','resnotification'))
				   ->where('resid = ?',$restid);
				   
		$row = $restTable->fetchRow($restSelect);

		return $row;
	}
	
	public function ReterieveRestemails($restid)
	{
		$restMapper	= new FirmManagement_Model_FirmDataMapper();
		$restTable  = $restMapper->getDbTable();
		$restSelect = $restTable->select();
		$restSelect->from(array('mt.restaurant'),array('resnotification','resemail'))
				   ->where('resid = ?',$restid);
		$result = $restTable->fetchRow($restSelect);
		$emailArr = array(); 
		$emailArr[] = $result->resemail; 
		
		$emailmapper = new FirmManagement_Model_FirmEmailsDataMapper();
		$emailselect = $emailmapper->getDbTable()->select();
		$emailselect->from(array('mt.restaurant_emails'),array('rese_email'));
		$emailselect->where('resefk_restaurantid = ?',$restid);
		$emailselect->where('rese_email_status_id = ?',1);
		$emailselect->where('feedback_email IS NULL');
		$emailresult = $emailmapper->getDbTable()->fetchAll($emailselect);
		foreach($emailresult as $row)
		{
			$emailArr[] = $row->rese_email;
		}
		
		$resultArr['status'] = $result->resnotification;
		$resultArr['emails'] = $emailArr;
		return $resultArr;
	}
	
	public function ReterieveRestFeedbackemails($restid)
	{
		$restMapper	= new FirmManagement_Model_FirmDataMapper();
		$restTable  = $restMapper->getDbTable();
		$restSelect = $restTable->select();
		$restSelect->from(array('mt.restaurant'),array('resfeedbacknotf','resfeedbacksmsnotf','resemail'))
				   ->where('resid = ?',$restid)
				   ->where('resapprovalstatus NOT IN (?)',array(3,2))
				   ->where('resstatus NOT IN (?)',array(3,2));
		$result = $restTable->fetchRow($restSelect);
		if($result){
			$emailArr = array(); 
			$emailArr[] = $result->resemail; 
			
			$emailmapper = new FirmManagement_Model_FirmEmailsDataMapper();
			$emailselect = $emailmapper->getDbTable()->select();
			$emailselect->from(array('mt.restaurant_emails'),array('rese_email'));
			$emailselect->where('resefk_restaurantid = ?',$restid);
			$emailselect->where('rese_email_status_id = ?',1);
			$emailselect->where('feedback_email = ?','feedback');
			$emailresult = $emailmapper->getDbTable()->fetchAll($emailselect);
			foreach($emailresult as $row)
			{
				$emailArr[] = $row->rese_email;
			}
			
			$resultArr['emails'] = $emailArr;
			$resultArr['Emailstatus'] = $result->resfeedbacknotf; 
			$resultArr['SmsStatus'] = $result->resfeedbacksmsnotf; 
			return $resultArr;
		}else{
			return false;
		}
	}
	
	
	/**
	 * @param instance of tableid, restaurant id
	 * function to retreive the booking details by table id
	 */
	public function GetBookingDetailsByTableId($tableid, $restid)
	{
		try{
			$count = 0;
			
			$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
			$bookStatus = array('BOK','CRD','DES','PTS','BKD');
			$bookStatusRes = $bookStatusMapper->GetBookingStatusByCode($bookStatus);
			$status = $bookStatusRes;
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			$today = date('Y-m-d');
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('bok'=>'mt.booking'),array('COUNT(bokid) as count'))
				   ->join(array('bktb'=>'mt.booking_tables'),'bok.bokid = bktb.bktbfk_booking',array())
				   ->where('bktb.status = ?',true)
				   ->where('bktb.bktbtableid = ?',$tableid)
				   ->where('bok.bokfk_restaurant = ?',$restid)
				   ->where('bok.bokbooking_date = ?',$today)
				   ->where("bok.bokbooking_status_id IN(?)",$statusId);
			$result = $table->fetchAll($select);
			foreach($result as $row){
				$count = $row->count;
			}
			if($count > 0){
				$status = true;
			}else{
				$status = false;
			}
			return $status;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of restaurantid,date,timings,status,limit,offset
	 * function to get the number of reservations
	 */
	public function GetNoOfReservations($resid,$date,$bookStatusRes,$endreDate,$originsarr)
	{
		try{
			$table = $this->getDbTable();
			$TotalValues = array();
			$result = array();
			$statusId = array();
			$status = $bookStatusRes;
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			//$timings = array_slice($Timings,$offset,$lim);
//			$totalcount = 0;
//			$select = $table->select();
//			$select->setIntegrityCheck(false);
//			$select->from(array('bok'=>'mt.booking'),array('SUM(bokparty_size) as totalParty'))
//		   		   ->where('bok.bokfk_restaurant = ?',$resid)
//			       ->where('bok.bokbooking_status_id IN(?)',$statusId);
//			       
//			if($endreDate != ""){
//				$select->where('bok.bokbooking_date >= ?',$date);
//				$select->where('bok.bokbooking_date <= ?',$endreDate);
//			}else{
//				$select->where('bok.bokbooking_date = ?',$date);
//			}
//			       
//			$rowSet = $table->fetchAll($select);
//				
//			foreach($rowSet as $bokDet){
//				$totalcount = $bokDet->totalParty;
//			}
//				
			$schIdArr = array();
			$TimeArr = array();
//			foreach($Timings as $time){
//				$schIdArr[] = $time['schid'];
//				$TimeArr[] = date("H:i:s",strtotime($time['st']));;
//			}
			$timeSelect = $table->select();
			//$timeSelect->setIntegrityCheck(false);
					
			$timeSelect->from($table,array('SUM(bokparty_size) as timePartycount','bokbooking_timings'))
			   ->where('bokfk_restaurant = ?',$resid)
			   //->where('bokbooking_date = ?',$date)
			   //->where('bokbooking_timings IN(?)',$TimeArr)
			   ->where('bokbooking_status_id IN(?)',$statusId)
			   ->group(array('bokbooking_timings'));
			if(count($originsarr) > 0){
				$timeSelect->where('bokreservation_mode_id IN(?)',$originsarr);
			}   
			if($endreDate != ""){
				$timeSelect->where('bokbooking_date >= ?',$date);
				$timeSelect->where('bokbooking_date <= ?',$endreDate);
			}else{
				$timeSelect->where('bokbooking_date = ?',$date);
			}
			$timeSelect->order('bokbooking_timings');
					   
			$timeSet = $table->fetchAll($timeSelect);
			$i = 0;
			$matchArr = array();
			$mismatchArr = array();
			$timeSetCount = count($timeSet);
			if($timeSetCount > 0){
				foreach($timeSet as $val){
					$TotalValues[$val->bokbooking_timings] = $val->timePartycount;
				}
			}
			return $TotalValues;
//				$count = count($TimeArr);
//				$matchCount = count($matchArr);
//				$matchTimes = array_keys($matchArr);
//				$j = 0;
//				for($i;$i<$count;$i++){
//					if($matchCount > $j){
//						if($TimeArr[$i] != $matchTimes[$j]){
//							$TotalValues[$TimeArr[$i]] = 0;
//						}else{
//							$TotalValues[$matchTimes[$j]] = $matchArr[$matchTimes[$j]];
//							$j++;
//						}
//					}else{
//						$TotalValues[$TimeArr[$i]] = 0;
//					}
//				}
//			}
//			else{
//				foreach($timings as $time){
//					$TotalValues[date("H:i:s",strtotime($time['st']))] = 0;
//				}
//			}			
//			$result['count'] = $totalcount;
//			$result['TimReserv'] = $TotalValues;
//			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of reservation id ,restaurantid
	 * function to check the join table 
	 */
	public function CheckJoinTableNo($bookid,$restid)
	{
		try{
			if($bookid){
				$bookTable  = $this->getDbTable();
				$bookSelect = $bookTable->select();
				$joinTableNo = 0;
				$bookSelect->from($bookTable,array('bokbooking_date'))
				           ->where('bokid = ?',$bookid);
				$row = $bookTable->fetchRow($bookSelect);
				$date = $row->bokbooking_date;	
				if($date){
					$bookTableMapper = new Reservation_Model_BlockTableDataMapper();
					$bookJoinTable   = $bookTableMapper->getDbTable();
					$bookTableSelect = $bookJoinTable->select();
					$bookTableSelect->setIntegrityCheck(false);
				
					$bookTableSelect->from(array('bktb'=>'mt.booking_tables'),array('MAX(bktb_join_table_no) as count'))
									->join(array('bok'=>'mt.booking'),'bktb.bktbfk_booking = bok.bokid',array())
									->where('bok.bokbooking_date = ?',$date)
									->where('bktb.status = ?',true)
									->where('bok.bokfk_restaurant = ?',$restid);
									
					$countRow = $bookJoinTable->fetchAll($bookTableSelect);
					
					foreach($countRow as $row){
						$joinTableNo = $row->count;
					}										
				}				
				
				return $joinTableNo;				
			}
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
		
	}
	
	/**
	 * function to get the created times
	 */
	public function getCreatedTime()
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from($table,array('sum(bokparty_size) as party','bokbooking_made_time as createdTime'))
				   ->where('bokbooking_status_id IN(1,3,5,6,7,8,10)')
				   ->where('bokfk_restaurant NOT IN (select resid from mt.restaurant where resstate_id = 1 or resid = 3)')
				   ->group(array('bokbooking_made_time'))
				   ->order(array('bokbooking_made_time'));
			$resultSet = $table->fetchAll($select);
			$time = "";
			$finalArr = array();
			$count = "";
			foreach($resultSet as $row){
				$count += $row->party; 
				$timeArr = explode(":",$row->createdTime);
				if($timeArr[1] > 30){
					$timeArr[0] += 1;
					if((int)$timeArr[0] < 10){
						$timeArr[0] = '0'.(int)$timeArr[0];
					}
					$timeArr[1] = '00';
					if((int)$timeArr[0] < 12){
						$timeArr[2] = 'AM';
					}else{
						$timeArr[0] = (int)$timeArr[0] - 12;
						$timeArr[2] = 'PM';
					} 
				}else{
					$timeArr[1] = '00';
					if((int)$timeArr[0] < 12){
						$timeArr[2] = 'AM';
					}else{
						$timeArr[0] = (int)$timeArr[0] - 12;
						$timeArr[2] = 'PM';
					}
				}
				$time = implode(":",array((int)$timeArr[0],$timeArr[1]));
				$time = $time.' '.$timeArr[2];
				if(array_key_exists($time, $finalArr)){
					$finalArr[$time] += $row->party;
				}else{
					$finalArr[$time] = $row->party;
				}
			}
			return $finalArr;
			
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	/**
	 * @param instance of reservation id
	 * function to get the previous status of the reservation
	 */
	public function getBookingPrevStatus($bokid)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('bokbooked_status'))
				   ->where('bokid = ?',$bokid);
			$result = $this->getDbTable()->fetchRow($select);
			return $result->bokbooked_status;	
		}catch(Exception $ex){
			throw new Exception($ex->getMessage());
		}
	}
	
	/**
	 * @param instance of no-show list
	 * fucntion to retreive all the no-show reservations of that day
	 */
	public function GetNoShowReservation(Reservation_Model_GetNoShowList $noshow)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$status = $noshow->getBookStatus();
			foreach($status as $key=>$value){
				$statusId = $value->getId();
			}
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$noshow->getRestaurantId())
							  ->where('rda_status = ?',true);
							
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
				   ->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))				   				   
				   ->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
				   ->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokstatuscode'))				   
				   ->where('bok.bokfk_restaurant = ?',$noshow->getRestaurantId())
				   ->where('bok.bokbooking_date = ?',$noshow->getDate())				   
				   ->where('bok.bokbooking_status_id = ?',$statusId);
			if($noshow->getSortOrder()){
				$order  = $noshow->getSortOrder();
				$sorton = $noshow->getSortOn();
				
				if($order == "ASC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));					
				}else if($order == "ASC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned ASC','bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned DESC','bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));		
				}else if($order == "ASC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size ASC','bokbooking_timings ASC','boklast_name ASC'));
				}else if($order == "DESC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size DESC','bokbooking_timings DESC','boklast_name DESC'));
				}				
			}else{
				$select->order(array('bokbooking_timings','bokid'));
			}

			$rowset = $table->fetchAll($select);
			if(count($rowset)>0){
				if($noshow->getIsAjaxCall()){
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$tablNoArr = array();
					$dinigid = "";
					
					foreach($rowset as $row)
					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$prevBookid		    = $bokid;						
							
						}else{
							$bokid = $row->bokid;
							
							if($prevBookid == $bokid){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}
								
								array_push($resultSet,array('bokid' 			  => $prevBookid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
				 											'bokfirst_name' 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $boktablenumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'diningid'			  => $dinigid));
								
									
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$prevBookid		    = $bokid;
								$tablNoArr[] = $row->bktbtable_no_assigned;							
								
							}
						}
					}
					$date = "";
					if($bokbooking_timings){
						$date = date("h:i A",strtotime($bokbooking_timings));
					}
					array_push($resultSet,array('bokid' 			  => $bokid,
		 							 			'bokuserid' 		  => $bokuserid,
		 							 			'bokfk_restaurant'    => $bokfk_restaurant,
	 											'bokfirst_name' 	  => $bokfirst_name,				 							 
	 											'bokparty_size' 	  => $bokparty_size,
		 							 			'bokbooking_timings'  => date("h:i A",strtotime($date)),
		 							 			'bokspecial_request'  => $bokspecial_request,
		 							 			'boktypcode'		  => $boktypcode,
		 							 			'boktablenumber'	  => $boktablenumber,
		 							 			'boktableid' 		  => $boktableid,
												'bokjointableno'	  => $bokjointableno,
		 							 			'bokresmodecode' 	  => $bokresmodecode,
		 							 			'bokrestaurant_note'  => $bokrestaurant_note,
									 			'bokstatuscode'       => $bokstatuscode,
												'tableNoArr'		  => $tablNoArr,
												'diningid'			  => $dinigid));				
				
				}
			}

		return $resultSet;
		
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateWaitingQuote($bokid,$quote)
	{
		try{
			
			$restid = $this->getRestIdByBookId($bokid);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			$set = array(
					'bokquoted_time'		=>$quote,
					'boksync_status'		=> 'C',
					'bokupdated_date'		=> date('Y-m-d'),
					'bokupdatedby_userid'	=> $data['User_Id'],
					'bokupdateddatetime'	=> date("H:i:s",time())
					);
			$where = array('bokid = ?'=>$bokid);
			$rowsEffected = $this->getDbTable()->update($set,$where);	
			return $rowsEffected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/* Mobile function start */
	
	public function ReservationReportMobile(Reservation_Model_GetReservationReport $reservationreport)
	{
		try{
			$statusId = array();			
			$table = $this->getDbTable();			
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$restId = $reservationreport->getRestaurantId();
			
			$bookSeatsMapper = new Reservation_Model_ReservationTableMapper();
			$bookSeatsTable  = $bookSeatsMapper->getDbTable();
			$bookSeatsSelect = $bookSeatsTable->select();
			
			$bookSeatsSelect->from($bookSeatsTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokspecial_request','bokbooking_status_id','bokreadstatus'))
				   ->where('bok.bokfk_restaurant = ?',$restId)
				   ->joinLeft(array('bktb'=>$bookSeatsSelect),'bok.bokid = bktb.bktbfk_booking',array('bktbtable_no_assigned'))
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id','code as resvmode');
			
			if($reservationreport->getBookStatus()){
				$select->where('bkstatus.code IN(?)',$reservationreport->getBookStatus());
			}
			if($reservationreport->getBookStartDate() && $reservationreport->getBookEndDate()){
				$select->where('bok.bokbooking_date >= ?',$reservationreport->getBookStartDate());
				$select->where('bok.bokbooking_date <= ?',$reservationreport->getBookEndDate());
			}else if($reservationreport->getBookStartDate()){
				$select->where('bok.bokbooking_date = ?',$reservationreport->getBookStartDate());
			}
			$select->order(array('bokbooking_timings','bokparty_size'));
			$rowSet = $table->fetchAll($select);
			$result = array();
			foreach($rowSet as $row){
				$bookTime = date("h:i A",strtotime($row->bokbooking_timings));
				$result[] = array('bookid'			   => $row->bokid,
								  'bokbooking_timings' => $bookTime,
								  'bokbooking_date'	   => $row->bokbooking_date,
								  'bokfirst_name'	   => $row->bokfirst_name." ".$row->boklast_name,
								  'boklast_name'	   => $row->boklast_name,
								  'bokparty_size'	   => $row->bokparty_size,
								  'bokstatuscode'	   => $row->bokstatuscode,
								  'bokstatusdesc'	   => $row->bokstatusdesc,
								  'bokemail'		   => $row->bokemail,
								  'bokphone'		   => $row->bokphone,
								  'bokspecial_request' => $row->bokspecial_request,
								  'bokreadstatus'	   => $row->bokreadstatus,
								  'bokresvmode'	   	   => $row->resvmode,
								  'bktbtable_no_assigned' => $row->bktbtable_no_assigned  	
								  );	
			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function ReservationListMobile(Reservation_Model_GetAttendingList $getAttenListObj)
	{
		try{
			$statusId = array();			
			$table = $this->getDbTable();			
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$restId = $getAttenListObj->getRestaurantId();
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$restId)
							  ->where('rda_status = ?',true);
							
//			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note'))
//				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
//				   ->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))	;	

			$select->from(array('bok'=>'mt.booking'),array('bokid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokrestaurant_note','bokbooking_status_id','bokreadstatus','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status','bokresv_runninglate_status','bokbooking_confirm_status','bokbooked_status'))
				   ->where('bok.bokfk_restaurant = ?',$restId)
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id','code as resvmode');
			
			if($getAttenListObj->getBookStatus()){
				$select->where('bkstatus.code IN(?)',$getAttenListObj->getBookStatus());
			}
			if($getAttenListObj->getDate()){
				$select->where('bok.bokbooking_date = ?',$getAttenListObj->getDate());
			}
			$select->order(array('bokbooking_timings','bokid'));
			$rowSet = $table->fetchAll($select);
			$resultSet = array();
			
//			foreach($rowSet as $row){
				
				$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$boklast_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$tablNoArr = array();
					$dinigid = "";
					$bokdate			= '';
					$bokstatusdesc		= '';
					$bokemail			= '';
					$bokphone			= '';
					$bokreadstatus		= '';
					$bokcheckstatus		= '';
					$bokpartialarr		= '';
					$bokallarrive 		= '';
					$bokrunninglate		= '';
					$bokconfirmstatus	= '';
					$bokstatusid		= '';
					$bokbooked_status	= '';
					$bookTime = '';
					foreach($rowSet as $row)
					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
//							$bokuserid 		    = $row->bokuserid;
//							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
							$boklast_name		= $row->boklast_name;
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokrestaurant_note;
//							$boktypcode 		= $row->boktypcode;
//							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
//							$bokresmodecode 	= $row->bokresmodecode;
//							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
//							$dinigid			= $row->rda_diningdisplyname;
							$prevBookid		    = $bokid;
							$bokdate			= $row->bokbooking_date;
							$bokstatusdesc		= $row->bokstatusdesc;
							$bokemail			= $row->bokemail;
							$bokphone			= $row->bokphone;
							$bokreadstatus		= $row->bokreadstatus;
							$bokcheckstatus		= $row->bokresv_checkedin_status;
							$bokpartialarr		= $row->bokresv_partialarrived_status;
							$bokallarrive		= $row->bokresv_allarrived_status;
							$bokrunninglate		= $row->bokresv_runninglate_status;	
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$bokbooked_status		= $row->bokbooked_status;
							$bookTime = date("h:i A",strtotime($bokbooking_timings));						
							
						}else{
							$bokid = $row->bokid;
							
							if($prevBookid == $bokid){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								
								
								array_push($resultSet,array('bookid' 			  	=> $prevBookid,
												'bokbooking_timings'  	=> $bookTime,
												'bokbooking_date'	  	=> $bokdate,
												'bokfirst_name'			=> $bokfirst_name,
								  				'boklast_name'	   		=> $boklast_name,
												'bokparty_size'	   		=> $bokparty_size,
												'bokstatuscode'	   		=> $bokstatuscode,
												'bokstatusdesc'	   		=> $bokstatusdesc,
												'bokemail'		   		=> $bokemail,
												'bokphone'		   		=> $bokphone,
												'bokspecial_request' 	=> $bokspecial_request,
												'bokreadstatus' 	   	=> $bokreadstatus,
												'bokcheckstatus'		=> $bokcheckstatus,	
												'bokpartialarr'			=> $bokpartialarr,
												'bokallarrive'			=> $bokallarrive,
												'bokrunninglate'		=> $bokrunninglate,
												'bokconfirmstatus'		=> $bokconfirmstatus,
												'boktablenumber'	  	=> $boktablenumber,
		 							 			'boktableid' 		  	=> $boktableid,
												'bokjointableno'	 	=> $bokjointableno,
											    'bokbooked_status'		=> $bokbooked_status,
												'tableNoArr'		 	=> $tablNoArr));
								
								$tablNoArr			= null;
//								$bokuserid 		    = $row->bokuserid;
//								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
								$boklast_name		= $row->boklast_name;
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokrestaurant_note;
//								$boktypcode 		= $row->boktypcode;
//								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
//								$bokresmodecode 	= $row->bokresmodecode;
//								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
//								$dinigid			= $row->rda_diningdisplyname;
								$prevBookid		    = $bokid;
								$tablNoArr[] = $row->bktbtable_no_assigned;		
								$bokdate			= $row->bokbooking_date;
								$bokstatusdesc		= $row->bokstatusdesc;
								$bokemail			= $row->bokemail;
								$bokphone			= $row->bokphone;
								$bokreadstatus		= $row->bokreadstatus;
								$bokcheckstatus		= $row->bokresv_checkedin_status;
								$bokpartialarr		= $row->bokresv_partialarrived_status;
								$bokallarrive		= $row->bokresv_allarrived_status;
								$bokrunninglate		= $row->bokresv_runninglate_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$bokbooked_status	= $row->bokbooked_status;
								$bookTime = date("h:i A",strtotime($bokbooking_timings));
							}
						}
					}
					$date = "";
					
					array_push($resultSet,array('bookid' 			  	=> $bokid,
												'bokbooking_timings'  	=> $bookTime,
												'bokbooking_date'	  	=> $bokdate,
												'bokfirst_name'			=> $bokfirst_name,
								  				'boklast_name'	   		=> $boklast_name,
												'bokparty_size'	   		=> $bokparty_size,
												'bokstatuscode'	   		=> $bokstatuscode,
												'bokstatusdesc'	   		=> $bokstatusdesc,
												'bokemail'		   		=> $bokemail,
												'bokphone'		   		=> $bokphone,
												'bokspecial_request' 	=> $bokspecial_request,
												'bokreadstatus' 	   	=> $bokreadstatus,
												'bokcheckstatus'		=> $bokcheckstatus,
												'bokpartialarr'			=> $bokpartialarr,
												'bokallarrive'			=> $bokallarrive,
												'bokrunninglate'		=> $bokrunninglate,
												'bokconfirmstatus'		=> $bokconfirmstatus,
												'boktablenumber'	  	=> $boktablenumber,
		 							 			'boktableid' 		  	=> $boktableid,
												'bokjointableno'	 	=> $bokjointableno,
												'bokbooked_status'		=> $bokbooked_status,
												'tableNoArr'		 	=> $tablNoArr));
					
//				
//				$result[] = array('bookid'			   => $row->bokid,
//								  'bokbooking_timings' => $bookTime,
//								  'bokbooking_date'	   => $row->bokbooking_date,
//								  'bokfirst_name'	   => $row->bokfirst_name." ".$row->boklast_name,
//								  'boklast_name'	   => $row->boklast_name,
//								  'bokparty_size'	   => $row->bokparty_size,
//								  'bokstatuscode'	   => $row->bokstatuscode,
//								  'bokstatusdesc'	   => $row->bokstatusdesc,
//								  'bokemail'		   => $row->bokemail,
//								  'bokphone'		   => $row->bokphone,
//								  'bokspecial_request' => $row->bokspecial_request,
//								  'bokreadstatus' 	   => $row->bokreadstatus
//								  );	
			
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateBookingStatusToRead($bookid = "")
	{
		try{
			if($bookid){
				$set = array('bokreadstatus'=>true);
				$where = array('bokid = ?'=>$bookid);
				$table = $this->getDbTable();
				$rows_affected = $table->update($set,$where);
				return $rows_affected;	
			}else{
				return false;
			}				
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}		
	}
	
	public function savebookingtabledata($request, $bokid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$id = '';
			$db->beginTransaction();
			$count = 0;
			$tableIdArr = array();
		    $tableNoArr = array();
		    
		    $tableIdArr = explode(',',$request->wintableid);
		    $tableNoArr = explode(',',$request->wintableno);
		    $bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
		    $bookTable  = $bookTableMapper->getDbTable();
		    $count = count($tableIdArr);		    
		    if($count > 2){
		    /* Check the previous join table no's */
		    	
		    	$joinTableNo = "";
		    	
		    	$joinTableNo = $this->CheckJoinTableNo($bokid,$request->restaurantid);
		    	if($joinTableNo){
		    		$joinTableNo++;
		    	}else if($joinTableNo == 0 || $joinTableNo == null){
		    		$joinTableNo++;
		    	}
		    	for($item = 0; $item < $count-1; $item++){
		    		$data = array('bktbfk_booking'        => $bokid,
		    					  'bkt_dining_id'		  => $request->windiningid,
		    					  'bktbtableid' 		  => $tableIdArr[$item],
		    					  'bktbtable_no_assigned' => $tableNoArr[$item],
		    					  'bktb_join_table_no'    => $joinTableNo,
		    					  'status'                => true);
		    		$id = $bookTable->insert($data);	    		
		    	}
		    }else{/* If count of table is equal to one no join table no is required */
				for($item = 0; $item < $count-1; $item++){
		    		$data = array('bktbfk_booking'        => $bokid,
		    					  'bkt_dining_id'		  => $request->windiningid,
		    					  'bktbtableid' 		  => $tableIdArr[$item],
		    					  'bktbtable_no_assigned' => $tableNoArr[$item],		    					  
		    					  'status'                => true);
		    		$id = $bookTable->insert($data);	    		
		    	}	    	
		    }
			
//			$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
//		    $bookTable  = $bookTableMapper->getDbTable();
//			$data = array('bktbfk_booking'        => $bokid,
//	    				  'bkt_dining_id'		  => $request->windiningid,
//	    				  'bktbtableid' 		  => $request->wintableid,
//	    				  'bktbtable_no_assigned' => $request->wintableno,		    					  
//	    				  'status'                => true);
//	    	$id = $bookTable->insert($data);
			$db->commit();
	    	return $id;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getBokStatus($bookid)
	{
		try{
			$table = $this->getDbTable();			
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('bokbooked_status'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooked_status = boksts.id',array('code as bokstatuscode'))	
				   ->where('bokid = ?',$bookid);
			$rowSet = $table->fetchRow($select);
			return $rowSet->bokstatuscode;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function getBokPrasentStatus($bookid)
	{
		try{
			$table = $this->getDbTable();			
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('bokbooking_status_id'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokstatuscode'))	
				   ->where('bok.bokid = ?',$bookid);
			$rowSet = $table->fetchRow($select);
			return $rowSet->bokstatuscode;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function getCusBokHistory($bokDetails)
	{
		try{
			$table = $this->getDbTable();			
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokspecial_request','bokbooking_status_id','bokreadstatus'))
				   ->where('bok.bokfk_restaurant = ?',$bokDetails->getbokfk_restaurant())
				   ->where('bok.bokfirst_name ILIKE(?)','%'.$bokDetails->getbokfirst_name().'%')
				   ->where('bok.boklast_name ILIKE(?)','%'.$bokDetails->getboklast_name().'%')
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id','code as resvmode');
			if($bokDetails->getbokemail() && $bokDetails->getbokphone()){
				$select->where('bok.bokemail ILIKE(?)','%'.$bokDetails->getbokemail().'%');
				$select->orwhere('bok.bokphone = ?',$bokDetails->getbokphone());
			}else if($bokDetails->getbokemail()){
		    	$select->where('bok.bokemail ILIKE(?)','%'.$bokDetails->getbokemail().'%');	
		   	}else if($bokDetails->getbokphone()){
				$select->where('bok.bokphone = ?',$bokDetails->getbokphone());
		   	}
			$select->order(array('bokid DESC'));
			
			$rowSet = $table->fetchAll($select);
			foreach($rowSet as $row){
				$bookTime = date("h:i A",strtotime($row->bokbooking_timings));
				$result[] = array('Id'			   	=> $row->bokid,
								  'Time' 				=> $bookTime,
								  'Date'	   			=> date('m-d-Y',strtotime($row->bokbooking_date)),
								  'Name'	   			=> $row->bokfirst_name." ".$row->boklast_name,
								  'Size'	   			=> $row->bokparty_size,
								  'Status'	   			=> $row->bokstatusdesc
								  );
			}
			return $result; 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getBokHistoryofCus($request)
	{
		try{
			$table = $this->getDbTable();			
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokspecial_request','bokbooking_status_id','bokreadstatus'))
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id','code as resvmode');
		    if(($request->email && $request->email != 'null') && ($request->mobile && $request->mobile != 'null')){
				$select->where('bok.bokemail ILIKE(?)','%'.$request->email.'%');
				$select->orwhere('bok.bokphone = ?',$request->mobile);
			}else if($request->email && $request->email != 'null'){
			    $select->where('bok.bokemail ILIKE(?)','%'.$request->email.'%');
			}else if($request->mobile && $request->mobile != 'null'){
				$select->where('bok.bokphone = ?',$request->mobile);
		   	}
		   	$select->where('bok.bokfk_restaurant = ?',$request->resid);	   
			$select->order(array('bokid DESC'));
			
			$rowSet = $table->fetchAll($select);
			$result = array();
			foreach($rowSet as $row){
				$bookTime = date("h:i A",strtotime($row->bokbooking_timings));
				$result[] = array('Id'			   	=> $row->bokid,
								  'Time' 				=> $bookTime,
								  'Date'	   			=> date('d M Y',strtotime($row->bokbooking_date)),
								  'Name'	   			=> $row->bokfirst_name." ".$row->boklast_name,
								  'Size'	   			=> $row->bokparty_size,
								  'Status'	   			=> $row->bokstatusdesc
								  );
			}
			return $result; 
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getBokHistoryofCuspage($request,$offset)
	{
		try{
			$limit = 10;
			$table = $this->getDbTable();			
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','bokreservation_mode_id','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokspecial_request','bokbooking_status_id','bokreadstatus'))
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('btbd'=>'mt.booking_type_bd'),'btbd.id = bok.bokreservation_mode_id',array('code as bokrsvcode','description as bokrsvdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id','code as resvmode');
		    if(($request->email && $request->email != 'null') && ($request->mobile && $request->mobile != 'null')){
				$select->where('bok.bokemail ILIKE(?)','%'.$request->email.'%');
				$select->orwhere('bok.bokphone = ?',$request->mobile);
			}else if($request->email && $request->email != 'null'){
			    $select->where('bok.bokemail ILIKE(?)','%'.$request->email.'%');
			}else if($request->mobile && $request->mobile != 'null'){
				$select->where('bok.bokphone = ?',$request->mobile);
		   	}
		   	$select->where('bok.bokfk_restaurant = ?',$request->resid);	   
			$select->order(array('bokid DESC'));
			$resultSet = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
			$result = array();
			foreach($resultSet as $row){
			$bookTime = date("h:i A",strtotime($row->bokbooking_timings));
			$result[] = array('Id'			   	=> $row->bokid,
							  'Time' 				=> $bookTime,
							  'Date'	   			=> date('d M Y',strtotime($row->bokbooking_date)),
							  'Origin'	   			=> $row->bokrsvdesc,
							  'Size'	   			=> $row->bokparty_size,
							  'Status'	   			=> $row->bokstatusdesc,	
							  );
			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getCountByMealType(FirmManagement_Model_FirmMealType  $mealType)
	{
		try{
			$seated = $mealType->getSeated();
			$seatedStatus = array();
			foreach($seated as $key=>$value){
				$seatedStatus[] = $value->getId();
			}
			
			$seating = $mealType->getSeating();
			$seatingStatus = array();
			foreach($seating as $key=>$value){
				$seatingStatus[] = $value->getId();
			}
			
			$about = $mealType->getAboutToSeat();
			$aboutStatus = array();
			foreach($about as $key=>$value){
				$aboutStatus[] = $value->getId();
			}
			
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('SUM(bokparty_size) as totalParty'))
		   		   ->where('bok.bokfk_restaurant = ?',$mealType->getResId())
		   		   ->where('bok.bokbooking_timings >= ?',$mealType->getStartTime())
				   ->where('bok.bokbooking_timings <= ?',$mealType->getEndTime())
			   	   ->where('bok.bokbooking_date = ?',$mealType->getDate())
			       ->where('bok.bokbooking_status_id IN(?)',$seatedStatus);
				       
			$seatedSet = $this->getDbTable()->fetchAll($select);
			
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('SUM(bokparty_size) as totalParty'))
		   		   ->where('bok.bokfk_restaurant = ?',$mealType->getResId())
		   		   ->where('bok.bokbooking_timings >= ?',$mealType->getStartTime())
				   ->where('bok.bokbooking_timings <= ?',$mealType->getEndTime())
			   	   ->where('bok.bokbooking_date = ?',$mealType->getDate())
				   ->where('bok.bokbooking_status_id IN(?)',$seatingStatus);
			
			$seatingSet = $this->getDbTable()->fetchAll($select);
			
			
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('SUM(bokparty_size) as totalParty'))
		   		   ->where('bok.bokfk_restaurant = ?',$mealType->getResId())
		   		   ->where('bok.bokbooking_timings >= ?',$mealType->getStartTime())
				   ->where('bok.bokbooking_timings <= ?',$mealType->getEndTime())
			   	   ->where('bok.bokbooking_date = ?',$mealType->getDate())
					->where('bok.bokbooking_status_id IN(?)',$aboutStatus);
			
			$aboutSet = $this->getDbTable()->fetchAll($select);
			$resultSet = array();
			$seatedCount = '';
			foreach($seatedSet as $row){
				$seatedCount = $row->totalParty;
			}
			$seatingCount = '';
			foreach($seatingSet as $row){
				$seatingCount = $row->totalParty;
			}
			$aboutCount = '';
			foreach($aboutSet as $row){
				$aboutCount = $row->totalParty;
			}
			$count = $seatedCount + $seatingCount + $aboutCount;
			$resultSet['seated'] = $seatedCount;
			$resultSet['seating'] = $seatingCount;
			$resultSet['about'] = $aboutCount;
			$resultSet['count'] = $count;
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function UpdateBookingGuestNotes(Reservation_Model_Reservation $bookingObj)
	{
		try{
			$status = false;
			$table  = $this->getDbTable();
			$set 	= array('bokspecial_request'	=> $bookingObj->getbokspecial_request());
			$where 	= array('bokid = ?' => $bookingObj->getbokid());

			$rows_affected = $table->update($set,$where);

			if($rows_affected){
				$status = true;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function changeBokConfirmStatus($bookid,$status)
	{
		try{
			$table  = $this->getDbTable();
			
			$restid = $this->getRestIdByBookId($bookid);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			
			$set = array(
							'bokbooking_confirm_status' => $status,
							'bokresv_checkedin_status' => 'f',
							'bokresv_allarrived_status' => 'f',
							'bokresv_partialarrived_status' => 'f',
							'bokresv_runninglate_status'	=> 'f',
							'boksync_status'			=> 'C',
							'bokupdated_date'			=> date('Y-m-d'),
							'bokupdateddatetime'		=> date("H:i:s",time()),
			 				'bokupdatedby_userid'		=> $data['User_Id'],
						);
			$where = array('bokid = ?'=>$bookid);
			$rows_affected = $table->update($set,$where);
			
			$bokStat = $this->getBookingPrevStatus($bookid);
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($bookid)
					->setbok_log_booked_type($bokStat)
					->setbok_log_updated_by($data['User_Id'])
					->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			if($status == 'leftmessage'){
				$bokLog->setbok_log_book_message('Reservation Guest Left Message');
			}else if($status == 'noanwser'){
				$bokLog->setbok_log_book_message('Reservation Guest No Answer');
			}else if($status == 'resvconfirm'){
				$bokLog->setbok_log_book_message('Reservation Confirmed');
				
				$resService = new Application_Service_Reservation();
				$result = $resService->sendAutoConfirmNotificationByBokId($bookid);
			}
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function ManageCheckedInResv($bookid,$status)
	{
		try{
			$table  = $this->getDbTable();
			$restid = $this->getRestIdByBookId($bookid);
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			$bokLog = new Reservation_Model_BookingLog();
			$bokStat = $this->getBookingPrevStatus($bookid);
			if($status == 'chekedin'){
				$set = array(
								'bokresv_checkedin_status' => true,
								'bokupdated_date'			=> date('Y-m-d'),
								'bokupdateddatetime'		=> date("H:i:s",time()),
				                'bokupdatedby_userid'		=> $data['User_Id'],
								'boksync_status'			=> 'C'
							);
				$bokLog->setbok_log_fk_booking($bookid)
						->setbok_log_booked_type($bokStat)
						->setbok_log_book_message('Reservation Checked In')
						->setbok_log_updated_by($data['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
			}else if($status == 'chekedoff'){
				$set = array(
								'bokresv_checkedin_status' => 'f',
								'bokupdated_date'			=> date('Y-m-d'),
								'bokupdateddatetime'		=> date("H:i:s",time()),
				 				'bokupdatedby_userid'		=> $data['User_Id'],
								'boksync_status'			=> 'C'
							);
				$bokLog->setbok_log_fk_booking($bookid)
						->setbok_log_booked_type($bokStat)
						->setbok_log_book_message('Reservation Checked Off')
						->setbok_log_updated_by($data['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
			}
			$where = array('bokid = ?'=>$bookid);
			$rows_affected = $table->update($set,$where);	
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function ManageAllArrivedResv($bookid,$status)
	{
		try{
			$table  = $this->getDbTable();
			
			$restid = $this->getRestIdByBookId($bookid);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			$bokStat = $this->getBookingPrevStatus($bookid);
			$bokLog = new Reservation_Model_BookingLog();
			
			if($status == 'chekedin'){
				$set = array(
								'bokresv_allarrived_status' => true,
								'bokresv_partialarrived_status' => 'f',
								'bokresv_checkedin_status'		=> 'f',
								'bokresv_runninglate_status'	=> 'f',
								'bokupdated_date'				=> date('Y-m-d'),
								'bokupdateddatetime'			=> date("H:i:s",time()),
								'boksync_status'				=> 'C'
							);
				$bokLog->setbok_log_fk_booking($bookid)
						->setbok_log_booked_type($bokStat)
						->setbok_log_book_message('Reservation Guest Arrived')
						->setbok_log_updated_by($data['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
			}else if($status == 'chekedoff'){
				$set = array(
								'bokresv_allarrived_status' => 'f',
								'bokupdated_date'			=> date('Y-m-d'),
								'bokupdateddatetime'		=> date("H:i:s",time()),
								'boksync_status'			=> 'C'
							);
				$bokLog->setbok_log_fk_booking($bookid)
						->setbok_log_booked_type($bokStat)
						->setbok_log_book_message('Reservation Guest not arrived')
						->setbok_log_updated_by($data['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
			}
			$where = array('bokid = ?'=>$bookid);
			$rows_affected = $table->update($set,$where);
			
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function ManagePartialArrivedResv($bookid,$status)
	{
		try{
			$table  = $this->getDbTable();
			
			$restid = $this->getRestIdByBookId($bookid);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			
			$bokStat = $this->getBookingPrevStatus($bookid);
			$bokLog = new Reservation_Model_BookingLog();
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();
			if($status == 'chekedin'){
				$set = array(
								'bokresv_partialarrived_status' => true,
								'bokresv_allarrived_status' 	=> 'f',
								'bokresv_checkedin_status'		=> 'f',
								'bokresv_runninglate_status'	=> 'f',
								'bokupdated_date'				=> date('Y-m-d'),
								'bokupdateddatetime'			=> date("H:i:s",time()),
								'boksync_status'				=> 'C'
							);
				$bokLog->setbok_log_fk_booking($bookid)
						->setbok_log_booked_type($bokStat)
						->setbok_log_book_message('Reservation Guest Partially Arrived')
						->setbok_log_updated_by($data['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
			}else if($status == 'chekedoff'){
				$set = array(
								'bokresv_partialarrived_status' => 'f',
								'bokupdated_date'			=> date('Y-m-d'),
								'bokupdateddatetime'		=> date("H:i:s",time()),
								'boksync_status'			=> 'C'
							);
				$bokLog->setbok_log_fk_booking($bookid)
						->setbok_log_booked_type($bokStat)
						->setbok_log_book_message('Reservation Not Arrived')
						->setbok_log_updated_by($data['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
			}
			$where = array('bokid = ?'=>$bookid);
			$rows_affected = $table->update($set,$where);
			
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function ManageRunningLateResv($bookid,$status,$userid=null)
	{
		try{
			$table  = $this->getDbTable();
			
			$restid = $this->getRestIdByBookId($bookid);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			$userdata = array();
			if($userid==null)
			{
				$storage = new Zend_Auth_Storage_Session();
				$userdata = $storage->read();
			}
			else
			{
				$userdata['User_Id'] = $userid;
			}
			$bokStat = $this->getBookingPrevStatus($bookid);
			$bokLog = new Reservation_Model_BookingLog();
			
			if($status == 'runninglate'){
				$set = array(
								'bokresv_runninglate_status'	=> true,
								'bokresv_checkedin_status'		=> 'f',
								'bokresv_partialarrived_status'	=> 'f',
								'bokresv_allarrived_status'		=> 'f',
								'bokupdated_date'				=> date('Y-m-d'),
								'bokupdateddatetime'			=> date("H:i:s",time()),
								'boksync_status'				=> 'C',
								'bokupdatedby_userid'			=> $userdata['User_Id']
							);
				$bokLog->setbok_log_fk_booking($bookid)
						->setbok_log_booked_type($bokStat)
						->setbok_log_book_message('Reservation Guest Running Late')
						->setbok_log_updated_by($userdata['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
			}else if($status == 'runninglateoff'){
				$set = array(
								'bokresv_runninglate_status'=> 'f',
								'bokupdated_date'			=> date('Y-m-d'),
								'bokupdateddatetime'		=> date("H:i:s",time()),
								'boksync_status'			=> 'C',
								'bokupdatedby_userid'		=> $userdata['User_Id']
							);
				$bokLog->setbok_log_fk_booking($bookid)
						->setbok_log_booked_type($bokStat)
						->setbok_log_book_message('Reservation Guest Cancel Running Late')
						->setbok_log_updated_by($userdata['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
			}
			$where = array('bokid = ?'=>$bookid);
			$rows_affected = $table->update($set,$where);
			
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function ClearReservationStatus($bookid)
	{
		try{
			$table  = $this->getDbTable();			
			$restid = $this->getRestIdByBookId($bookid);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			$set = array(
						'bokresv_checkedin_status'  => 'f',
						'bokresv_runninglate_status'=> 'f',
						'bokresv_allarrived_status'=>'f',
						'bokresv_partialarrived_status'=>'f',
						'bokbooking_confirm_status' => '',
						'bokupdated_date'			=> date('Y-m-d'),
						'bokupdateddatetime'		=> date("H:i:s",time()),
						'boksync_status'			=> 'C',
						'bokupdatedby_userid'		=> $userdata['User_Id']
					);
			$where = array('bokid = ?'=>$bookid);
			$rows_affected = $table->update($set,$where);
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
			$bookTable  = $bookTableMapper->getDbTable();
			$set = array('status' => 0);
			$where = array('bktbfk_booking = ?' => $bookid);
			$bookTable->update($set,$where);	

			$bokStat = $this->getBookingPrevStatus($bookid);
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($bookid)
					->setbok_log_booked_type($bokStat)
					->setbok_log_book_message('Reservation Clear Status')
					->setbok_log_updated_by($userdata['User_Id'])
					->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveReservationsForChitsAndDupes(Reservation_Model_ReservationsChitsAndDupes $ReservChitsAndDupes)
	{
		try{
			
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$statusId = array();
			$status = $ReservChitsAndDupes->getBookStatus();
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$ReservChitsAndDupes->getRestaurantId())
							  ->where('rda_status = ?',true);

			$servertablemapper = new Server_Model_ServerTableMapDataMapper();
			$servertable = $servertablemapper->getDbTable();
			$servertableselect = $servertable->select(); 
			$servertableselect->setIntegrityCheck(false);
			$servertableselect->from(array('stm'=>'mt.server_table_map'),array('stm_tableid','stm_fk_serv'))
			       ->join(array('sec'=>'mt.servers'),'stm.stm_fk_serv = sec.serv_id',array('serv_name'))
			       ->where('sec.serv_resid = ?',$ReservChitsAndDupes->getRestaurantId())
				   ->where('sec.serv_status = ?',1)
				   ->where('stm.stm_status = ?',true)
				   ->distinct();

			$rgutablemapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
			$rgutable = $rgutablemapper->getDbTable();
			$rgutableselect = $rgutable->select(); 
			$rgutableselect->from($rgutable,array('rguid','rguallergies_dislikes','rgu_reservation_count','rgu_noshow_count','rgu_cancel_count','rgu_reschedule_count','rgu_total_count','rgu_walkin_count','rgudesignation'));
			  
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note','bokresv_confirm_status','bokbooking_confirm_status','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status','bokphone','bokemail','bok_contactid'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
				   ->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))	
				   ->joinLeft(array('server'=>'mt.servers'),'serv_id = bok_serverid',array('serv_name as server_name'))	
				   ->joinLeft(array('serv'=>$servertableselect),'serv.stm_tableid = bktb.bktbtableid',array('serv_name as table_servername'))		
				   ->joinLeft(array('rgu'=>$rgutableselect),'rgu.rguid = bok.bok_contactid',array('rguallergies_dislikes','rgu_reservation_count','rgu_noshow_count','rgu_cancel_count','rgu_reschedule_count','rgu_total_count','rgu_walkin_count','rgudesignation'))		   				   
				   ->join(array('res'=>'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('resrestaurant_name','reslogo'))		   				   
				   ->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
				   ->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokstatuscode'))				   
				   ->where('bok.bokfk_restaurant = ?',$ReservChitsAndDupes->getRestaurantId())
				   ->where('bok.bokbooking_date = ?',$ReservChitsAndDupes->getDate())				   
				   ->where('bok.bokbooking_status_id IN(?)',$statusId);
				   
		    $select->order(array('bokbooking_timings','bokid'));
		    
		    $rowset = $table->fetchAll($select);
		    
		    if(count($rowset)>0){
		    					
					$prevBokidArr = array();
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$resname = "";
					$reslogo = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokresmodedesc = '';
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$tablNoArr = array();
					$dinigid = "";
					$resvconfirmstatus  = "";
					$resvnoanwser = "";
					$resvcheckedin = "";
					$bokconfirmstatus = "";
					$allarrived	= '';
					$partialarr	= '';
					$bokphone = "";
					$bokemail = "";
					$reserveCount = "";
					$canCount     = "";
					$noShowCount  = "";
					$walkinCount = "";
					$totalCount = "";
					$allergies = "";
					$servername = "";
					$Tableservername = "";
					$rgudesignation = '';
					
					foreach($rowset as $row)
					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$resname			= $row->resrestaurant_name;
							$reslogo			= $row->reslogo;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$bokphone			= $row->bokphone;
							$bokemail			= $row->bokemail;
							$servername      	= $row->server_name;
							$Tableservername	= $row->table_servername;
							$allergies     		= $row->rguallergies_dislikes;
							$reserveCount 		= $row->rgu_reservation_count;
							$canCount     		= $row->rgu_cancel_count;
							$noShowCount  		= $row->rgu_noshow_count;
							$walkinCount 		= $row->rgu_walkin_count;
							$totalCount 		= $row->rgu_total_count;
							$prevBookid		    = $bokid;	
							$prevBokidArr[]		= $bokid;
							$rgudesignation		= $row->rgudesignation;					
							
						}else{
							$bokid = $row->bokid;
							
							if(in_array($bokid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}	
								$tempTableNumber = null;
								if(count($tablNoArr)>0)
								{
									sort($tablNoArr);
									$tempTableNumber = $tablNoArr[0];
								}
																															
								array_push($resultSet,array('bokid' 			  => $prevBookid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
															'resname'			  => $resname,
															'reslogo'			  => $reslogo,
				 											'bok_name'		 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $tempTableNumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
															'bokresmodedesc'	  => $bokresmodedesc,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'diningid'			  => $dinigid,
															'resvconfirmstatus'   => $resvconfirmstatus,
															'bokconfirmstatus'	  => $bokconfirmstatus,
															'resvcheckedin'	   	  => $resvcheckedin,
															'allarrived'		  => $allarrived,
												 			'partialarr'		  => $partialarr,
															'bokphone'			  => $bokphone,
															'bokemail'			  => $bokemail,
															'reservecount'		  => $reserveCount,
															'cancelCount'		  => $canCount,
															'noShowCount'		  => $noShowCount,
															'servername'      	  => $servername,
															'Tableservername'	  => $Tableservername,
															'walkincount'		  => $walkinCount,
															'totalcount'		  => $totalCount,
															'allergies'			  => $allergies,
															'rgudesignation'	  => $rgudesignation
															));
								
									
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$resname			= $row->resrestaurant_name;
								$reslogo			= $row->reslogo;
								$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;
								$bokphone			= $row->bokphone;
								$bokemail			= $row->bokemail;
								$prevBookid		    = $bokid;
								$tablNoArr[] 		= $row->bktbtable_no_assigned;	
								$prevBokidArr[]		= $bokid;	
								$servername      	= $row->server_name;
								$Tableservername	= $row->table_servername;				
								$allergies     		= $row->rguallergies_dislikes;
								$reserveCount 		= $row->rgu_reservation_count;
								$canCount     		= $row->rgu_cancel_count;
								$noShowCount  		= $row->rgu_noshow_count;
								$walkinCount 		= $row->rgu_walkin_count;
								$totalCount 		= $row->rgu_total_count;
								$rgudesignation		= $row->rgudesignation;
							}
						}
					}
					$date = "";
					if($bokbooking_timings){
						$date = date("h:i A",strtotime($bokbooking_timings));
					}
					$tempTableNumber = null;
					if(count($tablNoArr)>0)
					{
						sort($tablNoArr);
						$tempTableNumber = $tablNoArr[0];
					}
					array_push($resultSet,array('bokid' 			  => $bokid,
		 							 			'bokuserid' 		  => $bokuserid,
		 							 			'bokfk_restaurant'    => $bokfk_restaurant,
	 											'resname'			  => $resname,
												'reslogo'			  => $reslogo,
	 											'bok_name'		 	  => $bokfirst_name,				 							 
	 											'bokparty_size' 	  => $bokparty_size,
		 							 			'bokbooking_timings'  => $date,
		 							 			'bokspecial_request'  => $bokspecial_request,
		 							 			'boktypcode'		  => $boktypcode,
		 							 			'boktablenumber'	  => $tempTableNumber,
		 							 			'boktableid' 		  => $boktableid,
												'bokjointableno'	  => $bokjointableno,
		 							 			'bokresmodecode' 	  => $bokresmodecode,
												'bokresmodedesc'	  => $bokresmodedesc,
		 							 			'bokrestaurant_note'  => $bokrestaurant_note,
									 			'bokstatuscode'       => $bokstatuscode,
												'tableNoArr'		  => $tablNoArr,
												'diningid'			  => $dinigid,
												'resvconfirmstatus'   => $resvconfirmstatus,
												'bokconfirmstatus'	  => $bokconfirmstatus,
												'resvcheckedin'	   	  => $resvcheckedin,
												'allarrived'		  => $allarrived,
												'partialarr'		  => $partialarr,
												'bokphone'			  => $bokphone,
												'bokemail'			  => $bokemail,
												'reservecount'		  => $reserveCount,
												'cancelCount'		  => $canCount,
												'noShowCount'		  => $noShowCount,
												'servername'      	  => $servername,
												'Tableservername'	  => $Tableservername,
												'walkincount'		  => $walkinCount,
												'totalcount'		  => $totalCount,
												'allergies'			  => $allergies,
												'rgudesignation'	  => $rgudesignation));					
				
				
			}
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function RetrieveReservationCounts($restid,$date = "",$bookstatus,$timesLimit = null)
	{
		try{
			
			$table 		 = $this->getDbTable();	
			
			$count = 0;
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			if(!$date){
				$date = date('Y-m-d');
			}
			
			$resultArr = array();
			foreach($bookstatus as $key=>$value){
				$statusId = array();
				foreach($value as $k=>$val){
					$statusId[] = $val->getId();
				}
				$countSelect = $table->select();
				$countSelect->from($table,array('count(bokid) as reserveCount','SUM(bokparty_size) as totalParty'))
							->where('bokfk_restaurant = ?',$restid)
							->where('bokbooking_date = ? ',$date);					
				$countSelect->where('bokbooking_status_id IN(?)',$statusId);
				if($timesLimit!=null)
				{
					$countSelect = $countSelect->where('bokbooking_timings >=?',$timesLimit['start_time']);
					$countSelect = $countSelect->where('bokbooking_timings <=?',$timesLimit['end_time']);

				}			
				$row = $table->fetchRow($countSelect);
				
				if($row){
					$resultArr[$key]['totalCount'] = $row->reserveCount;	
					if($row->totalParty){
						$resultArr[$key]['totalParty'] = $row->totalParty;	
					}else{
						$resultArr[$key]['totalParty'] = 0;
					}
				}
			}
						
			return $resultArr; 
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	
	public function cancelCompletion($bookid,$status)
	{
		try{
			$table  = $this->getDbTable();
			$restid = $this->getRestIdByBookId($bookid);
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			
			$set = array(
							'bokbooking_status_id' 		=> $status,
							'bokupdated_date'			=> date('Y-m-d'),
							'bokupdateddatetime'		=> date("H:i:s",time()),
							'bokupdatedby_userid'		=> $userdata['User_Id']
						);
			$where = array('bokid = ?'=>$bookid);
			$rows_affected = $table->update($set,$where);
			
			$bokStat = $this->getBookingPrevStatus($bookid);
			$bokLog = new Reservation_Model_BookingLog();
			$bokLog->setbok_log_fk_booking($bookid)
					->setbok_log_booked_type($bokStat)
					->setbok_log_book_message('Cancel Completed')
					->setbok_log_updated_by($userdata['User_Id'])
					->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    		->setbok_log_update_done_by('RES');
			$bokLogMapper = new Reservation_Model_BookingLogMapper();
			$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
			
			return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	/**
	 * @param instance of completedlist
	 * retreive all the reservations with status no show
	 */
	public function getCompletedList(Reservation_Model_GetCompletedList $completedlist)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
			$statusId = array();
			$status = $completedlist->getBookStatus();
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($completedlist->getRestaurantId());
			date_default_timezone_set($timezone);
			
			$seatStart = strtotime(date('Y-m-d H:i:s'));
			
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			
			$diningTableSelect = $diningTable->select();
			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
							  ->where('rda_restid = ?',$completedlist->getRestaurantId())
							  ->where('rda_status = ?',true);
			
			$initialTableMapper = new User_Model_PatronCodesDataMapper(); 
			$initialTableSelect = $initialTableMapper->getDbTable()->select();
			$initialTableSelect->from($initialTableMapper->getDbTable(),array('rsui_fk_user','rsui_initial'))
								->where('rsui_fk_restaurant = ?',$completedlist->getRestaurantId());
								
			$bookOptionsMapper = new Reservation_Model_ReservationOptionsMapDataMapper();
			$bookOptions       = $bookOptionsMapper->getDbTable();
			$bookOptionsSelect = $bookOptions->select(); 
			$bookOptionsSelect->setIntegrityCheck(false);
			$bookOptionsSelect->from(array('bom'=>'mt.booking_options_map'),array('bopmbokid','bopmbok_optionsid'))
							  ->join(array('bop'=>'mt.booking_options'),'bop.boptid = bom.bopmbok_optionsid',array('boptdescription','boptid','boptcode'));								
							
							
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokspecial_request','bokrestaurant_note','bokresv_confirm_status','bokbooking_confirm_status','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status','bokbooked_status','bokcreatedby','bokseat_start','bokseat_end','bokfeedback_status'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
				   ->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))				   				   
				   ->joinLeft(array('ini'=>$initialTableSelect),'ini.rsui_fk_user = bok.bokbooking_user_initials',array('rsui_initial as initial'))
				   ->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
				   ->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokstatuscode'))
				   ->joinLeft(array('bookopt'=>$bookOptionsSelect),'bookopt.bopmbokid = bok.bokid',array('array_agg(boptdescription) as bookoption','array_agg(boptid) as boptid','array_agg(boptcode) as boptcode'))				   
				   ->where('bok.bokfk_restaurant = ?',$completedlist->getRestaurantId())
//				   ->where('ini.rsui_fk_restaurant = ?',$completedlist->getRestaurantId())
				   ->where('bok.bokbooking_date = ?',$completedlist->getDate())				   
				   ->where('bok.bokbooking_status_id IN(?)',$statusId);
			/**ADD MEAL PERIOD FILTERS **/
			$starttime = $completedlist->getStartTime();
			$endtime = $completedlist->getEndTime();
			if((isset($starttime))&&(isset($endtime)))
			{
				$select = $select->where('bokbooking_timings >= ? ',$starttime);
				$select = $select->where('bokbooking_timings <= ?',$endtime);
			}
			/**END ADD MEAL PERIOD FILTERS **/	   
			if($completedlist->getSortOrder()){
				$order  = $completedlist->getSortOrder();
				$sorton = $completedlist->getSortOn();
				
				if($order == "ASC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "booktime"){
					$select->order(array('bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));					
				}else if($order == "ASC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned ASC','bokbooking_timings ASC','bokparty_size ASC','boklast_name ASC'));	
				}else if($order == "DESC" && $sorton == "boktablenumber"){
					$select->order(array('bktb.bktbtable_no_assigned DESC','bokbooking_timings DESC','bokparty_size DESC','boklast_name DESC'));		
				}else if($order == "ASC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size ASC','bokbooking_timings ASC','boklast_name ASC'));
				}else if($order == "DESC" && $sorton == "bokparty_size"){
					$select->order(array('bokparty_size DESC','bokbooking_timings DESC','boklast_name DESC'));
				}				
			}else{
				$select->order(array('bokbooking_timings','bokid'));
			}
			$select->group(array('bokid','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id','rda_diningdisplyname','rsui_initial','boktyp.code','boktyp.description','resmode.code','resmode.description','boksts.code'));
			$rowset = $table->fetchAll($select);
			if(count($rowset)>0){
				if($completedlist->getIsAjaxCall()){	
					$prevBokidArr = array();
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$tablNoArr = array();
					$dinigid = "";
					$resvconfirmstatus  = "";
					$resvnoanwser = "";
					$resvcheckedin = "";
					$bokconfirmstatus = "";
					$allarrived	= '';
					$partialarr	= '';
					$initial = '';
					$bokbooked_status = '';
					$bokoption	= '';
					$bokoptioncode = "";
					$bokoptionArr = "";
					$bokoptioncodeArr = "";
					$bokcreatedby = '';
					$bokseat_start = '';
					$bokseat_duration = '';
					$bokfeedback_status = '';
					foreach($rowset as $row)
					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = strtoupper($row->bokfirst_name." ".$row->boklast_name);				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBookid		    = $bokid;	
							$prevBokidArr[]		= $bokid;
							$initial			= $row->initial;
							$bokbooked_status   = $row->bokbooked_status;					
							$bokoptionArr		= explode(',',substr($row->bookoption,1,-1));
							$bokoptioncodeArr	= explode(',',substr($row->boptcode,1,-1));	
							if($bokoptionArr[0] && $bokoptionArr[0] != 'NULL' && $bokoptionArr[0] != "''"){
								$bokoption		= $bokoptionArr;
								$bokoptioncode	= $bokoptioncodeArr;	
							}else{
								$bokoption			= "";
								$bokoptioncode 		= "";
							}
							$bokcreatedby		= $row->bokcreatedby;
							$bokfeedback_status	= $row->bokfeedback_status;
							if($row->bokseat_start && $row->bokseat_end){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
							}else if($row->bokseat_start){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
							}else{
								$bokseat_start		= '' ;
								$bokseat_duration	= '';
							}
						}else{
							$bokid = $row->bokid;
							
							if(in_array($bokid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}
								
								array_push($resultSet,array('bokid' 			  => $prevBookid,
					 							 			'bokuserid' 		  => $bokuserid,
					 							 			'bokfk_restaurant'    => $bokfk_restaurant,
				 											'bokfirst_name' 	  => $bokfirst_name,				 							 
				 											'bokparty_size' 	  => $bokparty_size,
					 							 			'bokbooking_timings'  => $date,
					 							 			'bokspecial_request'  => $bokspecial_request,
					 							 			'boktypcode'		  => $boktypcode,
					 							 			'boktablenumber'	  => $boktablenumber,
					 							 			'boktableid' 		  => $boktableid,
															'bokjointableno'	  => $bokjointableno,
					 							 			'bokresmodecode' 	  => $bokresmodecode,
					 							 			'bokrestaurant_note'  => $bokrestaurant_note,
												 			'bokstatuscode'       => $bokstatuscode,
															'tableNoArr'		  => $tablNoArr,
															'diningid'			  => $dinigid,
															'resvconfirmstatus'   => $resvconfirmstatus,
															'bokconfirmstatus'	  => $bokconfirmstatus,
															'resvcheckedin'	   	  => $resvcheckedin,
															'allarrived'		   => $allarrived,
												 			'partialarr'		   => $partialarr,
															'bokbooked_status'	  => $bokbooked_status,
															'initial'			  => $initial,
															'bokoption'			  => $bokoption,
															'bokoptioncode'		  => $bokoptioncode,
															'bokcreatedby'		  => $bokcreatedby,
															'bokseat_start'		  => $bokseat_start,
															'bokfeedback_status'  => $bokfeedback_status,
															'bokseat_duration'	  => $bokseat_duration));
								
									
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = strtoupper($row->bokfirst_name." ".$row->boklast_name);				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;
								$prevBookid		    = $bokid;
								$tablNoArr[] = $row->bktbtable_no_assigned;	
								$prevBokidArr[]		= $bokid;
								$initial			= $row->initial;
								$bokbooked_status   = $row->bokbooked_status;
								$bokoptionArr		= explode(',',substr($row->bookoption,1,-1));
								$bokoptioncodeArr	= explode(',',substr($row->boptcode,1,-1));	
								if($bokoptionArr[0] && $bokoptionArr[0] != 'NULL' && $bokoptionArr[0] != "''"){
									$bokoption		= $bokoptionArr;
									$bokoptioncode	= $bokoptioncodeArr;	
								}else{
									$bokoption			= "";
									$bokoptioncode 		= "";
								}
								$bokcreatedby		= $row->bokcreatedby;
								$bokfeedback_status = $row->bokfeedback_status;
								if($row->bokseat_start && $row->bokseat_end){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
								}else if($row->bokseat_start){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
								}else{
									$bokseat_start		= '' ;
									$bokseat_duration	= '';
								}
							}
						}
					}
					$date = "";
					if($bokbooking_timings){
						$date = date("h:i A",strtotime($bokbooking_timings));
					}
					array_push($resultSet,array('bokid' 			  => $bokid,
		 							 			'bokuserid' 		  => $bokuserid,
		 							 			'bokfk_restaurant'    => $bokfk_restaurant,
	 											'bokfirst_name' 	  => $bokfirst_name,				 							 
	 											'bokparty_size' 	  => $bokparty_size,
		 							 			'bokbooking_timings'  => $date,
		 							 			'bokspecial_request'  => $bokspecial_request,
		 							 			'boktypcode'		  => $boktypcode,
		 							 			'boktablenumber'	  => $boktablenumber,
		 							 			'boktableid' 		  => $boktableid,
												'bokjointableno'	  => $bokjointableno,
		 							 			'bokresmodecode' 	  => $bokresmodecode,
		 							 			'bokrestaurant_note'  => $bokrestaurant_note,
									 			'bokstatuscode'       => $bokstatuscode,
												'tableNoArr'		  => $tablNoArr,
												'diningid'			  => $dinigid,
												'resvconfirmstatus'   => $resvconfirmstatus,
												'bokconfirmstatus'	  => $bokconfirmstatus,
												'resvcheckedin'	   	  => $resvcheckedin,
												'allarrived'		   => $allarrived,
												 'partialarr'		   => $partialarr,
												'bokbooked_status'	  => $bokbooked_status,
												'initial'			  => $initial,
												'bokoption'			  => $bokoption,
												'bokoptioncode'		  => $bokoptioncode,
												'bokcreatedby'		  => $bokcreatedby,
												'bokseat_start'		  => $bokseat_start,
												'bokfeedback_status'  => $bokfeedback_status,
												'bokseat_duration'	  => $bokseat_duration));				
				
				}else {
					$prevBookid         = "";
					$bokid	   	        = "";
					$bokuserid 	        = "";
					$bokfk_restaurant   = "";
					$bokfirst_name 	    = "";
					$boklast_name  	    = "";
					$bokparty_size 	    = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode 		= "";
					$boktypdesc 		= "";
					$boktablenumber 	= "";
					$bokjointableno 	= "";
					$boktableid 		= "";
					$bokresmodecode 	= "";
					$bokrestaurant_note = "";
					$bokstatuscode 		= "";				
					$tablNoArr 			= array();
					$dinigid			= "";
					$resvconfirmstatus  = "";
					$bokconfirmstatus	= "";
					$resvcheckedin	= "";
					$prevBokidArr 		= array();
					$initial			= '';
					$bokbooked_status   = '';
					$bokoption			= "";
					$bokoptioncode 		= "";
					$bokoptionArr = "";
					$bokoptioncodeArr = "";
					$bokcreatedby		= '';
					$bokseat_start		= '';
					$bokseat_duration	= '';
					$bokfeedback_status = '';
					foreach($rowset as $row)
					{
						
						if($prevBookid == ""){	
							
							$bookid			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name;						
							$boklast_name		= $row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$dinigid			= $row->rda_diningdisplyname;
							$prevBookid		    = $bookid;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;	
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$prevBokidArr[]		= $bookid;
							$initial			= $row->initial;
							$bokbooked_status   = $row->bokbooked_status;
							$bokoptionArr		= explode(',',substr($row->bookoption,1,-1));
							$bokoptioncodeArr	= explode(',',substr($row->boptcode,1,-1));	
							if($bokoptionArr[0] && $bokoptionArr[0] != 'NULL' && $bokoptionArr[0] != "''"){
								$bokoption		= $bokoptionArr;
								$bokoptioncode	= $bokoptioncodeArr;	
							}else{
								$bokoption			= "";
								$bokoptioncode 		= "";
							}
							$bokcreatedby		= $row->bokcreatedby;
							$bokfeedback_status = $row->bokfeedback_status;
							if($row->bokseat_start && $row->bokseat_end){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
							}else if($row->bokseat_start){
								$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
								$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
							}else{
								$bokseat_start		= '' ;
								$bokseat_duration	= '';
							}
						}else{
							$bookid = $row->bokid;
							if(in_array($bookid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								
								$bookObj = new Reservation_Model_Reservation();							
								$bookObj->setbokid($prevBookid)
										->setbokuserid($bokuserid)
										->setbokfk_restaurant($bokfk_restaurant)
										->setbokfirst_name($bokfirst_name)
										->setboklast_name($boklast_name)
										->setbokparty_size($bokparty_size)
										->setbokbooking_timings($bokbooking_timings)
										->setbokspecial_request($bokspecial_request)
										->setbokbooking_type_code($boktypcode)
										->setbokbooking_type_desc($boktypdesc)
										->setboktablenumber($boktablenumber)
										->setboktableid($boktableid)
										->setJoinTableNo($bokjointableno)
										->setbokreservation_mode_code($bokresmodecode)
										->setbokrestaurant_note($bokrestaurant_note)
										->setbokbooking_status_code($bokstatuscode)
										->setTableNoArray($tablNoArr)
										->setDiningId($dinigid)
										->setbokresv_confirm_status($resvconfirmstatus)
										->setbokbooking_confirm_status($bokconfirmstatus)
										->setbokresv_checkedin_status($resvcheckedin)
										->setbokresv_allarrived_status($allarrived)
										->setbokresv_partialarrived_status($partialarr)
										->setbokbooking_user_initials($initial)
										->setbokbooking_status_id($bokbooked_status)
										->setbokoptions($bokoption)
										->setbokoptioncode($bokoptioncode)
										->setbokcreatedby($bokcreatedby)
										->setbokseat_start($bokseat_start)
										->setfeedback_status($bokfeedback_status)
										->setbokseat_duration($bokseat_duration);
										
								$resultSet[] = $bookObj;
	
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$bokfirst_name 	    = $row->bokfirst_name;						
								$boklast_name		= $row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$tablNoArr[]		= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;	
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;		
								$prevBookid		    = $bookid;	
								$prevBokidArr[]		= $bookid;
								$initial			= $row->initial;
								$bokbooked_status   = $row->bokbooked_status;
								$bokoptionArr		= explode(',',substr($row->bookoption,1,-1));
								$bokoptioncodeArr	= explode(',',substr($row->boptcode,1,-1));	
								if($bokoptionArr[0] && $bokoptionArr[0] != 'NULL' && $bokoptionArr[0] != "''"){
									$bokoption		= $bokoptionArr;
									$bokoptioncode	= $bokoptioncodeArr;	
								}else{
									$bokoption			= "";
									$bokoptioncode 		= "";
								}
								$bokcreatedby		= $row->bokcreatedby;
								$bokfeedback_status = $row->bokfeedback_status;
								if($row->bokseat_start && $row->bokseat_end){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs(strtotime($row->bokseat_end)-strtotime($row->bokseat_start)) / 60,0);
								}else if($row->bokseat_start){
									$bokseat_start		= date('g:i a',strtotime($row->bokseat_start)) ;
									$bokseat_duration	= round(abs($seatStart-strtotime($row->bokseat_start)) / 60,0);
								}else{
									$bokseat_start		= '' ;
									$bokseat_duration	= '';
								}
							}
						}							
					}
					$bookObj = new Reservation_Model_Reservation();							
					$bookObj->setbokid($bookid)
							->setbokuserid($bokuserid)
							->setbokfk_restaurant($bokfk_restaurant)
							->setbokfirst_name($bokfirst_name)
							->setboklast_name($boklast_name)
							->setbokparty_size($bokparty_size)
							->setbokbooking_timings($bokbooking_timings)
							->setbokspecial_request($bokspecial_request)
							->setbokbooking_type_code($boktypcode)
							->setbokbooking_type_desc($boktypdesc)
							->setboktablenumber($boktablenumber)
							->setboktableid($boktableid)
							->setJoinTableNo($bokjointableno)
							->setbokreservation_mode_code($bokresmodecode)
							->setbokrestaurant_note($bokrestaurant_note)
							->setbokbooking_status_code($bokstatuscode)
							->setTableNoArray($tablNoArr)
							->setDiningId($dinigid)
							->setbokresv_confirm_status($resvconfirmstatus)
							->setbokbooking_confirm_status($bokconfirmstatus)
							->setbokresv_checkedin_status($resvcheckedin)
							->setbokresv_allarrived_status($allarrived)
							->setbokresv_partialarrived_status($partialarr)
							->setbokbooking_user_initials($initial)
							->setbokbooking_status_id($bokbooked_status)
							->setbokoptions($bokoption)
							->setbokoptioncode($bokoptioncode)
							->setbokcreatedby($bokcreatedby)
							->setbokseat_start($bokseat_start)
							->setfeedback_status($bokfeedback_status)
							->setbokseat_duration($bokseat_duration);
										
					$resultSet[] = $bookObj;
				}
			}

		return $resultSet;
		
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function GetBookingsMonthView(Reservation_Model_ReservationsMonthView $BookingMonthView)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);	
					
			$select->from(array('bok'=>'mt.booking'),array('sum(bokparty_size) as mealcount','bokbooking_date'))				  
				   ->join(array('boksts'=>'mt.booking_status_bd'),'boksts.id = bok.bokbooking_status_id',array())
				   ->join(array('meal'=>'mt.restaurant_meal_type'),'meal.rmt_restaurant = bok.bokfk_restaurant',array('rmt_id'))
				   ->join(array('mealtyp'=>'mt.meal_type_bd'),'meal.rmt_meal_type = mealtyp.id',array('description as mealtype'))
				   ->where('bok.bokfk_restaurant = ?',$BookingMonthView->getrestaurantid())
				   ->where('bok.bokbooking_date >= ?',$BookingMonthView->getfirstdayofmonth())
				   ->where('bok.bokbooking_date <= ?',$BookingMonthView->getlastdayofmonth())
				   ->where('bok.bokbooking_timings >= meal.rmt_start_time')
				   ->where('bok.bokbooking_timings <= meal.rmt_end_time')
				   ->where('boksts.code IN(?)',$BookingMonthView->getbookstatus())
				   ->where('meal.rmt_status = ?','Y')
				   ->group(array('bok.bokbooking_date','meal.rmt_id','mealtyp.description'))
				   ->order('bok.bokbooking_date');
				   
			$rowset = $table->fetchAll($select);
	
			$bookCount = array();
			
			if(count($rowset) > 0){
				
				$bookdate = "";
				$prevbookDate = "";
				$mealCountArr = array();
				foreach($rowset as $row){
					if($bookdate == ""){
						$bookdate = $row->bokbooking_date;
						$mealCountArr[$row->mealtype] =  $row->mealcount;
						$prevbookDate = $bookdate;
					}else{
						$bookdate = $row->bokbooking_date;
						if($bookdate == $prevbookDate){
							$mealCountArr[$row->mealtype] =  $row->mealcount;
						}else{
							$bookCount[$prevbookDate] = $mealCountArr;
							$mealCountArr = null;
							$bookdate = $row->bokbooking_date;
							$mealCountArr[$row->mealtype] =  $row->mealcount;
							$prevbookDate = $bookdate;
						}
					}					
				}			
				$bookCount[$bookdate] = $mealCountArr;				
			}
			
			return $bookCount;
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function GetBookingsWeekView(Reservation_Model_ReservationsWeekView $BookingWeekView)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);	
					
			$select->from(array('bok'=>'mt.booking'),array('count(bokid) as mealcount','bokbooking_date','bokbooking_timings','bokparty_size'))				  
				   ->join(array('boksts'=>'mt.booking_status_bd'),'boksts.id = bok.bokbooking_status_id',array())
				   ->join(array('meal'=>'mt.restaurant_meal_type'),'meal.rmt_restaurant = bok.bokfk_restaurant',array('rmt_id'))
				   ->join(array('mealtyp'=>'mt.meal_type_bd'),'meal.rmt_meal_type = mealtyp.id',array('description as mealtype'))
				   ->where('bok.bokfk_restaurant = ?',$BookingWeekView->getrestaurantid())
				   ->where('bok.bokbooking_date >= ?',$BookingWeekView->getfirstdayofweek())
				   ->where('bok.bokbooking_date <= ?',$BookingWeekView->getlastdayofweek())
				   ->where('bok.bokbooking_timings >= meal.rmt_start_time')
				   ->where('bok.bokbooking_timings <= meal.rmt_end_time')
				   ->where('boksts.code IN(?)',$BookingWeekView->getbookstatus())
				   ->where('meal.rmt_status = ?','Y')
				   ->group(array('bok.bokbooking_date','bok.bokbooking_timings','bokparty_size','meal.rmt_id','mealtyp.description'))
				   ->order('bok.bokbooking_date','bok.bokbooking_timings','bokparty_size');
				   
			$rowset = $table->fetchAll($select);
	
			$bookCount = array();
			
			if(count($rowset) > 0){	

				$bookdate = "";
				$prevbookDate = "";
				$mealtype = "";
				$prevmealtype = "";
				$booktime = "";
				$prevbooktime = "";
				
				$mealTypeArr = array();
				$timeCountArr = array();
				$partyCountArr = array();
				
				foreach($rowset as $row){
					if($bookdate == ""){
						$bookdate = $row->bokbooking_date;
						$mealtype = $row->mealtype;
						$booktime = $row->bokbooking_timings;
						
						$partyCountArr[] = array($row->bokparty_size => $row->mealcount);
						
						$prevbookDate = $bookdate;
						$prevmealtype = $mealtype;
						$prevbooktime = $booktime;
						
					}else{
						$bookdate = $row->bokbooking_date;
						$mealtype = $row->mealtype;
						
						if($bookdate == $prevbookDate){
							if($mealtype == $prevmealtype){
								
								$booktime = $row->bokbooking_timings;
								if($booktime == $prevbooktime){
									$partyCountArr[] = array($row->bokparty_size => $row->mealcount);	
								}else{
									$timeCountArr[date("h:i A",strtotime($prevbooktime))] = $partyCountArr;
									$partyCountArr = null;
									$prevbooktime = $booktime;
									$partyCountArr[] = array($row->bokparty_size => $row->mealcount);
								}
								$timeCountArr[date("h:i A",strtotime($prevbooktime))] = $partyCountArr;
								$mealCountArr[$prevmealtype] =  $timeCountArr;
							}else{
								if(!$timeCountArr){
									$timeCountArr[date("h:i A",strtotime($prevbooktime))] = $partyCountArr;
								}
								$mealCountArr[$prevmealtype] =  $timeCountArr;								
								$timeCountArr = null;
								$partyCountArr = null;
								$booktime = $row->bokbooking_timings;	
								$mealtype = $row->mealtype;								
								$partyCountArr[] = array($row->bokparty_size => $row->mealcount);
															
								$prevmealtype = $mealtype;
								$prevbooktime = $booktime;							
							}
						}else{
							$timeCountArr[date("h:i A",strtotime($prevbooktime))] = $partyCountArr;
							$mealCountArr[$prevmealtype] =  $timeCountArr;	
							
							$bookCount[$prevbookDate] = $mealCountArr;
							
							$mealCountArr = null;
							$timeCountArr = null;
							$partyCountArr = null;
							
							$bookdate = $row->bokbooking_date;
							$mealtype = $row->mealtype;
							
							$partyCountArr[] = array($row->bokparty_size => $row->mealcount);
							
							$booktime = $row->bokbooking_timings;
							$prevbookDate = $bookdate;
							$prevmealtype = $mealtype;
							$prevbooktime = $booktime;
						}
					}					
				}
				$timeCountArr[date("h:i A",strtotime($prevbooktime))] = $partyCountArr;
				$mealCountArr[$prevmealtype] =  $timeCountArr;			
				$bookCount[$bookdate] = $mealCountArr;										
			}			
			return $bookCount;
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function getSumOfReservations($restaurantid, $weekdDateArr, $bookStatusRes)
	{
		try{
			$table = $this->getDbTable();
			$result = array();
			$fianlArr = array();
			$statusId = array();
			$status = $bookStatusRes;
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('SUM(bokparty_size) as totalParty','bokbooking_date'))
				   ->join(array('meal'=>'mt.restaurant_meal_type'),'meal.rmt_restaurant = bok.bokfk_restaurant',array())
				   ->join(array('mealtyp'=>'mt.meal_type_bd'),'meal.rmt_meal_type = mealtyp.id',array())
		   		   ->where('bok.bokfk_restaurant = ?',$restaurantid)
			   	   ->where('bok.bokbooking_date IN (?) ',$weekdDateArr)
			       ->where('bok.bokbooking_status_id IN(?)',$statusId)
			       ->where('bok.bokbooking_timings >= meal.rmt_start_time')
				   ->where('bok.bokbooking_timings <= meal.rmt_end_time')
				   ->where('meal.rmt_status = ?','Y')
			       ->group('bok.bokbooking_date')
			       ->order('bok.bokbooking_date');
			       
			$rowSet = $table->fetchAll($select);
			
			foreach($rowSet as $row){
				$result[$row->bokbooking_date] = $row->totalParty;
			}
			foreach($weekdDateArr as $date){
				if(array_key_exists($date,$result)){							
					$fianlArr[$date] = $result[$date];
				}else{
					$fianlArr[$date] = 0;
				}
			}
			return $fianlArr;
		
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function updateBookingDetailsByBookid(Reservation_Model_Reservation $bookdetails)
	{
		try{			
			$restid = $this->getRestIdByBookId($bookdetails->getbokid());
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);			
			
			$db = Zend_Db_Table::getDefaultAdapter();
			$table = $this->getDbTable();
			$set = array(
			  'bokemail'			=> $bookdetails->getbokemail(),
			  'bokfirst_name' 		=> $bookdetails->getbokfirst_name(),
			  'boklast_name' 		=> $bookdetails->getboklast_name(),
			  'bokphone' 			=> str_replace("-","",$bookdetails->getbokphone()),
			  'bokspecial_request'	=> $bookdetails->getbokspecial_request(),
			  'bokupdated_date'		=> date('Y-m-d'),
			  'bokupdateddatetime'	=> date("H:i:s",time()),
			  'boksync_status'		=> 'C'	
			);
			$where = $db->quoteInto('bokid = ?',$bookdetails->getbokid());
			$row_affected = $table->update($set,$where);
			if($row_affected){
				return true;
			}else{
				return false;
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function SynchronizationOfReservationsByRestaurantid($restaurantid, $date)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			

			$select->from(array('bok'=>'mt.booking'),array('bokid',
														   'bokfk_restaurant',
														   'bokuserid','bokemail',
														   'bokfirst_name',
														   'boklast_name',
														   'bokparty_size',
														   'bokfk_rest_sch_table',
														   'bokphone',
														   'bokconfirmation_number',
														   'bokpayment_type',
														   'bokspecial_request',
														   'bokbooking_date',
														   'bokbooking_timings',
														   'bokbooking_status_id',
														   'bokbooking_made_on',
														   'bokbooking_type_id',
														   'bokcreated_date',
														   'bokupdated_date',
														   'bokcreatedby_userid',
														   'bokcreateddatetime',
														   'bokupdatedby_userid',
														   'bokupdateddatetime',
														   'bokcontact_information',
														   'bokreservation_mode_id',
														   'bokrestaurant_note',
														   'boknotification_type',
														   'bokbooking_made_time',
														   'bokbooked_status',
														   'bokquoted_time',
														   'bokreadstatus',
														   'bokresv_confirm_status',
														   'bokbooking_confirm_status',
														   'bokresv_checkedin_status',
														   'bokresv_partialarrived_status',
														   'bokresv_allarrived_status',
														   'bokbooking_user_initials',
														   'bokbooking_block_status',
														   'bokbooking_block_desc',
														   'bokbooking_block_amount',
														   'bokseat_start',
														   'bokbooking_phrase',
														   'bok_restsch_setting_id',
														   'bokresv_runninglate_status',
														   'bokseat_end',
														   'bokcountrycode',
														   'bok_contactid',
														   'bokfeedback_status',
														   'bokresv_partialarrived_status',
														   'bokresv_allarrived_status',
														   'bokcompany_id',
														   'bok_serverid'))
				   ->where('bok.bokfk_restaurant = ?',$restaurantid)
				   ->where('bok.bokbooking_date >= ?',$date)
				   ->where('bok.bokbooking_type_id <> ?',4);
				   
			$resultset = $this->getDbTable()->fetchAll($select);
			$bookingArr= array();
			$bokidsArr = array();
			$finalArr = array();
			foreach($resultset as $key=>$value){
				$subArr = array();
				$bokidsArr[] = $value->bokid;
				foreach($value as  $key1=>$value1){
					if($key1 == 'bokuserid' || $key1 == 'bokcreatedby_userid' || $key1 == 'bokupdatedby_userid'){
						$subArr[$key1]= null;
					}else{
						$subArr[$key1]= $value1;
					}
				}
				$bookingArr[] = $subArr;
			}
			$finalArr['bokidsArr'] = $bokidsArr;
			$finalArr['bookingsArr'] = $bookingArr;
			return $finalArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function GetBookingtableDataByBookingIds($bokingIds)
	{
		try{
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$table = $bookTableMapper->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('bktbid','bktbfk_booking','bktbtableid','bktbtable_no_assigned','status','bktb_join_table_no','bkt_dining_id'))
				   ->where('bktbfk_booking IN(?)',$bokingIds)
				   ->where('status = ?',true);
							
			$resultset = $table->fetchAll($select);
			$boktablesArr = array();
			foreach($resultset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					$subArr[$key1]= $value1;
				}
				$boktablesArr[] = $subArr;
			}
			return $boktablesArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function GetbookingCountTableData($restaurantid,$date)
	{
		try{
			$mapper = new Reservation_Model_ReservationCountDataMapper();
			$table = $mapper->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('btcid','btcbooking_date','btcfkres_id','btcbooking_timings','btcbooking_count','boktablesize','boknooftables','btcfk_restaurant_schedule'))
				   ->where('btcfkres_id = ?',$restaurantid)
				   ->where('btcbooking_date >= ?',$date);
			$resultset = $table->fetchAll($select);
			$bokcountArr = array();
			foreach($resultset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					$subArr[$key1]= $value1;
				}
				$bokcountArr[] = $subArr;
			}
			return $bokcountArr;	   
		}catch(Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function MigrateBookings($bookDetails)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			$resultArray = array();
			$bookDetailsArr = array();
			foreach($bookDetails as $row){
				$data = array();
				$result = '';
				//if($row->bokwebbookingid && $row->bokwebbookingid != null){
					
				//}else 
				$bookPhrase = uniqid ();
				if($row->bokwebbookingid == null && $row->bokwebbookingid == ""){
					$data = array(
					  	'bokfk_restaurant'	   			=> 	$row->bokfk_restaurant, 
						'bokemail'		 	   			=>	$row->bokemail,
						'bokfirst_name' 		   		=>	$row->bokfirst_name,
						'boklast_name' 		   			=>	$row->boklast_name,
						'bokparty_size' 		   		=>	$row->bokparty_size,
						'bokphone' 			   			=>	str_replace("-","",$row->bokphone),
					    'bokcountrycode'				=>	$row->bokcountrycode,
						'bokspecial_request'     		=>	$row->bokspecial_request,
						'bokbooking_date'		   		=>	$row->bokbooking_date,
						'bokbooking_timings' 	   		=>	$row->bokbooking_timings,
						'bokbooking_status_id'   		=>	$row->bokbooking_status_id,
						'bokbooked_status'	   			=>	$row->bokbooked_status,
						'bokbooking_made_on' 	   		=>	$row->bokbooking_made_on,
						'bokbooking_type_id'      		=>	$row->bokbooking_type_id,
						'bokreservation_mode_id' 		=>	$row->bokreservation_mode_id,
						'boknotification_type'    		=>	$row->boknotification_type,
						'bokcreated_date'				=>	$row->bokcreated_date,
						'bokbooking_migration_status'	=>	'T',
						'bokbooking_source_type'		=>	'native',
						'bokbooking_phrase'				=> 	$bookPhrase
						
						
					);
					if($row->bokfk_rest_sch_table){
						$data['bokfk_rest_sch_table']    	=	$row->bokfk_rest_sch_table;
					}
					if($row->bokuserid){
						$data['bokuserid']    	=	$row->bokuserid;
					}
					if($row->bokbooking_user_initials){
						$data['bokbooking_user_initials']		=	$row->bokbooking_user_initials;
					}
					if($row->bokquoted_time)
					{
						$data['bokquoted_time']	= $row->bokquoted_time;
					}
					if($row->bokseat_start)
					{
						$data['bokseat_start'] = $row->bokseat_start;
					}
					
					if($row->bokresv_runninglate_status != null & $row->bokresv_runninglate_status != "")
					{
						$data['bokresv_runninglate_status']	= $row->bokresv_runninglate_status;
					}
					
					if($row->bokresv_partialarrived_status != null & $row->bokresv_partialarrived_status != "")
					{
						$data['bokresv_partialarrived_status']	= $row->bokresv_partialarrived_status;
					}
					
					if($row->bokresv_allarrived_status != null & $row->bokresv_allarrived_status != "")
					{
						$data['bokresv_allarrived_status']	= $row->bokresv_allarrived_status;
					}
					
//					if($bookdetails->getRescheduleCode() && $bookdetails->getRescheduleCode()== 'RES'){
//						/* Chech the stautus of rescheduled reservation and if it is waiting list do not decrement the count. */
//						$resvstatus = "";
//			
//						$statusSelect = $table->select();
//						$statusSelect->setIntegrityCheck(false);
//						$statusSelect->from(array('bok'=>'mt.booking'),array('bokid'))
//									 ->join(array('boksts'=>'mt.booking_status_bd'),'boksts.id = bok.bokbooking_status_id',array('code as bookcode'))
//									 ->where('bok.bokid = ?',$bookdetails->getbokid());
//						$bookStatusRow = $table->fetchRow($statusSelect);
//						$resvstatus = $bookStatusRow->bookcode;
//						
//						$set = array('bokbooking_status_id' => $bookdetails->getRessch_Status_Id(),
//									 'bokrestaurant_note'   => $bookdetails->getbokrestaurant_note());
//		
//						$where = $db->quoteInto('bokid = ?',$bookdetails->getbokid());
//						$row_affected = $table->update($set,$where);
//		
//						$result = $table->insert($data);
//		
//						/* Decrement the booking count upon reschedule start */
//						if($resvstatus != "" && $resvstatus != "WAL" && $bookdetails->getbokbooking_status_code() != 'OVB'){
//							$status = $this->ResetBookingCount($bookdetails);
//						}
//					}else{
						$result = $this->getDbTable()->insert($data);
						
						$resultArray[] = array('bokid'=>$row->bokid,'bokwebbookingid'=>$result);
						$row->bokId = $result;
//					}
//
//					if($row->bookingOptions){
//						$bokoptionsmapper = new Reservation_Model_ReservationOptionsMapDataMapper();
//						$bokoptionsmapper->saveBookingOptions($result, $row->bookingOptions);
//					}
//					

//					$boktypeMapper = new Application_Model_ReservationTypeDataMapper();
//					$boktype = $boktypeMapper->GetBookingTypeById($row->bokbooking_type_id);
//					if($boktype->getCode() == 'SPL' || $boktype->getCode() == 'SPLPAID'){
//						$splData = array('bksfk_booking' => $result,
//										 'bksspecial_id' => $bookdetails->getSpecialId(),
//										 'bksamount'     => $bookdetails->getSpecialPrice());
//						
//						$bookSplMapper = new Reservation_Model_ReservationSpecialDataMapper();
//						$bookSplTable = $bookSplMapper->getDbTable();
//						$bookSplTable->insert($splData);
//					}
//					
					/* Retrieve schedule id by inventory id */
					$schIdRow = "";
					if(($row->bokfk_rest_sch_table) && ($row->bookstatuscode == "RSD" ||  $row->bookstatuscode == "BKD" ||  $row->bookstatuscode == "BOK" ||  $row->bookstatuscode == "CRD" ||  $row->bookstatuscode == "DES" ||  $row->bookstatuscode == "PTS" ||  $row->bookstatuscode == "WRD" || $row->bookstatuscode == "COM")){
						$restSchTblMapperObj = new FirmManagement_Model_FirmScheduleTableDataMapper();
						$restSchTbl = $restSchTblMapperObj->getDbTable();
						$restSchTblSelect = $restSchTbl->select();
		
						$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule','rsttable_pax','rstno_of_tables'))
										 ->where('rstid = ?',$row->bokfk_rest_sch_table);
										 
					    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);				
					
						$table = $this->getDbTable();
						$select = $table->select();
						$select->setIntegrityCheck(false);
						$select->from(array('btc'=>'mt.booking_time_count'),array('count(btcid) as countbtc','btcid','btcbooking_count','btc.boktablesize'))
						->where('btc.btcfkres_id = ?',$row->bokfk_restaurant)
						->where('btc.btcbooking_timings = ?',$row->bokbooking_timings)
						->where('btc.btcbooking_date = ?',$row->bokbooking_date);
						if($schIdRow){
							$select->where('btc.btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
						}				   
					    $select->group(array('btcid','btcbooking_count','btc.boktablesize'));
			
						$bookingCountId = 0;
						$bookingId= 0;
						$bookingCount = 0;
						
						$rowS = $table->fetchRow($select);
			
						$bookingCountId = $rowS['countbtc'];
						$bookingId = $rowS['btcid'];
						$bookingCount = (int)$rowS['btcbooking_count'];
						
			
						$mapper = new Reservation_Model_ReservationCountDataMapper();
						if($bookingCountId != 0){
							
							if($bookingCount < $schIdRow->rstno_of_tables)
							{
								$bookingCount++;
								$set = array('btcbooking_count' => $bookingCount);
								$where = array('btcid = ?' => $bookingId,
											   'btcfk_restaurant_schedule = ?' => $schIdRow->rstfk_restaurant_schedule);
								
								$mapper->getDbTable()->update($set,$where);
							}else if($bookingCount == $schIdRow->rstno_of_tables){
								
								$set = array('bokbooked_status' => 13);
								$where = array('bokid = ?' => $result);
								$roweff = $this->getDbTable()->update($set,$where);
							}	
						}else{
							$data = array(
									'btcbooking_count'    => 1,
									'btcbooking_timings'  => $row->bokbooking_timings,
							        'btcbooking_date' 	  => $row->bokbooking_date,
			 						'btcfkres_id'    	  => $row->bokfk_restaurant,
									'boktablesize'		  => $schIdRow->rsttable_pax,
						  			'boknooftables'		  => $schIdRow->rstno_of_tables,
									'btcfk_restaurant_schedule'	=> $schIdRow->rstfk_restaurant_schedule
							);
							$mapper->getDbTable()->insert($data);
						}
					}
					if($row->bookstatuscode == "WAL" && $row->boknewquotedtimeinfo){
						
//						$quote = new Reservation_Model_ReservationWaitingQuoteMap();
//						$quote->setBookId($result);
//						$quote->setQuoteId($row->bokquoted_time);

						$boknewquotedtimeinfo = json_decode($row->boknewquotedtimeinfo);
						foreach($boknewquotedtimeinfo as $boknewquotedtimerow)
						{
							$splitdatetime = split (" ", $boknewquotedtimerow->updateddatetime);
							$updateddatetime = $splitdatetime[0].' '.$splitdatetime[1];
							$quoteMapper = new Reservation_Model_ReservationWaitingQuoteMapDataMapper();
							$quoteMapper->InsertQuotedTimesFromNativeApp($result,$boknewquotedtimerow->quotedtimeid,$updateddatetime);
						}
					}
					
					if($row->booktable)
					{
						$count = 0;
						$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
					    $bookTable  = $bookTableMapper->getDbTable();
						$bookTableSelect = $bookTable->select();
						
						$bookTableSelect->from($bookTable,array('COUNT(bktbid) as count'))
						                ->where('bktbfk_booking = ?',$result)
						                ->where('status = ?',true);
			            
						$countRes = $bookTable->fetchAll($bookTableSelect);
						foreach($countRes as $countrow)
						{
							$count = $countrow->count;
						}
						if($count == 0 && $row->booktable)
						{	
							$booktableDetails = json_decode($row->booktable);							
							$joinTableNo = "";
							if(count($booktableDetails) > 1)
							{
							    	$joinTableNo = $this->CheckJoinTableNo($result,$row->bokfk_restaurant);
							    	if($joinTableNo){
							    		$joinTableNo++;
							    	}else if($joinTableNo == 0 || $joinTableNo == null){
							    		$joinTableNo++;
							    	}
							}	
//							$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
//			   				$bookTable  = $bookTableMapper->getDbTable();
							foreach($booktableDetails as $boktablerow)
							{
								if(count($booktableDetails) > 1)
								{
						    		$data = array('bktbfk_booking'        => $result,
						    					  'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
						    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
						    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
						    					  'bktb_join_table_no'    => $joinTableNo,
						    					  'status'                => true);
						    		$id = $bookTable->insert($data);	 
						    		
								}else{
									$data = array('bktbfk_booking'        => $result,
				    					  	'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
				    					  	'bktbtableid' 		  => $boktablerow->bktbtableid,
				    					  	'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,		    					  
			    					  		'status'                => true);
			    					$id = $bookTable->insert($data);
								}
							}
						}
					}
					
					$countMapper = new Reservation_Model_ReservationsCountDataMapper();
					$countResult = $countMapper->saveReservationsCount($row->bokfk_restaurant,$row->bokparty_size);
				}
				
				$bokStat = $this->getBookingPrevStatus($row->bokId);
				$bokLog = new Reservation_Model_BookingLog();
				$bokLog->setbok_log_fk_booking($bookingObj->bokId)
						->setbok_log_booked_type($bokStat)
						->setbok_log_bok_status($row->bokbooking_status_id)
						->setbok_log_book_message('Reservation Done')
// 						->setbok_log_updated_by($userdata['User_Id'])
						->setbok_log_updated_at(date('Y-m-d H:i:s'))
		    			->setbok_log_update_done_by('RES');
				$bokLogMapper = new Reservation_Model_BookingLogMapper();
				$bokLogResult = $bokLogMapper->updateBookingLog($bokLog);
				
				$bookDetailsArr[] = $row; 
			}
			$db->commit();
			return array('result'=>$resultArray,'bookDetails'=>$bookDetailsArr);
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function BookingWebSync($resid,$date)
	{
		try{
			
//			$statusId = array();
//			foreach($bookStatusRes as $key=>$value){
//				$statusId[] = $value->getId();
//			}
//			
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid',
															'bokfk_restaurant',
															'bokuserid',
															'bokemail',
															'bokfirst_name',
															'boklast_name',
															'bokparty_size',
															'bokfk_rest_sch_table',
															'bokphone',
															'bokconfirmation_number',
															'bokpayment_type',
															'bokspecial_request',
															'bokbooking_date',
															'bokbooking_timings',
															'bokbooking_status_id',
															'bokbooking_made_on',
															'bokbooking_type_id',
															'bokcreated_date',
															'bokupdated_date',
															'bokcreatedby_userid',
															'bokcreateddatetime',
															'bokupdatedby_userid',
															'bokupdateddatetime',
															'bokcontact_information',
															'bokreservation_mode_id',
															'bokrestaurant_note',
															'boknotification_type',
															'bokbooking_made_time',
															'bokbooked_status',
															'bokquoted_time',
															'bokreadstatus',
															'bokresv_confirm_status',
															'bokbooking_confirm_status',
															'bokresv_checkedin_status',
															'bokresv_partialarrived_status',
															'bokresv_allarrived_status',
															'bokbooking_user_initials',
															'bokbooking_block_status',
															'bokbooking_block_desc',
															'bokbooking_block_amount',
															'bokcreatedby',
															'bokseat_start',
															'bokbooking_manual_comp_status',
															'bokbooking_migration_status',
															'bokbooking_source_type',
															'bok_restsch_setting_id',
															'bokresv_runninglate_status',
															'bokcountrycode',
															'bok_contactid',
															 ))
					->join(array('res'=>'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('resrestaurant_name','resaddress','resphone','resemail','reszipcode'))
					->join(array('bst'=>'mt.booking_status_bd'),'bst.id = bok.bokbooking_status_id',array('code as stat','description'))
					->join(array('boktyp'=>'mt.booking_type_bd'),'bok.bokbooking_type_id = boktyp.id',array('code as boktypecode','description as boktypedesc'))
					->join(array('rmb'=>'mt.reservation_mode_bd'),'rmb.id = bok.bokreservation_mode_id',array('code','description as mode'))
					->join(array('cty'=>'mt.city_bd'),'cty.id = res.rescity_id',array('description as rescity'))
					->join(array('ngbh'=>'mt.neighborhood_bd'),'ngbh.id = res.resneighborhood_id',array('description as neighbor'))
//					->joinLeft(array('bookopt'=>$bookOptionsSelect),'bookopt.bopmbokid = bok.bokid',array('boptdescription as bookoption','boptid'))
					->where('bok.bokfk_restaurant = ?',$resid)
					->where('bok.bokbooking_date = ?',$date);
					//->where('bok.bokbooking_status_id IN(?)',$statusId);;

			$resultSetData = $this->getDbTable()->fetchAll($select);
			$resultArr = array();
			$resultFinalArr = array();
			$finalTimeValue = '';
			foreach($resultSetData as $resultSet){
				if($resultSet){
					$boktableArr = array();
					$bokquotedTimeArr = array();
					$bookOptionsMapper = new Reservation_Model_ReservationOptionsMapDataMapper();
					$bookOptions       = $bookOptionsMapper->getDbTable();
					$bookOptionsSelect = $bookOptions->select(); 
					$bookOptionsSelect->setIntegrityCheck(false);
					$bookOptionsSelect->from(array('bom'=>'mt.booking_options_map'),array('bopmbokid','bopmbok_optionsid'))
									  ->join(array('bop'=>'mt.booking_options'),'bop.boptid = bom.bopmbok_optionsid',array('boptdescription','boptid'))
									  ->where('bopmbokid = ?',$resultSet->bokid);
					$bookoptionsRow = $bookOptionsMapper->getDbTable()->fetchRow($bookOptionsSelect);				  
					$timeValue = explode(':',$resultSet->bokbooking_timings);
					if($timeValue[0] >=12){
						if((int)$timeValue[0] != 12){
							(int)$timeValue[0] -= 12;
						}
						$timeValue[2] = 'PM';
						$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
					}else{
						$timeValue[2] = 'AM';
						$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
					}
					
					$resultArr['bokid']                        =	$resultSet->bokid;
					$resultArr['bokfk_restaurant']             =	$resultSet->bokfk_restaurant;
					//$resultArr['bokuserid']                    =	$resultSet->bokuserid;
					$resultArr['bokuserid']                    =	null;
					$resultArr['bokemail']                     =	$resultSet->bokemail;
					$resultArr['bokfirst_name']                =	$resultSet->bokfirst_name;
					$resultArr['boklast_name']                 =	$resultSet->boklast_name;
					$resultArr['bokparty_size']                =	$resultSet->bokparty_size;
					$resultArr['bokfk_rest_sch_table']         =	$resultSet->bokfk_rest_sch_table;
					$resultArr['bokphone']                     =	$resultSet->bokphone;
					$resultArr['bokconfirmation_number']       =	$resultSet->bokconfirmation_number;
					$resultArr['bokpayment_type']              =	$resultSet->bokpayment_type;
					$resultArr['bokspecial_request']           =	$resultSet->bokspecial_request;
					$resultArr['bokbooking_date']              =	$resultSet->bokbooking_date;
					$resultArr['bokbooking_timings']           =	$finalTimeValue;
					$resultArr['bokbooking_status_id']         =	$resultSet->bokbooking_status_id;
					$resultArr['bokbooking_made_on']           =	$resultSet->bokbooking_made_on;
					$resultArr['bokbooking_type_id']           =	$resultSet->bokbooking_type_id;
					$resultArr['bokcreated_date']              =	$resultSet->bokcreated_date;
					$resultArr['bokupdated_date']              =	$resultSet->bokupdated_date;
					//$resultArr['bokcreatedby_userid']          =	$resultSet->bokcreatedby_userid;
					$resultArr['bokcreatedby_userid']          =	null;
					$resultArr['bokcreateddatetime']           =	$resultSet->bokcreateddatetime;
					//$resultArr['bokupdatedby_userid']          =	$resultSet->bokupdatedby_userid;
					$resultArr['bokupdatedby_userid']          =	null;
					$resultArr['bokupdateddatetime']           =	$resultSet->bokupdateddatetime;
					$resultArr['bokcontact_information']       =	$resultSet->bokcontact_information;
					$resultArr['bokreservation_mode_id']       =	$resultSet->bokreservation_mode_id;
					$resultArr['bokrestaurant_note']           =	$resultSet->bokrestaurant_note;
					$resultArr['boknotification_type']         =	$resultSet->boknotification_type;
					$resultArr['bokbooking_made_time']         =	$resultSet->bokbooking_made_time;
					$resultArr['bokbooked_status']             =	$resultSet->bokbooked_status;
					$resultArr['bokquoted_time']               =	$resultSet->bokquoted_time;
					$resultArr['bokreadstatus']                =	$resultSet->bokreadstatus;
					$resultArr['bokresv_confirm_status']       =	$resultSet->bokresv_confirm_status;
					$resultArr['bokbooking_confirm_status']    =	$resultSet->bokbooking_confirm_status;
					$resultArr['bokresv_checkedin_status']     =	$resultSet->bokresv_checkedin_status;
					$resultArr['bokresv_allarrived_status']    =	$resultSet->bokresv_allarrived_status;
					$resultArr['bokresv_partialarrived_status']=	$resultSet->bokresv_partialarrived_status;
					$resultArr['bokbooking_user_initials']     =	$resultSet->bokbooking_user_initials;
					$resultArr['bokbooking_block_status']      =	$resultSet->bokbooking_block_status;
					$resultArr['bokbooking_block_desc']        =	$resultSet->bokbooking_block_desc;
					$resultArr['bokbooking_block_amount']      =	$resultSet->bokbooking_block_amount;
					$resultArr['bokcreatedby']                 =	$resultSet->bokcreatedby;
					$resultArr['bokseat_start']                =	$resultSet->bokseat_start;
					$resultArr['bokbooking_manual_comp_status']=	$resultSet->bokbooking_manual_comp_status;
					$resultArr['bokbooking_migration_status']  =	$resultSet->bokbooking_migration_status;
					$resultArr['bokbooking_source_type']       =	$resultSet->bokbooking_source_type;
					$resultArr['bok_restsch_setting_id']       =	$resultSet->bok_restsch_setting_id;
					$resultArr['bokresv_runninglate_status']   =	$resultSet->bokresv_runninglate_status;
					$resultArr['bokcountrycode']   			   =	$resultSet->bokcountrycode;
					
					if($bookoptionsRow){
						$resultArr['booking_option_id']				=	$bookoptionsRow->boptid;
					}else{
						$resultArr['booking_option_id']				=	'';
					}
					$resultArr['bookstatuscode']       =	$resultSet->stat;
	
					if($resultSet->stat == "BOK" || $resultSet->stat == "CRD" || $resultSet->stat == "DES" || $resultSet->stat == "PTS" || $resultSet->stat == "WRD" || $resultSet->stat == "COM")
					{
						$bookTableMapper = new Reservation_Model_ReservationTableMapper();
						$bookTable = $bookTableMapper->getDbTable();
						$boktableselect = $bookTable->select();
						
						$boktableselect->from($bookTable,array('bktbid','bktbfk_booking','bktbtableid','bktbtable_no_assigned','status','bktb_join_table_no','bkt_dining_id'))
							   ->where('bktbfk_booking = ?',$resultSet->bokid);
							   
						$boktableres = $bookTable->fetchAll($boktableselect);
						
						foreach($boktableres as $boktable)
						{
							$arr = array();
							
							$arr['bktbid'] = $boktable->bktbid;
							$arr['bktbfk_booking'] = $boktable->bktbfk_booking;
							$arr['bktbtableid'] = $boktable->bktbtableid;
							$arr['bktbtable_no_assigned'] = $boktable->bktbtable_no_assigned;
							$arr['status'] = $boktable->status;
							$arr['bktb_join_table_no'] = $boktable->bktb_join_table_no;
							$arr['bkt_dining_id'] = $boktable->bkt_dining_id;
							
							$boktableArr[] = $arr;
						}	
						
					}
					if($resultSet->stat == "WAL")
					{
						$bookids = array($resultSet->bokid);
						$quoteMapper = new Reservation_Model_ReservationWaitingQuoteMapDataMapper();
						$bokquotedTimeArr = $quoteMapper->GetWaitingQuoteByBookingIds($bookids);
					}
					
					$resultFinalArr[$resultSet->bokid]	=	array(
																'bokresult' 		=>	$resultArr,
																'boktableresult'	=>	$boktableArr,
																'bokwaitingquotemap'=> 	$bokquotedTimeArr
																  );
				}else{
					return false;
				}
			}
			return $resultFinalArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	

	public function getRestIdByBookId($bokid)
	{
		try{
			$table = $this->getDbTable();			
			$select = $table->select();
			
			$select->from($table,array('bokfk_restaurant'))
				   ->where('bokid = ?',$bokid);

			$rowSet = $table->fetchRow($select);
			return $rowSet->bokfk_restaurant;				   
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function syncBookingStatusChange($resid,$date, $bookStatusRes)
	{
		try{			
			$statusId = array();
			foreach($bookStatusRes as $key=>$value){
				$statusId[] = $value->getId();
			}
			
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid',
															'bokfk_restaurant',
															'bokuserid',
															'bokemail',
															'bokfirst_name',
															'boklast_name',
															'bokparty_size',
															'bokfk_rest_sch_table',
															'bokphone',
															'bokconfirmation_number',
															'bokpayment_type',
															'bokspecial_request',
															'bokbooking_date',
															'bokbooking_timings',
															'bokbooking_status_id',
															'bokbooking_made_on',
															'bokbooking_type_id',
															'bokcreated_date',
															'bokupdated_date',
															'bokcreatedby_userid',
															'bokcreateddatetime',
															'bokupdatedby_userid',
															'bokupdateddatetime',
															'bokcontact_information',
															'bokreservation_mode_id',
															'bokrestaurant_note',
															'boknotification_type',
															'bokbooking_made_time',
															'bokbooked_status',
															'bokquoted_time',
															'bokreadstatus',
															'bokresv_confirm_status',
															'bokbooking_confirm_status',
															'bokresv_checkedin_status',
															'bokresv_partialarrived_status',
															'bokresv_allarrived_status',
															'bokbooking_user_initials',
															'bokbooking_block_status',
															'bokbooking_block_desc',
															'bokbooking_block_amount',
															'bokcreatedby',
															'bokseat_start',
															'bokbooking_manual_comp_status',
															'bokbooking_migration_status',
															'bokbooking_source_type',
															'bokbooking_migration_status',
															'boksync_status',
															'bokbooking_phrase',
															'bok_restsch_setting_id',
															'bokcountrycode',
															'bok_contactid',
															'bokcompany_id',
															'bok_serverid',
														    'bokresv_runninglate_status'))
					->join(array('res'=>'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('resrestaurant_name','resaddress','resphone','resemail','reszipcode'))
					->join(array('bst'=>'mt.booking_status_bd'),'bst.id = bok.bokbooking_status_id',array('code as stat','description'))
					->join(array('boktyp'=>'mt.booking_type_bd'),'bok.bokbooking_type_id = boktyp.id',array('code as boktypecode','description as boktypedesc'))
					->join(array('rmb'=>'mt.reservation_mode_bd'),'rmb.id = bok.bokreservation_mode_id',array('code','description as mode'))
					->join(array('cty'=>'mt.city_bd'),'cty.id = res.rescity_id',array('description as rescity'))
					->join(array('ngbh'=>'mt.neighborhood_bd'),'ngbh.id = res.resneighborhood_id',array('description as neighbor'))
					->where('bok.bokfk_restaurant = ?',$resid)
					->where('bok.bokbooking_date = ?',$date)
					//->where('bok.boksync_status = ?','C')
					->where('bok.bokbooking_status_id IN(?)',$statusId);
					

			$resultSetData = $this->getDbTable()->fetchAll($select);
			$resultArr = array();
			$resultFinalArr = array();
			$finalTimeValue = '';
			foreach($resultSetData as $resultSet){
				if($resultSet){
					$boktableArr = array();
					$bokquotedTimeArr = array();
					$bookOptionsMapper = new Reservation_Model_ReservationOptionsMapDataMapper();
					$bookOptions       = $bookOptionsMapper->getDbTable();
					$bookOptionsSelect = $bookOptions->select(); 
					$bookOptionsSelect->setIntegrityCheck(false);
					$bookOptionsSelect->from(array('bom'=>'mt.booking_options_map'),array('bopmbokid','bopmbok_optionsid'))
									  ->join(array('bop'=>'mt.booking_options'),'bop.boptid = bom.bopmbok_optionsid',array('boptdescription','boptid'))
									  ->where('bopmbokid = ?',$resultSet->bokid);
					$bookoptionsRow = $bookOptionsMapper->getDbTable()->fetchRow($bookOptionsSelect);				  
					$timeValue = explode(':',$resultSet->bokbooking_timings);
					if($timeValue[0] >=12){
						if((int)$timeValue[0] != 12){
							(int)$timeValue[0] -= 12;
						}
						$timeValue[2] = 'PM';
						$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
					}else{
						$timeValue[2] = 'AM';
						$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
					}
					
					$resultArr['bokwebbookingid']              =	$resultSet->bokid;
					$resultArr['bokfk_restaurant']             =	$resultSet->bokfk_restaurant;
					//$resultArr['bokuserid']                    =	$resultSet->bokuserid;
					$resultArr['bokuserid']                    =    null;
					$resultArr['bokemail']                     =	$resultSet->bokemail;
					$resultArr['bokfirst_name']                =	$resultSet->bokfirst_name;
					$resultArr['boklast_name']                 =	$resultSet->boklast_name;
					$resultArr['bokparty_size']                =	$resultSet->bokparty_size;
					$resultArr['bokfk_rest_sch_table']         =	$resultSet->bokfk_rest_sch_table;
					$resultArr['bokphone']                     =	$resultSet->bokphone;
					$resultArr['bokconfirmation_number']       =	$resultSet->bokconfirmation_number;
					$resultArr['bokpayment_type']              =	$resultSet->bokpayment_type;
					$resultArr['bokspecial_request']           =	$resultSet->bokspecial_request;
					$resultArr['bokbooking_date']              =	$resultSet->bokbooking_date;
					$resultArr['bokbooking_timings']           =	$finalTimeValue;
					$resultArr['bokbooking_status_id']         =	$resultSet->bokbooking_status_id;
					$resultArr['bokbooking_made_on']           =	$resultSet->bokbooking_made_on;
					$resultArr['bokbooking_type_id']           =	$resultSet->bokbooking_type_id;
					$resultArr['bokcreated_date']              =	$resultSet->bokcreated_date;
					$resultArr['bokupdated_date']              =	$resultSet->bokupdated_date;
					//$resultArr['bokcreatedby_userid']          =	$resultSet->bokcreatedby_userid;
					$resultArr['bokcreatedby_userid']          =	null;
					$resultArr['bokcreateddatetime']           =	$resultSet->bokcreateddatetime;
					//$resultArr['bokupdatedby_userid']          =	$resultSet->bokupdatedby_userid;
					$resultArr['bokupdatedby_userid']          =	null;
					$resultArr['bokupdateddatetime']           =	$resultSet->bokupdateddatetime;
					$resultArr['bokcontact_information']       =	$resultSet->bokcontact_information;
					$resultArr['bokreservation_mode_id']       =	$resultSet->bokreservation_mode_id;
					$resultArr['bokrestaurant_note']           =	$resultSet->bokrestaurant_note;
					$resultArr['boknotification_type']         =	$resultSet->boknotification_type;
					$resultArr['bokbooking_made_time']         =	$resultSet->bokbooking_made_time;
					$resultArr['bokbooked_status']             =	$resultSet->bokbooked_status;
					$resultArr['bokquoted_time']               =	$resultSet->bokquoted_time;
					$resultArr['bokreadstatus']                =	$resultSet->bokreadstatus;
					$resultArr['bokresv_confirm_status']       =	$resultSet->bokresv_confirm_status;
					$resultArr['bokresv_checkedin_status']     =	$resultSet->bokresv_checkedin_status;
					$resultArr['bokresv_allarrived_status']    =	$resultSet->bokresv_allarrived_status;
					$resultArr['bokresv_partialarrived_status']=	$resultSet->bokresv_partialarrived_status;
					$resultArr['bokbooking_user_initials']     =	$resultSet->bokbooking_user_initials;
					$resultArr['bokbooking_block_status']      =	$resultSet->bokbooking_block_status;
					$resultArr['bokbooking_block_desc']        =	$resultSet->bokbooking_block_desc;
					$resultArr['bokbooking_block_amount']      =	$resultSet->bokbooking_block_amount;
					$resultArr['bokcreatedby']                 =	$resultSet->bokcreatedby;
					$resultArr['bokbooking_manual_comp_status']=	$resultSet->bokbooking_manual_comp_status;
					$resultArr['bokbooking_migration_status']  =	$resultSet->bokbooking_migration_status;
					$resultArr['bokbooking_source_type']       =	$resultSet->bokbooking_source_type;
					$resultArr['boksync_status']			   =    $resultSet->boksync_status;
					$resultArr['bokbooking_phrase']			   =    $resultSet->bokbooking_phrase;
					$resultArr['bok_restsch_setting_id']	   =    $resultSet->bok_restsch_setting_id;															
					$resultArr['bokcountrycode']	           =    $resultSet->bokcountrycode;											
					$resultArr['bok_contactid']	               =    $resultSet->bok_contactid;		
					$resultArr['bokcompany_id']	               =    $resultSet->bokcompany_id;										
					$resultArr['bok_serverid']	               =    $resultSet->bok_serverid;
					$resultArr['bokresv_runninglate_status']   =    $resultSet->bokresv_runninglate_status;																		
															
					if($bookoptionsRow){
						$resultArr['booking_option_id']				=	$bookoptionsRow->boptid;
					}else{
						$resultArr['booking_option_id']				=	'';
					}
					if($resultSet->bokseat_start)
					{
						$resultArr['bokseat_start'] =	$resultSet->bokseat_start;	
					}else
					{
						$resultArr['bokseat_start'] = "";
					}
					if($resultSet->bokbooking_confirm_status)
					{
						$resultArr['bokbooking_confirm_status']    =	$resultSet->bokbooking_confirm_status;
					}else
					{
						$resultArr['bokbooking_confirm_status'] = "";
					}
					$resultArr['bookstatuscode']       =	$resultSet->stat;
					
					if(($resultSet->boksync_status == "C") && ($resultSet->stat == "BOK" || $resultSet->stat == "CRD" || $resultSet->stat == "DES" || $resultSet->stat == "PTS" || $resultSet->stat == "WRD" || $resultSet->stat == "RSD" || $resultSet->stat == "OVB"))
					{
						$bookTableMapper = new Reservation_Model_ReservationTableMapper();
						$bookTable = $bookTableMapper->getDbTable();
						$boktableselect = $bookTable->select();
						
						$boktableselect->from($bookTable,array('bktbid','bktbfk_booking','bktbtableid','bktbtable_no_assigned','status','bktb_join_table_no','bkt_dining_id'))
							   ->where('bktbfk_booking = ?',$resultSet->bokid)
							   ->where('status = ?', true);
							   
						$boktableres = $bookTable->fetchAll($boktableselect);
						
						foreach($boktableres as $boktable)
						{
							$arr = array();
							
							$arr['bktbid'] = $boktable->bktbid;
							$arr['bktbfk_booking'] = $boktable->bktbfk_booking;
							$arr['bktbtableid'] = $boktable->bktbtableid;
							$arr['bktbtable_no_assigned'] = $boktable->bktbtable_no_assigned;
							$arr['status'] = $boktable->status;
							$arr['bktb_join_table_no'] = $boktable->bktb_join_table_no;
							$arr['bkt_dining_id'] = $boktable->bkt_dining_id;
							
							$boktableArr[] = $arr;
						}	
						
					}
					if(($resultSet->boksync_status == "C") && ($resultSet->stat == "QUOTE"))
					{
						$bookids = array($resultSet->bokid);
						$quoteMapper = new Reservation_Model_ReservationWaitingQuoteMapDataMapper();
						$bokquotedTimeArr = $quoteMapper->GetWaitingQuoteByBookingIds($bookids);
					}
					
					$resultFinalArr[$resultSet->bokid]	=	array(
																	'bokresult' 		=>	$resultArr,
																	'boktableresult'	=>	$boktableArr,
																	'bokwaitingquotemap'=> 	$bokquotedTimeArr
																  );
				}else{
					return false;
				}
			}
			return $resultFinalArr;				   
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function MigratingChangeStatusReservationsToWeb($bookDetails)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			
			$table  = $this->getDbTable();
			
			$bookIds = array();
			$webbookingTimes = array();
			$restid = "";
			foreach($bookDetails as $val)
			{
				if($val->bokwebbookingid != null && $val->bokwebbookingid != ""){
					$bookIds[] = $val->bokwebbookingid;	
					$restid = $val->bokfk_restaurant;
				}
			}
			
			if($restid != ""){
				$timezone = "";
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$timezone = $mapper->GetRestaurantTimeZone($restid);
				date_default_timezone_set($timezone);
			}
			if(count($bookIds) > 0){
				$select = $table->select();			
				$select->from($table,array('bokid','bokupdateddatetime'))
					   ->where('bokid IN (?)',$bookIds);
	
				$rowSet = $table->fetchAll($select);
				
				foreach($rowSet as $dateandid)
				{
					$webbookingTimes[$dateandid->bokid] = $dateandid->bokupdateddatetime;
				}
			}
			$resultArray = array();
			foreach($bookDetails as $row){
				$data = array();
				if(array_key_exists($row->bokwebbookingid,$webbookingTimes))
				{
					if($webbookingTimes[$row->bokwebbookingid] != "" && $webbookingTimes[$row->bokwebbookingid] != null){
						$webupadateddate = strtotime($webbookingTimes[$row->bokwebbookingid]);
					}else{
						$webupadateddate = 0;
					}
					$nativeupadateddate = strtotime($row->bokupdateddatetime);
					
					if($nativeupadateddate > $webupadateddate)
					{			
						if($row->bookstatuscode == "QUOTE" || $row->bookstatuscode == "READY" || $row->bookstatuscode == "CAN")
						{
							$set = array('boksync_status' 		=> 'S',
									'bokupdated_date'			=> date('Y-m-d'),
									'bokupdateddatetime'		=> date("H:i",time()),
									'bokbooking_status_id'		=> $row->bokbooking_status_id);		
							
							if($row->bokquoted_time != "")
							{
								$set['bokquoted_time'] = $row->bokquoted_time;
							}
							
							$where = $db->quoteInto('bokid = ?',$row->bokwebbookingid);
							$table->update($set,$where);
							
							$mailmapper = new Application_Service_Communication();
							
							if($row->bookstatuscode == "QUOTE")
							{
								$boknewquotedtimeinfo = json_decode($row->boknewquotedtimeinfo);
								foreach($boknewquotedtimeinfo as $boknewquotedtimerow)
								{
									$splitdatetime = split (" ", $boknewquotedtimerow->updateddatetime);
									$updateddatetime = $splitdatetime[0].' '.$splitdatetime[1];
									$quoteMapper = new Reservation_Model_ReservationWaitingQuoteMapDataMapper();
									$quoteMapper->InsertQuotedTimesFromNativeApp($row->bokwebbookingid,$boknewquotedtimerow->quotedtimeid,$updateddatetime);
								}
							}
							
							if($row->bookstatuscode == "READY")
							{
								$smsObj = new Communication_Model_Sms();
								
								$resDataMapper = new FirmManagement_Model_FirmDataMapper();
								$restObj= new FirmManagement_Model_FirmById();
								$restObj->setRestaurantId($row->bokfk_restaurant);
								$resDetails = $resDataMapper->getRestaurantById($restObj);
								
								$smsObj->setMsgCode('WaitingReady');
								$Waitdata = array(
												'to'			=>	trim($row->bokphone),
												'RestName' 		=> $resDetails->getRestaurantname(),
												'UserName'		=> $row->bokfirst_name.' '.$row->boklast_name,
												'BookId'		=> $row->bokwebbookingid
								);
								
								$smsObj->setData($Waitdata);
								$mailStatus = $mailmapper->SendSms($smsObj);
							}
								
							if($row->bookstatuscode == "CAN")
							{
								$resDataMapper = new FirmManagement_Model_FirmDataMapper();
								$restObj= new FirmManagement_Model_FirmById();
								$restObj->setRestaurantId($row->bokfk_restaurant);
								$resDetails = $resDataMapper->getRestaurantById($restObj);
								
								$bookingservice = new Application_Service_Reservation();									
								$stateCity = $bookingservice->getRestaurantStateByResId($row->bokfk_restaurant);
								$stateId = $stateCity['state'];
								$cityId = $stateCity['city'];
								$regionId = $stateCity['region'];
										
								$userType = 'CUS';
								$adminService = new Application_Service_Administrator();
								$campProp = new Application_Model_GetCampaignForPost();
								$campProp->setAudType($userType)
								->setStateId($stateId)
								->setCityId($cityId)
								->setRegionId($regionId)
								->setIsAjaxCall(false);		
								$campDetails = array();
								if(!$resDetails->getrescampaignstatus() === false){
									$campDetails = $adminService->GetCampaignDetails($campProp);
								}
								
								$mailObj = new Communication_Model_Mail();
								
								$mailObj->setMsgCode('Cancel');
								$name = $row->bokfirst_name.' '.$row->boklast_name;
								
								$data = array('UserName' => $name,
											  'SenTo'    => $row->bokemail,
											  'phone'	 => $row->bokphone,
											  'RestName' => $resDetails->getRestaurantname(),
											  'ResDate'  => $row->bokbooking_date,
											  'Time'     => $row->bokbooking_timings,
											  'Size'     => $row->bokparty_size,
											  'Address'	 => $resDetails->getRestaddress(),
											  'Status'	 => $row->bookstatuscode,
											  'State_Id' =>	$stateId,
											  'City_Id'	 =>	$cityId,
											  'resphone' => $resDetails->getRestphone(),
											  'UserType' =>	$userType,
											  'BookId'	 => $row->bokwebbookingid,
											  'BookNotCan' => false,
								
								);
								
								if(count($campDetails)){
									$count = count($campDetails);
									if($count > 1){
										$campaign = $campDetails[rand(0,$count-1)];
									}else{
										$campaign = $campDetails[0];
									}
									$notfService = new Application_Service_Communication();
									$countUpdate = $notfService->UpdateCampaignEmailCount($campaign->getId(),1);
									$data['campaignName'] = trim($campaign->getSponsor());
									$data['campaignDesc'] =	trim($campaign->getCampDesc());
									$data['campaignImg'] =	trim($campaign->getCampImage());
									$data['campId']	= $campaign->getId();
								}
								
								$mailObj->setData($data);
								$mailStatus = $mailmapper->SendMail($mailObj);
									
								}		
							}else{
								$set = array('boksync_status' 		=> 'S',
										'bokupdated_date'			=> date('Y-m-d'),
										'bokupdateddatetime'		=> date("H:i",time()),
										'bokbooking_status_id'		=> $row->bokbooking_status_id,
										'bokparty_size'				=> $row->bokparty_size,
										'bokfirst_name'				=> $row->bokfirst_name,
										'boklast_name'				=> $row->boklast_name,
										'bokbooking_confirm_status'	=> $row->bokbooking_confirm_status,
										'bokresv_checkedin_status'	=> $row->bokresv_checkedin_status,	
										'bokresv_allarrived_status' => $row->bokresv_allarrived_status,
										'bokresv_partialarrived_status'=> $row->bokresv_partialarrived_status
									);		
								if($row->bokseat_start)
								{
									$set['bokseat_start'] = $row->bokseat_start;
								}			
								$where = $db->quoteInto('bokid = ?',$row->bokwebbookingid);
								$table->update($set,$where);
									
								$count = 0;
								$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
							    $bookTable  = $bookTableMapper->getDbTable();
								$bookTableSelect = $bookTable->select();
								
								$bookTableSelect->from($bookTable,array('COUNT(bktbid) as count'))
								                ->where('bktbfk_booking = ?',$row->bokwebbookingid)
								                ->where('status = ?',true);
					            
								$countRes = $bookTable->fetchAll($bookTableSelect);
								foreach($countRes as $countrow)
								{
									$count = $countrow->count;
								}
								
								if($count == 0 && $row->booktable)
								{	
									$booktableDetails = json_decode($row->booktable);							
									$joinTableNo = "";
									if($row->bookstatuscode != "RSD" && $row->bookstatuscode != "OVB"){
										if(count($booktableDetails) > 1)
										{
										    	$joinTableNo = $this->CheckJoinTableNo($row->bokwebbookingid,$row->bokfk_restaurant);
										    	if($joinTableNo){
										    		$joinTableNo++;
										    	}else if($joinTableNo == 0 || $joinTableNo == null){
										    		$joinTableNo++;
										    	}
										}	
									}									
									$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
					   				$bookTable  = $bookTableMapper->getDbTable();
									foreach($booktableDetails as $boktablerow)
									{
										if(count($booktableDetails) > 1)
										{
											if($row->bookstatuscode != "RSD" && $row->bookstatuscode != "OVB"){
									    		$data = array('bktbfk_booking'        => $row->bokwebbookingid,
									    					  'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
									    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
									    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
									    					  'bktb_join_table_no'    => $joinTableNo,
									    					  'status'                => true);
									    		$id = $bookTable->insert($data);	 
											}else
											{
												$data = array('bktbfk_booking'        => $row->bokwebbookingid,
									    					  'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
									    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
									    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
									    					  'status'                => true);
									    		$id = $bookTable->insert($data);	
											}
										}else{
											$data = array('bktbfk_booking'        => $row->bokwebbookingid,
						    					  	'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
						    					  	'bktbtableid' 		  => $boktablerow->bktbtableid,
						    					  	'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,		    					  
					    					  		'status'                => true);
					    					$id = $bookTable->insert($data);
										}
									}
								}else
								{
									$desktopAppTables = array();
									$desktopAppTablesIds = array();
									/* CHECKS JOIN TABLES ARE SAME OR NOT START */ 
									if($count > 0 && $row->booktable)
									{
										$booktableDetails = json_decode($row->booktable);
										foreach($booktableDetails as $boktablerow)
										{
											$desktopAppTablesIds[] = $boktablerow->bktbtableid;
											$desktopAppTables[$boktablerow->bktbtableid] = $boktablerow->bktbtable_no_assigned;
										}
										
										$TableSelect = $bookTable->select();
										$TableSelect->from($bookTable,array('bktbtable_no_assigned','bktbtableid','bktb_join_table_no'))
									                ->where('bktbfk_booking = ?',$row->bokwebbookingid)
									                ->where('status = ?',true);
						           		
										$webbooktableDetails = $bookTable->fetchAll($TableSelect);
										$movPartystatus = "";
										$joinTableNo = "";
										foreach($webbooktableDetails as $webbooktable)
										{
											if($row->bookstatuscode != "RSD" && $row->bookstatuscode != "OVB"){
												$joinTableNo = $webbooktable->bktb_join_table_no;
											}
											if(!array_key_exists($webbooktable->bktbtableid, $desktopAppTables)){
												$movPartystatus = true;
											}
										}
										/* CHECKS JOIN TABLES ARE SAME OR NOT END */
										if($movPartystatus)
										{
											/* CHECKS TABLES ARE ALREDY ASSIGN START  */
											if($row->bookstatuscode != "RSD" && $row->bookstatuscode != "OVB"){
												$select = $this->getDbTable()->select();
												$select->setIntegrityCheck(false);
												
												$bookStatus = array('BOK','CRD','DES','PTS','WRD');
												$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
												$bookStatusRes = $bookStatusMapper->GetBookingStatusByCode($bookStatus);
												$statusId = array();
												foreach($bookStatusRes as $key=>$value){
													$statusId[] = $value->getId();
												}
												
												$select->from(array('bok'=>'mt.booking'),array('COUNT(bokid) as count'))
													   ->join(array('bktb'=>'mt.booking_tables'),'bktb.bktbfk_booking  = bok.bokid',array())
													   ->where('bktb.bktbtableid IN (?)',$desktopAppTablesIds)
													   ->where('bok.bokbooking_date = ?',$row->bokbooking_date)
													   ->where('bok.bokid <> ?',$row->bokwebbookingid)
													   ->where('bok.bokbooking_status_id IN (?)',$statusId)
													   ->where('bktb.status = ?',true);
													   
												$resultSetData = $this->getDbTable()->fetchAll($select);
												$tablecount = "";
												foreach($resultSetData as $resultSet){
													$tablecount = $resultSet->count;
												}
											}else
											{
												$tablecount = 0;
											}
											/* CHECKS TABLES ARE ALREDY ASSIGN END 
											 *  IF NOT INSERT TABLES */
											
											if($tablecount == 0)
											{	
												$set = array('status' => 0);
												$where = array('bktbfk_booking = ?' => $row->bokwebbookingid);
												$bookTable->update($set,$where);
												
												foreach($booktableDetails as $boktablerow)
												{
													if(count($booktableDetails) > 1)
													{
														if($row->bookstatuscode != "RSD" && $row->bookstatuscode != "OVB"){
												    		$data = array('bktbfk_booking'        => $row->bokwebbookingid,
												    					  'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
												    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
												    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
												    					  'bktb_join_table_no'    => $joinTableNo,
												    					  'status'                => true);
												    		$id = $bookTable->insert($data);	 
														}else
														{
															$data = array('bktbfk_booking'        => $row->bokwebbookingid,
												    					  'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
												    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
												    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
												    					  'status'                => true);
												    		$id = $bookTable->insert($data);
														}
													}else{
														$data = array('bktbfk_booking'        => $row->bokwebbookingid,
									    					  	'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
									    					  	'bktbtableid' 		  => $boktablerow->bktbtableid,
									    					  	'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,		    					  
								    					  		'status'                => true);
								    					$id = $bookTable->insert($data);
													}
												}
											}										
										}
									}else
									{
										if($row->bookstatuscode == "RSD" || $row->bookstatuscode == "OVB"){
											$set = array('status' => 0);
											$where = array('bktbfk_booking = ?' => $row->bokwebbookingid);
											$bookTable->update($set,$where);
										}
									}
								}
							}	
							$resultArray[] = array('bokid'=>$row->bokid,'bokwebbookingid'=>$row->bokwebbookingid,'boksync_status' => 'S');				
						}
				}
			}			
			return $resultArray;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function updateBokSyncStatusFromNative($bookDetails)
	{
		try
		{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table  = $this->getDbTable();
			foreach($bookDetails as $parentrow){
				$timezone = "";
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$timezone = $mapper->GetRestaurantTimeZone($parentrow->Key);
				date_default_timezone_set($timezone);
				
				$childDetails = $parentrow->Value;
				
				foreach($childDetails as $childrow)
				{
					$set = array('boksync_status' 	=> $childrow->Value,
							 'bokupdated_date'		=> date('Y-m-d'),
							 'bokupdateddatetime'	=> date("H:i:s",time()),
								
					);					
					$where = $db->quoteInto('bokid = ?',$childrow->Key);
					$table->update($set,$where);
				}
			}
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function GetBookingPhraseByBookid($bokid)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('bokbooking_phrase'))
					->where('bokid = ?',$bokid);
			$result = $this->getDbTable()->fetchRow($select);
			return $result->bokbooking_phrase;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function GetBookingIdByBookPhrase($phrase)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('bokid'))
					->where('bokbooking_phrase = ?',$phrase);
			$result = $this->getDbTable()->fetchRow($select);
			return $result->bokid;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function getBookingCountByDateAndTime($resid, $date, $time, $bookStatusRes)
	{
		try{
			$count = 0;
			$statusId = array();
			foreach($bookStatusRes as $key=>$value){
				$statusId[] = $value->getId();
			}
			
			$select = $this->getDbTable()->select();
			$select->from($this->getDbTable(),array('SUM(bokparty_size) as totalParty'))
					->where('bokbooking_date = ?',$date)
					->where('bokfk_restaurant = ?',$resid)
					->where('bokbooking_timings = ?',$time)
					->where('bok_restsch_setting_id = ?',3)
					->where('bokbooked_status = ?',10)
					->where('bokbooking_status_id IN (?)',$statusId);
			$result = $this->getDbTable()->fetchAll($select);
			foreach($result as $row){
				$count = $row->totalParty;
			}
			return $count;	
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetRestReservations(FirmManagement_Model_FirmSearch $restObj,$resids)
	{
		try{
			$table  = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$resultSet = array();
						
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
							->where('status = ?',true);
							
			$diningAreaMapper = new FirmManagement_Model_FirmDiningAreaDataMapper();
			$diningTable = $diningAreaMapper->getDbTable();
			$diningTableSelect = $diningTable->select();
//			$diningTableSelect->from($diningTable,array('rdaid','rda_diningname','rda_diningdisplyname'))
//							  ->where('rda_restid = ?',$resid)
//							  ->where('rda_status = ?',true);
			$storage = new Zend_Auth_Storage_Session();
			$data = $storage->read();				  
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokuserid','bokfirst_name','boklast_name','bokparty_size','bokbooking_timings','bokbooking_made_on','bokbooking_made_time','bokspecial_request','bokrestaurant_note','bokresv_confirm_status','bokbooking_confirm_status','bokresv_checkedin_status','bokresv_partialarrived_status','bokresv_allarrived_status','bokphone','bokemail'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtableid','bktbtable_no_assigned','bktb_join_table_no','bkt_dining_id'))
//				   ->joinLeft(array('rda'=>$diningTableSelect),'rda.rdaid = bktb.bkt_dining_id',array('rda_diningdisplyname'))		
				   ->join(array('res'=>'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('resrestaurant_name','res_companyid'))		   				   
				   ->join(array('boktyp'=>'mt.booking_type_bd'),'boktyp.id = bokbooking_type_id',array('code as boktypcode','description as boktypdesc'))
				   ->join(array('resmode'=>'mt.reservation_mode_bd'),'resmode.id = bok.bokreservation_mode_id',array('code as bokresmodecode','description as bokresmodedesc'))
				   ->join(array('boksts'=>'mt.booking_status_bd'),'bok.bokbooking_status_id = boksts.id',array('code as bokstatuscode','description as bokstatusdesc'));
			if($restObj->getStartDate() && $restObj->getEndDate()){
				$select->where('bok.bokbooking_date >= ?',$restObj->getStartDate());
				$select->where('bok.bokbooking_date <= ?',$restObj->getEndDate());
			}else if($restObj->getStartDate()){
				$select->where('bok.bokbooking_date = ?',$restObj->getStartDate());
			}
			if($restObj->getRestaurantname() && $restObj->getRestaurantname() != 'All'){
				$select->where('bok.bokfk_restaurant = ?',$restObj->getRestaurantname());
			}
			$select->where('bok.bokbooking_status_id NOT IN (?)',array(4,9));	   
		    $select->order(array('resid','bokid'));
//		    $select->group('resid');
		    $rowset = $table->fetchAll($select);
		    
		    if(count($rowset)>0){
		    					
					$prevBokidArr = array();
					$prevBookid = "";
					$bokid	   = "";
					$bokuserid = "";
					$resname = "";
					$rescomp = "";
					$bokfk_restaurant = "";
					$bokfirst_name = "";
					$bokparty_size = "";
					$bokbooking_timings = "";					
					$bokspecial_request = "";
					$boktypcode = "";
					$boktypdesc = "";
					$boktablenumber = "";
					$bokjointableno = "";
					$boktableid = "";
					$bokresmodecode = "";
					$bokresmodedesc = '';
					$bokrestaurant_note = "";
					$bokstatuscode = "";
					$bokstatusdesc = '';
					$tablNoArr = array();
					$dinigid = "";
					$resvconfirmstatus  = "";
					$resvnoanwser = "";
					$resvcheckedin = "";
					$bokconfirmstatus = "";
					$allarrived	= '';
					$partialarr	= '';
					$bokbooking_made_on = '';
					$bokbooking_made_time = '';
					$bokphone = "";
					$bokemail = "";
					
					$reserveCount = "";
					$canCount     = "";
					$noShowCount  = "";
										
					foreach($rowset as $row)
					{				
						if($prevBookid == ""){						
							$bokid 			   	= $row->bokid;
							$bokuserid 		    = $row->bokuserid;
							$resname			= $row->resrestaurant_name;
							$rescomp			= $row->res_companyid;
							$bokfk_restaurant   = $row->bokfk_restaurant;
							$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
							$bokparty_size 	    = $row->bokparty_size;
							$bokbooking_timings = $row->bokbooking_timings;
							$bokspecial_request = $row->bokspecial_request;
							$boktypcode 		= $row->boktypcode;
							$boktypdesc 		= $row->boktypdesc;					
							$boktablenumber 	= $row->bktbtable_no_assigned;
							$tablNoArr[]		= $row->bktbtable_no_assigned;
							$bokjointableno     = $row->bktb_join_table_no;
							$boktableid 		= $row->bktbtableid;
							$bokresmodecode 	= $row->bokresmodecode;
							$bokresmodedesc		= $row->bokresmodedesc;
							$bokrestaurant_note = $row->bokrestaurant_note;
							$bokstatuscode      = $row->bokstatuscode;
							$bokstatusdesc		= $row->bokstatusdesc;
//							$dinigid			= $row->rda_diningdisplyname;
							$resvconfirmstatus  = $row->bokresv_confirm_status;
							$bokconfirmstatus	= $row->bokbooking_confirm_status;
							$resvcheckedin		= $row->bokresv_checkedin_status;
							$allarrived			= $row->bokresv_allarrived_status;
							$partialarr			= $row->bokresv_partialarrived_status;
							$bokphone			= $row->bokphone;
							$bokemail			= $row->bokemail;
							$bokbooking_made_on = $row->bokbooking_made_on;
							$bokbooking_made_time = $row->bokbooking_made_time;
							$prevBookid		    = $bokid;	
							$prevBokidArr[]		= $bokid;					
							
						}else{
							$bokid = $row->bokid;
							
							if(in_array($bokid,$prevBokidArr)){
								$tablNoArr[] = $row->bktbtable_no_assigned;
							}else{
								$date = "";
								if($bokbooking_timings){
									$date = date("h:i A",strtotime($bokbooking_timings));	
								}	
								if($bokbooking_made_time){
									$made_time = date("h:i A",strtotime($bokbooking_made_time));	
								}
								
																																
								array_push($resultSet,array('booking' 			=> $prevBookid,
					 							 			'restid'			=> $bokfk_restaurant,
															'resname'			=> $resname,
				 											'bok_name'		 	=> $bokfirst_name,				 							 
				 											'bok_party'		 	=> $bokparty_size,
					 							 			'bok_timings'  		=> $date,
															'bok_phone'			=> $bokphone,
															'bok_email'			=> $bokemail,
					 							 			'bok_request'  		=> $bokspecial_request,
					 							 			'bok_modecode' 	  	=> $bokresmodecode,
															'bok_modedesc'	  	=> $bokresmodedesc,
					 							 			'bok_note'  		=> $bokrestaurant_note,
												 			'bok_code'       	=> $bokstatuscode,
															'bok_desc'			=> $bokstatusdesc,
															'bok_created'		=> $bokbooking_made_on.' '.$made_time
															));
								
									
								$tablNoArr			= null;
								$bokuserid 		    = $row->bokuserid;
								$bokfk_restaurant   = $row->bokfk_restaurant;
								$resname			= $row->resrestaurant_name;
								$rescomp			= $row->res_companyid;
								$bokfirst_name 	    = $row->bokfirst_name." ".$row->boklast_name;				
								$bokparty_size 	    = $row->bokparty_size;
								$bokbooking_timings = $row->bokbooking_timings;
								$bokspecial_request = $row->bokspecial_request;
								$boktypcode 		= $row->boktypcode;
								$boktypdesc 		= $row->boktypdesc;					
								$boktablenumber 	= $row->bktbtable_no_assigned;
								$bokjointableno     = $row->bktb_join_table_no;
								$boktableid 		= $row->bktbtableid;
								$bokresmodecode 	= $row->bokresmodecode;
								$bokresmodedesc		= $row->bokresmodedesc;
								$bokrestaurant_note = $row->bokrestaurant_note;
								$bokstatuscode      = $row->bokstatuscode;
								$bokstatusdesc		= $row->bokstatusdesc;
//								$dinigid			= $row->rda_diningdisplyname;
								$resvconfirmstatus  = $row->bokresv_confirm_status;
								$bokconfirmstatus	= $row->bokbooking_confirm_status;
								$resvcheckedin		= $row->bokresv_checkedin_status;
								$allarrived			= $row->bokresv_allarrived_status;
								$partialarr			= $row->bokresv_partialarrived_status;
								$bokphone			= $row->bokphone;
								$bokemail			= $row->bokemail;
								$prevBookid		    = $bokid;
								$tablNoArr[] 		= $row->bktbtable_no_assigned;	
								$bokbooking_made_on = $row->bokbooking_made_on;
								$bokbooking_made_time = $row->bokbooking_made_time;
								$prevBokidArr[]		= $bokid;						
								
							}
						}
					}
					$date = "";
					if($bokbooking_timings){
						$date = date("h:i A",strtotime($bokbooking_timings));
					}
		    		if($bokbooking_made_time){
						$made_time = date("h:i A",strtotime($bokbooking_made_time));	
					}

					
					array_push($resultSet,array('booking' 			=> $prevBookid,
		 							 			'restid'			=> $bokfk_restaurant,
												'resname'			=> $resname,
												'bok_name'		 	=> $bokfirst_name,				 							 
	 											'bok_party'		 	=> $bokparty_size,
		 							 			'bok_timings'  		=> $date,
												'bok_phone'			=> $bokphone,
												'bok_email'			=> $bokemail,
		 							 			'bok_request'  		=> $bokspecial_request,
		 							 			'bok_modecode' 	  	=> $bokresmodecode,
												'bok_modedesc'	  	=> $bokresmodedesc,
		 							 			'bok_note'  		=> $bokrestaurant_note,
									 			'bok_code'       	=> $bokstatuscode,
												'bok_desc'			=> $bokstatusdesc,
												'bok_created'		=> $bokbooking_made_on.' '.$made_time));					
				
				
			}
			return $resultSet;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}	

	public function GetRestInfoByCusId(User_Model_FevRestById $userid,$offset,$email,$phone)
	{
		try{
			$id = $userid->getUserId();
			$query = $this->getDbTable()->select();
			$query->setIntegrityCheck(false);
			$query->distinct();
			$query->from(array('bok' => 'mt.booking'),array('bokfk_restaurant'));
			$query->join(array('res' => 'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('resid','resrestaurant_name','resaddress','resdescription','resimage'));
			$query->join(array('nbh' => 'mt.neighborhood_bd'),'nbh.id = res.resneighborhood_id',array('description as neighbor'));
			$query->join(array('rgn' =>'mt.region_bd'),'rgn.id = res.resregion_id',array('description as region'));
			$query->join(array('cty' =>'mt.city_bd'),'cty.id = res.rescity_id',array('description as city'));
			$query->join(array('sbd'=>'mt.state_bd'),'sbd.id = res.resstate_id',array('description as state'));
			$query->joinLeft(array('crc' => new Zend_Db_Expr('(SELECT crcrestaurant_id,crcstatus FROM mt.customer_restaurant_choice WHERE  crcfk_user ='.$id.')')), 'crc.crcrestaurant_id  = bok.bokfk_restaurant');
			
			$query->where('bokuserid = ?',$id);
			$query->orWhere('bokemail = ?',$email);
//			$query->orWhere('bokphone = ?',$phone);
			$query->order('res.resrestaurant_name');
		//	$query->where('crc.crcfk_user =? ',$id);
		//	$Result = $this->getDbTable()->fetchAll($query);
			$Result = new Zend_Paginator(
			new Zend_Paginator_Adapter_DbTableSelect($query)
			);
			$Result->setItemCountPerPage(2);
			$Result->setCurrentPageNumber($offset);
			
			
			$resultList = array();
			 foreach($Result as $value){
			 	$resdesc = $value->resdescription;
					 if(strlen($resdesc) > 1000){
						$resdesc = substr($resdesc, 0, 1000)."...";
					 }
			 	$obj = new User_Model_CustomerRestChoice();
			 	$obj->setRestId($value->resid)
			 		->setRestaurantname($value->resrestaurant_name)
			 		->setRestneighboorhood($value->neighbor)
			 		->setRestRegion($value->city)
			 		->setRestCity($value->city)
			 		->setRestState($value->state)
			 		->setResAddress($value->resaddress)
			 		->setResDesc($resdesc)
			 		->setRestImage($value->resimage);
			 	$resultList[] = $obj;
			 }
			 
			 return $Result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getRestaurantLocByBookingId($bokid)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('bokfk_restaurant'))
					->join(array('res'=>'mt.restaurant'),'bok.bokfk_restaurant = res.resid',array('resid','resstate_id','rescity_id','resregion_id','res_companyid'))
					->joinLeft(array('com'=>'mt.company'),'com.com_id = res_companyid',array('com_companyname'))
					->joinLeft(array('region'=>'mt.region_bd'),'region.id = resregion_id',array('code as region'))
					->joinLeft(array('state'=>'mt.state_bd'),'state.id = resstate_id',array('code as state','country_dial_code'))
				   ->where('bokid = ?',$bokid);
			$result = $this->getDbTable()->fetchRow($select);
			
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getRestaurantLocByResId($resid)
	{
		try{
			$select = $this->getDbTable()->select();
			$select->setIntegrityCheck(false);
			$select->from(array('res'=>'mt.restaurant'),array('resid','resrestaurant_name','resstate_id','rescity_id','resregion_id','res_companyid'))
					->joinLeft(array('com'=>'mt.company'),'com.com_id = res_companyid',array('com_companyname'))
					->joinLeft(array('region'=>'mt.region_bd'),'region.id = resregion_id',array('code as region'))
					->joinLeft(array('state'=>'mt.state_bd'),'state.id = resstate_id',array('code as state'))
				   ->where('resid = ?',$resid);
			$result = $this->getDbTable()->fetchRow($select);
			
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetMonthlyTimeSlotsForChart($request)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			
			$mealMapper = new FirmManagement_Model_FirmMealTypeDataMapper();
			
					
			$select->from($table,array("COUNT(bokbooking_timings) as booking_timings","bokbooking_timings","array_agg(bokfirst_name) as firstname", "array_agg(boklast_name)as lastname", "array_agg(bokbooking_date) as date"));		
			$select->where('bokfk_restaurant =?',$request->restid);
			$select->where('bok_contactid =?',$request->customerid);
//			if ($request->phone && $request->email) {
//				$select->where("bokphone = '$request->phone' OR bokemail = '$request->email'");	
//			}else if ($request->phone) {
//				$select->where('bokphone = ?',$request->phone);	
//			}else if ($request->email) {
//				$select->where('bokemail =?',$request->email);	
//			}
			if($request->startDate && $request->endDate){
				$dateSplit = explode(' ',$request->startDate);
				$smonth = date('m',strtotime($dateSplit[1]));
				$startdate = date("Y-m-d", mktime(0,0,0,$smonth,$dateSplit[0],$dateSplit[2]));
				$dateSplit = explode(' ',$request->endDate);
				$emonth = date('m',strtotime($dateSplit[1]));
				$enddate = date("Y-m-d", mktime(0,0,0,$emonth,$dateSplit[0],$dateSplit[2]));
				$select->where('bokbooking_date >= ?',$startdate);
				$select->where('bokbooking_date <= ?',$enddate);
			}else{
				$select->where('bokbooking_date >= ?',date("Y-m-d", strtotime("-1 months")));
				$select->where('bokbooking_date <= ?',date("Y-m-d"));
			}
    		$select->group('bokbooking_timings');
			$select->order('bokbooking_timings');
			$Result = $table->fetchAll($select);
			$result = array();
			$resultCount = array();
			$resultName = array();
			$book_details = array();
			function map_Name($x, $y) { return $x .";". $y; }
			foreach($Result as $booktime_details){
				$Fname = str_getcsv(trim($booktime_details->firstname, '{}'));
				$Lname = str_getcsv(trim($booktime_details->lastname, '{}'));
				$Bkdate = str_getcsv(trim($booktime_details->date, '{}'));
				
				$FName = implode(',',$Fname);
				$LName = implode(',',$Lname);
				$fname = explode(",",$FName);
				$lname = explode(",",$LName);
				
				$name = array_map('map_Name', $fname, $lname);
				$BkdateArr = array();
				foreach($Bkdate as $bkdate){
					$BkdateArr[] = date("d M Y", strtotime($bkdate));
				}				
				$bookDate = implode(",",$BkdateArr);
				$bookdate = explode(",",$bookDate);
				$res = array_map('map_Name', $name, $bookdate);
				$Timeslots = date("h:i A",strtotime($booktime_details->bokbooking_timings));
				$resultCount[$Timeslots] = $booktime_details->booking_timings;				
				$resultName[$Timeslots] =	$res; 
			}	
			$result = array('resultCount'=>$resultCount,'resultName'=>$resultName);
			if($result['resultCount']){
				return $result;		
			}else{
				return '';
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetMonthlyOriginForChart($request)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
					
			$select->from($table,array("COUNT(bokreservation_mode_id) as reservation_mode","array_agg(bokbooking_timings) as booking_time","array_agg(bokfirst_name) as firstname", "array_agg(boklast_name)as lastname", "array_agg(bokbooking_date) as date"));		
			$select->join(array('rmb'=>'mt.reservation_mode_bd'),'rmb.id = bokreservation_mode_id',array('description as mode'));
			$select->where('bokfk_restaurant =?',$request->restid);
			$select->where('bok_contactid =?',$request->customerid);
//			if ($request->phone && $request->email) {
//				$select->where("bokphone = '$request->phone' OR bokemail = '$request->email'");	
//			}else if ($request->phone) {
//				$select->where('bokphone = ?',$request->phone);	
//			}else if ($request->email) {
//				$select->where('bokemail =?',$request->email);	
//			}
			if($request->startDate && $request->endDate){
//				$select->where('bokbooking_date >= ?',date("Y-m-d", strtotime($request->startDate)));
//				$select->where('bokbooking_date <= ?',date("Y-m-d", strtotime($request->endDate)));

				$dateSplit = explode(' ',$request->startDate);
				$smonth = date('m',strtotime($dateSplit[1]));
				$startdate = date("Y-m-d", mktime(0,0,0,$smonth,$dateSplit[0],$dateSplit[2]));
				$dateSplit = explode(' ',$request->endDate);
				$emonth = date('m',strtotime($dateSplit[1]));
				$enddate = date("Y-m-d", mktime(0,0,0,$emonth,$dateSplit[0],$dateSplit[2]));
								
				$select->where('bokbooking_date >= ?',$startdate);
				$select->where('bokbooking_date <= ?',$enddate);
			}else{
				$select->where('bokbooking_date >= ?',date("Y-m-d", strtotime("-1 months")));
				$select->where('bokbooking_date <= ?',date("Y-m-d"));
			}
    		$select->group(array('mode'));
			
			$Result = $table->fetchAll($select);
			$result = array();
			$resultCount = array();
			$resultName = array();
			$book_details = array();
			function map_Name($x, $y) { return $x .";". $y; }
			foreach($Result as $booktime_details){
				$booking_time = str_getcsv(trim($booktime_details->booking_time, '{}'));
				$Fname = str_getcsv(trim($booktime_details->firstname, '{}'));
				$Lname = str_getcsv(trim($booktime_details->lastname, '{}'));
				$Bkdate = str_getcsv(trim($booktime_details->date, '{}'));
				
				$FName = implode(',',$Fname);
				$LName = implode(',',$Lname);
				$fname = explode(",",$FName);
				$lname = explode(",",$LName);
				
				$Booking_Time = implode(',',$booking_time);
				$Booking_Time = explode(",",$Booking_Time);
				$Booking_TimeArr = array();
				foreach($Booking_Time as $time){
					$Booking_TimeArr[] = date("h:i A",strtotime($time));
				}
				$rest = array_map('map_Name', $Booking_TimeArr,$fname);
				
				$name = array_map('map_Name', $rest, $lname);
				
				$BkdateArr = array();
				foreach($Bkdate as $bkdate){
					$BkdateArr[] = date("d M Y", strtotime($bkdate));
				}
				
				$bookDate = implode(",",$BkdateArr);
				$bookdate = explode(",",$bookDate);
				$res = array_map('map_Name', $name, $bookdate);
				
				$resultCount[$booktime_details->mode] = $booktime_details->reservation_mode;				
				$resultName[$booktime_details->mode] =	$res; 
			}	
			$result = array('resultCount'=>$resultCount,'resultName'=>$resultName);
			if($result['resultCount']){
				return $result;		
			}else{
				return '';
			}
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	
	public function getpastandfuturereservations($request,$offset)
	{
		try{
			$resService = new Application_Service_Firm();
			$timeZone = $resService->GetRestaurantTimeZone($request->resid);
			date_default_timezone_set($timeZone);
			$limit = 10;
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokspecial_request','bokbooking_status_id','bokreadstatus'))
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id','code as resvmode');
//		    if(($request->email && $request->email != 'null') && ($request->mobile && $request->mobile != 'null')){
//				$select->where('bok.bokemail ILIKE(?)','%'.$request->email.'%');
//				$select->orwhere('bok.bokphone = ?',$request->mobile);
//			}else if($request->email && $request->email != 'null'){
//			    $select->where('bok.bokemail ILIKE(?)','%'.$request->email.'%');
//			}else if($request->mobile && $request->mobile != 'null'){
//				$select->where('bok.bokphone = ?',$request->mobile);
//		   	}
			if($request->type == 'past'){
				$select->where('bok.bokbooking_date < ?',date('Y-m-d'));
			}else{
				$select->where('bok.bokbooking_date >= ?',date('Y-m-d'));
			}
			$select->where('bok.bok_contactid = ?',$request->customerid);
		   	$select->where('bok.bokfk_restaurant = ?',$request->resid);	   
			$select->order(array('bokid DESC'));			
//			$rowSet = $table->fetchAll($select);
			$resultSet = new Zend_Paginator(
				new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
			$result = array();
			foreach($resultSet as $row){
				$result[] = array('Id'			   	=> $row->bokid,
							  'Time' 				=> date("h:i A",strtotime($row->bokbooking_timings)),
							  'Date'	   			=> date('d M Y',strtotime($row->bokbooking_date)),
							  'Name'	   			=> $row->bokfirst_name." ".$row->boklast_name,
							  'Size'	   			=> $row->bokparty_size,
							  'Status'	   			=> $row->bokstatusdesc,
							  );								
			}
			return $result; 			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	public function updateServeridByBookingid($bookingid,$serverid,$restid)
	{
		try{
			$table = $this->getDbTable();
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			
			$set = array(
						'bok_serverid'				=> $serverid,	
						'bokupdated_date'			=> date('Y-m-d'),
						'bokupdateddatetime'		=> date("H:i:s",time()),
						'bokupdatedby_userid'		=> $userdata['User_Id'],
						'boksync_status'			=> 'C');
			
		    $where = array('bokid = ?' 			  => $bookingid,
					   	   'bokfk_restaurant = ?' => $restid);
			  
		    $rows_affected = $table->update($set,$where);
		    return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateContactIdByBookingid($bookingid,$contactid,$restid)
	{
		try{
			$table = $this->getDbTable();
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($restid);
			date_default_timezone_set($timezone);
			
			$set = array('bok_contactid'				=> $contactid,	
						'bokupdated_date'			=> date('Y-m-d'),
						'bokupdateddatetime'		=> date("H:i:s",time()),
						'boksync_status'			=> 'C');
			
			$mapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
			$rowset = $mapper->searchCusContactByGroupId($contactid,$restid);
			foreach($rowset as $row){
				$set['bokfirst_name'] = $row['firstName'];
				if($row['lastName']){
					$set['boklast_name'] = $row['lastName'];
				}
				if($row['Phone']){
					$set['bokphone'] = $row['Phone'];
				}
				if($row['Email']){
					$set['bokemail'] = $row['Email'];
				}
			}
			
		    $where = array('bokid = ?' 			  => $bookingid,
					   	   'bokfk_restaurant = ?' => $restid);
			  
		    $rows_affected = $table->update($set,$where);
		    return $rows_affected;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateBookingInfoByBookingid(Reservation_Model_Reservation $bookingObj)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();
			
			$table = $this->getDbTable();
			
			$select = $table->select();
			$select->from($table,array('bok_contactid'))
			       ->where('bokid = ?' ,$bookingObj->getbokid());
            
			$row = $table->fetchRow($select);                
            
			$contactid = '';			
			if($row->bok_contactid){
				$contactid = $row->bok_contactid;
			}
			
			$timezone = "";
			$mapper = new FirmManagement_Model_FirmDataMapper();
			$timezone = $mapper->GetRestaurantTimeZone($bookingObj->getbokfk_restaurant());
			date_default_timezone_set($timezone);
			$storage = new Zend_Auth_Storage_Session();
			$userdata = $storage->read();
			if($bookingObj->getbokcontactid()){
				$set['bok_contactid'] = $bookingObj->getbokcontactid();
			}
			$set = array('bokupdated_date'			=> date('Y-m-d'),
						'bokupdateddatetime'		=> date("H:i:s",time()),
						'bokupdatedby_userid'		=> $userdata['User_Id'],
						'boksync_status'			=> 'C');
			
			$set['bokfirst_name'] = $bookingObj->getbokfirst_name();
			$set['boklast_name'] = $bookingObj->getboklast_name();
			$set['boknotification_type'] = $bookingObj->getNotificationType();
//			if($bookingObj->getNotificationType() == 'both'){
//				$set['bokphone'] = $bookingObj->getbokphone();
//				$set['bokemail'] = $bookingObj->getbokemail();
//			}else if($bookingObj->getNotificationType() == 'sms'){
//				$set['bokphone'] = $bookingObj->getbokphone();
//			}else{
//				$set['bokemail'] = $bookingObj->getbokemail();
//			}
			if($bookingObj->getbokphone()){
				$set['bokphone'] = $bookingObj->getbokphone();
			}
                        else{
                            $set['bokphone']='';
                        }
			if($bookingObj->getbokemail()){
				$set['bokemail'] = $bookingObj->getbokemail();
			}
                        else
                        {
                            $set['bokemail'] ='';
                        }
			if($bookingObj->getbokcountry_code()){
				$set['bokcountrycode'] =  $bookingObj->getbokcountry_code();
			}
			if($bookingObj->getbokrestaurant_note()){
				$set['bokrestaurant_note'] = $bookingObj->getbokrestaurant_note();
			}
                        else{
                            $set['bokrestaurant_note'] ='';
                        }
                        if($bookingObj->getguest_notes()){
				$set['bokspecial_request'] = $bookingObj->getguest_notes();
			}
                        else{
                            $set['bokspecial_request'] ='';
                        }
                        
			if($bookingObj->getbokparty_size()){
				$set['bokparty_size'] = $bookingObj->getbokparty_size();
			}
			
		    $where = array('bokid = ?' 			  => $bookingObj->getbokid(),
					   	   'bokfk_restaurant = ?' => $bookingObj->getbokfk_restaurant());
			  
		    $rows_affected = $table->update($set,$where);
// 		 	if($contactid == '' || $contactid != $bookingObj->getbokcontactid()){
// 			    $groupmapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
// 			    if($contactid)
// 				$groupmapper->updateGuestReservationCount($bookingObj->getbokcontactid(),'RSD',2);
// 		 	}
			$db->commit();
		    return $rows_affected;
		}catch (Exception $ex){
			$db->rollBack();
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function updateFeedbackStatusByBookingId($bookingid)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table  = $this->getDbTable();
			$set = array('bokfeedback_status' 	=> true);					
			$where = $db->quoteInto('bokid = ?',$bookingid);
			$roweff = $table->update($set,$where);
			return $roweff;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function GetWaitingListCount($resid,$date,$bookStatusRes)
	{	
		try{
			$statusId = array();
			$status = $bookStatusRes;
			foreach($status as $key=>$value){
				$statusId[] = $value->getId();
			}
			$table = $this->getDbTable();
			$select = $table->select();
			$select->from(array('mt.booking'),array('count(bokid) as count'))
			      	->where('bokfk_restaurant = ?',$resid)
					->where('bokbooking_date = ?',$date)
					->where('bokbooking_status_id IN(?)',$statusId);
            $row = $table->fetchRow($select);  
            $result = $row->count;
            return $result;
		 }catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}    
	
        public function getWebReservationListbyCompanyid($resFilter,$isAjax, $pageOffset=null, $perPage=null)
	{	
		try{
			$s = "bok.bokfirst_name||' '||bok.boklast_name";
			$notifyTableMapper = new FirmManagement_Model_FirmNotifyTimesMapper(); 
			$notifyTableSelect = $notifyTableMapper->getDbTable()->select();
			$notifyTableSelect->from($notifyTableMapper->getDbTable(),array('rntfk_restaurants','array_agg(rntphone) as phoneNo'))
							  ->where('rntnotify_type = ?','sms')
							  ->group(array('rntfk_restaurants'));
								
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfirst_name','boklast_name','bokemail','bokphone','bokcountrycode','bokspecial_request','bokuserid','bokparty_size','bokbooking_date','bokbooking_timings','bokreservation_mode_id','bokrestaurant_note','bokcompany_id','bokfk_restaurant','bokbooking_made_time','bokbooking_made_on'))
				   ->joinLeft(array('rmb'=>'mt.reservation_mode_bd'),'rmb.id = bok.bokreservation_mode_id',array('description as mode'))
				   ->joinLeft(array('bst'=>'mt.booking_status_bd'),'bst.id = bok.bokbooking_status_id',array('code as stat','description'))
				   ->joinLeft(array('res'=>'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('resrestaurant_name','resfk_user','resemail','resphone','resaddress','reszipcode','res_companyid','resmanager_name'))
				   ->joinLeft(array('restown'=>'mt.restaurant_owner'),'restown.rsofk_user = res.resfk_user',array('rsofirst_name','rsolast_name','rsotechfirst_name','rsocountrycode','rsophone','rsotechlast_name','rsobilfirst_name','rsobillast_name','rsotechphone','rsotechcountrycode','rsobilphone','rsobilcountrycode','rsotechemail','rsobilemail'))
			 	   ->joinLeft(array('nbh' => 'mt.neighborhood_bd'),'nbh.id = res.resneighborhood_id',array('description as neighbor'))
				   ->joinLeft(array('rgn' =>'mt.region_bd'),'rgn.id = res.resregion_id',array('description as region'))
				   ->joinLeft(array('cty' =>'mt.city_bd'),'cty.id = res.rescity_id',array('description as city'))
			       ->joinLeft(array('sbd'=>'mt.state_bd'),'sbd.id = res.resstate_id',array('description as state'))
			       ->joinleft(array('rgu'=>'mt.restaurant_group_users'),'rgu.rguid = bok.bok_contactid',array('rguspecial_request'))
       			   ->joinLeft(array('tz'=>'mt.timezone_bd'),'tz.code = res.restimezone',array('description as TimeZone'))
       			   ->joinleft(array('bio'=>'mt.booking_inat_operations'),'bio.biobokid = bok.bokid',array('operations'))
				   ->joinleft(array('rnt'=>$notifyTableSelect),'rnt.rntfk_restaurants = res.resid',array('phoneNo'))
				   ->joinLeft(array('par'=>'mt.company'),'par.com_companyname = rmb.description',array('com_id','com_logo'))
				   //->where('bok.bokreservation_mode_id IN (?)',array(1,6))
				   ->where('bok.bokbooking_status_id IN (?)',array(10,13));
			if($resFilter['CompanyId'] != 1){
				$select->where('res.res_companyid = ?',$resFilter['CompanyId']);
			}
			if(isset($resFilter['restname'])){
				$select->where('res.resrestaurant_name Ilike ?','%'.trim($resFilter['restname']).'%');
			}
			if(isset($resFilter['restId'])){
				$select->where('res.resid = ?',$resFilter['restId']);
			}			
			if(isset($resFilter['resCountry']) && $resFilter['resCountry'] != ''){
				$select->where('res.resstate_id = ?',$resFilter['resCountry']);
			}			
			if(isset($resFilter['resState']) && $resFilter['resState'] != ''){
				$select->where('res.resregion_id = ?',$resFilter['resState']);
			}
			if(isset($resFilter['resCity']) && $resFilter['resCity'] != ''){
				$select->where('res.rescity_id = ?',$resFilter['resCity']);
			}
			if(isset($resFilter['bookStatus']) && $resFilter['bookStatus'] == 1){
				$select->where('bio.operations = ?','Notified');
			}
			if(isset($resFilter['bookStatus']) && $resFilter['bookStatus'] == 2){
				$select->where('bio.operations = ?','Phone Not Receiving');
			}
			if(isset($resFilter['bookStatus']) && $resFilter['bookStatus'] == 3){
				$select->where('bio.operations = ?','Wrong Number');
			}
			
			if(isset($resFilter['reservDateType']) && $resFilter['reservDateType'] == 2){
				if(isset($resFilter['StartDate'])&& isset($resFilter['EndDate'])){
					$select->where('bok.bokbooking_date >= ?',$resFilter['StartDate']);
					$select->where('bok.bokbooking_date <= ?',$resFilter['EndDate']);
				}else if(isset($resFilter['StartDate'])){
					$select->where('bok.bokbooking_date = ?',$resFilter['StartDate']);
				}else{
					$select->where('bok.bokbooking_date = ?',date('Y-m-d'));
				}
			}else{
				if(isset($resFilter['StartDate'])&& isset($resFilter['EndDate'])){
					$select->where('bok.bokbooking_made_on >= ?',$resFilter['StartDate']);
					$select->where('bok.bokbooking_made_on <= ?',$resFilter['EndDate']);
				}else if(isset($resFilter['StartDate'])){
					$select->where('bok.bokbooking_made_on = ?',$resFilter['StartDate']);
				}else{
					$select->where('bok.bokbooking_made_on = ?',date('Y-m-d'));
				}
			}
			
			if(isset($resFilter['rguName'])){
				$select->where($s.' ILIKE(?)','%'.$resFilter['rguName'].'%');
			}
			if(isset($resFilter['rguEmail'])){
				$select->where('bok.bokemail ILIKE(?)','%'.$resFilter['rguEmail'].'%');
			}
			if(isset($resFilter['rguPhone'])){
				$select->where('bok.bokphone  = ? ', $resFilter['rguPhone']);
			}
			$sorton = 'bok.bokid DESC';
			if(isset($resFilter['booksorton'])){
				$explode = explode(',',$resFilter['booksorton']);
				if(isset($explode[1])){
					$sorton = array($explode[0],$explode[1]);
				}else{
					$sorton = array($explode[0]);
				}
			}
			$select->order($sorton);
                        if($perPage!=null){
                           $select->limit($perPage,$pageOffset); 
                        }
			
			$resultSet = $table->fetchAll($select); 
		    $result = array();
		    foreach($resultSet as $row){
				$timeValue = explode(':',$row->bokbooking_timings);
				if($timeValue[0] >=12){
					if((int)$timeValue[0] != 12){
						(int)$timeValue[0] -= 12;
					}
					$timeValue[2] = 'PM';
					$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
				}else{
					$timeValue[2] = 'AM';
					$finalTimeValue = $timeValue[0].':'.$timeValue[1].' '.$timeValue[2];
				}
				$madetimeValue = explode(':',$row->bokbooking_made_time);
		    	if($madetimeValue[0] >=12){
					if((int)$madetimeValue[0] != 12){
						(int)$madetimeValue[0] -= 12;
					}
					$madetimeValue[2] = 'PM';
					$madefinalTimeValue = $madetimeValue[0].':'.$madetimeValue[1].' '.$madetimeValue[2];
				}else{
					$madetimeValue[2] = 'AM';
					$madefinalTimeValue = $madetimeValue[0].':'.isset($madetimeValue[1]).' '.$madetimeValue[2];
				}
				
				
		        if($row->bokbooking_date){
					$tSel = explode('-',$row->bokbooking_date);
					if($tSel[0] > 12){
						$formDateVal = date("d M Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
					}else {
						$formDateVal = date("d M Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
					}
		        }
		        
		    	if($row->bokbooking_made_on){
					$madetSel = explode('-',$row->bokbooking_made_on);
					if($madetSel[0] > 12){
						$madeformDateVal = date("d M Y",mktime(0,0,0,$madetSel[1],$madetSel[2],$madetSel[0]));
					}else {
						$madeformDateVal = date("d M Y",mktime(0,0,0,$madetSel[0],$madetSel[1],$madetSel[2]));
					}
		        }
		      
		        $contactNo = substr($row->phoneNo, 1, -1);
		        
				$bookDetails = new Reservation_Model_Reservation();
				$bookDetails->setbokid($row->bokid);
				$bookDetails->setbokuserid($row->bokuserid);
				$bookDetails->setbokfirst_name($row->bokfirst_name);
				$bookDetails->setboklast_name($row->boklast_name);
				$bookDetails->setbokbooking_status_code($row->stat);
				$bookDetails->setbokparty_size($row->bokparty_size);
				$bookDetails->setbokbooking_date($formDateVal);
				$bookDetails->setbokbooking_made_on($madeformDateVal);
				$bookDetails->setbokbooking_timings($finalTimeValue);
				$bookDetails->setBookingMadeTime($madefinalTimeValue);
				$bookDetails->setbokphone($row->bokphone);
				$bookDetails->setbokcountry_code($row->bokcountrycode);
				$bookDetails->setbokemail($row->bokemail);
				$bookDetails->setbokspecial_request($row->bokspecial_request);
				$bookDetails->setbokcompany_id($row->res_companyid);
				$bookDetails->setbokfk_restaurant($row->bokfk_restaurant);
				$bookDetails->setresrestaurant_name($row->resrestaurant_name);
				$bookDetails->setresaddress($row->resaddress);
				$bookDetails->setbokreservation_mode_desc($row->mode);
				$bookDetails->setbokrestaurant_note($row->bokrestaurant_note);
				$bookDetails->setResPhone($row->resphone);
				$bookDetails->setResEmail($row->resemail);
				$bookDetails->setResCity($row->city);
				$bookDetails->setResNeighborhood($row->neighbor);
				$bookDetails->setResState($row->region);
				$bookDetails->setResCountry($row->state);
				$bookDetails->setResZipcode($row->reszipcode);
				$bookDetails->setguest_notes($row->rguspecial_request);
				$bookDetails->setbok_notified($row->operations);
				$bookDetails->setres_contactNotify($contactNo);
				$bookDetails->setresManagerName($row->resmanager_name);
				$bookDetails->setresOwnerName($row->rsofirst_name. ' '.$row->rsolast_name);
				$bookDetails->setresTechName($row->rsotechfirst_name. ' '.$row->rsotechlast_name);
				$bookDetails->setresBillName($row->rsobilfirst_name. ' '.$row->rsobillast_name);
				$bookDetails->setresOwnerPhone($row->rsophone);
				$bookDetails->setresTechPhone($row->rsotechphone);
				$bookDetails->setresBillPhone($row->rsobilphone);
				$bookDetails->setresOwnerCountryCode($row->rsocountrycode);
				$bookDetails->setresTechCountryCode($row->rsotechcountrycode);
				$bookDetails->setresBillCountryCode($row->rsobilcountrycode);
				$bookDetails->setresTechEmail($row->rsotechemail);
				$bookDetails->setresBillEmail($row->rsobilemail);
				$bookDetails->setresOwnerID($row->resfk_user);
				$bookDetails->setCusCompany($row->com_logo);

				
				if($isAjax){					
					array_push($result,array('bokid'				=>		$bookDetails->getbokid(),
									  'bokuserid'					=> 		$bookDetails->getbokuserid(),
									  'bokfirst_name'				=>		$bookDetails->getbokfirst_name(),
									  'boklast_name'				=>		$bookDetails->getboklast_name(),
								  	  'bokstat'						=>  	$bookDetails->getbokbooking_status_code(),
									  'bokparty_size'				=>		$bookDetails->getbokparty_size(),
									  'bokbooking_date'				=>		$bookDetails->getbokbooking_date(),
									  'bokbooking_timings'			=>	 	$bookDetails->getbokbooking_timings(),
									  'bokbooking_made_on'			=>		$bookDetails->getbokbooking_made_on(),
									  'bokbooking_made_time'		=>		$bookDetails->getBookingMadeTime(),
									  'bokphone'					=>		$bookDetails->getbokphone(),
									  'bokcountrycode'				=>		$bookDetails->getbokcountry_code(),
									  'bokemail'					=>		$bookDetails->getbokemail(),
									  'special_request'				=>		$bookDetails->getbokspecial_request(),
									  'companyID'					=>		$bookDetails->getbokcompany_id(),
									  'bokfk_restaurant'			=>		$bookDetails->getbokfk_restaurant(),
									  'resrestaurant_name'			=>		$bookDetails->getresrestaurant_name(),
									  'resaddress'					=>		$bookDetails->getresaddress(),
									  'bokreservation_mode_desc'	=>		$bookDetails->getbokreservation_mode_desc(),
									  'bokrestaurant_note'			=>		$bookDetails->getbokrestaurant_note(),
									  'resphone'					=>		$bookDetails->getResPhone(),
									  'resemail'					=>		$bookDetails->getResEmail(),
									  'city'						=>		$bookDetails->getResCity(),
									  'neighbor'					=>		$bookDetails->getResNeighborhood(),
									  'region'						=>		$bookDetails->getResState(),
									  'state'						=>		$bookDetails->getResCountry(),
									  'reszipcode'					=>		$bookDetails->getResZipcode(),
									  'guest_notes'					=>		$bookDetails->getguest_notes(),
									  'bionotified'					=>		$bookDetails->getbok_notified(),
									  'resContactNumber'			=>		$bookDetails->getres_contactNotify(),
									  'resOwnerName'				=>		$bookDetails->getresOwnerName(),
									  'resManagerName'				=>		$bookDetails->getresManagerName(),
									  'resTechName'					=>		$bookDetails->getresTechName(),
									  'resBillName'					=>		$bookDetails->getresBillName(),
								      'resOwnerPhone'				=>		$bookDetails->getresOwnerPhone(),
									  'resTechPhone'				=>		$bookDetails->getresTechPhone(),
									  'resBillPhone'				=>		$bookDetails->getresBillPhone(),
									  'resTechEmail'				=>		$bookDetails->getresTechEmail(),
									  'resBillEmail'				=>		$bookDetails->getresBillEmail(),
									  'resOwnerCountryCode'			=>		$bookDetails->getresOwnerCountryCode(),
								   	  'resTechCountryCode'			=>		$bookDetails->getresTechCountryCode(),
									  'resBillCountryCode'			=>		$bookDetails->getresBillCountryCode(),
									  'resOwnerId'					=>		$bookDetails->getresOwnerID(),
									  'companyLogo'					=>		$bookDetails->getCusCompany()
					));
				}else{
					$result[] = $bookDetails;
				}
			}	 
			return $result;  
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	} 
        
	public function getConsWebReservationListbyCompanyid($resFilter,$isAjax, $page=null)
	{	
		try{
                        $limit=12;
			$s = "bok.bokfirst_name||' '||bok.boklast_name";
			$notifyTableMapper = new FirmManagement_Model_FirmNotifyTimesMapper(); 
			$notifyTableSelect = $notifyTableMapper->getDbTable()->select();
			$notifyTableSelect->from($notifyTableMapper->getDbTable(),array('rntfk_restaurants','array_agg(rntphone) as phoneNo'))
							  ->where('rntnotify_type = ?','sms')
							  ->group(array('rntfk_restaurants'));
								
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfirst_name','boklast_name','bokemail','bokphone','bokcountrycode','bokspecial_request','bokuserid','bokparty_size','bokbooking_date','bokbooking_timings','bokreservation_mode_id','bokrestaurant_note','bokcompany_id','bokfk_restaurant','bokbooking_made_time','bokbooking_made_on'))
				   ->joinLeft(array('rmb'=>'mt.reservation_mode_bd'),'rmb.id = bok.bokreservation_mode_id',array('description as mode'))
				   ->joinLeft(array('bst'=>'mt.booking_status_bd'),'bst.id = bok.bokbooking_status_id',array('code as stat','description'))
				   ->joinLeft(array('res'=>'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('resrestaurant_name','resfk_user','resemail','resphone','resaddress','reszipcode','res_companyid','resmanager_name'))
				   ->joinLeft(array('restown'=>'mt.restaurant_owner'),'restown.rsofk_user = res.resfk_user',array('rsofirst_name','rsolast_name','rsotechfirst_name','rsocountrycode','rsophone','rsotechlast_name','rsobilfirst_name','rsobillast_name','rsotechphone','rsotechcountrycode','rsobilphone','rsobilcountrycode','rsotechemail','rsobilemail'))
			 	   ->joinLeft(array('nbh' => 'mt.neighborhood_bd'),'nbh.id = res.resneighborhood_id',array('description as neighbor'))
				   ->joinLeft(array('rgn' =>'mt.region_bd'),'rgn.id = res.resregion_id',array('description as region'))
				   ->joinLeft(array('cty' =>'mt.city_bd'),'cty.id = res.rescity_id',array('description as city'))
			       ->joinLeft(array('sbd'=>'mt.state_bd'),'sbd.id = res.resstate_id',array('description as state'))
			       ->joinleft(array('rgu'=>'mt.restaurant_group_users'),'rgu.rguid = bok.bok_contactid',array('rguspecial_request'))
       			   ->joinLeft(array('tz'=>'mt.timezone_bd'),'tz.code = res.restimezone',array('description as TimeZone'))
       			   ->joinleft(array('bio'=>'mt.booking_inat_operations'),'bio.biobokid = bok.bokid',array('operations'))
				   ->joinleft(array('rnt'=>$notifyTableSelect),'rnt.rntfk_restaurants = res.resid',array('phoneNo'))
				   ->joinLeft(array('par'=>'mt.company'),'par.com_companyname = rmb.description',array('com_id','com_logo'))
				   //->where('bok.bokreservation_mode_id IN (?)',array(1,6))
				   ->where('bok.bokbooking_status_id IN (?)',array(10,13));
			if($resFilter['CompanyId'] != 1){
				$select->where('res.res_companyid = ?',$resFilter['CompanyId']);
			}
			if(isset($resFilter['restname'])){
				$select->where('res.resrestaurant_name Ilike ?','%'.trim($resFilter['restname']).'%');
			}
			if(isset($resFilter['restId'])){
				$select->where('res.resid = ?',$resFilter['restId']);
			}			
			if(isset($resFilter['resCountry']) && $resFilter['resCountry'] != ''){
				$select->where('res.resstate_id = ?',$resFilter['resCountry']);
			}			
			if(isset($resFilter['resState']) && $resFilter['resState'] != ''){
				$select->where('res.resregion_id = ?',$resFilter['resState']);
			}
			if(isset($resFilter['resCity']) && $resFilter['resCity'] != ''){
				$select->where('res.rescity_id = ?',$resFilter['resCity']);
			}
			if(isset($resFilter['bookStatus']) && $resFilter['bookStatus'] == 1){
				$select->where('bio.operations = ?','Notified');
			}
			if(isset($resFilter['bookStatus']) && $resFilter['bookStatus'] == 2){
				$select->where('bio.operations = ?','Phone Not Receiving');
			}
			if(isset($resFilter['bookStatus']) && $resFilter['bookStatus'] == 3){
				$select->where('bio.operations = ?','Wrong Number');
			}
			
			if(isset($resFilter['reservDateType']) && $resFilter['reservDateType'] == 2){
				if(isset($resFilter['StartDate'])&& isset($resFilter['EndDate'])){
					$select->where('bok.bokbooking_date >= ?',$resFilter['StartDate']);
					$select->where('bok.bokbooking_date <= ?',$resFilter['EndDate']);
				}else if(isset($resFilter['StartDate'])){
					$select->where('bok.bokbooking_date = ?',$resFilter['StartDate']);
				}else{
					$select->where('bok.bokbooking_date = ?',date('Y-m-d'));
				}
			}else{
				if(isset($resFilter['StartDate'])&& isset($resFilter['EndDate'])){
					$select->where('bok.bokbooking_made_on >= ?',$resFilter['StartDate']);
					$select->where('bok.bokbooking_made_on <= ?',$resFilter['EndDate']);
				}else if(isset($resFilter['StartDate'])){
					$select->where('bok.bokbooking_made_on = ?',$resFilter['StartDate']);
				}else{
					$select->where('bok.bokbooking_made_on = ?',date('Y-m-d'));
				}
			}
			
			if(isset($resFilter['rguName'])){
				$select->where($s.' ILIKE(?)','%'.$resFilter['rguName'].'%');
			}
			if(isset($resFilter['rguEmail'])){
				$select->where('bok.bokemail ILIKE(?)','%'.$resFilter['rguEmail'].'%');
			}
			if(isset($resFilter['rguPhone'])){
				$select->where('bok.bokphone  = ? ', $resFilter['rguPhone']);
			}
			$sorton = 'bok.bokid DESC';
			if(isset($resFilter['booksorton'])){
				$explode = explode(',',$resFilter['booksorton']);
				if(isset($explode[1])){
					$sorton = array($explode[0],$explode[1]);
				}else{
					$sorton = array($explode[0]);
				}
			}
			$select->order($sorton);
			
			
                        $resultset = "";
                        if($page!=null){
                        $resultSet = new Zend_Paginator(
				new Zend_Paginator_Adapter_DbTableSelect($select));
				$resultSet->setItemCountPerPage($limit);
				$resultSet->setCurrentPageNumber($page);
                        }
                        else
                        {
                            $resultSet = $table->fetchAll($select);
                            
                        }
                        
                        return $resultSet;		    	 		
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}	
	}    
	
/* Tablet App Functions */
	
	/* Save Tablet App reservations */
		
	public function SaveTabletAppReservations($bookings_array)
	{
		try
		{
			$db = Zend_Db_Table::getDefaultAdapter();
			$db->beginTransaction();			
			$table = $this->getDbTable();
			$result = array();
			$bookidArr = array();
			$restservice = new Application_Service_Firm();
			
			$bookIds = array();
			$webbookingTimes = array();
			$restid = "";
			foreach($bookings_array as $val)
			{
				if($val->bokid != null && $val->bokid != "" && $val->bokid != 0){
					$bookIds[] = $val->bokid;	
					$restid = $val->bokfk_restaurant;
				}
			}
			
			if($restid != ""){
				$timezone = "";
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$timezone = $mapper->GetRestaurantTimeZone($restid);
				date_default_timezone_set($timezone);
			}
			
			if(count($bookIds) > 0){
				$select = $table->select();			
				$select->from($table,array('bokid','bokupdateddatetime'))
					   ->where('bokid IN (?)',$bookIds);
	
				$rowSet = $table->fetchAll($select);
				
				foreach($rowSet as $dateandid)
				{
					$webbookingTimes[$dateandid->bokid] = $dateandid->bokupdateddatetime;
				}
			}
			
			foreach($bookings_array as $bookdetails)
			{
				$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
				$bookStatusArr = $bookStatusMapper->GetBookingStatusById(array($bookdetails->getbokbooking_status_id()));
				$bookStatus = $bookStatusArr[$bookdetails->getbokbooking_status_id()];
				
				if($bookdetails->bokid == 0)
				{
					$data = array(
						  'bokfk_restaurant' 	   		=> $bookdetails->getbokfk_restaurant(), 
						  'bokemail'		 	   		=> $bookdetails->getbokemail(),
						  'bokfirst_name' 		   		=> $bookdetails->getbokfirst_name(),
						  'boklast_name' 		   		=> $bookdetails->getboklast_name(),
						  'bokparty_size' 		   		=> $bookdetails->getbokparty_size(),
						  'bokphone' 			   		=> $bookdetails->getbokphone(),
				          'bokcountrycode'				=> $bookdetails->getbokcountry_code(),
						  'bokrestaurant_note'         	=> $bookdetails->getbokspecial_request(),
					      'bokbooking_date'		   		=> $bookdetails->getbokbooking_date(),
						  'bokbooking_timings' 	   		=> $bookdetails->getbokbooking_timings(),
						  'bokbooking_status_id'       	=> $bookdetails->getbokbooking_status_id(),
						  'bokbooked_status'			=> $bookdetails->getbokbooking_status(),
						  'bokbooking_made_on' 	   		=> $bookdetails->getbokbooking_made_on(),
						  'bokbooking_made_time'       	=> $bookdetails->getBookingMadeTime(),
						  'bokbooking_type_id'         	=> $bookdetails->getbokbooking_type_id(),
						  'bokreservation_mode_id' 	   	=> $bookdetails->getbokreservation_mode_id(),
						  'boknotification_type'       	=> $bookdetails->getNotificationType(),
						  'bokbooking_phrase'			=> $bookdetails->getbokbookingphrase(),
						  'bokquoted_time'				=> $bookdetails->getQuotedTime(),
						  'bokupdateddatetime'			=> $bookdetails->getbokupdateddatetime(),
					   );
					
					if($bookdetails->getbokfk_rest_sch_table()){
						$data['bokfk_rest_sch_table']    	=	$bookdetails->getbokfk_rest_sch_table();
					}
					   /* Save Contact Details */						  
				   
					   /* Create contact data */
						$guestid = "";  
						$restservice = new Application_Service_Firm();
						
						if($bookStatus->getCode() == 'WAL' && $bookdetails->getbokphone() != ""){
							$contact = array('restaurantid'  => $bookdetails->getbokfk_restaurant(),
						   					'waitfirstName' => $bookdetails->getbokfirst_name(),
						   					'waitlastName'	=> $bookdetails->getboklast_name(),
						   					'waitnumber'    => $bookdetails->getbokphone(),
						   					'countryCode'   => $bookdetails->getbokcountry_code(),
						   					'waitcontactInfo' => $bookdetails->getbokspecial_request(),
						   					);
						   					
							$guestid = $restservice->AddWaitingCustomerContact($contact);
						}else{
							if($bookdetails->getbokfirst_name() != '' && $bookdetails->getboklast_name() != ''){
								if($bookdetails->getbokemail() != '' || $bookdetails->getbokphone() != ''){
									$user = new FirmManagement_Model_FirmGroupUsers();
									$user->setRestaurantId($bookdetails->getbokfk_restaurant())
										->setGroupId(3)
										->setFirstName($bookdetails->getbokfirst_name())
										->setLastName($bookdetails->getboklast_name())
										->setEmail($bookdetails->getbokemail())
										->setPhone(str_replace("-","",$bookdetails->getbokphone()))
										->setcountry_code($bookdetails->getbokcountry_code())
										->setSplRequest('')
										->setStatus(TRUE);
									
									$mapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
									$guestid = $mapper->addUserContact($user);
								}
							}
						}
							   
						if($bookdetails->getbokuserid() != '' || $bookdetails->getbokuserid() != null){
						   		$data['bokuserid'] = $bookdetails->getbokuserid();
					    }
					    
	   					if($guestid){
							$data['bok_contactid'] = $guestid;
						}
								
					    $bookid = $table->insert($data);
					      		   
					    $bookidArr[] = array("boklokid" => $bookdetails->gettablet_book_id(), "bookid" => $bookid, "bokbooking_phrase" => $bookdetails->getbokbookingphrase(),"bok_contactid"=>$guestid);
					   
					    $bookdetails->setbokid($bookid);
					   
					    if($bookStatus->getCode() == 'WAL' && $bookdetails->getbokphone() != ""){
							$this->SendTabletWaitingSms($bookdetails);
						}else{
					    	
						}
						$result['web_bookid'] = $bookidArr;
					    $result["status"] = true;
				   }else{
				   		
				   		
				   		$data = array();
						if(array_key_exists($bookdetails->bokid,$webbookingTimes))
						{
				   			if($webbookingTimes[$bookdetails->bokid] != "" && $webbookingTimes[$bookdetails->bokid] != null){
								$webupadateddate = strtotime($webbookingTimes[$bookdetails->bokid]);
							}else{
								$webupadateddate = 0;
							}
							$nativeupadateddate = strtotime($bookdetails->bokupdateddatetime);
							if($nativeupadateddate > $webupadateddate)
							{
								
								if($bookStatus->getCode() == "QUOTE" || $bookStatus->getCode() == "READY" || $bookStatus->getCode() == "CAN")
								{
									$set = array('boksync_status' 		=> 'S',
											'bokupdated_date'			=> date('Y-m-d'),
											'bokupdateddatetime'		=> date("H:i",time()),
											'bokbooking_status_id'		=> $bookdetails->getbokbooking_status_id());		
									
									if($bookdetails->getQuotedTime() != "" && $bookdetails->getQuotedTime() != null)
									{
										$set['bokquoted_time'] = $bookdetails->getQuotedTime();
									}

									$where = $db->quoteInto('bokid = ?',$bookdetails->bokid);
									$table->update($set,$where);
									
									$mailmapper = new Application_Service_Communication();
									
									if($bookStatus->getCode() == "QUOTE")
									{
										$quoteMapper = new Reservation_Model_ReservationWaitingQuoteMapDataMapper();
										$quoteMapper->InsertQuotedTimesFromNativeApp($bookdetails->bokid,$bookdetails->getQuotedTime(),date('Y-m-d')." ".$bookdetails->bokupdateddatetime);
									}

									if($bookStatus->getCode() == "READY")
									{
										$smsObj = new Communication_Model_Sms();
										
										$resDataMapper = new FirmManagement_Model_FirmDataMapper();
										$restObj= new FirmManagement_Model_FirmById();
										$restObj->setRestaurantId($bookdetails->bokfk_restaurant);
										$resDetails = $resDataMapper->getRestaurantById($restObj);
										
										$smsObj->setMsgCode('WaitingReady');
										$Waitdata = array(
														'to'			=>	trim($bookdetails->bokphone),
														'RestName' 		=> $resDetails->getRestaurantname(),
														'UserName'		=> $bookdetails->bokfirst_name.' '.$bookdetails->boklast_name,
														'BookId'		=> $bookdetails->bokid
										);
										
										$smsObj->setData($Waitdata);
										$mailStatus = $mailmapper->SendSms($smsObj);
									}
								
									if($bookStatus->getCode() == "CAN")
									{
										$resDataMapper = new FirmManagement_Model_FirmDataMapper();
										$restObj= new FirmManagement_Model_FirmById();
										$restObj->setRestaurantId($bookdetails->bokfk_restaurant);
										$resDetails = $resDataMapper->getRestaurantById($restObj);
										
										$bookingservice = new Application_Service_Reservation();									
										$stateCity = $bookingservice->getRestaurantStateByResId($bookdetails->bokfk_restaurant);
										$stateId = $stateCity['state'];
										$cityId = $stateCity['city'];
										$regionId = $stateCity['region'];
												
										$userType = 'CUS';
										$adminService = new Application_Service_Administrator();
										$campProp = new Application_Model_GetCampaignForPost();
										$campProp->setAudType($userType)
										->setStateId($stateId)
										->setCityId($cityId)
										->setRegionId($regionId)
										->setIsAjaxCall(false);		
										$campDetails = array();
										if(!$resDetails->getrescampaignstatus() === false){
											$campDetails = $adminService->GetCampaignDetails($campProp);
										}
										
										$mailObj = new Communication_Model_Mail();
										
										$mailObj->setMsgCode('Cancel');
										$name = $bookdetails->bokfirst_name.' '.$bookdetails->boklast_name;
										
										$data = array('UserName' => $name,
													  'SenTo'    => $bookdetails->bokemail,
													  'phone'	 => $bookdetails->bokphone,
													  'RestName' => $resDetails->getRestaurantname(),
													  'ResDate'  => $bookdetails->bokbooking_date,
													  'Time'     => $bookdetails->bokbooking_timings,
													  'Size'     => $bookdetails->bokparty_size,
													  'Address'	 => $resDetails->getRestaddress(),
													  'Status'	 => $bookStatus->getCode(),
													  'State_Id' =>	$stateId,
													  'City_Id'	 =>	$cityId,
													  'resphone' => $resDetails->getRestphone(),
													  'UserType' =>	$userType,
													  'BookId'	 => $bookdetails->bokid,
													  'BookNotCan' => false,
										);
									
									if(count($campDetails)){
										$count = count($campDetails);
										if($count > 1){
											$campaign = $campDetails[rand(0,$count-1)];
										}else{
											$campaign = $campDetails[0];
										}
										$notfService = new Application_Service_Communication();
										$countUpdate = $notfService->UpdateCampaignEmailCount($campaign->getId(),1);
										$data['campaignName'] = trim($campaign->getSponsor());
										$data['campaignDesc'] =	trim($campaign->getCampDesc());
										$data['campaignImg'] =	trim($campaign->getCampImage());
										$data['campId']	= $campaign->getId();
									}
									
									$mailObj->setData($data);
									$mailStatus = $mailmapper->SendMail($mailObj);
										
								}		
							}else{
								
								$set = array('boksync_status' 		=> 'S',
										'bokupdated_date'			=> date('Y-m-d'),
										'bokupdateddatetime'		=> date("H:i",time()),
										'bokbooking_status_id'		=> $bookdetails->bokbooking_status_id,
										'bokparty_size'				=> $bookdetails->bokparty_size,
										'bokfirst_name'				=> $bookdetails->bokfirst_name,
										'boklast_name'				=> $bookdetails->boklast_name,
										'bokbooking_confirm_status'	=> $bookdetails->bokbooking_confirm_status,
										'bokresv_checkedin_status'	=> $bookdetails->bokresv_checkedin_status,	
										'bokresv_allarrived_status' => $bookdetails->bokresv_allarrived_status,
										'bokresv_partialarrived_status'=> $bookdetails->bokresv_partialarrived_status,
										'bokresv_runninglate_status' => $bookdetails->bokresv_runninglate_status
									);
									
								if($bookdetails->bokseat_start != '' && $bookdetails->bokseat_start != 'null')
								{
									$set['bokseat_start'] = $bookdetails->bokseat_start;
								}			
								$where = $db->quoteInto('bokid = ?',$bookdetails->bokid);
								$table->update($set,$where);
								
								$count = 0;
								$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
							    $bookTable  = $bookTableMapper->getDbTable();
								$bookTableSelect = $bookTable->select();
								
								$bookTableSelect->from($bookTable,array('COUNT(bktbid) as count'))
								                ->where('bktbfk_booking = ?',$bookdetails->bokid)
								                ->where('status = ?',true);
					            
								$countRes = $bookTable->fetchAll($bookTableSelect);
								foreach($countRes as $countrow)
								{
									$count = $countrow->count;
								}
								
								if($count == 0 && $bookdetails->booktable)
								{	
									$booktableDetails = $bookdetails->booktable;							
									$joinTableNo = "";
									
									if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
										if(count($booktableDetails) > 1)
										{
										    	$joinTableNo = $this->CheckJoinTableNo($bookdetails->bokid,$bookdetails->bokfk_restaurant);
										    	if($joinTableNo){
										    		$joinTableNo++;
										    	}else if($joinTableNo == 0 || $joinTableNo == null){
										    		$joinTableNo++;
										    	}
										}	
									}									
									$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
					   				$bookTable  = $bookTableMapper->getDbTable();
									foreach($booktableDetails as $boktablerow)
									{
										if(count($booktableDetails) > 1)
										{
											if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
									    		$data = array('bktbfk_booking'        => $bookdetails->bokid,
									    					  'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
									    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
									    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
									    					  'bktb_join_table_no'    => $joinTableNo,
									    					  'status'                => true);
									    		$id = $bookTable->insert($data);	 
											}else
											{
												$data = array('bktbfk_booking'        => $bookdetails->bokid,
									    					  'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
									    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
									    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
									    					  'status'                => true);
									    		$id = $bookTable->insert($data);	
											}
										}else{
											$data = array('bktbfk_booking'        => $bookdetails->bokid,
						    					  	'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
						    					  	'bktbtableid' 		  => $boktablerow->bktbtableid,
						    					  	'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,		    					  
					    					  		'status'                => true);
					    					$id = $bookTable->insert($data);
										}
									}
								}else{
									
									$desktopAppTables = array();
									$desktopAppTablesIds = array();
									/* CHECKS JOIN TABLES ARE SAME OR NOT START */ 
									if($count > 0 && $bookdetails->booktable)
									{
										$booktableDetails = $bookdetails->booktable;
										foreach($booktableDetails as $boktablerow)
										{
											$desktopAppTablesIds[] = $boktablerow->bktbtableid;
											$desktopAppTables[$boktablerow->bktbtableid] = $boktablerow->bktbtable_no_assigned;
										}
										
										$TableSelect = $bookTable->select();
										$TableSelect->from($bookTable,array('bktbtable_no_assigned','bktbtableid','bktb_join_table_no'))
									                ->where('bktbfk_booking = ?',$bookdetails->bokid)
									                ->where('status = ?',true);
						           		
										$webbooktableDetails = $bookTable->fetchAll($TableSelect);
										$movPartystatus = "";
										$joinTableNo = "";
										foreach($webbooktableDetails as $webbooktable)
										{
											if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
												$joinTableNo = $webbooktable->bktb_join_table_no;
											}
											if(!array_key_exists($webbooktable->bktbtableid, $desktopAppTables)){
												$movPartystatus = true;
											}
										}
										/* CHECKS JOIN TABLES ARE SAME OR NOT END */
										if($movPartystatus)
										{
											/* CHECKS TABLES ARE ALREDY ASSIGN START  */
											if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
												$select = $this->getDbTable()->select();
												$select->setIntegrityCheck(false);
												
												$bookStat = array('BOK','CRD','DES','PTS','WRD');
												$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
												$bookStatusRes = $bookStatusMapper->GetBookingStatusByCode($bookStat);
												$statusId = array();
												foreach($bookStatusRes as $key=>$value){
													$statusId[] = $value->getId();
												}
												
												$select->from(array('bok'=>'mt.booking'),array('COUNT(bokid) as count'))
													   ->join(array('bktb'=>'mt.booking_tables'),'bktb.bktbfk_booking  = bok.bokid',array())
													   ->where('bktb.bktbtableid IN (?)',$desktopAppTablesIds)
													   ->where('bok.bokbooking_date = ?',$bookdetails->bokbooking_date)
													   ->where('bok.bokid <> ?',$bookdetails->bokid)
													   ->where('bok.bokbooking_status_id IN (?)',$statusId)
													   ->where('bktb.status = ?',true);
													   
												$resultSetData = $this->getDbTable()->fetchAll($select);
												$tablecount = "";
												foreach($resultSetData as $resultSet){
													$tablecount = $resultSet->count;
												}
											}else
											{
												$tablecount = 0;
											}
											/* CHECKS TABLES ARE ALREDY ASSIGN END 
											 *  IF NOT INSERT TABLES */
											
											if($tablecount == 0)
											{	
												$set = array('status' => 0);
												$where = array('bktbfk_booking = ?' => $bookdetails->bokid);
												$bookTable->update($set,$where);
												
												foreach($booktableDetails as $boktablerow)
												{
													if(count($booktableDetails) > 1)
													{
														if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
												    		$data = array('bktbfk_booking'        => $bookdetails->bokid,
												    					  'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
												    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
												    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
												    					  'bktb_join_table_no'    => $joinTableNo,
												    					  'status'                => true);
												    		$id = $bookTable->insert($data);
														}else
														{
															$data = array('bktbfk_booking'        => $bookdetails->bokid,
												    					  'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
												    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
												    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
												    					  'status'                => true);
												    		$id = $bookTable->insert($data);
														}
													}else{
														$data = array('bktbfk_booking'        => $bookdetails->bokid,
									    					  	'bkt_dining_id'		  => $boktablerow->bkt_dining_id,
									    					  	'bktbtableid' 		  => $boktablerow->bktbtableid,
									    					  	'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,		    					  
								    					  		'status'                => true);
								    					$id = $bookTable->insert($data);
													}
												}
											}										
										}
									}else
									{
										if($bookStatus->getCode() == "RSD" || $bookStatus->getCode() == "OVB"){
											$set = array('status' => 0);
											$where = array('bktbfk_booking = ?' => $bookdetails->bokid);
											$bookTable->update($set,$where);
										}
									}
								}
							}				
						}
					}
					$result['web_bookid'] = $bookidArr;
					$result["status"] = false;
				}
			}			
			$db->commit();
			return $result;
		}catch (Exception $ex){
			$db->rollBack();
			$result["status"] = false;
			Uss_Logger_FileLogger::info($ex->getMessage());
			return $result;
			throw new Exception($ex->getMessage()) ;
		}	
	}
	
	public function SendTabletWaitingSms($waitobj)
	{
		try
		{
			if($waitobj->getbokphone() != ""  && $waitobj->getbokphone() != null){
								
					$name = $waitobj->getbokfirst_name().' '.$waitobj->getboklast_name();
					$custMsg = '';
					$custMsg = 'Hi '.$name.', we have put your reservation in waiting, please wait for '.$waitobj->getquotetimedesc().'. '.$waitobj->getrestarantname();
					$smsObj = new Communication_Model_Sms();
					$smsObj->setMsgCode('WaitingReserv');
					$data = array(
									'to'			=> trim($waitobj->getbokphone()),
									'countrycode'	=> $waitobj->getbokcountry_code(),
									'RestName' 		=> $waitobj->getrestarantname(),
									'UserName'		=> $name,
									'Quote'			=> $waitobj->getquotetimedesc(),
									'BookId'		=> $waitobj->getbokid()
					);
					
					$smsObj->setData($data);
					
					$mailmapper = new Application_Service_Communication();
					$mailStatus = $mailmapper->SendSms($smsObj);
				}
		}catch(Exception $ex)
		{
			Uss_Logger_FileLogger::info($ex->getMessage());
			return false;
		}
	}
	
	public function getBookingDetailsBybookingidAndrestid($bookingid,$restaurantid)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokfk_restaurant','bokemail','bokfirst_name','boklast_name','bokparty_size','bokphone','bokbooking_date','bokbooking_timings'))
					->join(array('bst'=>'mt.booking_status_bd'),'bst.id = bok.bokbooking_status_id',array('code as stat','description'))
					->where('bok.bokfk_restaurant = ?',$restaurantid)
					->where('bok.bokid = ?',$bookingid);

			$result = $table->fetchRow($select);
			$Obj = array();
			if($result){			
				$Obj = array('bookingid'=>	$result->bokid,
						'firstName'		=>	$result->bokfirst_name,
					  	'lastName'		=>	$result->boklast_name,
					  	'number'		=>	$result->bokphone,
						'email'			=>	$result->bokemail,
						'bookingtime' 	=> 	date("h:i A",strtotime($result->bokbooking_timings)),
						'partysize'		=> 	$result->bokparty_size,
						'status'		=> 	$result->description);
				if($result->bokbooking_date){
					$date = explode('-',$result->bokbooking_date);
					$Obj['bookingdate'] = date("d M Y",mktime(0,0,0,$date[1],$date[2],$date[0]));	
				}
			}
			return $Obj;

		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetReservationReportByResid($resid,$offset,$request)
	{
		try{
			$limit = 10;
			$statusId = array();			
			$table = $this->getDbTable();			
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokspecial_request','bokbooking_status_id','bokreadstatus'))
				   ->where('bok.bokfk_restaurant = ?',$resid)
				   ->join(array('res'=>'mt.restaurant'),'res.resid = bok.bokfk_restaurant',array('res_companyid'))
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id',array('code as resvmode','description as source'));
			
			if($request->reportStartDate && $request->reportEndDate){
				$select->where('bok.bokbooking_date >= ?',$request->reportStartDate);
				$select->where('bok.bokbooking_date <= ?',$request->reportEndDate);
			}else if($request->reportStartDate){
				$select->where('bok.bokbooking_date = ?',$request->reportStartDate);
			}else{
				$select->where('bok.bokbooking_date = ?', date('Y-m-d'));
			}
			$select->order(array('bok.bokid DESC'));
			$pdfResult = $table->fetchAll($select);
			$resultSet = new Zend_Paginator(
				new Zend_Paginator_Adapter_DbTableSelect($select)
			);
			$resultSet->setItemCountPerPage($limit);
			$resultSet->setCurrentPageNumber($offset);
			$result = array();
			if(count($resultSet) > 0){
				foreach($resultSet as $row){
					$bookTime = date("h:i A",strtotime($row->bokbooking_timings));
					if($row->bokbooking_date){
						$tSel = explode('-',$row->bokbooking_date);
						if($tSel[0] > 12){
							$bookDate = date("d M Y",mktime(0,0,0,$tSel[1],$tSel[2],$tSel[0]));
						}else {
							$bookDate = date("d M Y",mktime(0,0,0,$tSel[0],$tSel[1],$tSel[2]));
						}
			        }
					$result[] = array('bookid'			   => $row->bokid,
									  'bokbooking_timings' => $bookTime,
									  'bokbooking_date'	   => $bookDate,
									  'bokfirst_name'	   => $row->bokfirst_name." ".$row->boklast_name,
									  'boklast_name'	   => $row->boklast_name,
									  'bokparty_size'	   => $row->bokparty_size,
									  'bokstatuscode'	   => $row->bokstatuscode,
									  'bokstatusdesc'	   => $row->bokstatusdesc,
									  'bokemail'		   => $row->bokemail,
									  'bokphone'		   => $row->bokphone,
									  'bokspecial_request' => $row->bokspecial_request,
									  'bokreadstatus'	   => $row->bokreadstatus,
									  'boksource'		   => $row->source,
									  'resvmode'		   => $row->resvmode,
									  'resCompanyId'	   => $row->res_companyid
									  );	
				}
			}
			$finalResult = array('result'=>$result,'pdfResult'=> $pdfResult);
			return $finalResult;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function ValidateBookingTableAvailability($booingkid,$statusId)
	{
		try{
			$table = $this->getDbTable();			
			$select = $table->select();
			$select->setIntegrityCheck(false);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokbooking_date','bokparty_size','bokbooking_timings','bokfk_restaurant'))
				   ->where('bok.bokid = ?',$booingkid);
			$bokResult = $this->getDbTable()->fetchRow($select);
			$startTime = date('H:i:s',strtotime($bokResult->bokbooking_timings)-5400); 
			$endTime = date('H:i:s',strtotime($bokResult->bokbooking_timings)+5400);
			$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
		    $bookTable  = $bookTableMapper->getDbTable();
		    $select = $table->select();
		    $select->setIntegrityCheck(false);
		    $select->from(array('book'=>'mt.booking'),array('bokid','bokbooking_timings'))
		    		->join(array('boktab'=>'mt.booking_tables'),'book.bokid = boktab.bktbfk_booking',array('bktbtableid','bkt_dining_id'))
		    		->where("book.bokbooking_timings < '$startTime' or book.bokbooking_timings > '$endTime'")
		    		->where('book.bokfk_restaurant = ?',$bokResult->bokfk_restaurant)
		    		->where('book.bokbooking_date = ?',$bokResult->bokbooking_date)
		    		->where('book.bokbooking_status_id in (?)',$statusId)
		    		->where('boktab.status = ?',true);
		    $result = $this->getDbTable()->fetchAll($select);	
		    $resultArr = array();
		    foreach($result as $row){
		    	$resultArr['tableid_'.$row->bktbtableid] = array('bokid'=>$row->bokid,'boktime'=>$row->bokbooking_timings,'table'=>$row->bktbtableid,'dining'=>$row->bkt_dining_id);
		    }
		    return $resultArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function GetBookingtableDataByBookingIdsForTablet($bokingIds)
	{
		try{
			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$table = $bookTableMapper->getDbTable();
			$select = $table->select();
			
			$select->from($table,array('bktbid','bktbfk_booking','bktbtableid','bktbtable_no_assigned','status','bktb_join_table_no','bkt_dining_id'))
				   ->where('bktbfk_booking IN(?)',$bokingIds);
							
			$resultset = $table->fetchAll($select);
			$boktablesArr = array();
			foreach($resultset as $key=>$value){
				$subArr = array();
				foreach($value as  $key1=>$value1){
					$subArr[$key1]= $value1;
				}
				$boktablesArr[] = $subArr;
			}
			return $boktablesArr;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function SynchronizationOfReservationsByRestaurantidforTablet($restaurantid, $date)
	{
		try{
			$table = $this->getDbTable();
			$select = $table->select();
			// Pratik Code
      //$fromdate	= date('Y-m-d',strtotime("-3 Months"));
      //$todate	= date('Y-m-d',strtotime("+1 Months"));
      //echo $fromdate.' '.$todate; exit;
			$select->from(array('bok'=>'mt.booking'),array('bokid',
														   'bokfk_restaurant',
														   'bokuserid','bokemail',
														   'bokfirst_name',
														   'boklast_name',
														   'bokparty_size',
														   'bokfk_rest_sch_table',
														   'bokphone',
														   'bokconfirmation_number',
														   'bokpayment_type',
														   'bokspecial_request',
														   'bokbooking_date',
														   'bokbooking_timings',
														   'bokbooking_status_id',
														   'bokbooking_made_on',
														   'bokbooking_type_id',
														   'bokcreated_date',
														   'bokupdated_date',
														   'bokcreatedby_userid',
														   'bokcreateddatetime',
														   'bokupdatedby_userid',
														   'bokupdateddatetime',
														   'bokcontact_information',
														   'bokreservation_mode_id',
														   'bokrestaurant_note',
														   'boknotification_type',
														   'bokbooking_made_time',
														   'bokbooked_status',
														   'bokquoted_time',
														   'bokreadstatus',
														   'bokresv_confirm_status',
														   'bokbooking_confirm_status',
														   'bokresv_checkedin_status',
														   'bokresv_partialarrived_status',
														   'bokresv_allarrived_status',
														   'bokbooking_user_initials',
														   'bokbooking_block_status',
														   'bokbooking_block_desc',
														   'bokbooking_block_amount',
														   'bokseat_start',
														   'bokbooking_phrase',
														   'bok_restsch_setting_id',
														   'bokresv_runninglate_status',
														   'bokseat_end',
														   'bokcountrycode',
														   'bok_contactid',
														   'bokfeedback_status',
														   'bokresv_partialarrived_status',
														   'bokresv_allarrived_status',
														   'bokcompany_id',
														   'bok_serverid'))
				   ->where('bok.bokfk_restaurant = ?',$restaurantid);
       if($date == ''){
         $cdate = date('Y-m-d');
				 $select->where('bok.bokbooking_date >= ?',$cdate);
       }else{
         $select->where('bok.bokbooking_date = ?',$date);
       }
           //->where('bok.bokbooking_date <= ?',$todate)
				   $select->where('bok.bokbooking_type_id <> ?',4);
			//$sql = $select->__toString();
      //echo "$sql\n"; exit;
			$resultset = $this->getDbTable()->fetchAll($select);
			$bookingArr= array();
			$bokidsArr = array();
			$finalArr = array();
			foreach($resultset as $key=>$value){
				$subArr = array();
				$bokidsArr[] = $value->bokid;
				foreach($value as  $key1=>$value1){
					if($key1 == 'bokuserid' || $key1 == 'bokcreatedby_userid' || $key1 == 'bokupdatedby_userid'){
						$subArr[$key1]= null;
					}else{
						$subArr[$key1]= $value1;
					}
				}				
				
				$bookTableMapper = new Reservation_Model_ReservationTableMapper();
				$table = $bookTableMapper->getDbTable();
				$select = $table->select();
				
				$select->from($table,array('bktbid','bktbfk_booking','bktbtableid','bktbtable_no_assigned','status','bktb_join_table_no','bkt_dining_id'))
					   ->where('bktbfk_booking = ?',$value->bokid);
								
				$resultset = $table->fetchAll($select);
				$boktablesArr = array();
				foreach($resultset as $key=>$value){
					$subArray = array();
					foreach($value as  $key1=>$value1){
						$subArray[$key1]= $value1;
					}
					//$subArray['table_hash_identifier'] = md5(json_encode($subArray));
					$boktablesArr[] = $subArray;
				}
				$subArr['bookingtable'] = $boktablesArr;
				//$subArr['booking_hash_identifier'] = md5(json_encode($subArr));
				$bookingArr[] = $subArr;
			}
			$finalArr['bokidsArr'] = $bokidsArr;
			$finalArr['bookingsArr'] = $bookingArr;
			return $finalArr;			
			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function getpastandfuturereservationsforTablet($request)
	{
		try{
			$resService = new Application_Service_Firm();
			$timeZone = $resService->GetRestaurantTimeZone($request->resid);
			date_default_timezone_set($timeZone);
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokspecial_request','bokbooking_status_id','bokreadstatus'))
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id','code as resvmode');
			if($request->type == 'past'){
				$select->where('bok.bokbooking_date < ?',date('Y-m-d'));
			}else{
				$select->where('bok.bokbooking_date >= ?',date('Y-m-d'));
			}
			$select->where('bok.bok_contactid = ?',$request->customerid);
		   	$select->where('bok.bokfk_restaurant = ?',$request->resid);	   
			$select->order(array('bokid DESC'));			
			$rowSet = $table->fetchAll($select);			
			$result = array();
			foreach($rowSet as $row){
				$result[] = array('Id'			   	=> $row->bokid,
							  'Time' 				=> date("h:i A",strtotime($row->bokbooking_timings)),
							  'Date'	   			=> date('d M Y',strtotime($row->bokbooking_date)),
							  'Name'	   			=> $row->bokfirst_name." ".$row->boklast_name,
							  'Size'	   			=> $row->bokparty_size,
							  'Status'	   			=> $row->bokstatusdesc,
							  );								
			}
			return $result; 			
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function MigratingChangeStatusReservationsToWebFromIpad($bookDetails)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$table  = $this->getDbTable();
			
			$bookIds = array();
			$webbookingTimes = array();
			$restid = "";
			foreach($bookDetails as $val)
			{
				if($val->bokwebbookingid != null && $val->bokwebbookingid != ""){
					$bookIds[] = $val->bokwebbookingid;	
					$restid = $val->bokfk_restaurant;
				}
			}
			
			if($restid != ""){
				$timezone = "";
				$mapper = new FirmManagement_Model_FirmDataMapper();
				$timezone = $mapper->GetRestaurantTimeZone($restid);
				date_default_timezone_set($timezone);
			}
			if(count($bookIds) > 0){
				$select = $table->select();			
				$select->from($table,array('bokid','bokupdateddatetime'))
					   ->where('bokid IN (?)',$bookIds);
	
				$rowSet = $table->fetchAll($select);
				
				foreach($rowSet as $dateandid)
				{
					$webbookingTimes[$dateandid->bokid] = $dateandid->bokupdateddatetime;
				}
			}
			$resultArray = array();
			foreach($bookDetails as $row){
				$data = array();
				if(array_key_exists($row->bokwebbookingid,$webbookingTimes))
				{
					if($webbookingTimes[$row->bokwebbookingid] != "" && $webbookingTimes[$row->bokwebbookingid] != null){
						$webupadateddate = strtotime($webbookingTimes[$row->bokwebbookingid]);
					}else{
						$webupadateddate = 0;
					}
					$nativeupadateddate = strtotime($row->bokupdateddatetime);
					$currenttime = date("H:i:s",time());
					if($nativeupadateddate > $webupadateddate || $nativeupadateddate > strtotime($currenttime))
					{	
						$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
						$bookStatusArr = $bookStatusMapper->GetBookingStatusById(array($row->bokbooking_status_id));
						$bookStatus = $bookStatusArr[$row->bokbooking_status_id];		
						if($bookStatus->getCode() == "QUOTE" || $bookStatus->getCode() == "READY" || $bookStatus->getCode() == "CAN")
						{
							$set = array('boksync_status' 		=> 'S',
									'bokupdated_date'			=> date('Y-m-d'),
									'bokbooking_status_id'		=> $row->bokbooking_status_id);		
							
							if($row->bokquoted_time != "")
							{
								$set['bokquoted_time'] = $row->bokquoted_time;
							}

							if($nativeupadateddate > strtotime($currenttime)){
								$set['bokupdateddatetime'] = $currenttime;
							}else{
								$set['bokupdateddatetime'] = $row->bokupdateddatetime;
							}
							
							$where = $db->quoteInto('bokid = ?',$row->bokwebbookingid);
							$table->update($set,$where);
							
							$mailmapper = new Application_Service_Communication();
							
							if($bookStatus->getCode() == "QUOTE")
							{
								$boknewquotedtimeinfo = json_decode($row->boknewquotedtimeinfo);
								foreach($boknewquotedtimeinfo as $boknewquotedtimerow)
								{
									$splitdatetime = split (" ", $boknewquotedtimerow->updateddatetime);
									$updateddatetime = $splitdatetime[0].' '.$splitdatetime[1];
									$quoteMapper = new Reservation_Model_ReservationWaitingQuoteMapDataMapper();
									$quoteMapper->InsertQuotedTimesFromNativeApp($row->bokwebbookingid,$boknewquotedtimerow->quotedtimeid,$updateddatetime);
								}
							}
							
							if($bookStatus->getCode() == "READY")
							{
								$smsObj = new Communication_Model_Sms();
								
								$resDataMapper = new FirmManagement_Model_FirmDataMapper();
								$restObj= new FirmManagement_Model_FirmById();
								$restObj->setRestaurantId($row->bokfk_restaurant);
								$resDetails = $resDataMapper->getRestaurantById($restObj);
								
								$smsObj->setMsgCode('WaitingReady');
								$Waitdata = array(
												'to'			=>	trim($row->bokphone),
												'RestName' 		=> $resDetails->getRestaurantname(),
												'UserName'		=> $row->bokfirst_name.' '.$row->boklast_name,
												'BookId'		=> $row->bokwebbookingid
								);
								
								$smsObj->setData($Waitdata);
								$mailStatus = $mailmapper->SendSms($smsObj);
							}
								
							if($bookStatus->getCode() == "CAN")
							{
								$resDataMapper = new FirmManagement_Model_FirmDataMapper();
								$restObj= new FirmManagement_Model_FirmById();
								$restObj->setRestaurantId($row->bokfk_restaurant);
								$resDetails = $resDataMapper->getRestaurantById($restObj);
								
								$bookingservice = new Application_Service_Reservation();									
								$stateCity = $bookingservice->getRestaurantStateByResId($row->bokfk_restaurant);
								$stateId = $stateCity['state'];
								$cityId = $stateCity['city'];
								$regionId = $stateCity['region'];
										
								$userType = 'CUS';
								$adminService = new Application_Service_Administrator();
								$campProp = new Application_Model_GetCampaignForPost();
								$campProp->setAudType($userType)
								->setStateId($stateId)
								->setCityId($cityId)
								->setRegionId($regionId)
								->setIsAjaxCall(false);		
								$campDetails = array();
								if(!$resDetails->getrescampaignstatus() === false){
									$campDetails = $adminService->GetCampaignDetails($campProp);
								}
								
								$mailObj = new Communication_Model_Mail();
								
								$mailObj->setMsgCode('Cancel');
								$name = $row->bokfirst_name.' '.$row->boklast_name;
								
								$data = array('UserName' => $name,
											  'SenTo'    => $row->bokemail,
											  'phone'	 => $row->bokphone,
											  'RestName' => $resDetails->getRestaurantname(),
											  'ResDate'  => $row->bokbooking_date,
											  'Time'     => $row->bokbooking_timings,
											  'Size'     => $row->bokparty_size,
											  'Address'	 => $resDetails->getRestaddress(),
											  'Status'	 => $bookStatus->getCode(),
											  'State_Id' =>	$stateId,
											  'City_Id'	 =>	$cityId,
											  'resphone' => $resDetails->getRestphone(),
											  'UserType' =>	$userType,
											  'BookId'	 => $row->bokwebbookingid,
											  'BookNotCan' => false,
								
								);
								
								if(count($campDetails)){
									$count = count($campDetails);
									if($count > 1){
										$campaign = $campDetails[rand(0,$count-1)];
									}else{
										$campaign = $campDetails[0];
									}
									$notfService = new Application_Service_Communication();
									$countUpdate = $notfService->UpdateCampaignEmailCount($campaign->getId(),1);
									$data['campaignName'] = trim($campaign->getSponsor());
									$data['campaignDesc'] =	trim($campaign->getCampDesc());
									$data['campaignImg'] =	trim($campaign->getCampImage());
									$data['campId']	= $campaign->getId();
								}
								
								$mailObj->setData($data);
								$mailStatus = $mailmapper->SendMail($mailObj);
									
								}		
							}else{
								$set = array('boksync_status' 		=> 'S',
										'bokupdated_date'			=> date('Y-m-d'),
										'bokbooking_status_id'		=> $row->bokbooking_status_id,
										'bokparty_size'				=> $row->bokparty_size,
										'bokfirst_name'				=> $row->bokfirst_name,
										'boklast_name'				=> $row->boklast_name,
										'bokemail'		   			=> $row->bokemail,
										'bokphone'		  			=> $row->bokphone,
										'bokrestaurant_note' 		=> $row->bokrestaurant_note
									);	

								if($nativeupadateddate > strtotime($currenttime)){
									$set['bokupdateddatetime'] = $currenttime;
								}else{
									$set['bokupdateddatetime'] = $row->bokupdateddatetime;
								}

								if($row->bokresv_checkedin_status != null & $row->bokresv_checkedin_status != "")
								{
									$set['bokresv_checkedin_status']	= $row->bokresv_checkedin_status;
								}
									
								if($row->bokresv_runninglate_status != null & $row->bokresv_runninglate_status != "")
								{
									$set['bokresv_runninglate_status']	= $row->bokresv_runninglate_status;
								}
								
								if($row->bokresv_partialarrived_status != null & $row->bokresv_partialarrived_status != "")
								{
									$set['bokresv_partialarrived_status']	= $row->bokresv_partialarrived_status;
								}
								
								if($row->bokresv_allarrived_status != null & $row->bokresv_allarrived_status != "")
								{
									$set['bokresv_allarrived_status']	= $row->bokresv_allarrived_status;
								}	
									
								if($row->bokbooking_confirm_status != null & $row->bokbooking_confirm_status != "")
								{
									$set['bokbooking_confirm_status']	= $row->bokbooking_confirm_status;
								}
										
								$where = $db->quoteInto('bokid = ?',$row->bokwebbookingid);
								$table->update($set,$where);
									
								$count = 0;
								$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
							    $bookTable  = $bookTableMapper->getDbTable();
								$bookTableSelect = $bookTable->select();
								
								$bookTableSelect->from($bookTable,array('COUNT(bktbid) as count'))
								                ->where('bktbfk_booking = ?',$row->bokwebbookingid)
								                ->where('status = ?',true);
								$countRes = $bookTable->fetchAll($bookTableSelect);
								
								foreach($countRes as $countrow)
								{
									$count = $countrow->count;
								}
								$booktableDetails = $row->booktable;
								if($count == 0 && $booktableDetails)
								{								
									$joinTableNo = "";
									if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
										if(count($booktableDetails) > 1)
										{
										    	$joinTableNo = $this->CheckJoinTableNo($row->bokwebbookingid,$row->bokfk_restaurant);
										    	if($joinTableNo){
										    		$joinTableNo++;
										    	}else if($joinTableNo == 0 || $joinTableNo == null){
										    		$joinTableNo++;
										    	}
										}	
									}									
									$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
					   				$bookTable  = $bookTableMapper->getDbTable();
									foreach($booktableDetails as $boktablerow)
									{
										if(count($booktableDetails) > 1)
										{
											if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
									    		$data = array('bktbfk_booking'        => $row->bokwebbookingid,
									    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
									    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
									    					  'bktb_join_table_no'    => $joinTableNo,
									    					  'status'                => true);
									    		if($boktablerow->bkt_dining_id != null & $boktablerow->bkt_dining_id != ""){
									    			$data['bkt_dining_id']	= $boktablerow->bkt_dining_id;
									    		}
									    		
									    		$id = $bookTable->insert($data);	 
											}else
											{
												$data = array('bktbfk_booking'        => $row->bokwebbookingid,
									    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
									    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
									    					  'status'                => true);
												if($boktablerow->bkt_dining_id != null & $boktablerow->bkt_dining_id != ""){
									    			$data['bkt_dining_id']	= $boktablerow->bkt_dining_id;
									    		}
									    		$id = $bookTable->insert($data);	
											}
										}else{
											$data = array('bktbfk_booking'  => $row->bokwebbookingid,
						    					  	'bktbtableid' 		  	=> $boktablerow->bktbtableid,
						    					  	'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,		    					  
					    					  		'status'                => true);
											if($boktablerow->bkt_dining_id != null & $boktablerow->bkt_dining_id != ""){
									    		$data['bkt_dining_id']	= $boktablerow->bkt_dining_id;
									    	}
					    					$id = $bookTable->insert($data);
										}
									}
								}else
								{
									$desktopAppTables = array();
									$desktopAppTablesIds = array();
									/* CHECKS JOIN TABLES ARE SAME OR NOT START */ 
									if($count > 0 && $booktableDetails)
									{
										foreach($booktableDetails as $boktablerow)
										{
											$desktopAppTablesIds[] = $boktablerow->bktbtableid;
											$desktopAppTables[$boktablerow->bktbtableid] = $boktablerow->bktbtable_no_assigned;
										}
										
										$TableSelect = $bookTable->select();
										$TableSelect->from($bookTable,array('bktbtable_no_assigned','bktbtableid','bktb_join_table_no'))
									                ->where('bktbfk_booking = ?',$row->bokwebbookingid)
									                ->where('status = ?',true);
						           		
										$webbooktableDetails = $bookTable->fetchAll($TableSelect);
										$movPartystatus = "";
										$joinTableNo = "";
										foreach($webbooktableDetails as $webbooktable)
										{
											if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
												$joinTableNo = $webbooktable->bktb_join_table_no;
											}
											if(!array_key_exists($webbooktable->bktbtableid, $desktopAppTables)){
												$movPartystatus = true;
											}
										}
										
										/* CHECKS JOIN TABLES ARE SAME OR NOT END */
										if($movPartystatus)
										{
											/* CHECKS TABLES ARE ALREDY ASSIGN START  */
											if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
												$select = $this->getDbTable()->select();
												$select->setIntegrityCheck(false);
												
												$newbookStatus = array('BOK','CRD','DES','PTS','WRD');
												$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
												$bookStatusRes = $bookStatusMapper->GetBookingStatusByCode($newbookStatus);
												$statusId = array();
												foreach($bookStatusRes as $key=>$value){
													$statusId[] = $value->getId();
												}
												
												$select->from(array('bok'=>'mt.booking'),array('COUNT(bokid) as count'))
													   ->join(array('bktb'=>'mt.booking_tables'),'bktb.bktbfk_booking  = bok.bokid',array())
													   ->where('bktb.bktbtableid IN (?)',$desktopAppTablesIds)
													   ->where('bok.bokbooking_date = ?',$row->bokbooking_date)
													   ->where('bok.bokid <> ?',$row->bokwebbookingid)
													   ->where('bok.bokbooking_status_id IN (?)',$statusId)
													   ->where('bktb.status = ?',true);
													   
												$resultSetData = $this->getDbTable()->fetchAll($select);
												$tablecount = "";
												foreach($resultSetData as $resultSet){
													$tablecount = $resultSet->count;
												}
											}else
											{
												$tablecount = 0;
											}
											/* CHECKS TABLES ARE ALREDY ASSIGN END 
											 *  IF NOT INSERT TABLES */
											
											
											if($tablecount == 0)
											{	
												$set = array('status' => 0);
												$where = array('bktbfk_booking = ?' => $row->bokwebbookingid);
												$bookTable->update($set,$where);
												
												foreach($booktableDetails as $boktablerow)
												{
													if(count($booktableDetails) > 1)
													{
														if($bookStatus->getCode() != "RSD" && $bookStatus->getCode() != "OVB"){
												    		$data = array('bktbfk_booking'        => $row->bokwebbookingid,
												    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
												    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
												    					  'bktb_join_table_no'    => $joinTableNo,
												    					  'status'                => true);
															if($boktablerow->bkt_dining_id != null & $boktablerow->bkt_dining_id != ""){
									    						$data['bkt_dining_id']	= $boktablerow->bkt_dining_id;
									    					}
												    		$id = $bookTable->insert($data);	 
														}else
														{
															$data = array('bktbfk_booking'        => $row->bokwebbookingid,
												    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
												    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
												    					  'status'                => true);
															if($boktablerow->bkt_dining_id != null & $boktablerow->bkt_dining_id != ""){
												    			$data['bkt_dining_id']	= $boktablerow->bkt_dining_id;
												    		}
												    		$id = $bookTable->insert($data);
														}
													}else{
														$data = array('bktbfk_booking'        => $row->bokwebbookingid,
									    					  	'bktbtableid' 		  => $boktablerow->bktbtableid,
									    					  	'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,		    					  
								    					  		'status'                => true);
														if($boktablerow->bkt_dining_id != null & $boktablerow->bkt_dining_id != ""){
											    			$data['bkt_dining_id']	= $boktablerow->bkt_dining_id;
											    		}
								    					$id = $bookTable->insert($data);
													}
												}
											}										
										}
									}else
									{
										if($bookStatus->getCode() == "RSD" || $bookStatus->getCode() == "OVB"){
											$set = array('status' => 0);
											$where = array('bktbfk_booking = ?' => $row->bokwebbookingid);
											$bookTable->update($set,$where);
										}
									}
								}
							}	
							$resultArray[] = array('bokid'=>$row->bokid,'bokwebbookingid'=>$row->bokwebbookingid,'boksync_status' => 'S');				
						}
				}
			}			
			return $resultArray;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
	
	public function MigrateIosBookings($bookDetails)
	{
		try{
			$db = Zend_Db_Table::getDefaultAdapter();
			$resultArray = array();
			$bookidArr = array();
			$bookDetailsArr = array();
			foreach($bookDetails as $row){
				try
				{
				$db->beginTransaction();
				$bookStatusMapper = new Application_Model_ReservationStatusDataMapper();
				$bookStatusArr = $bookStatusMapper->GetBookingStatusById(array($row->bokbooking_status_id));
				$bookStatus = $bookStatusArr[$row->bokbooking_status_id];
				
				$data = array();
				$result = '';
				$bookPhrase = uniqid ();
				if($row->bokid == 0)
				{
						$data = array(
						  	'bokfk_restaurant'	   			=> 	$row->bokfk_restaurant, 
							'bokemail'		 	   			=>	$row->bokemail,
							'bokfirst_name' 		   		=>	$row->bokfirst_name,
							'boklast_name' 		   			=>	$row->boklast_name,
							'bokparty_size' 		   		=>	$row->bokparty_size,
							'bokphone' 			   			=>	$row->bokphone,
						    'bokcountrycode'				=>	$row->bokcountry_code,
							'bokspecial_request'     		=>	$row->bokspecial_request,
							'bokbooking_date'		   		=>	$row->bokbooking_date,
							'bokbooking_timings' 	   		=>	$row->bokbooking_timings,
							'bokbooking_status_id'   		=>	$row->bokbooking_status_id,
							'bokbooked_status'	   			=>	$row->bokbooked_status,
							'bokbooking_made_on' 	   		=>	$row->bokbooking_made_on,
							'bokbooking_type_id'      		=>	$row->bokbooking_type_id,
							'bokreservation_mode_id' 		=>	$row->bokreservation_mode_id,
							'boknotification_type'    		=>	$row->boknotification_type,
							'bokcreated_date'				=>	$row->bokcreated_date,
							'bokbooking_migration_status'	=>	'T',
							'bokbooking_phrase'				=> 	$bookPhrase
						);
						if($row->bokupdateddatetime){
							$data['bokupdateddatetime']   =	$row->bokupdateddatetime;
						}
	                    if($row->bokupdated_date){
							$data['bokupdated_date']   =	$row->bokupdated_date;
						}
						if($row->bokfk_rest_sch_table){
							$data['bokfk_rest_sch_table']   =	$row->bokfk_rest_sch_table;
						}
						if($row->bokuserid){
							$data['bokuserid']   =	$row->bokuserid;
						}
						if($row->bokbooking_user_initials){
							$data['bokbooking_user_initials']	=	$row->bokbooking_user_initials;
						}
						if($row->bokquoted_time)
						{
							$data['bokquoted_time']	= $row->bokquoted_time;
						}
						if($row->bokseat_start)
						{
							$data['bokseat_start'] = $row->bokseat_start;
						}
						
						if($row->bokresv_runninglate_status != null & $row->bokresv_runninglate_status != "")
						{
							$data['bokresv_runninglate_status']	= $row->bokresv_runninglate_status;
						}
						
						if($row->bokresv_partialarrived_status != null & $row->bokresv_partialarrived_status != "")
						{
							$data['bokresv_partialarrived_status']	= $row->bokresv_partialarrived_status;
						}
						
						if($row->bokresv_allarrived_status != null & $row->bokresv_allarrived_status != "")
						{
							$data['bokresv_allarrived_status']	= $row->bokresv_allarrived_status;
						}
						
						if($row->bok_restsch_setting_id != null & $row->bok_restsch_setting_id != ""){
							$data['bok_restsch_setting_id']	=	$row->bok_restsch_setting_id;
						}
						
						$schIdRow = "";
						if($row->bok_schedule_id != null & $row->bok_schedule_id != ""){
							$resSech = new FirmManagement_Model_FirmScheduleDataMapper();
							$schDetails = $resSech->ReterieveSchedulesForBlock($row->bok_schedule_id,$row->bokparty_size);
									
							$restSchTblMapperObj = new FirmManagement_Model_FirmScheduleTableDataMapper();
							$restSchTbl = $restSchTblMapperObj->getDbTable();
							$restSchTblSelect = $restSchTbl->select();
			
							$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule'))
											 ->where('rstid = ?',$row->bok_schedule_id);
											 
						    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);				
							
						    $table = $this->getDbTable();
							$select = $table->select();
							$select->setIntegrityCheck(false);
							$select->from(array('btc'=>'mt.booking_time_count'),array('count(btcid) as countbtc','btcid','btcbooking_count','btc.boktablesize'))
							->where('btc.btcfkres_id = ?',$row->bokfk_restaurant)
							->where('btc.btcbooking_timings = ?',$schDetails['schtime'])
							->where('btc.btcbooking_date = ?',$row->bokbooking_date)
							->where('btc.boktablesize = ?',$schDetails['tablesize'])
							->where('btc.btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
							$select->group(array('btcid','btcbooking_count','btc.boktablesize'));
							$bookingCountId = 0;
							$bookingId= 0;
							$bookingCount = 0;
							$rowtable = $table->fetchRow($select);
							
							$bookingCountId = $rowtable['countbtc'];
							$bookingId = $rowtable['btcid'];
							$bookingCount = (int)$rowtable['btcbooking_count'];
							$btcmapper = new Reservation_Model_ReservationCountDataMapper();
							if($row->bokbooking_status_id != 11){
								if($bookingCountId != 0){
									$bookingCount++;
									$set = array('btcbooking_count' => $bookingCount);
									$where = array('btcid = ?'=>$bookingId,
												   'btcfk_restaurant_schedule = ?'=>$schIdRow->rstfk_restaurant_schedule);
									//$where = $db->quoteInto('btcid = ?',$bookingId);
				
									$btcmapper->getDbTable()->update($set,$where);
				
								}else{
									$dataset = array(
										'btcbooking_count'    => 1,
										'btcbooking_timings'  => $schDetails['schtime'],
								        'btcbooking_date' 	  => $row->bokbooking_date,
				 						'btcfkres_id'    	  => $row->bokfk_restaurant,
										'boktablesize'		  => $schDetails['tablesize'],
							  			'boknooftables'		  => $schDetails['nooftables'],
										'btcfk_restaurant_schedule'	=> $schIdRow->rstfk_restaurant_schedule
									);
									$btcmapper->getDbTable()->insert($dataset);
								}
							}
						}
						/* Save Contact Details */						  
					   
					   /* Create contact data */
						$guestid = "";  
						$restservice = new Application_Service_Firm();
						
						if($bookStatus->getCode() == 'WAL' && $row->bokphone != ""){
							$contact = array('restaurantid'  => $row->bokfk_restaurant,
						   					'waitfirstName' => $row->bokfirst_name,
						   					'waitlastName'	=> $row->boklast_name,
						   					'waitnumber'    => $row->bokphone,
						   					'countryCode'   => $row->bokcountry_code,
						   					'waitcontactInfo' => $row->bokspecial_request,
						   					);
						   					
							$guestid = $restservice->AddWaitingCustomerContact($contact);
						}else{
							if($row->bokfirst_name != '' && $row->boklast_name != ''){
								if($row->bokemail != '' || $row->bokphone != ''){
									$user = new FirmManagement_Model_FirmGroupUsers();
									$user->setRestaurantId($row->bokfk_restaurant)
										->setGroupId(3)
										->setFirstName($row->bokfirst_name)
										->setLastName($row->boklast_name)
										->setEmail($row->bokemail)
										->setPhone($row->bokphone)
										->setcountry_code($row->bokcountry_code)
										->setSplRequest('')
										->setStatus(TRUE);
									
									$mapper = new FirmManagement_Model_FirmGroupUsersDataMapper();
									$guestid = $mapper->addUserContact($user);
								}
							}
						}
					    
	   					if($guestid){
							$data['bok_contactid'] = $guestid;
						}
						$result = $this->getDbTable()->insert($data);
						$bookidArr[] = array("boklokid" => $row->boklokid, "bookid" => $result, "bokbooking_phrase" => $bookPhrase,"bok_contactid"=>$guestid);
						$resultArray['web_bookid'] = $bookidArr;
						$resultArray["status"] = true;
						
						$row->bokId = $result;
						$row->bookstatuscode = $bookStatus->getCode();
						
						/* Retrieve schedule id by inventory id */
						$schIdRow = "";
						if(($row->bokfk_rest_sch_table) && ($bookStatus->getCode() == "RSD" ||  $bookStatus->getCode() == "BKD" ||  $bookStatus->getCode() == "BOK" ||  $bookStatus->getCode() == "CRD" ||  $bookStatus->getCode() == "DES" ||  $bookStatus->getCode() == "PTS" ||  $bookStatus->getCode() == "WRD" || $bookStatus->getCode() == "COM")){
							$restSchTblMapperObj = new FirmManagement_Model_FirmScheduleTableDataMapper();
							$restSchTbl = $restSchTblMapperObj->getDbTable();
							$restSchTblSelect = $restSchTbl->select();
			
							$restSchTblSelect->from($restSchTbl,array('rstfk_restaurant_schedule','rsttable_pax','rstno_of_tables'))
											 ->where('rstid = ?',$row->bokfk_rest_sch_table);
											 
						    $schIdRow = $restSchTbl->fetchRow($restSchTblSelect);				
						
							$table = $this->getDbTable();
							$select = $table->select();
							$select->setIntegrityCheck(false);
							$select->from(array('btc'=>'mt.booking_time_count'),array('count(btcid) as countbtc','btcid','btcbooking_count','btc.boktablesize'))
							->where('btc.btcfkres_id = ?',$row->bokfk_restaurant)
							->where('btc.btcbooking_timings = ?',$row->bokbooking_timings)
							->where('btc.btcbooking_date = ?',$row->bokbooking_date);
							if($schIdRow){
								$select->where('btc.btcfk_restaurant_schedule = ?',$schIdRow->rstfk_restaurant_schedule);
							}				   
						    $select->group(array('btcid','btcbooking_count','btc.boktablesize'));
				
							$bookingCountId = 0;
							$bookingId= 0;
							$bookingCount = 0;
							
							$rowS = $table->fetchRow($select);
				
							$bookingCountId = $rowS['countbtc'];
							$bookingId = $rowS['btcid'];
							$bookingCount = (int)$rowS['btcbooking_count'];
							
				
							$mapper = new Reservation_Model_ReservationCountDataMapper();
							if($bookingCountId != 0){
								
								if($bookingCount < $schIdRow->rstno_of_tables)
								{
									$bookingCount++;
									$set = array('btcbooking_count' => $bookingCount);
									$where = array('btcid = ?' => $bookingId,
												   'btcfk_restaurant_schedule = ?' => $schIdRow->rstfk_restaurant_schedule);
									
									$mapper->getDbTable()->update($set,$where);
								}else if($bookingCount == $schIdRow->rstno_of_tables){
									
									$set = array('bokbooked_status' => 13);
									$where = array('bokid = ?' => $result);
									$roweff = $this->getDbTable()->update($set,$where);
								}	
							}else{
								$data = array(
										'btcbooking_count'    => 1,
										'btcbooking_timings'  => $row->bokbooking_timings,
								        'btcbooking_date' 	  => $row->bokbooking_date,
				 						'btcfkres_id'    	  => $row->bokfk_restaurant,
										'boktablesize'		  => $schIdRow->rsttable_pax,
							  			'boknooftables'		  => $schIdRow->rstno_of_tables,
										'btcfk_restaurant_schedule'	=> $schIdRow->rstfk_restaurant_schedule
								);
								$mapper->getDbTable()->insert($data);
							}
						}
						if($bookStatus->getCode() == "WAL" && $row->boknewquotedtimeinfo){
							
	//						$quote = new Reservation_Model_ReservationWaitingQuoteMap();
	//						$quote->setBookId($result);
	//						$quote->setQuoteId($row->bokquoted_time);

							$boknewquotedtimeinfo = $row->boknewquotedtimeinfo;
							foreach($boknewquotedtimeinfo as $boknewquotedtimerow)
							{
								$splitdatetime = split (" ", $boknewquotedtimerow->updateddatetime);
								$updateddatetime = $splitdatetime[0].' '.$splitdatetime[1];
								$quoteMapper = new Reservation_Model_ReservationWaitingQuoteMapDataMapper();
								$quoteMapper->InsertQuotedTimesFromNativeApp($result,$boknewquotedtimerow->quotedtimeid,$updateddatetime);
							}
						}
						
						if($row->booktable)
						{
							$count = 0;
							$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
						    $bookTable  = $bookTableMapper->getDbTable();
							$bookTableSelect = $bookTable->select();
							
							$bookTableSelect->from($bookTable,array('COUNT(bktbid) as count'))
							                ->where('bktbfk_booking = ?',$result)
							                ->where('status = ?',true);
				            
							$countRes = $bookTable->fetchAll($bookTableSelect);
							foreach($countRes as $countrow)
							{
								$count = $countrow->count;
							}
							if($count == 0 && $row->booktable)
							{
								$booktableDetails = $row->booktable;							
								$joinTableNo = "";
								if(count($booktableDetails) > 1)
								{
								    	$joinTableNo = $this->CheckJoinTableNo($result,$row->bokfk_restaurant);
								    	if($joinTableNo){
								    		$joinTableNo++;
								    	}else if($joinTableNo == 0 || $joinTableNo == null){
								    		$joinTableNo++;
								    	}
								}	
	//							$bookTableMapper = new Reservation_Model_ReservationTableMapper(); 
	//			   				$bookTable  = $bookTableMapper->getDbTable();
								
								foreach($booktableDetails as $boktablerow)
								{
									if(count($booktableDetails) > 1)
									{
							    		$data = array('bktbfk_booking'        => $result,
							    					  'bktbtableid' 		  => $boktablerow->bktbtableid,
							    					  'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,
							    					  'bktb_join_table_no'    => $joinTableNo,
							    					  'status'                => true);
							    		
							    		if($boktablerow->bkt_dining_id != null & $boktablerow->bkt_dining_id != ""){
							    			$data['bkt_dining_id']	= $boktablerow->bkt_dining_id;
							    		}
							    		$id = $bookTable->insert($data);	 
									}else{
										$data = array('bktbfk_booking'        => $result,
					    					  	'bktbtableid' 		  => $boktablerow->bktbtableid,
					    					  	'bktbtable_no_assigned' => $boktablerow->bktbtable_no_assigned,		    					  
				    					  		'status'                => true
				    					  		);
										if($boktablerow->bkt_dining_id != null & $boktablerow->bkt_dining_id != ""){
							    			$data['bkt_dining_id']	= $boktablerow->bkt_dining_id;
							    		}
				    					$id = $bookTable->insert($data);
									}
								}
							}
						}
						
						$countMapper = new Reservation_Model_ReservationsCountDataMapper();
						$countResult = $countMapper->saveReservationsCount($row->bokfk_restaurant,$row->bokparty_size);
					
						
				}
				$bookDetailsArr[] = $row; 
			$db->commit();
				}
				catch (Exception $ex){
			$db->rollBack();
			Uss_Logger_FileLogger::info($ex->getMessage());
		}
			}
			return array('result'=>$resultArray,'bookDetails'=>$bookDetailsArr);
		}catch (Exception $ex){
			Uss_Logger_FileLogger::info($ex->getMessage());
		}
	}
	
	public function ReservationReportIos(Reservation_Model_GetReservationReport $reservationreport,$bookStatusRes)
	{
		try{
			$statusId = array();
			$status = $bookStatusRes;
			foreach($status as $key=>$value){
				$statusId[$value->getId()] = $value->getId();
			}
			
			$table = $this->getDbTable();
			$select = $table->select();
			$select->setIntegrityCheck(false);
			$rest_id = $reservationreport->getRestaurantId();

			$bookTableMapper = new Reservation_Model_ReservationTableMapper();
			$bookTable       = $bookTableMapper->getDbTable();
			$bookTableSelect = $bookTable->select(); 
			$bookTableSelect->from($bookTable,array('bktbfk_booking','bktbtableid','bktbtable_no_assigned','bktb_join_table_no'))
							->where('status = ?',true);
			
			$select->from(array('bok'=>'mt.booking'),array('bokid','bokuserid','bokbooking_date','bokparty_size','bokbooking_timings','bokfirst_name','boklast_name','boknotification_type','bokemail','bokphone','bokbooking_made_on','bokbooking_made_time','bokspecial_request','bokbooking_status_id','bokrestaurant_note','bokcreatedby','bokcountrycode','bokupdatedby_userid','bokupdated_date','bokreadstatus'))
				   ->where('bok.bokfk_restaurant = ?',$rest_id)
				   ->joinLeft(array('restowner'=>'mt.restaurant_owner'),'restowner.rsofk_user = bok.bokuserid',array('rsofirst_name','rsolast_name','rsophone'))
				   ->joinLeft(array('resuser'=>'mt.restaurant_user'), 'bok.bokuserid = resuser.rsufk_user', array('rsufirst_name','rsulast_name'))
				   ->joinLeft(array('cus'=>'mt.customer'), 'bok.bokuserid = cus.cusfk_user', array('cusfirst_name','cuslast_name'))
				   ->joinLeft(array('restowner1'=>'mt.restaurant_owner'),'restowner1.rsofk_user = bok.bokupdatedby_userid',array('rsofirst_name as updatersofname','rsolast_name as updatersolname','rsophone as updatersophone'))
				   ->joinLeft(array('resuser1'=>'mt.restaurant_user'), 'bok.bokupdatedby_userid = resuser1.rsufk_user', array('rsufirst_name as updateuserfname','rsulast_name as updateuserlname'))
				   ->joinLeft(array('cus1'=>'mt.customer'), 'bok.bokupdatedby_userid = cus1.cusfk_user', array('cusfirst_name as updatecusfname','cuslast_name as updatecuslname'))
				   ->joinLeft(array('bktb'=>$bookTableSelect),'bktb.bktbfk_booking = bok.bokid',array('bktbtable_no_assigned'))
				   ->join(array('bkstatus'=>'mt.booking_status_bd'),'bkstatus.id = bok.bokbooking_status_id',array('code as bokstatuscode','description as bokstatusdesc'))
				   ->join(array('mode'=>'mt.reservation_mode_bd'),'mode.id = bok.bokreservation_mode_id',array('code as resvmode','description as resvDesc'))
				   ->joinLeft(array('par'=>'mt.company'),'par.com_companyname = mode.description',array('com_id','com_logo'));
			$statRec = false;
			
			if($reservationreport->getReservationId()){
				$select->where('bok.bokid =?',$reservationreport->getReservationId());
				$statRec = true;
			}
			if($reservationreport->getBookStatus()){
				$statRec = true;
				if($reservationreport->getBookStatus() == 'RSD')
				{
					$arr = array('OVB','RSD');
					$select->where('bkstatus.code IN(?)',$arr);
				}else{
					$select->where('bkstatus.code IN(?)',$reservationreport->getBookStatus());
				}
			}
			if($reservationreport->getOrigin()){
				$select->where('mode.code = ?',$reservationreport->getOrigin());
			}

			if($reservationreport->getBookStartDate() && $reservationreport->getBookEndDate()){
				$select->where('bok.bokbooking_date >= ?',$reservationreport->getBookStartDate());
				$select->where('bok.bokbooking_date <= ?',$reservationreport->getBookEndDate());
			}else if($reservationreport->getBookStartDate()){
				$select->where('bok.bokbooking_date = ?',$reservationreport->getBookStartDate());
			}
						
			if($reservationreport->getBookStartTime() && $reservationreport->getBookEndTime())
			{
				$select->where('bok.bokbooking_timings >= ?',$reservationreport->getBookStartTime());
				$select->where('bok.bokbooking_timings <= ?',$reservationreport->getBookEndTime());
			}else if($reservationreport->getBookStartTime()){
				$select->where('bok.bokbooking_timings = ?',$reservationreport->getBookStartTime());
			}			
			$sorton = 'bok.bokid DESC';
			if($reservationreport->getReportSortOn() && $reservationreport->getReportSortOrder()){
				$sorton = $reservationreport->getReportSortOn().' '.$reservationreport->getReportSortOrder();
			}
			$select->order($sorton);
			$rowSet = $table->fetchAll($select);
		
			$result = array();
			foreach($rowSet as $row){
				$bookTime = date("h:i A",strtotime($row->bokbooking_timings));
				$result[] = array('bookid'			   => $row->bokid,
								  'bokbooking_timings' => $bookTime,
								  'bokbooking_date'	   => $row->bokbooking_date,
								  'bokfirst_name'	   => $row->bokfirst_name." ".$row->boklast_name,
								  'boklast_name'	   => $row->boklast_name,
								  'bokparty_size'	   => $row->bokparty_size,
								  'bokstatuscode'	   => $row->bokstatuscode,
								  'bokstatusdesc'	   => $row->bokstatusdesc,
								  'bokemail'		   => $row->bokemail,
								  'bokphone'		   => $row->bokphone,
								  'bokspecial_request' => $row->bokspecial_request,
								  'bokreadstatus'	   => $row->bokreadstatus,
								  'bokresvmode'	   	   => $row->resvmode,
								  'bktbtable_no_assigned' => $row->bktbtable_no_assigned  	
								  );	
			}
			return $result;
		}catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}

	/**
	 * CHECK IF RESERVATION ALREADY EXISTS
	 */
	public function checkIfReserationExits($bookDetails)
	{
		try
		{
			$dataArray = array();
		 	foreach ($bookDetails as $key => $row) {
		 		$data = array();
						$data [] = $row->bokfk_restaurant;
						$data []= $row->bokemail;
						$data []=	 $row->bokfirst_name;
						$data []=  $row->boklast_name;
						$data 	[]=	 $row->bokparty_size;
						$data []=	 $row->bokphone;
						$data []=	 $row->bokbooking_date;
						$data []=	$row->bokbooking_timings;
						$data []=	$row->bokbooking_status_id;
						$data []=	$row->bokbooking_made_on;
						//$data []=	 $row->bokbooking_made_time;
				$str = "('".implode("','",$data)."')";
			$dataArray[] = $str;
		 	}
		 	$dataArrayStr = '('.implode(',',$dataArray).')';
			$db = $this->getDbTable();
			$select = $db->select();
			$select = $select->where('(bokfk_restaurant,bokemail,bokfirst_name,boklast_name,bokparty_size,bokphone,bokbooking_date,bokbooking_timings,bokbooking_status_id,bokbooking_made_on) IN '.$dataArrayStr);  
			$result = $select->query()->fetchAll();
			return $result;
		}
		catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
	}
        
        public function getReservationNotifiByRestId($restid, $lastbokid){
            
            	try
		{                
                    $data = array();
                   // $rmode = array(1, 6, 7, 8, 10, 15, 16, 14, 13, 9, 11, 12, 18, 20, 21, 22, 23);
                    $table = $this->getDbTable();                                        
                    if($lastbokid){
                    $select = $table->select()
                                    ->from(array('bok' =>'mt.booking'), array('bokid','bokfirst_name','boklast_name','bokparty_size','bokbooking_date'))                                    
                                    ->where('bok.bokfk_restaurant = ?', $restid)
                                    ->where('bok.bokid  > ?', $lastbokid);  
                    
                                    
                                                            
                    $result = $table->fetchAll($select);
                     foreach ($result as $row){
                         $data[] = array(
                             'bookid'=> $row->bokid,                             
                             'bokfirst_name'=>$row->bokfirst_name,
                             'boklast_name'=>$row->boklast_name,
                             'bokparty_size' =>$row->bokparty_size,
                             'bokbooking_date' =>$row->bokbooking_date                                 
                         );
                     } 
                        
                    }else {
                      $select = $table->select()
                                    ->from(array('bok' =>'mt.booking'), array('bokid'))                                    
                                    ->where('bok.bokfk_restaurant = ?', $restid)
                                    ->order('bokid desc')                                    
                                    ->limit(1);
                                                            
                      $result = $table->fetchAll($select);
                     foreach ($result as $row){
                         $data[] = array(
                             'bookid'=> $row->bokid                            
                         );
                     }   
                    }                         
                    return $data;	
		}
		catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
            
        }

 /**
  * GET RESERVATION STATISTICS
  */
 public function getReservationStatistics($resid,$conditions = null,$range)
 {
 	try
 	{
 		$response = array();
 		$table = $this->getDbTable();
 		$servedCountsQuery = $table->select()
 							->from(array('mt.booking'),array('pax_count'=>'sum(bokparty_size)'))
 							->where('bokfk_restaurant = ?',$resid)
 							->where('bokbooking_status_id NOT IN (?)',array(4,14));
 		$lostCountsQuery = $table->select()
 							->from(array('mt.booking'),array('lost_count'=>'count(bokid)'))
 							->where('bokfk_restaurant = ?',$resid)
 							->where('bokbooking_status_id IN (?)',array(4,14));
 		$servedCounts = $servedCountsQuery->query()->fetchAll();
 		$lostCounts = $lostCountsQuery->query()->fetchAll();
 		$basicCounts['served_pax'] = $servedCounts[0]['pax_count'];
 		$basicCounts['lost_reservations'] = $lostCounts[0]['lost_count'];
 		$orginPie = $table->select()
 						->from(array('mt.booking'),array('bokreservation_mode_id','bokid','bokbooking_date','bokbooking_timings'))
 						->joinLeft(array('mt.reservation_mode_bd'),'id = bokreservation_mode_id',array('label'=>'description'))
 						->where('bokfk_restaurant = ?',$resid)
 						->group(array('bokreservation_mode_id','description','bokid','bokbooking_timings','bokbooking_date'))
 						->order('bokbooking_date ASC')
 						->order('bokbooking_timings ASC')
 						->setIntegrityCheck(false);
 		$raworginData = $orginPie->query()->fetchAll();
 		$orginPieData = array();
 		$orginFlotData = array();
 		$orginData = array();
 		if(count($raworginData)>0)
 		{
 			$basicCounts['walk_in_count'] = 0;
 			$basicCounts['reservation_count'] = 0;
 			foreach ($raworginData as $key => $row) {
 				$pieIndex = $row['bokreservation_mode_id'];
 				switch($row['bokreservation_mode_id'])
 				{
 					case 2:
 					$basicCounts['walk_in_count']++;
 					break;
 					case 4:
 					$basicCounts['reservation_count']++;
 					break;
 				}
 				if(!array_key_exists($pieIndex, $orginPieData))
 				{
 					$orginPieData[$pieIndex] = array();
 					$orginPieData[$pieIndex]['data'] = 0;
 				}
 				$orginPieData[$pieIndex]['data']++;
 				$orginPieData[$pieIndex]['label'] = $row['label']; 
 				$orginPieData[$pieIndex]['color'] = '#' . str_pad(dechex(mt_rand(0, 0xFFFFFF)), 6, '0', STR_PAD_LEFT);
 			}
 		}
 		$respOrgin = array();
 		if(count($orginPieData)>0)
 		{
 			foreach ($orginPieData as $key => $opd) {
 				$respOrgin[] = $opd;
 			}
 		}
 		$response['basic_counts'] = $basicCounts;
 		$response['orgin_analysis'] = $respOrgin;
 		$response['orgin_raw_data'] = $raworginData;
 		return $response;
 	}
 	catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
 }

 /**
  * GET LIVE RESERVATIONS DATA
  */
 public function getLiveReservationCount()
 {
 	try
 	{
 		$db = $this->getDbTable();
 		$rawDb =Zend_Db_Table_Abstract::getDefaultAdapter();
 		$yearWiseString = 'select 
       extract(year from bokbooking_made_on) as yyyy,
       count(bokid) as "bookings"
		from mt.booking
		where bokfk_restaurant not in (1,4) and bokbooking_status_id not in (4,9)
		group by 1 order by 1';
		
		$monthWiseString = 'select to_char(bokbooking_made_on,'."'MM'".') as mon,   count(bokid) as "bookings"
		from mt.booking
		where bokfk_restaurant not in (1,4) and bokbooking_status_id not in (4,9) and bokbooking_made_on > '."'2015-12-31'".'
		group by 1 order by 1 asc';



		$yearData = $rawDb->query($yearWiseString)->fetchAll();
		$mothData = $rawDb->query($monthWiseString)->fetchAll();


 		$select = $db->select()
 					   ->from(array('mt.booking'),array('count(bokid)','sum(bokparty_size)'))
 					   ->setIntegrityCheck(false);

 		$allRestaurantsData = $select->query()->fetchAll();
 		$select = $select->where('bokfk_restaurant not in (?)',array(1,4));
 		$select = $select->where('bokbooking_status_id not in (?)',array(4,9));
 		$activeRestaurantData = $select->query()->fetchAll();
 		$response = array();
 		$response['active_data'] = $activeRestaurantData;
 		$response['all_data'] = $allRestaurantsData;
 		$response['month_data'] = $mothData;
 		$response['year_data'] = $yearData;
 		return $response;


 	}
 	catch (Exception $ex){
			throw new Exception($ex->getMessage()) ;
		}
 }
        
}